(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1567101,      32219]*)
(*NotebookOutlinePosition[   1568043,      32251]*)
(*  CellTagsIndexPosition[   1567951,      32245]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Load Wavica and Rayica", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Wavica`Wavica`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["+++++++++++++++++++++++++++++++++++++++", "Print",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \("Rayica 2.0 was loaded in 19 s and needs 7123 kilobytes of memory on \
top of 4776 kilobytes already used"\)], "Print",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \("Wavica 1.0 was loaded."\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Arbitrary Precision Calculations", "SubsectionIcon"],

Cell[TextData[{
  "Both ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Wavica",
    FontSlant->"Italic"],
  " permit the use of abitrary precision calculations. This is controlled \
with the ",
  StyleBox["RayTracePrecision", "Input"],
  " option:"
}], "Text"],

Cell[CellGroupData[{

Cell["?RayTracePrecision", "Input",
  CellLabel->"In[2]:=",
  FormatType->InputForm],

Cell[BoxData[
    \("RayTracePrecision -> precision gives the number of decimal digits of \
precision used for ray-tracing."\)], "Print",
  CellTags->"Info3334565137-3359157"]
}, Open  ]],

Cell["\<\
To illustrate this, we will work with the following optical system:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
sys = \
{WedgeOfRays[20],Move[PlanoConvexLens[100,50,10,CurvatureDirection->Back],90],\
Move[Screen[{50,50}],150]}\
\>", "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox[
            TagBox[\(WedgeOfRays[20]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            
            TagBox[\(Move[
                PlanoConvexLens[100, 50, 
                  10, {CurvatureDirection \[Rule] Back}], 90.`]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            TagBox[\(Move[Screen[{50, 50}], 150.`]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm]}], "}"}]], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[sys];", "Input",
  CellLabel->"In[15]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67912 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0224888 1.02249 -0.150431 1.02249 [
[ 0 0 0 0 ]
[ 1 .67912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .67912 L
0 .67912 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.62394 .34325 m
.613 .30737 L
s
.613 .30737 m
.63144 .30143 L
s
.613 .30737 m
.59908 .27326 L
s
.63124 .37875 m
.62394 .34325 L
s
.62394 .34325 m
.64242 .3374 L
s
.59908 .27326 m
.61754 .26723 L
s
.59908 .27326 m
.58301 .24299 L
s
.63144 .30143 m
.64242 .3374 L
s
.61754 .26723 m
.63144 .30143 L
s
.64242 .3374 m
.6498 .37297 L
s
.63124 .37875 m
.6498 .37297 L
s
.60152 .23685 m
.61754 .26723 L
s
.58301 .24299 m
.60152 .23685 L
s
.656 .751 .92 r
.61275 .38687 m .65312 .40599 L .63444 .41172 L F
0 g
.63326 .4401 m
.63444 .41172 L
s
.63124 .37875 m
.63296 .39644 L
s
.656 .751 .92 r
.61275 .38687 m .65099 .37496 L .65312 .40599 L F
0 g
.65209 .43439 m
.65312 .40599 L
s
.6498 .37297 m
.65003 .37526 L
s
.63444 .41172 m
.65312 .40599 L
s
.544 .324 .532 r
.56574 .21847 m .60459 .24413 L .56644 .25675 L F
.56574 .21847 m .58434 .21221 L .60459 .24413 L F
0 g
.58434 .21221 m
.60152 .23685 L
s
.56574 .21847 m
.58434 .21221 L
s
.54831 .20135 m
.56574 .21847 L
s
.56705 .19499 m
.58434 .21221 L
s
.62767 .46196 m
.63326 .4401 L
s
.63326 .4401 m
.65209 .43439 L
s
.65209 .43439 m
.64667 .45625 L
s
.656 .751 .92 r
.59057 .36146 m .65099 .37496 L .61275 .38687 L F
0 g
.61275 .38687 m
.63444 .41172 L
s
.039 .916 .04 r
.11741 .4797 m
.61065 .38446 L
s
.61065 .38446 m
.65102 .37509 L
s
.544 .324 .532 r
.56644 .25675 m .61677 .2796 L .56716 .29575 L F
.56644 .25675 m .60459 .24413 L .61677 .2796 L F
0 g
.56574 .21847 m
.56644 .25675 L
s
.58434 .21221 m
.60459 .24413 L
s
.54831 .20135 m
.56705 .19499 L
s
.54831 .20135 m
.53185 .19296 L
s
.94767 .19408 m
.97441 .43595 L
s
.82983 .01827 m
.94767 .19408 L
s
.039 .916 .04 r
.65102 .37509 m
.94188 .28468 L
s
0 0 0 r
2.5 Mabswid
.65102 .37509 Mdot
.656 .751 .92 r
.59057 .36146 m .64025 .34578 L .65099 .37496 L F
0 g
.5 Mabswid
.65099 .37496 m
.65312 .40599 L
s
.55075 .18651 m
.56705 .19499 L
s
.6179 .47571 m
.62767 .46196 L
s
.62767 .46196 m
.64667 .45625 L
s
.64667 .45625 m
.63709 .46997 L
s
.656 .751 .92 r
.5679 .33548 m .64025 .34578 L .59057 .36146 L F
0 g
.59057 .36146 m
.61275 .38687 L
s
.544 .324 .532 r
.56716 .29575 m .62162 .31828 L .5679 .33548 L F
.56716 .29575 m .61677 .2796 L .62162 .31828 L F
0 g
.56644 .25675 m
.56716 .29575 L
s
.60459 .24413 m
.61677 .2796 L
s
.53185 .19296 m
.55075 .18651 L
s
.53185 .19296 m
.51749 .19413 L
s
.53657 .18761 m
.55075 .18651 L
s
.656 .751 .92 r
.5679 .33548 m .62162 .31828 L .64025 .34578 L F
0 g
.64025 .34578 m
.65099 .37496 L
s
.60448 .48014 m
.6179 .47571 L
s
.6179 .47571 m
.63709 .46997 L
s
.63709 .46997 m
.62386 .47434 L
s
.544 .324 .532 r
.5679 .33548 m .61921 .36004 L .56864 .37595 L F
.5679 .33548 m .62162 .31828 L .61921 .36004 L F
.656 .751 .92 r
.54471 .30891 m .62162 .31828 L .5679 .33548 L F
0 0 0 r
2.5 Mabswid
.5679 .33548 Mdot
.039 .916 .04 r
.5 Mabswid
.11741 .4797 m
.5679 .33548 L
s
0 g
.56716 .29575 m
.56746 .31168 L
s
.51749 .19413 m
.50629 .20511 L
s
.53657 .18761 m
.51749 .19413 L
s
.52555 .19854 m
.53657 .18761 L
s
.656 .751 .92 r
.54471 .30891 m .5952 .29251 L .62162 .31828 L F
0 0 0 r
2.5 Mabswid
.62162 .31828 Mdot
.039 .916 .04 r
.5 Mabswid
.62162 .31828 m
.90255 .22834 L
s
.5679 .33548 m
.62162 .31828 L
s
0 g
.61677 .2796 m
.62162 .31828 L
s
.62162 .31828 m
.64025 .34578 L
s
.58821 .47462 m
.60448 .48014 L
s
.60448 .48014 m
.62386 .47434 L
s
.544 .324 .532 r
.56864 .37595 m .60903 .40496 L .5694 .4172 L F
.56864 .37595 m .61921 .36004 L .60903 .40496 L F
0 g
.5679 .33548 m
.56864 .37595 L
s
.61921 .36004 m
.62162 .31828 L
s
.62386 .47434 m
.60776 .46875 L
s
.96066 .31159 m
.94173 .28448 L
s
.96066 .31159 m
.96066 .31159 L
s
.656 .751 .92 r
.52099 .28173 m .5952 .29251 L .54471 .30891 L F
0 g
.54471 .30891 m
.5679 .33548 L
s
.50629 .20511 m
.52555 .19854 L
s
.50629 .20511 m
.49915 .22544 L
s
.89076 .10918 m
.89076 .10918 L
s
.89076 .10918 m
.89462 .14814 L
s
.51859 .21886 m
.52555 .19854 L
s
.656 .751 .92 r
.52099 .28173 m .5605 .26871 L .5952 .29251 L F
.039 .916 .04 r
.11741 .4797 m
.52328 .28436 L
s
0 g
.5952 .29251 m
.62162 .31828 L
s
.58821 .47462 m
.60776 .46875 L
s
.544 .324 .532 r
.5694 .4172 m .58987 .45327 L .57018 .45924 L F
0 g
.57018 .45924 m
.58821 .47462 L
s
.544 .324 .532 r
.5694 .4172 m .60903 .40496 L .58987 .45327 L F
0 g
.56864 .37595 m
.5694 .4172 L
s
.5694 .4172 m
.57018 .45924 L
s
.60903 .40496 m
.61921 .36004 L
s
.58987 .45327 m
.60776 .46875 L
s
0 0 0 r
2.5 Mabswid
.94188 .28468 Mdot
0 g
.5 Mabswid
.94173 .28448 m
.92237 .25673 L
s
0 0 0 r
2.5 Mabswid
.52328 .28436 Mdot
.656 .751 .92 r
.49672 .25392 m .5605 .26871 L .52099 .28173 L F
0 g
.5 Mabswid
.52099 .28173 m
.54471 .30891 L
s
.58987 .45327 m
.60903 .40496 L
s
.89854 .18785 m
.89462 .14814 L
s
.51859 .21886 m
.49915 .22544 L
s
.656 .751 .92 r
.49672 .25392 m .51633 .24736 L .5605 .26871 L F
0 g
.51633 .24736 m
.5605 .26871 L
s
.49672 .25392 m
.49915 .22544 L
s
.5605 .26871 m
.5952 .29251 L
s
.039 .916 .04 r
.52328 .28436 m
.56033 .26861 L
s
0 g
.49672 .25392 m
.52099 .28173 L
s
.039 .916 .04 r
.56033 .26861 m
.86132 .16928 L
s
0 0 0 r
2.5 Mabswid
.56033 .26861 Mdot
0 g
.5 Mabswid
.51633 .24736 m
.51859 .21886 L
s
.55165 .43482 m
.57018 .45924 L
s
.57018 .45924 m
.58987 .45327 L
s
.57146 .42874 m
.58987 .45327 L
s
.92237 .25673 m
.90255 .22834 L
s
.49672 .25392 m
.51633 .24736 L
s
.49672 .25392 m
.4993 .28862 L
s
.89854 .18785 m
.90255 .22834 L
s
.53403 .40302 m
.55165 .43482 L
s
.55165 .43482 m
.57146 .42874 L
s
.51633 .24736 m
.51904 .28211 L
s
.97441 .43595 m
.85121 .26732 L
s
.57146 .42874 m
.5539 .39682 L
s
.4993 .28862 m
.51904 .28211 L
s
.4993 .28862 m
.5068 .327 L
s
.51868 .36614 m
.53403 .40302 L
s
.53403 .40302 m
.5539 .39682 L
s
.52663 .32058 m
.51904 .28211 L
s
.5068 .327 m
.51868 .36614 L
s
.52663 .32058 m
.5068 .327 L
s
.51868 .36614 m
.53855 .35982 L
s
.5539 .39682 m
.53855 .35982 L
s
0 0 0 r
2.5 Mabswid
.90255 .22834 Mdot
0 g
.5 Mabswid
.90663 .26962 m
.90255 .22834 L
s
.90255 .22834 m
.88226 .19927 L
s
.53855 .35982 m
.52663 .32058 L
s
.85121 .26732 m
.82983 .01827 L
s
.90663 .26962 m
.91079 .31173 L
s
.88226 .19927 m
.86148 .1695 L
s
.91504 .35469 m
.91079 .31173 L
s
.86148 .1695 m
.8402 .13901 L
s
0 0 0 r
2.5 Mabswid
.86132 .16928 Mdot
0 g
.5 Mabswid
.91504 .35469 m
.91504 .35469 L
s
.8402 .13901 m
.8402 .13901 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{558.25, 379.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008^0001Nb000`400?l00000o`00003ooooooooo
oooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo
003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooo
oooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool0
0?oooooocoooool00ol0003oooooooooo`1Mooooo`00ooooooo?ooooo`03o`000?oooooooooo05go
oooo003ooooooloooooo0_l0001Nooooo`00ooooooo?ooooo`03o`000?oooooo000005gooooo003o
oooooloooooo00?o0000ooooool00000GOooool00?oooooocoooool01?l0003oooooooooool0001L
ooooo`00ooooooo?ooooo`05o`000?ooooooooooooooool00000Foooool00?ooooood?ooool01?l0
003oooooooooool0001Kooooo`00ooooooo@ooooo`05o`000?ooooooooooooooool00000F_ooool0
0?ooooood?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Oooooo003oooooom3o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Gooooo`00ooooooo@ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool00?ooooood?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo05Gooooo003oooooom3ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Eooooo`00ooooooo@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0E?ooool00?ooooood?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05?o
oooo003oooooom3ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Cooooo`00oooo
ooo@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D_ooool00?oooooodOooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo057ooooo003oooooom7ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Aooooo`00oooooooAooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0D?ooool00?oooooodOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo04oooooo003oooooom7ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1?ooooo`00oooooooAooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0C_ooool0
0?oooooodOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04gooooo003oooooom7o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1=ooooo`00oooooooAooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0C?ooool00?oooooodOooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo04_ooooo003oooooom7ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1;ooooo`00oooooooAooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0B_ooool00?ooooood_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Wo
oooo003oooooom;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`19ooooo`00oooo
oooBooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00?ooooood_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Oooooo003oooooom;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`17ooooo`00oooooooBooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0A_ooool00?ooooood_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo04Gooooo003oooooom;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`15ooooo`00oooooooBooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0A?ooool0
0?ooooood_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?ooooo003oooooom;o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`13ooooo`00oooooooCooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0@_ooool00?oooooodoooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo047ooooo003oooooom?ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`11ooooo`00oooooooCooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0@?ooool00?oooooodoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03oo
oooo003oooooom?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0oooooo`00oooo
oooCooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?_ooool00?oooooodoooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03gooooo003oooooom?ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0looooo`00oooooooCooooo`03o`000?oooooooooo01[o
oooo0_l0000mooooo`00oooooooCooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
>oooool00?oooooodoooool00ol0003oooooooooo`0Kooooo`;o0000??ooool00?ooooooe?ooool0
0ol0003oooooooooo`0Jooooo`;o0000??ooool00?ooooooe?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooo000003_ooooo003oooooomCooooo00?o0000ooooooooool06_ooool01?l0003o
ooooooooool0000jooooo`00oooooooDooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool0
0000>_ooool00?ooooooe?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0003Wo
oooo003oooooomCooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000003So
oooo003oooooomCooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000003So
oooo003oooooomCooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Gooooo003oooooomCooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Cooooo003oooooomCooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo003oooooomCooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo003oooooomGo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;o
oooo003oooooomGooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03;ooooo003oooooomGooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo037ooooo003oooooomGooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo003oooooomGooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo003oooooomGo
oooo0_l0000Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool00?oooooo
eOooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
;_ooool00?ooooooeOooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0;_ooool00?ooooooeOooool01?l0003oooooooooool0000Jooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0;Oooool00?ooooooeOooool01Ol0003ooooooooooooo
oooo000001Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0/ooooo`00oooooooE
ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02cooooo003oooooomGooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:oooool00?ooooooe_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Zooooo`00oooooooFooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo003oooooomKooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0:Oooool00?ooooooe_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`00oooooooF
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo02Sooooo003oooooomKooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00?oo
ooooe_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Vooooo`00oooooooFooooo`03o`000?oooooooooo00Kooooo
0ol0000Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09_ooool00?ooooooe_oo
ool00ol0003oooooooooo`05ooooo`;o2NX:0_l0000Booooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool09Oooool00?ooooooe_ooool00ol0003oooooooooo`02ooooo`?o2NX:0_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool0
0?ooooooe_ooool00ol0003oooooo`WZ2P02o`WZ2PKooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo003oooooomGooooo0_l9jPX00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Sooooo`00oooooooBooooo`?o2NX:0_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Rooooo`00oooo
ooo?ooooo`?o2NX:1Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`00ooooooo<ooooo`?o2NX:2?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Qooooo`00ooooooo9ooooo`?o2NX:2oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Poooo
o`00ooooooo6ooooo`?o2NX:3_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`00ooooool_ooooo`Ko0000
S_ooool3o`WZ2Q7ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool07oooool00?oooooo:Oooool9o`0000?ooooo0_l0
0029ooooo`?o2NX:5?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`00oooooolVooooo`?o000000Cooooo
o`000?oooooooooo0_l00008ooooo`;o0000Q?ooool3o`WZ2QOooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_oo
ool00?oooooo8oooool3o`0000?ooooo1?l0000<ooooo`03o`000?oooooooooo07kooooo0ol9jPXJ
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01gooooo003oooooob7ooooo2_l0000?ooooo`;o0000Noooool3o`WZ
2Qgooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool07?ooool00?oooooo8Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00003Oooool3o`0007Oooooo0ol9jPXPooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01cooooo003oooooob3ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`?o
00001oooool3o`0000?ooooo00?o0000ooooooooool0LOooool3o`WZ2RCooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool07?ooool00?oooooo7oooool00ol0003oooooooooo`02ooooo`;o00002_ooool2o`0000;ooooo
0ol00007ooooo`03o`000?oooooooooo06gooooo0ol9jPXWooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo
003ooooooakooooo00?o0000ooooooooool00ol000000ooooooo0000ooooo`0;ooooo`;o00002ooo
ool00ol0003oooooooooo`1Yooooo`?o2NX::_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`00oooooolM
ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo06Gooooo0ol9jPX]ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo003o
oooooacooooo0ol00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Qooooo`?o2NX:<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`00oooooolKoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo05gooooo0ol9jPXcooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo003ooooooa_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0FOooool3o`WZ2SKooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06oooool00?oooooo
6_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Eooooo`?o2NX:>Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`00oooo
oolJooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo057ooooo0ol9jPXlooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo003o
oooooa[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo0ol0001?ooooo`?o2NX:?oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`00oooooolIoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04oooo
o`?o00000_n;DXP00ol0003oooooooooo`1:ooooo`?o2NX:@_ooool00ol0003oooooooooo`0Goooo
o`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`0Kooooo`00oooooolIoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03o`00
00KoRe:800?o0000ooooooooool0A_ooool3o`WZ2TKooooo00?o0000ooooooooool05_ooool01Ol0
003ooooooooooooooooo000001[ooooo00?o0000ooooooooool06oooool00?oooooo6Oooool00ol0
003oooooooooo`04ooooo`;o00006_ooool2o`0000[oRe:800?o0000ooooooooool0@Oooool4o`WZ
2TWooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0000Kooooo`03o`000?oooooo
oooo01[ooooo003ooooooaSooooo00?o0000ooooooooool00_ooool3o`000003ooooool0003ooooo
01Wooooo00?o0000oh]BR?n;DXP02On;DXP2o`0003oooooo0ol9jPY=ooooo`03o`000?oooooooooo
01Oooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo01[ooooo003ooooo
oaSooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo01Sooooo00?o0000oh]B
R?n;DXP02_n;DXP00ol0003oooooooooo`0jooooo`?o2NX:D?ooool00ol0003oooooooooo`0Hoooo
o`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool06_ooool00?oooooo6?ooool3o`00
00Kooooo00?o0000ooooooooool06?ooool00ol0003oRe:8oh]BR00;oh]BR003o`000?oooooooooo
03Kooooo0ol9jPYCooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool000006_ooool00ol0
003oooooooooo`0Jooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool06?ooool00ol0003oRe:8oh]BR00;oh]BR0;o0000=?ooool3o`WZ2UKooooo00?o0000oooooooo
ool06Oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo01[ooooo003ooooooaOooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?n;DXSoRe:800coRe:8
0_l0000`ooooo`?o2NX:FOooool00ol0003oooooooooo`0Jooooo`?o00006Oooool00ol0003ooooo
ooooo`0Jooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?oo
ool00ol0003oRe:8oh]BR00=oh]BR0;o0000;?ooool3o`WZ2Ucooooo00?o0000ooooooooool06Ooo
ool2o`WZ2P;o00006Oooool00ol0003oooooooooo`0Jooooo`00oooooolGooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oRe:8oh]BR00=oh]BR0;o0000:Oooool3
o`WZ2Uoooooo00?o0000ooooooooool05_ooool3o`WZ2P;ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Jooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06?ooool00ol0003oRe:8oh]BR00>oh]BR0;o00009Oooool3o`WZ2V;ooooo00?o0000oooo
ooooool04oooool3o`WZ2PGooooo0_l0000Iooooo`03o`000?oooooooooo01[ooooo003ooooooaKo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?n;DXSoRe:800ko
Re:800?o0000ooooool000008Oooool3o`WZ2VGooooo00?o0000ooooooooool04?ooool3o`WZ2PSo
oooo00?o0000ooooool000006Oooool00ol0003oooooooooo`0Iooooo`00oooooolFooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oRe:8oh]BR00?oh]BR0?o0000
7Oooool3o`WZ2VSooooo00?o0000ooooooooool03Oooool3o`WZ2P_ooooo00Co0000oooooooooooo
00006?ooool00ol0003oooooooooo`0Iooooo`00oooooolFooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06Oooool00ol0003oRe:8oh]BR00@oh]BR0;o00006_ooool3o`WZ2Vcooooo
00?o0000ooooooooool02Oooool3o`WZ2Poooooo00?o0000ooooool000006?ooool00ol0003ooooo
ooooo`0Iooooo`00oooooolFooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oRe:8oh]BR00@oh]BR003o`000?oooooo000001Kooooo0ol9jPY_ooooo`03o`000?oo
oooooooo00Kooooo0ol9jPXBooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool0
6Oooool00?oooooo5_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o
0000oh]BR?n;DXP04On;DXP2o`0001?ooooo0ol9jPYbooooo`03o`000?oooooooooo00?ooooo0ol9
jPXEooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`0Iooooo`00oooo
oolFooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oRe:8oh]B
R00Boh]BR0;o00003oooool3o`WZ2WGooooo00?o0000ooooool9jPX00ol9jPXHooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Iooooo`00oooooolF
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oRe:8oh]BR00B
oh]BR0;o00003?ooool3o`WZ2WOooooo00?o2NX:o`000?l9jPX07?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06Oooool00?oooooo5_ooool00ol0
003oooooooooo`06ooooo`?o00006_ooool00ol0003oRe:8oh]BR00Coh]BR0;o00002?ooool3o`WZ
2WOooooo0ol9jPX00ooooooo0000ooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Iooooo`00oooooolEooooo`03o`000?oooooooooo00Co
oooo0ol000000onW`>_o0000ojO0j`02o`0001Sooooo00?o0000oh]BR?n;DXP04on;DXP2o`0000Go
oooo0ol9jPYgooooo`?o2NX:1?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`00oooooolEooooo`04o`00
0?ooooooooooooooo`?o00001?nW`>/01?l0003oYl3[ojO0jonW`>/2o`0001Kooooo00?o0000oh]B
R?n;DXP04on;DXP01?l0003oooooo`000?ooool3o`WZ2WOooooo0ol9jPX7ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Sooooo003ooooooaGooooo1?l00007ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l0000Doooo
o`03o`000?n;DXSoRe:801CoRe:80ol9jPYgooooo`?o2NX:2_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hoooo
o`00oooooolEooooo`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/01OnW`>/2o`0001;o
oooo00?o0000oh]BR?n;DXP04On;DXP3o`WZ2P03o`000?oooooo000007Cooooo0ol9jPX=ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Sooooo003ooooooaGooooo00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[
ojO0j`07ojO0j`;o00004?ooool00ol0003oRe:8oh]BR00>oh]BR0?o2NX:0on;DXP01?l0003ooooo
ooooool0001`ooooo`?o2NX:4?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`00oooooolEooooo`;o0000
2_nW`>/00ol0003oYl3[ojO0j`08ojO0j`?o00003Oooool00ol0003oRe:8oh]BR00;oh]BR0?o2NX:
1on;DXP00ol0003oooooo`00001]ooooo`?o2NX:5?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`00oooo
oolEooooo`03o`000?oooooo000000WoYl3[00?o0000ojO0jonW`>/02onW`>/2o`0000_ooooo00?o
0000oh]BR?n;DXP02?n;DXP3o`WZ2P[oRe:800Co0000oooooooooooo0000J?ooool4o`WZ2QOooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool06?ooool00?oooooo5Oooool01?l0003oooooooooool00008ojO0j`03o`00
0?nW`>_oYl3[00goYl3[0_l00009ooooo`03o`000?n;DXSoRe:800GoRe:80ol9jPX=oh]BR004o`00
0?ooooooooooo`0006Gooooo0ol9jPXKooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo003ooooooaGooooo
00Go0000ooooooooooooooooo`000007ojO0j`03o`000?nW`>_oYl3[00ooYl3[0_l00007ooooo`03
o`000?n;DXSoRe:800;oRe:80ol9jPXAoh]BR004o`000?ooooooooooo`00067ooooo0ol9jPXNoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Sooooo003ooooooaKooooo00Go0000ooooooooooooooooo`000006ojO0
j`03o`000?nW`>_oYl3[017oYl3[0_l00005ooooo`03o`000?n;DXSo2NX:00;o2NX:5?n;DXP01?l0
003oooooooooool0001Nooooo`?o2NX:8Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`00oooooolFoooo
o`03o`000?oooooooooo00;ooooo00?o0000ojO0jonW`>/00onW`>/00ol0003oYl3[ojO0j`0CojO0
j`;o00000_ooool3o`WZ2QOoRe:800?o0000ooooooooool00_l0001Jooooo`?o2NX:9?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Gooooo`00oooooolFooooo`03o`000?oooooooooo00?ooooo00?o0000ojO0jonW
`>/00_nW`>/00ol0003oYl3[ojO0j`0DojO0j`;o000000?o2NX:ooooool000006On;DXP2o`000003
ooooool0003ooooo05Kooooo0ol9jPXWooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo003ooooooaKooooo
00?o0000ooooooooool01?ooool01Ol0003oYl3[ojO0jonW`>_o000001?oYl3[0ol9jPX2o`000003
ojO0jol0003o000001WoRe:800Go0000ooooooooooooooooo`00001Cooooo`?o2NX::oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Gooooo`00oooooolFooooo`03o`000?oooooooooo00Gooooo00Co0000ojO0jonW
`>_o00004OnW`>/2o`WZ2POoYl3[0_l0000Hoh]BR005o`000?ooooooooooooooool00000D?ooool3
o`WZ2Roooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool05oooool00?oooooo5_ooool00ol0003oooooooooo`06oooo
o`04o`000?nW`>_oYl3[o`0000koYl3[0_l9jPX;ojO0j`03o`000?n;DXSoRe:801KoRe:800Co0000
oooooooooooo0000C?ooool4o`WZ2S?ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00?oooooo5_ooool0
0ol0003oooooooooo`07ooooo`03o`000?nW`>_o000000_oYl3[0ol9jPX>ojO0j`;o00005_n;DXP0
1Ol0003ooooooooooooooooo000004Sooooo0ol9jPXgooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo003o
oooooaKooooo00?o0000ooooooooool02?ooool2o`0000WoYl3[0_l9jPXCojO0j`03o`000?n;DXSo
Re:801?oRe:800Go0000ooooooooooooooooo`000015ooooo`?o2NX:>oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Gooooo`00oooooolFooooo`03o`000?oooooooooo00Wooooo00?o0000ojO0jonW`>/01OnW`>/2
o`WZ2QKoYl3[0_l0000Doh]BR004o`000?ooooooooooo`0004;ooooo0ol9jPXoooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Oooooo003ooooooaOooooo00?o0000ooooooooool01oooool3o`0000?oYl3[0ol9jPXJ
ojO0j`03o`000?n;DXSoRe:8017oRe:800Go0000ooooooooooooooooo`00000nooooo`?o2NX:@_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Gooooo`00oooooolGooooo`03o`000?oooooooooo00Cooooo0ol00000
1?oooooo0000o`000?l00002o`WZ2QkoYl3[00?o0000oh]BR?n;DXP04?n;DXP01Ol0003ooooooooo
oooooooo000003_ooooo0ol9jPY6ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo003ooooooaOooooo00Co
0000oooooooooooooooo0ol00004ooooo`;o000000?o2NX:ojO0jonW`>/07onW`>/2o`00013oRe:8
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`?o2NX:B_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o2NX:o`000?l000002?ooool00ol0003ooooo
ooooo`0Fooooo`00oooooolGooooo`Co00001_ooool01Ol9jP[o0000oooooooooooo000002;oYl3[
00?o0000oh]BR?n;DXP03On;DXP00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo
0ol9jPY>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool3o`WZ2P03oooo
ool0003o000000Sooooo00?o0000ooooooooool05_ooool00?oooooo5oooool00ol0003ooooooooo
o`05ooooo`;o2NX:0_ooool01?l0003oooooooooool0000RojO0j`;o00003_n;DXP01Ol0003ooooo
oooooooooooo0000033ooooo1?l9jPYAooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01oooool3o`WZ2PKooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`00
oooooolGooooo`03o`000?oooooooooo00?ooooo0_l9jPX4ooooo`05o`000?ooooooooooooooool0
00008onW`>/00ol0003oRe:8oh]BR00;oh]BR003o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0:_ooool3o`WZ2UKooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`?o
2NX:2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo003ooooooaOooooo
00Co0000oooooooooooooooo0_l9jPX6ooooo`03o`000?oooooooooo00;ooooo00?o0000ojO0jonW
`>/08OnW`>/00ol0003oRe:8oh]BR00:oh]BR003o`000?oooooooooo00;ooooo00?o0000oooooooo
ool09oooool3o`WZ2U[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04o`WZ2Pko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`00oooooolGooooo`04o`00
0?l9jP[o2NX:o`WZ2PSooooo00?o0000ooooooooool00oooool00ol0003oYl3[ojO0j`0QojO0j`03
o`000?n;DXSoRe:800WoRe:800?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`?o
2NX:GOooool00ol0003oooooooooo`0Cooooo`03o`000?l9jP[o2NX:01;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Fooooo`00oooooolFooooo`;o2NX:00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`04ooooo`03o`000?nW`>_oYl3[027oYl3[00?o0000oh]BR?n;DXP0
2?n;DXP00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo0ol9jPYQooooo`03o`00
0?oooooooooo00oooooo0ol9jPX00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool05_ooool00?oooooo5?ooool2o`WZ2P;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?nW`>_oYl3[02;oYl3[00?o0000oh]BR?n;DXP01on;
DXP00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo0ol9jPYUooooo`03o`000?oo
oooooooo00_ooooo0ol9jPX3ooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooooooooooo
o`00000Hooooo`00oooooolBooooo`;o2NX:1?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ojO0jonW`>/08_nW`>/00ol0003oRe:8oh]BR006oh]BR003o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06_ooool3o`WZ2VWooooo00?o0000ooooooooool01_oo
ool4o`WZ2PKooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000001Oooooo
003ooooooa3ooooo0_l9jPX6ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oYl3[ojO0j`0RojO0j`03o`000?n;DXSoRe:800KoRe:800?o0000ooooooooool00_oo
ool2o`0001Sooooo0ol9jPY/ooooo`03o`000?oooooooooo00?ooooo0ol9jPX:ooooo`03o`000?oo
oooooooo01Gooooo00Go0000ooooooooooooooooo`00000Gooooo`00ooooool>ooooo`;o2NX:2?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ojO0jonW`>/08_nW
`>/00ol0003oRe:8oh]BR005oh]BR003o`000?oooooo000000;o000000?oooooo`000?ooool05?oo
ool3o`WZ2W3ooooo00?o0000ooooool9jPX00_l9jPX>ooooo`03o`000?oooooooooo01Gooooo00Co
0000oooooooooooo00005oooool00?oooooo3?ooool2o`WZ2P_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?nW`>_oYl3[02;oYl3[00?o0000oh]BR?n;DXP01?n;
DXP2o`0000Cooooo00?o0000ooooooooool03oooool4o`WZ2W;ooooo0_l9jPX00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000005oooool00?oooooo2_ooool2
o`WZ2Pgooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?nW`>_o
Yl3[02;oYl3[00?o0000oh]BR?n;DXP00on;DXP00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00_ooooo0ol9jPYbooooo`Co2NX:0oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooool000005oooool00?oooooo2?ooool2o`WZ2Poooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?nW`>_oYl3[02;oYl3[00?o0000oh]B
R?n;DXP00_n;DXP00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0ol9jPYboooo
o`?o2NX:1oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo0_l0000Goooo
o`00ooooool6ooooo`;o2NX:4Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ojO0jonW`>/08onW`>/01Ol0003oRe:8oh]BR?n;DXSo000000Kooooo00?o0000oooo
ooooool01Oooool3o`WZ2W;ooooo0ol9jPX;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Eooooo`00ooooool4ooooo`;o2NX:4oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ojO0jonW`>/08onW`>/01?l0003o
Re:8oh]BR?l00007ooooo`04o`000?ooooooooooooooo`?o2NX:L_ooool3o`WZ2Poooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`;o00005_ooool00?oooooo0Oooool3o`WZ
2QKooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?nW`>_oYl3[
02?oYl3[00Co0000oh]BR?n;DXSo00001_ooool01?l0003o2NX:o`WZ2_l9jPYbooooo`?o2NX:4_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05Ooo
ool00?kooooo0_l9jPXIooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool0
0ol0003oYl3[ojO0j`0SojO0j`03o`000?n;DXSo000000Cooooo0ol9jPYaooooo`Co2NX:5_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?ooool0
0?cooooo0_l9jPXKooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0
003oYl3[ojO0j`0SojO0j`;o000000Coooooo`WZ2_l9jP[o2NX:0oooool00ol0003oooooooooo`1[
ooooo`?o2NX:6oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool05?ooool00?[ooooo0_l9jPXMooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03?ooool00ol0003oYl3[ojO0j`0QojO0j`;o2NX:00?o0000o`WZ2_ooool01Oooool00ol0
003oooooooooo`1Xooooo`?o2NX:7oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool05?ooool00?Sooooo0_l9jPXOooooo`03o`000?oooooooooo00Oo
oooo0ol0000?ooooo`03o`000?nW`>_oYl3[01goYl3[0ol9jPX2oh]BR003o`000?oooooooooo00Go
oooo00?o0000ooooooooool0IOooool3o`WZ2R;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo003fooooo`;o2NX:8_ooool00ol0003ooooo
ooooo`02ooooo`Co00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?nW`>_oYl3[01WoYl3[
0ol9jPX5oh]BR0;o00001_ooool00ol0003oooooooooo`1Qooooo`Co2NX:9_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?ooool00?Cooooo0_l9
jPXTooooo`03o`000?oooooo000000;o00001_ooool00ol0003oooooooooo`0>ooooo`03o`000?nW
`>_oYl3[01GoYl3[1?l9jPX8oh]BR003o`000?nW`>_o000000Kooooo00?o0000ooooooooool0GOoo
ool3o`WZ2R_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Cooooo003booooo`;o2NX:9_ooool2o`0000[ooooo00?o0000ooooooooool03_ooool0
0ol0003oYl3[ojO0j`0AojO0j`?o2NX:3?n;DXP00ol0003oYl3[o`000006ooooo`03o`000?oooooo
oooo05[ooooo0ol9jPX_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Dooooo`00l?ooool2o`WZ2RSooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0?ooooo`03o`000?nW`>_oYl3[00goYl3[0ol9jPX?oh]BR004o`000?nW`>_oYl3[
o`0000Gooooo00?o0000ooooooooool0Eoooool3o`WZ2S;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo003^ooooo`;o2NX::_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ojO0jonW`>/02?nW`>/4o`WZ
2Q;oRe:800Go0000ojO0jonW`>_oYl3[o`000005ooooo`03o`000?oooooooooo05;ooooo1?l9jPXf
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0D
ooooo`00k?ooool2o`WZ2Rgooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@oooo
o`03o`000?nW`>_oYl3[00CoYl3[0ol9jPXFoh]BR005o`000?nW`>_oYl3[ojO0jol000001Oooool0
0ol0003oooooooooo`1?ooooo`?o2NX:>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool04oooool00>Wooooo0ol9jPX_ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool00ol0003oYl3[ojO0j`03o`WZ2QWoRe:800?o0000ojO0
jonW`>/00_nW`>/00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04cooooo0ol9jPXnoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Coooo
o`00ioooool2o`WZ2S;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`;o
2NX:00?o0000o`WZ2_n;DXP06on;DXP00ol0003oYl3[ojO0j`03ojO0j`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0B?ooool3o`WZ2T;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo003Uooooo`;o2NX:=Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00cooooo0ol9jPX00ooooooo0000o`00000Moh]BR003o`00
0?nW`>_oYl3[00?oYl3[00?o0000ooooooooool00ol00016ooooo`Co2NX:A_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04oooool00>?ooooo0_l9
jPXgooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool3o`WZ2PGooooo00?o
0000oh]BR?n;DXP06on;DXP00ol0003oYl3[ojO0j`04ojO0j`;o00000_ooool00ol0003ooooooooo
o`11ooooo`?o2NX:Boooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool04oooool00>7ooooo0_l9jPXiooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01_ooool3o`WZ2PSooooo00?o0000oh]BR?n;DXP06_n;DXP00ol0003oYl3[ojO0j`06
ojO0j`04o`000?ooooooooooo`00043ooooo0ol9jPY>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`00goooool2o`WZ2Scooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`?o2NX:2oooool00ol0003oRe:8oh]BR00J
oh]BR003o`000?nW`>_oYl3[00KoYl3[00Go0000ooooooooooooooooo`00000looooo`?o2NX:D_oo
ool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool04oooool00=gooooo0_l9
jPXnooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool9jPX00_l9jPX>ooooo`03o`000?n;
DXSoRe:801[oRe:800?o0000ojO0jonW`>/01onW`>/01?l0003oooooooooool0000hooooo`Co2NX:
E_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo01?ooooo003Kooooo`;o2NX:
@?ooool00ol0003oooooooooo`08ooooo`03o`WZ2_l0003o2NX:017ooooo00?o0000oh]BR?n;DXP0
6_n;DXP00ol0003oYl3[ojO0j`08ojO0j`03o`000?oooooo000003Gooooo0ol9jPYJooooo`05o`00
0?ooooooooooooooool000006_ooool00ol0003oooooooooo`0Cooooo`00fOooool2o`WZ2T?ooooo
00?o0000ooooooooool00oooool4o`WZ2P;ooooo00?o0000ooooooooool03oooool00ol0003oRe:8
oh]BR00Joh]BR003o`000?nW`>_oYl3[00SoYl3[00?o0000ooooool00000<_ooool3o`WZ2Ukooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0Booooo`00eoooool2o`WZ2TGooooo
00?o0000ooooooooool00ol9jPX6ooooo`03o`000?oooooooooo00oooooo00?o0000oh]BR?n;DXP0
6_n;DXP00ol0003oYl3[ojO0j`09ojO0j`03o`000?oooooo000002kooooo0ol9jPYRooooo`03o`00
0?oooooo000001_ooooo00?o0000ooooooooool04_ooool00=Gooooo0_l9jPY7ooooo`03o`000?l9
jP[o2NX:00Wooooo00?o0000ooooooooool03oooool00ol0003oRe:8oh]BR00Joh]BR003o`000?nW
`>_oYl3[00WoYl3[00?o0000ooooool00000:_ooool4o`WZ2VKooooo0_l0000Kooooo`03o`000?oo
oooooooo01;ooooo003Booooo`?o2NX:A_ooool3o`WZ2P03ooooool0003ooooo00[ooooo00?o0000
ooooooooool03_ooool00ol0003oRe:8oh]BR00Joh]BR003o`000?nW`>_oYl3[00WoYl3[00?o0000
ooooool000009oooool3o`WZ2V[ooooo0_l0000Kooooo`03o`000?oooooooooo01;ooooo003@oooo
o`;o2NX:A_ooool3o`WZ2PCooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>oooo
o`03o`000?n;DXSoRe:801[oRe:800?o0000ojO0jonW`>/02_nW`>/2o`0002Cooooo0ol9jPY^oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04_ooool00<kooooo0_l9jPY5ooooo`?o
2NX:1oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oh]BR?n;
DXP06_n;DXP00ol0003oYl3[ojO0j`0:ojO0j`03o`000?oooooo0000023ooooo0ol9jPYbooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool00<cooooo0_l9jPY4ooooo`?o2NX:
2oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000oh]BR?n;DXP0
6_n;DXP00ol0003oYl3[ojO0j`0:ojO0j`03o`000?oooooo000001gooooo0ol9jPYfooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool04_ooool00<[ooooo0_l9jPY3ooooo`?o2NX:3_oo
ool00ol0003oooooooooo`07ooooo`?o00003oooool00ol0003oRe:8oh]BR00Joh]BR003o`000?nW
`>_oYl3[00_oYl3[0_l0000Iooooo`Co2NX:NOooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01;ooooo0038ooooo`;o2NX:@Oooool4o`WZ2Q7ooooo00?o0000ooooooooool00oooool4
o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003oRe:8oh]BR00Joh]BR003o`000?nW`>_o
Yl3[00_oYl3[0_l0000Fooooo`?o2NX:O_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01;ooooo0036ooooo`;o2NX:@?ooool3o`WZ2QKooooo00?o0000ooooool000000_l00007oooo
o`03o`000?oooooooooo00cooooo00?o0000oh]BR?n;DXP06_n;DXP00ol0003oYl3[ojO0j`0<ojO0
j`;o00004_ooool3o`WZ2X;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aoooo
o`00a?ooool2o`WZ2Soooooo0ol9jPXIooooo`;o00002_ooool00ol0003oooooooooo`0<ooooo`03
o`000?n;DXSoRe:801WoRe:800?o0000ojO0jonW`>/03OnW`>/2o`0000oooooo0ol9jPZ5ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool00<;ooooo0_l9jPXnooooo`?o2NX:
7?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oh]BR?n;DXP0
6On;DXP00ol0003oYl3[ojO0j`0=ojO0j`;o00002oooool4o`WZ2XWooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Aooooo`00`?ooool2o`WZ2Sgooooo0ol9jPXPooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oRe:8oh]BR00Ioh]BR003o`000?nW
`>_oYl3[00koYl3[00?o0000ooooooooool01_ooool3o`WZ2Xkooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Aooooo`00__ooool2o`WZ2Scooooo0ol9jPXSooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02oooool00ol0003oRe:8oh]BR00Ioh]BR003o`000?nW`>_o
Yl3[00koYl3[0_l00004ooooo`?o2NX:T_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo017ooooo002kooooo`?o2NX:>oooool3o`WZ2RKooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?n;DXSoRe:801SoRe:800?o0000ojO0jonW`>/03onW`>/2o`00
0004ooooool9jP[o2NX:o`WZ2YGooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0A
ooooo`00^Oooool2o`WZ2S[ooooo1?l9jPXZooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oRe:8oh]BR00Hoh]BR003o`000?nW`>_oYl3[00koYl3[00Co2NX:ojO0
jol0003o2NX:VOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo002goooo
o`;o2NX:>Oooool3o`WZ2Rkooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?n;DXSoRe:801SoRe:800?o0000ojO0jonW`>/02OnW`>/5o`WZ2P03ojO0jol0003o0000
09_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`00]Oooool2o`WZ2SSo
oooo0ol9jPXaooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
Re:8oh]BR00Hoh]BR003o`000?nW`>_oYl3[00GoYl3[1?l9jPX7ojO0j`03o`000?oooooooooo09Wo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`00/oooool2o`WZ2SOooooo
0ol9jPXeooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oRe:8
oh]BR00Goh]BR003o`000?nW`>_oYl3[00;oYl3[1?l9jPX;ojO0j`03o`000?oooooooooo09[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`00/Oooool2o`WZ2SKooooo0ol9
jPXhooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oRe:8oh]B
R00Goh]BR003o`000?l9jP[o2NX:00;o2NX:3onW`>/00ol0003oooooooooo`2Kooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00:oooooo0_l9jPXeooooo`?o2NX:??ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oh]BR?n;DXP05on;DXP0
0ol0003oYl3[ojO0j`0AojO0j`03o`000?oooooooooo09cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`00[Oooool2o`WZ2SCooooo0ol9jPXoooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oRe:8oh]BR00Goh]BR003o`000?nW`>_oYl3[
017oYl3[00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo002[ooooo`;o2NX:<_ooool4o`WZ2T;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`07ooooo`03o`000?n;DXSoRe:801OoRe:800?o0000ojO0jonW`>/04OnW`>/00ol0003o
ooooooooo`2Mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool00:Wooooo
0_l9jPXaooooo`?o2NX:Aoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo
00?o0000oh]BR?n;DXP05_n;DXP00ol0003oYl3[ojO0j`0BojO0j`03o`000?oooooooooo09kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`00Y_ooool3o`WZ2S3ooooo0ol9
jPY:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oRe:8oh]B
R00Foh]BR0;o00005?nW`>/00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04?ooool00:Cooooo0_l9jPX`ooooo`?o2NX:C_ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooooooo`Go2NX:00?o0000oh]BR?n;DXP05_n;DXP00ol0003oooooo`00
000CojO0j`03o`000?oooooooooo09kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0@ooooo`00X_ooool2o`WZ2Roooooo0ol9jPYAooooo`03o`000?oooooooooo00Sooooo00?o2NX:
o`000?l9jPX00_l9jPX5ooooo`03o`000?n;DXSoRe:801KoRe:800Co0000oooooooooooo00004_nW
`>/00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?oo
ool00:3ooooo0_l9jPX^ooooo`?o2NX:E?ooool00ol0003oooooooooo`03ooooo`Go2NX:00?ooooo
o`000?l000001oooool00ol0003oRe:8oh]BR00Eoh]BR003o`000?oooooooooo00;ooooo00?o0000
ojO0jonW`>/03onW`>/00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03oooool009kooooo0_l9jPX]ooooo`?o2NX:F?ooool00ol0003o2NX:o`WZ2P02o`WZ
2P?ooooo0ol000000ooooooo0000ooooo`07ooooo`03o`000?n;DXSoRe:801CoRe:800?o0000oooo
ooooool00oooool00ol0003oYl3[ojO0j`0>ojO0j`03o`000?oooooooooo0:3ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0?ooooo`00W?ooool2o`WZ2R_ooooo1?l9jPYFooooo`Go
2NX:00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003o
Re:8oh]BR00Doh]BR003o`000?oooooooooo00Cooooo00?o0000ojO0jonW`>/03OnW`>/00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool009[ooooo
0_l9jPXZooooo`?o2NX:EOooool5o`WZ2PGooooo00?o0000ooooool000000_l00008ooooo`03o`00
0?oooooooooo00Gooooo00?o0000oh]BR?n;DXP05?n;DXP00ol0003oooooooooo`04ooooo`03o`00
0?nW`>_oYl3[00goYl3[00?o0000ooooooooool0X_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00oooooo002Hooooo`;o2NX::Oooool3o`WZ2U;ooooo1_l9jPX;ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oRe:8oh]BR00Coh]BR003o`000?oo
oooooooo00Kooooo00?o0000ojO0jonW`>/03?nW`>/00ol0003oooooooooo`2Sooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03oooool009Kooooo0_l9jPXXooooo`?o2NX:D?ooool5
o`WZ2Q7ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?n;DXSo
Re:801?oRe:800?o0000ooooooooool01oooool00ol0003oYl3[ojO0j`0:ojO0j`;o0000YOooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo002Dooooo`;o2NX:9oooool3o`WZ
2Tkooooo1Ol9jPXGooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0
003oRe:8oh]BR00Coh]BR003o`000?oooooooooo00Sooooo00?o0000ojO0jonW`>/01_nW`>/3o`00
0003ooooool0003ooooo0:Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?oooo
o`00T_ooool2o`WZ2RKooooo0ol9jPY<ooooo`Go2NX:7?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo00?o0000oh]BR?n;DXP04_n;DXP00ol0003oooooooooo`0:ooooo`03
o`000?nW`>_oYl3[00?oYl3[0_l00004ooooo`03o`000?oooooooooo0:Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0?ooooo`00Soooool3o`WZ2RGooooo0ol9jPY:ooooo`Go2NX:
8_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oh]BR?n;DXP0
4_n;DXP00ol0003oooooooooo`0;ooooo`03o`000?nW`>_o000000;o00001_ooool00ol0003ooooo
ooooo`2Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool008gooooo0_l9
jPXUooooo`?o2NX:Aoooool6o`WZ2RSooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooo
oooooooo000001CoRe:800?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0:Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`00Rooo
ool2o`WZ2R?ooooo1?l9jPY5ooooo`Go2NX:;_ooool00ol0003oooooooooo`0:ooooo`05o`000?oo
ooooooooooooool000004on;DXP00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo
0029ooooo`;o2NX:8_ooool3o`WZ2TCooooo1Ol9jPXdooooo`03o`000?oooooooooo00[ooooo00Co
0000oooooooooooo00004on;DXP00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo
0027ooooo`;o2NX:8Oooool3o`WZ2T;ooooo1Ol9jPXiooooo`03o`000?oooooooooo00[ooooo00Co
0000oooooooooooo00004_n;DXP00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo
0025ooooo`;o2NX:8?ooool3o`WZ2T3ooooo1Ol9jPXoooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooool000004_n;DXP00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo0023
ooooo`;o2NX:7oooool3o`WZ2Sgooooo1_l9jPY5ooooo`03o`000?oooooooooo00[ooooo0_l0000B
oh]BR003o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Z
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0087ooooo0_l9jPXNoooo
o`?o2NX:>oooool5o`WZ2T_ooooo00?o0000ooooooooool02_ooool2o`00017oRe:800?o0000oooo
ooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:_ooooo00Go0000oooo
ooooooooooooo`00000@ooooo`00Ooooool2o`WZ2Qgooooo0ol9jPXiooooo`Go2NX:DOooool00ol0
003oooooooooo`0:ooooo`03o`000?n;DXSoRe:800ooRe:800?o0000ooooooooool03oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0:_ooooo00Go0000ooooooooooooooooo`00000@
ooooo`00OOooool2o`WZ2Q_ooooo1?l9jPXgooooo`Go2NX:E_ooool00ol0003oooooooooo`0:oooo
o`03o`000?n;DXSoRe:800koRe:800?o0000ooooooooool03oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo00004?ooool007_ooooo0_l9jPXJoooo
o`?o2NX:=_ooool5o`WZ2Ucooooo00?o0000ooooooooool02?ooool3o`0000ooRe:800?o0000oooo
ooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:gooooo00Co0000oooo
oooooooo00003oooool007Sooooo0ol9jPXIooooo`?o2NX:<oooool6o`WZ2V;ooooo00?o0000oooo
ooooool00oooool4o`000003ooooool0003o000000koRe:800?o0000ooooooooool04?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0:gooooo00Co0000oooooooooooo00003oooool0
07Kooooo0_l9jPXIooooo`?o2NX:<Oooool5o`WZ2VSooooo00?o0000ooooooooool00ol00005oooo
o`03o`000?n;DXSo000000goRe:800?o0000ooooooooool04?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0:kooooo00?o0000ooooool000003oooool007Cooooo0_l9jPXHooooo`?o
2NX:;oooool5o`WZ2Vkooooo0_l00008ooooo`04o`000?n;DXSoRe:8o`0000coRe:800?o0000oooo
ooooool04?ooool00ol0003oooooooooo`06ooooo`?o0000/Oooool2o`0000oooooo001booooo`;o
2NX:5oooool3o`WZ2Rgooooo1Ol9jPYcooooo`03o`000?oooooooooo00Oooooo00Go0000oh]BR?n;
DXSoRe:8o`00000:oh]BR003o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool4o`00
00;ooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0=ooooo`00L?ooool2o`WZ2QKo
oooo0ol9jPX[ooooo`Go2NX:NOooool00ol0003oooooooooo`06ooooo`05o`000?n;DXSoRe:8oh]B
R?l000002_n;DXP00ol0003oooooooooo`0Aooooo`03o`000?oooooo000000;o00001_ooool00ol0
003oooooooooo`30ooooo`00K_ooool2o`WZ2QCooooo1?l9jPXYooooo`Go2NX:Ooooool00ol0003o
ooooooooo`05ooooo`03o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?n;DXP01_n;DXP00ol0003o
ooooooooo`0Booooo`;o00002?ooool00ol0003oooooooooo`31ooooo`00K?ooool2o`WZ2Q?ooooo
0ol9jPXWooooo`Ko2NX:QOooool00ol0003oooooooooo`04ooooo`03o`000?n;DXSoRe:800?oRe:8
00?o0000oh]BR?n;DXP01On;DXP00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0`Oooool006[ooooo0_l9jPXBooooo`?o2NX:9Oooool5o`WZ2X_ooooo00?o
0000ooooooooool01?ooool00ol0003oRe:8oh]BR003oh]BR003o`000?n;DXSoRe:800GoRe:800?o
0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<7ooooo001X
ooooo`;o2NX:4Oooool3o`WZ2R?ooooo1Ol9jPZAooooo`03o`000?oooooooooo00?ooooo00?o0000
oh]BR?n;DXP01?n;DXP00ol0003oRe:8oh]BR003oh]BR003o`000?oooooooooo01;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`31ooooo`00I_ooool2o`WZ2Q3ooooo0ol9jPXQoooo
o`Go2NX:Uoooool00ol0003oooooooooo`02ooooo`03o`000?n;DXSoRe:800GoRe:800?o0000oh]B
R?n;DXP00_n;DXP00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0`_ooool006Cooooo0_l9jPX?ooooo`?o2NX:7oooool5o`WZ2Ycooooo00?o0000oooooooo
ool00_ooool00ol0003oRe:8oh]BR006oh]BR004o`000?n;DXSoRe:8o`0001Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`32ooooo`00HOooool3o`WZ2Pkooooo0ol9jPXLooooo`Ko
2NX:X_ooool01Ol0003ooooooooooooooooo000000SoRe:800Co0000oh]BR?n;DXSo00005Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<;ooooo001Oooooo`;o2NX:3Oooool4o`WZ
2Q[ooooo1Ol9jPZYooooo`04o`000?ooooooooooo`0000WoRe:800?o0000oh]BR?l000005?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<;ooooo001Mooooo`;o2NX:3?ooool3o`WZ
2QWooooo1Ol9jPZ_ooooo`03o`000?oooooo000000SoRe:81?l0000Dooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0`oooool005_ooooo0_l9jPX;ooooo`?o2NX:5oooool5o`WZ2[Co
oooo00?o0000ooooool000001?n;DXP4o`0000Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`06ooooo`;o0000aOooool005Wooooo0_l9jPX:ooooo`?o2NX:5Oooool5o`WZ2[[ooooo
0_l000001?n;DXSo0000o`000?l00009ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00oooool3o`000003ooooool0003ooooo0<Cooooo001Gooooo`;o2NX:2Oooool3o`WZ2Q;ooooo
1_l9jP[0ooooo`;o00003Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?o0000
0oooool00ol0003oooooooooo`34ooooo`00EOooool2o`WZ2PSooooo0ol9jPX@ooooo`Go2NX:b?oo
ool00ol0003oooooooooo`0;ooooo`;o00003_ooool4o`0000Gooooo00?o0000ooooooooool0aOoo
ool005?ooooo0_l9jPX7ooooo`?o2NX:3_ooool5o`WZ2/kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0a_ooool0
057ooooo0_l9jPX6ooooo`?o2NX:3?ooool5o`WZ2]Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0a_ooool004oo
oooo0_l9jPX4ooooo`Co2NX:2_ooool5o`WZ2][ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0aoooool004gooooo
0_l9jPX3ooooo`?o2NX:2Oooool5o`WZ2^3ooooo00?o0000ooooooooool02oooool4o`0000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00B_ooool3o`WZ2P;ooooo0ol9
jPX6ooooo`Ko2NX:i_ooool00ol0003oooooooooo`07ooooo`?o00001?ooool3o`0000;ooooo00?o
0000ooooooooool00oooool3o`000<_ooooo0018ooooo`;o2NX:0_ooool3o`WZ2PCooooo1Ol9jP[]
ooooo`03o`000?oooooooooo00?ooooo0ol0000:ooooo`?o00000_ooool3o`000<kooooo0016oooo
o`;o2NX:00Coooooo`WZ2_l9jP[o2NX:0_ooool5o`WZ2_?ooooo00?o0000ooooool000000_l0000>
ooooo`Co0000dOooool004Cooooo2_l9jP[iooooo`?o00003Oooool3o`000=Cooooo0012ooooo`Oo
2NX:ooooool2ooooo`?o00001oooool3o`000=Oooooo0011ooooo`?o2NX:ooooool:ooooo`?o0000
00Coooooo`000?l0003o0000f_ooool00?ooooooDOooool00ol0003oooooooooo`3Kooooo`00oooo
oooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3o
oooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooo
oooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?oo
ool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?oooooo
ooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`oooo
o`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooo
oooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo
003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooo
oooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool0
0?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?oooooooooo
ool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00
oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooo
oc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003o
oooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo
<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?oo
ooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`
ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooo
oooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3o
oooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooo
oooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?oo
ool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?oooooo
ooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`oooo
o`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooo
oooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo
003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooo
oooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool0
0?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?oooooooooo
ool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00
oooooooooooooc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooo
oc3ooooo003ooooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003o
oooooooooooo<?ooool00?ooooooooooool`ooooo`00oooooooooooooc3ooooo003ooooooooooooo
<?ooool00001\
\>"],
  ImageRangeCache->{{{0, 557.25}, {378.125, 0}} -> {0.0215824, 0.147119, \
0.00175653, 0.00175653}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Arbitrary Precision Calculations in ",
  StyleBox["Rayica",
    FontSlant->"Italic"]
}], "SubsectionIcon"],

Cell[TextData[{
  "In ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  ", both the ",
  StyleBox["TurboPlot", "Input"],
  " and ",
  StyleBox["TurboTrace", "Input"],
  " functions support arbitrary precision calculations. In its default mode, \
however, all calculations are carried out in machine precision of 16 decimal \
places. Here is a default calculation of the optical length of the rays \
traced to the final screen surface:"
}], "Text"],

Cell[CellGroupData[{

Cell["TurboTrace[sys,OpticalLength]//InputForm", "Input",
  CellLabel->"In[6]:="],

Cell["{155.2594749592117, 155.23244752966428, 155.2594749592117}", "Output",
  CellLabel->"Out[6]//InputForm="]
}, Open  ]],

Cell[TextData[{
  "Next, we use ",
  StyleBox["RayTracePrecision->50", "Input"],
  " to repeat the above calculation with 50 decimal places of precision:"
}], "Text"],

Cell[CellGroupData[{

Cell["TurboTrace[sys,OpticalLength,RayTracePrecision->50]", "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({155.259474947573901666175818636139183393839888978834732853702`47.\
875917318972164, 
      155.232447518638721991153023889871698547914633582534753936173`49.\
606237256279734, 
      155.259474947573901666175818636139183393839888978834732853702`47.\
875917318972164}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "We can use ",
  StyleBox["TurboTrace", "Input"],
  " with ",
  StyleBox["OutputType->RayTraceFunction", "Input"],
  " to extract a ray-trace function model of the system. Again, we use ",
  StyleBox["RayTracePrecision->50", "Input"],
  ". This model is stored in a variable called ",
  StyleBox["res", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
res = \
RayTraceFunction/.TurboTrace[sys,OpticalLength,OutputType->RayTraceFunction,\
RayTracePrecision->50]\
\>", "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \("RayTraceFunction[{$inputrays}, -raytrace code: 111232 Bytes- : \
RayTracePrecision -> 50]"\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "This stored ",
  StyleBox["RayTraceFunction", "Input"],
  " can now make new calculations with different light source models. Here we \
use a ",
  StyleBox["LineOfRays", "Input"],
  " and ",
  StyleBox["WedgeOfRays", "Input"],
  " in separate calculations."
}], "Text"],

Cell[CellGroupData[{

Cell["res[LineOfRays[20]]", "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({155.000005077442143626971785416070154101281859153591468673576`49.\
24123730261394, 
      155.232447518638721991153023889871698547914633582534753936173`49.\
606237256279734, 
      155.000005077442143626971785416070154101281859153591468673576`49.\
24123730261394}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["res[WedgeOfRays[20]]", "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({155.259474947573901666175818636139183393839888978834732853702`47.\
875917318972164, 
      155.232447518638721991153023889871698547914633582534753936173`49.\
606237256279734, 
      155.259474947573901666175818636139183393839888978834732853702`47.\
875917318972164}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Arbitrary Precision Calculations in ",
  StyleBox["Wavica",
    FontSlant->"Italic"]
}], "SubsectionIcon"],

Cell[TextData[{
  "Most functions in ",
  StyleBox["Wavica",
    FontSlant->"Italic"],
  " supports arbitrary precision control. This includes: ",
  StyleBox["SymbolicTrace", "Input"],
  ", ",
  StyleBox["FindInterference", "Input"],
  ", ",
  StyleBox["GaussianPlot", "Input"],
  ", ",
  StyleBox["GaussianTrace", "Input"],
  ", ",
  StyleBox["FindABCDMatrix", "Input"],
  " , ",
  StyleBox["ZernikeFit", "Input"],
  ", and ",
  StyleBox["FindWaveFronts", "Input"],
  ". For remaining discussion, we will examine the use of ",
  StyleBox["FindWaveFronts", "Input"],
  " and ",
  StyleBox["GaussianPlot", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["FindWaveFronts in one dimension", "SubsubsectionIcon"],

Cell[TextData[{
  "Here is the default behavior of ",
  StyleBox["FindWaveFronts", "Input"],
  ". This calculation shows the one-dimensional wavefront at the final screen \
surface in the system."
}], "Text"],

Cell[CellGroupData[{

Cell["FindWaveFronts[sys]", "Input"],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 2, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 2, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 -3387.18 21.8202 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06927 -42 -4.5 ]
[-0.0125 .06927 0 4.5 ]
[-0.0125 .17837 -36 -4.5 ]
[-0.0125 .17837 0 4.5 ]
[-0.0125 .28747 -42 -4.5 ]
[-0.0125 .28747 0 4.5 ]
[-0.0125 .39657 -36 -4.5 ]
[-0.0125 .39657 0 4.5 ]
[-0.0125 .50567 -42 -4.5 ]
[-0.0125 .50567 0 4.5 ]
[-0.0125 .61478 -36 -4.5 ]
[-0.0125 .61478 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06927 m
.00625 .06927 L
s
[(155.235)] -0.0125 .06927 1 0 Mshowa
0 .17837 m
.00625 .17837 L
s
[(155.24)] -0.0125 .17837 1 0 Mshowa
0 .28747 m
.00625 .28747 L
s
[(155.245)] -0.0125 .28747 1 0 Mshowa
0 .39657 m
.00625 .39657 L
s
[(155.25)] -0.0125 .39657 1 0 Mshowa
0 .50567 m
.00625 .50567 L
s
[(155.255)] -0.0125 .50567 1 0 Mshowa
0 .61478 m
.00625 .61478 L
s
[(155.26)] -0.0125 .61478 1 0 Mshowa
.125 Mabswid
0 .09109 m
.00375 .09109 L
s
0 .11291 m
.00375 .11291 L
s
0 .13473 m
.00375 .13473 L
s
0 .15655 m
.00375 .15655 L
s
0 .20019 m
.00375 .20019 L
s
0 .22201 m
.00375 .22201 L
s
0 .24383 m
.00375 .24383 L
s
0 .26565 m
.00375 .26565 L
s
0 .30929 m
.00375 .30929 L
s
0 .33111 m
.00375 .33111 L
s
0 .35293 m
.00375 .35293 L
s
0 .37475 m
.00375 .37475 L
s
0 .41839 m
.00375 .41839 L
s
0 .44021 m
.00375 .44021 L
s
0 .46203 m
.00375 .46203 L
s
0 .48385 m
.00375 .48385 L
s
0 .52749 m
.00375 .52749 L
s
0 .54931 m
.00375 .54931 L
s
0 .57114 m
.00375 .57114 L
s
0 .59296 m
.00375 .59296 L
s
0 .04745 m
.00375 .04745 L
s
0 .02563 m
.00375 .02563 L
s
0 .00381 m
.00375 .00381 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06927 m
1 .06927 L
s
.99375 .17837 m
1 .17837 L
s
.99375 .28747 m
1 .28747 L
s
.99375 .39657 m
1 .39657 L
s
.99375 .50567 m
1 .50567 L
s
.99375 .61478 m
1 .61478 L
s
.125 Mabswid
.99625 .09109 m
1 .09109 L
s
.99625 .11291 m
1 .11291 L
s
.99625 .13473 m
1 .13473 L
s
.99625 .15655 m
1 .15655 L
s
.99625 .20019 m
1 .20019 L
s
.99625 .22201 m
1 .22201 L
s
.99625 .24383 m
1 .24383 L
s
.99625 .26565 m
1 .26565 L
s
.99625 .30929 m
1 .30929 L
s
.99625 .33111 m
1 .33111 L
s
.99625 .35293 m
1 .35293 L
s
.99625 .37475 m
1 .37475 L
s
.99625 .41839 m
1 .41839 L
s
.99625 .44021 m
1 .44021 L
s
.99625 .46203 m
1 .46203 L
s
.99625 .48385 m
1 .48385 L
s
.99625 .52749 m
1 .52749 L
s
.99625 .54931 m
1 .54931 L
s
.99625 .57114 m
1 .57114 L
s
.99625 .59296 m
1 .59296 L
s
.99625 .04745 m
1 .04745 L
s
.99625 .02563 m
1 .02563 L
s
.99625 .00381 m
1 .00381 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06927 m
1 .06927 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94697 .58474 Mdot
.91743 .55331 Mdot
.88759 .51189 Mdot
.85748 .46316 Mdot
.82714 .40964 Mdot
.79658 .35362 Mdot
.76584 .29721 Mdot
.73494 .24229 Mdot
.70389 .19055 Mdot
.67272 .14347 Mdot
.64146 .1023 Mdot
.6101 .06811 Mdot
.57869 .04173 Mdot
.54723 .02379 Mdot
.51575 .01472 Mdot
.48425 .01472 Mdot
.45277 .02379 Mdot
.42131 .04173 Mdot
.3899 .06811 Mdot
.35854 .1023 Mdot
.32728 .14347 Mdot
.29611 .19055 Mdot
.26506 .24229 Mdot
.23416 .29721 Mdot
.20342 .35362 Mdot
.17286 .40964 Mdot
.14252 .46316 Mdot
.11241 .51189 Mdot
.08257 .55331 Mdot
.05303 .58474 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03837 .59406 L
.04579 .58935 L
.04987 .58675 L
.05187 .58548 L
.05372 .58401 L
.05574 .58185 L
.05794 .57952 L
.06178 .57543 L
.06929 .56744 L
.08634 .54808 L
.11681 .50478 L
.1461 .45685 L
.17729 .40153 L
.20731 .34649 L
.23922 .28821 L
.26996 .23412 L
.29953 .18538 L
.331 .13857 L
.36129 .0993 L
.39349 .06509 L
.40964 .05153 L
.42451 .0399 L
.43994 .0311 L
.44748 .02681 L
.45077 .02493 L
.45167 .02442 L
.45251 .02394 L
.45338 .02361 L
.45435 .02333 L
.45623 .02279 L
.45796 .02229 L
.46138 .02131 L
.46892 .01913 L
.47672 .01689 L
.48097 .01566 L
.48203 .01535 L
.48304 .01506 L
.48394 .0148 L
.48492 .01472 L
.48583 .01472 L
.4868 .01472 L
.48853 .01472 L
.49238 .01472 L
.50055 .01472 L
.50803 .01472 L
.51131 .01472 L
.51303 .01472 L
.51398 .01472 L
.51487 .01472 L
Mistroke
.51589 .01476 L
.51682 .01502 L
.51862 .01554 L
.52218 .01657 L
.53003 .01883 L
.53679 .02078 L
.54421 .02292 L
.5461 .02346 L
.54665 .02362 L
.54716 .02377 L
.54813 .0243 L
.55178 .02638 L
.55978 .03094 L
.57409 .0391 L
.60381 .06282 L
.63542 .09572 L
.66586 .13443 L
.69513 .17731 L
.72629 .22788 L
.75628 .28022 L
.78818 .33819 L
.81889 .39452 L
.84844 .44721 L
.87988 .49941 L
.91015 .54321 L
.92559 .562 L
.94232 .57979 L
.95845 .59204 L
.97331 .60149 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00??ooool3o`0000?ooooo0ol0000Jooooo`?o00001?ooool2o`0001co
oooo0ol0000Mooooo`;o00008?ooool3o`0001cooooo0ol00004ooooo`;o00006_ooool3o`0000?o
oooo0ol0000?ooooo`00?Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooo
ooooooooooooo`00000Kooooo`04o`000?ooooooooooo`0001kooooo00Go0000oooooooooooooooo
o`00000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool03?ooool003Gooooo1Ol00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool5o`0000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Dooooo`Go00001Oooool00ol0003oooooooooo`0Ioooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`00?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo01Wooooo00Co
0000oooooooooooo00008_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00co
oooo000mooooo`04o`000?ooooooooooooooo`Co00006oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0001[ooooo1?l0000Looooo`04o`000?ooooooooooo`0001kooooo1?l0000M
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool01?l0003ooooooooo
ooooool4o`0000oooooo000looooo`;o00000oooool00ol0003oooooooooo`0Kooooo`;o00001?oo
ool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo
00007_ooool00ol0003oooooooooo`0Mooooo`;o00001?ooool01?l0003oooooooooool0000Ioooo
o`;o00000oooool00ol0003oooooooooo`0@ooooo`00?Oooool01?l0003oooooooooooooool5o`00
01[ooooo00?o0000ooooooooool00oooool2o`0001_ooooo1Ol0000Looooo`;o00007oooool5o`00
01cooooo00?o0000ooooooooool00oooool2o`0001_ooooo00Co0000oooooooooooooooo1Ol0000>
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00;Oooooob
o`00007ooooo000]ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00001
ooooo`00;Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00kooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo07Kooooo0Ol00001ooooo`00
;Oooool00ol0003oooooooooo`1_ooooo`ko0000LOooool1o`00007ooooo000]ooooo`03o`000?oo
oooooooo06cooooo0ol00002ooooo`;o00000_ooool01?l0003oooooooooooooool2o`0000;ooooo
0ol0001^ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0JOooool3o`0000Wooooo00?o
0000ooooooooool02?ooool2o`0006_ooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1X
ooooo`?o00002_ooool00ol0003oooooooooo`08ooooo`Co0000J_ooool1o`00007ooooo000]oooo
o`03o`000?oooooooooo06Kooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo0_l0001Xoooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0I?ooool2o`0000oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Uooooo`7o00000Oooool002gooooo00?o0000ooooooooool0
H_ooool2o`00017ooooo00?o0000ooooooooool03oooool3o`0006Cooooo0Ol00001ooooo`00;Ooo
ool00ol0003oooooooooo`1Rooooo`;o00004Oooool00ol0003oooooooooo`0@ooooo`;o0000I?oo
ool1o`00007ooooo000]ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Booooo`;o0000HOooool2o`00007ooooo000]ooooo`03o`000?oooooooooo
05oooooo0_l0000Dooooo`03o`000?oooooooooo01Cooooo0_l0001Pooooo`7o00000Oooool002go
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0GOooool1o`00007ooooo00001?oooooo0000o`000?l00003ooooo`?o
00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00000oooool3o`00
00Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0G?ooool1o`00007ooooo0002ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Jooooo`?o00006?ooool00ol0003oooooooooo`0Gooooo`;o0000GOoo
ool1o`00007ooooo0002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02oooooo;o00000Oooool000;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool2o`00
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Jooooo`7o00000Oooool000;o
oooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo0Ol00001
ooooo`0000?oooooo`000?l000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Hooooo`7o00000Oooool000;ooooo00Co0000oooooooooooooooo1Ol0
00000ooooooo0000o`000003o`0000Sooooo0ol00003ooooo`?o00000_ooool5o`0000Cooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0Eoooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Gooooo0_l00001
ooooo`00;Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Eooooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0EOooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05?ooooo0_l0000Pooooo`03o`00
0?oooooooooo01oooooo0_l0001Eooooo`7o00000Oooool002gooooo00?o0000ooooooooool0Dooo
ool2o`00023ooooo00?o0000ooooooooool07oooool2o`0005Gooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1Booooo`7o00000Oooool002gooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0D?ooool2o`00
007ooooo000]ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo057ooooo0Ol00001ooooo`00;Oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1@ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Coooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo04kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<oooo
o`;o00000Oooool002gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0COooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo04_ooooo0ol0000Wooooo`03o`000?oooooooooo02Oooooo0_l0001=ooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool0Boooool2o`0002Sooooo00?o0000ooooooooool09ooo
ool2o`0004gooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1;ooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0BOooool2o`00007ooooo000]ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Wo
oooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`7o00000Oooool000Oooooo0ol0
0003ooooo`?o00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00003ooooo`?o0000
1?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`18ooooo`7o00000Oooool000Sooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Aoooool1o`00007o
oooo0008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0004Sooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`00
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0A_ooool1o`00007ooooo0008ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000So
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0AOooool1o`00007ooooo0007ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`;o00001Oooool00ol0
003oooooooooo`13ooooo`?o0000;oooool00ol0003oooooooooo`0^ooooo`;o0000A_ooool1o`00
007ooooo0008ooooo`04o`000?ooooooooooooooo`Go000000?oooooo`000?l000000ol00008oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo0_l0000`oooo
o`03o`000?oooooooooo02kooooo0_l00016ooooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0@oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04;ooooo0_l00001ooooo`00;Ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`12ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0@_ooool1
o`00007ooooo000]ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo047ooooo0Ol00001ooooo`00;Oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`10ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0?oooool2o`00007ooooo
000]ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0o
ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0?_ooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo03kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0looooo`;o0000
=oooool00ol0003oooooooooo`0fooooo`;o0000?Oooool2o`00007ooooo000]ooooo`03o`000?oo
oooooooo03cooooo0_l0000gooooo`03o`000?oooooooooo03Kooooo0_l0000nooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0??ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
03_ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0kooooo`7o00000Oooool002gooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0>_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Wooooo0_l0
0001ooooo`00;Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0iooooo`7o00000Oooool00004ooooool0003o0000
o`0000?ooooo0ol00003ooooo`?o00001?ooool01?l0003oooooooooooooool5o`0000?ooooo0ol0
0002ooooo`?o00001Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0iooooo`7o00000Oooool000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0hooooo`7o00000Oooool000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
oooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>?ooool1o`00007o
oooo0002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`;o0000=oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0=_ooool2o`00007ooooo0002ooooo`04o`000?ooooooooooooooo`Co
00000_ooool4o`0000Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000
00;ooooo1?l00005ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo03Oooooo0Ol00001ooooo`0000?oooooo`000?l0
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Cooooo0_l0000oooooo`03o`000?oooooooooo03gooooo0_l0000gooooo`7o00000Oooool000;o
oooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`0000Sooooo0ol00005oooo
o`03o`000?oooooooooo00Go00001?ooool00ol0003oooooooooo`0dooooo`;o0000?oooool00ol0
003oooooooooo`0mooooo`;o0000=oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Go
oooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0cooooo`;o00000Oooool002gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0=?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03?ooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0cooooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0<_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo033ooooo0_l00001ooooo`00;Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0aooooo`7o00000Oooool002gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<?ooool1
o`00007ooooo000]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo033ooooo0Ol00001ooooo`00;Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0_ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0;oooool1o`00007ooooo
000]ooooo`03o`000?oooooooooo02gooooo0_l00016ooooo`03o`000?oooooooooo04Cooooo0_l0
000_ooooo`;o00000Oooool002gooooo00?o0000ooooooooool0;Oooool2o`0004Kooooo00?o0000
ooooooooool0A?ooool3o`0002oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0]oooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0;?ooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo02cooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Zooooo`;o00000Ooo
ool002gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0:oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
02[ooooo0Ol00001ooooo`001oooool3o`0000?ooooo0ol00003ooooo`?o00001?ooool01?l0003o
ooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo0Ol00001oooo
o`002?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo02Wooooo0Ol00001ooooo`002?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo0_l0000Yooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Wooooo`;o00000Oooool000Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02Sooooo0Ol00001oooo
o`002?ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00008ooooo`06o`000?oooooooooo
ooooool0003ooooo1?l00005ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Oooooo0Ol00001ooooo`001oooool2
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`07o`000?oooooo
ooooooooool0003oooooo`000008ooooo`03o`000?oooooooooo02Kooooo0_l0001=ooooo`03o`00
0?oooooooooo04cooooo0_l0000Xooooo`7o00000Oooool000Sooooo00Co0000oooooooooooooooo
1Ol000000ooooooo0000o`000003o`0000Sooooo0ol00002ooooo`Go00001?ooool00ol0003ooooo
ooooo`0Vooooo`;o0000COooool00ol0003oooooooooo`1<ooooo`;o0000:?ooool1o`00007ooooo
000]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo02Cooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0U
ooooo`7o00000Oooool002gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool09?ooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo02Cooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool08_ooool1o`00007ooooo000]ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo027ooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Qooooo`7o00000Oooool002go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool08Oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo023ooooo
0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0Pooooo`7o00000Oooool002gooooo00?o0000
ooooooooool07_ooool3o`0005Cooooo00?o0000ooooooooool0Doooool2o`00023ooooo0_l00001
ooooo`00;Oooool00ol0003oooooooooo`0Nooooo`;o0000EOooool00ol0003oooooooooo`1Coooo
o`;o00008Oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01kooooo0Ol00001ooooo`00
;Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`0Mooooo`7o00000Oooool002gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07Ooo
ool1o`00007ooooo000]ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01_ooooo0_l00001ooooo`00;Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`0Looooo`7o00000Oooool002gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool06oooool1o`00007o
oooo00001?oooooo0000o`000?l00003ooooo`?o00000oooool3o`0000Cooooo00Co0000oooooooo
oooooooo1Ol00002ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool06oooool1o`00
007ooooo0002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Jooooo`7o00000Ooo
ool000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool06_ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool06?ooool2o`00
007ooooo0002ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000Sooooo00Ko0000oooo
ooooooooooooo`000?ooool4o`0000;ooooo1?l00005ooooo`03o`000?oooooooooo01Oooooo0_l0
001Looooo`03o`000?oooooooooo05_ooooo0_l0000Iooooo`7o00000Oooool00003ooooool0003o
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`07o`000?oooooo
ooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5oooool2o`0005cooooo00?o0000ooooooooool0Foooool2o`0001Wooooo0Ol00001ooooo`000_oo
ool01?l0003oooooooooooooool5o`000003ooooool0003o000000?o00002?ooool3o`0000;ooooo
1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool05oooool1o`00007ooooo
000]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo01Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0D
ooooo`;o00000Oooool002gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool05Oooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo01Cooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Cooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool04_ooool1o`00007ooooo000]ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo017ooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0@ooooo`;o0000Hoooool00ol0
003oooooooooo`1Rooooo`;o00004_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo013o
oooo0_l0001Sooooo`03o`000?oooooooooo06;ooooo0_l0000Booooo`7o00000Oooool002gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool03oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00oooooo0Ol0
0001ooooo`00;Oooool00ol0003oooooooooo`0<ooooo`;o0000Ioooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00gooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0=oooo
o`7o00000Oooool002gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool03?ooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo00Wooooo0_l0001Zooooo`03o`000?oooooooooo06Sooooo0ol0000;ooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool02Oooool2o`0006[ooooo00?o0000ooooooooool0JOoo
ool3o`0000[ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`07ooooo`;o0000K?ooool0
0ol0003oooooooooo`1/ooooo`;o00002?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo
00Gooooo0_l0001^ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool2o`00
007ooooo000]ooooo`03o`000?oooooooooo00?ooooo0_l0001`ooooo`03o`000?oooooooooo06oo
oooo00?o0000ooooooooool01?ooool1o`00007ooooo0007ooooo`?o00000oooool3o`0000?ooooo
0ol00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000Gooooo00?o0000oooooooo
ool00_ooool2o`00077ooooo00?o0000ooooooooool0L?ooool2o`0000Cooooo0Ol00001ooooo`00
2?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo0_l0001aooooo`03o`000?oooooooooo073ooooo0_l00004
ooooo`7o00000Oooool000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0>ooooo`7o00000Oooool0
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01?l00005ooooo`;o000000?oooooo`000?ooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02o`00007ooooo0008ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`00
00Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000Soooool_l00001ooooo`001oooool2
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`3hooooo`002?ooool01?l0003ooooooooooooo
ool5o`000003ooooool0003o000000?o00002?ooool3o`0000Cooooo0_l0003hooooo`00oooooolQ
ooooo`00=_ooool3o`0005Sooooo0ol0000Gooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool02?ooool003Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool01oooool0037ooooo0ol00003ooooo`?o0000
1?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4o`000003ooooool0003o000000?o0000
1oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Kooooo1Ol00002ooooo`?o0000
0_ooool3o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo1_l00007ooooo`03
o`000?oooooooooo00?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo1?l00003ooooo`?o
00000_ooool5o`0000?ooooo0_l000001?oooooo0000ooooooooool2o`0000?ooooo0ol00009oooo
o`Co000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000Cooooo0_l00003oooo
o`Co000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000o`0000?ooooo0ol0
0005ooooo`03o`000?oooooooooo00Kooooo000`ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00006ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00002oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
0002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool01_ooool0033ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool00oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`Go00001oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`06
o`000?ooooooooooo`000?oooooo00001Oooool5o`0000Cooooo00?o0000ooooooooool01_ooool0
033ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool00000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`06o`000?oooooo
ooooo`000?oooooo00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo000`ooooo`06o`000?ooooooooooooooool0003ooooo1?l0
0002ooooo`Co00000_ooool3o`0000Cooooo0ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Wooooo
00?o0000ooooooooool00oooool3o`0000;ooooo1?l00003ooooo`Wo00000oooool3o`0000Wooooo
00?o0000ooooooooool00oooool2o`0000Cooooo0ol00003ooooo`Co00000_ooool3o`0000Cooooo
00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00009oooo
o`?o00000_ooool3o`0000Cooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00003oooo
o`Co00000oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo000`ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01oooool0037ooooo0ol00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo
00;ooooo0_l0000:ooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o00003Oooool00ol0
003oooooooooo`06ooooo`;o00004?ooool3o`0000[ooooo00?o0000ooooooooool04?ooool2o`00
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Sooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.1051, 155.229, 0.145256, \
0.000189494}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 -1.36833 0.66001 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0837 -18 -4.5 ]
[-0.0125 .0837 0 4.5 ]
[-0.0125 .2157 -18 -4.5 ]
[-0.0125 .2157 0 4.5 ]
[-0.0125 .3477 -18 -4.5 ]
[-0.0125 .3477 0 4.5 ]
[-0.0125 .4797 -18 -4.5 ]
[-0.0125 .4797 0 4.5 ]
[-0.0125 .6117 -6 -4.5 ]
[-0.0125 .6117 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0837 m
.00625 .0837 L
s
[(2.2)] -0.0125 .0837 1 0 Mshowa
0 .2157 m
.00625 .2157 L
s
[(2.4)] -0.0125 .2157 1 0 Mshowa
0 .3477 m
.00625 .3477 L
s
[(2.6)] -0.0125 .3477 1 0 Mshowa
0 .4797 m
.00625 .4797 L
s
[(2.8)] -0.0125 .4797 1 0 Mshowa
0 .6117 m
.00625 .6117 L
s
[(3)] -0.0125 .6117 1 0 Mshowa
.125 Mabswid
0 .1167 m
.00375 .1167 L
s
0 .1497 m
.00375 .1497 L
s
0 .1827 m
.00375 .1827 L
s
0 .2487 m
.00375 .2487 L
s
0 .2817 m
.00375 .2817 L
s
0 .3147 m
.00375 .3147 L
s
0 .3807 m
.00375 .3807 L
s
0 .4137 m
.00375 .4137 L
s
0 .4467 m
.00375 .4467 L
s
0 .5127 m
.00375 .5127 L
s
0 .5457 m
.00375 .5457 L
s
0 .5787 m
.00375 .5787 L
s
0 .0507 m
.00375 .0507 L
s
0 .01769 m
.00375 .01769 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0837 m
1 .0837 L
s
.99375 .2157 m
1 .2157 L
s
.99375 .3477 m
1 .3477 L
s
.99375 .4797 m
1 .4797 L
s
.99375 .6117 m
1 .6117 L
s
.125 Mabswid
.99625 .1167 m
1 .1167 L
s
.99625 .1497 m
1 .1497 L
s
.99625 .1827 m
1 .1827 L
s
.99625 .2487 m
1 .2487 L
s
.99625 .2817 m
1 .2817 L
s
.99625 .3147 m
1 .3147 L
s
.99625 .3807 m
1 .3807 L
s
.99625 .4137 m
1 .4137 L
s
.99625 .4467 m
1 .4467 L
s
.99625 .5127 m
1 .5127 L
s
.99625 .5457 m
1 .5457 L
s
.99625 .5787 m
1 .5787 L
s
.99625 .0507 m
1 .0507 L
s
.99625 .01769 m
1 .01769 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .0837 m
1 .0837 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .03562 m
.03837 .29638 L
.05372 .49288 L
.05761 .54273 L
.05815 .54961 L
.05874 .55708 L
.05929 .56414 L
.0598 .56548 L
.06076 .56665 L
.06178 .5679 L
.06929 .57704 L
.0775 .58705 L
.08203 .59257 L
.08634 .59782 L
.08817 .60004 L
.08917 .60127 L
.09012 .60234 L
.09066 .60206 L
.09124 .60175 L
.09225 .60122 L
.09424 .60019 L
.10146 .59643 L
.11563 .58905 L
.14738 .57247 L
.17795 .5583 L
.20735 .54646 L
.23864 .53551 L
.26876 .5265 L
.30079 .51836 L
.33163 .51186 L
.36131 .50676 L
.39288 .50239 L
.40856 .50074 L
.42328 .49936 L
.43735 .49835 L
.45251 .49743 L
.45609 .49721 L
.45704 .49715 L
.45806 .49709 L
.45903 .49704 L
.45992 .49702 L
.46212 .49696 L
.46412 .4969 L
.46802 .4968 L
.47646 .49656 L
.48059 .49645 L
.48436 .49635 L
.48608 .4963 L
.48795 .49625 L
.48881 .49623 L
Mistroke
.48972 .49621 L
.49058 .49621 L
.49136 .49622 L
.49888 .49626 L
.50721 .4963 L
.51086 .49632 L
.51486 .49634 L
.51668 .49635 L
.51768 .49636 L
.51862 .49636 L
.5195 .49637 L
.52046 .49638 L
.52133 .49641 L
.52213 .49645 L
.52979 .49674 L
.53812 .49705 L
.54592 .49735 L
.54932 .49748 L
.55015 .49751 L
.55103 .49755 L
.552 .49762 L
.5529 .49768 L
.55681 .49796 L
.5604 .49822 L
.57636 .49936 L
.60853 .50257 L
.63953 .5068 L
.66935 .51198 L
.70107 .5187 L
.73161 .52649 L
.76098 .5353 L
.79226 .54619 L
.82235 .55833 L
.85435 .57319 L
.88517 .58972 L
.89926 .59569 L
.90728 .59875 L
.91121 .60025 L
.91482 .60162 L
.91668 .60233 L
.9184 .60299 L
.91927 .60332 L
.92021 .60131 L
.92074 .59956 L
.92124 .5979 L
.92218 .5948 L
.93011 .5686 L
.93801 .54254 L
.94233 .52828 L
.94637 .51493 L
Mistroke
.94819 .50892 L
.94909 .50596 L
.94992 .50321 L
.95087 .49095 L
.95138 .48148 L
.95191 .47139 L
.95374 .4371 L
.96185 .28455 L
.97613 .01593 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;_ooool3o`0000?ooooo0ol0000Jooooo`?o00001?ooool2o`0001gooooo0ol0000Noooo
o`;o00008Oooool3o`0001gooooo0ol00004ooooo`;o00006_ooool3o`0000?ooooo0ol0000Ioooo
o`00;oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`00
000Looooo`04o`000?ooooooooooo`0001oooooo00Go0000ooooooooooooooooo`00000Mooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool05_ooool002Oooooo1Ol00003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Eooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`04o`000?oooooo
ooooo`0002?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`00;ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo
00008oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo000_ooooo`04
o`000?ooooooooooooooo`Co00006oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0001_ooooo1?l0000Mooooo`04o`000?ooooooooooo`0001oooooo1?l0000Nooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00006_ooool01?l0003oooooooooooooool4o`0001Wo
oooo000^ooooo`;o00000oooool00ol0003oooooooooo`0Kooooo`;o00001?ooool01?l0003ooooo
ooooool0000Kooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00007oooool00ol0
003oooooooooo`0Nooooo`;o00001?ooool01?l0003oooooooooool0000Iooooo`;o00000oooool0
0ol0003oooooooooo`0Jooooo`00;oooool01?l0003oooooooooooooool5o`0001[ooooo00?o0000
ooooooooool00oooool2o`0001cooooo1Ol0000Mooooo`;o00008?ooool5o`0001gooooo00?o0000
ooooooooool00oooool2o`0001_ooooo00Co0000oooooooooooooooo1Ol0000Hooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`007_oooooho`0000[ooooo000N
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000[ooooo
000Nooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0007Wooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo1Ol00003ooooo`04o`000?oooooo
ooooooooo`Go00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01?oooooho`0000[ooooo000<ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool000[ooooo0ol00009ooooo`?o00001Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000
1Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
0oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001_ooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?oo
ool000Wooooo1Ol00003ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
00_ooooo00?o0000ooooooooool01oooool5o`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`003?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00
00Gooooo0_l00006ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`04ooooo`;o00002_ooool000Wooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`002Oooool01Ol0003ooooooooooooooooo000000Wooooo0_l00005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool000[ooooo0ol0000;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o
00001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool01Oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo0_l00007
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Oooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool000Wooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oo
oooooooo00Kooooo1?l00005ooooo`;o00002?ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01_ooool2o`0000[ooooo0009ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`002_ooool3
o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool01oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000:ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`07ooooo`;o00002_ooool001kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool01Ol0003o
oooooooooooooooo000000Cooooo0_l0000;ooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`08ooooo`;o00002_ooool000cooooo00?o0000oooooooo
ool01oooool3o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`00
2Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo000:ooooo`?o00002Oooool3o`0000Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Roooooa?o0000I_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Doooool?o`0000Wooooo00?o0000ooooooooool01oooool>o`0005Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo04gooooo1_l0000Hooooo`03o`000?oooooooooo01Gooooo2?l0001@ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`16ooooo`Oo00007_ooool00ol0003oooooooooo`0Mooooo`So0000Aooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00002oooool0
0ol0003oooooooooo`10ooooo`Ko00009Oooool00ol0003oooooooooo`0Uooooo`Go0000@_ooool0
0ol0003oooooooooo`09ooooo`;o00002_ooool001kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0looooo`Co0000:oooool00ol0003oooooooooo`0Zooooo`Co0000?_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0=oooool4o`0002oooooo00?o0000ooooooooool0;_ooool4o`0003[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo03?ooooo1?l0000cooooo`03o`000?oooooooooo03;ooooo
1?l0000eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0_ooooo`Co0000=oooool00ol0003ooooooooo
o`0fooooo`Co0000<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;?ooool3o`0003_ooooo00?o0000
ooooooooool0>_ooool3o`0002kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0000noooo
o`03o`000?oooooooooo03gooooo0ol0000[ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`?o
0000@Oooool00ol0003oooooooooo`10ooooo`?o00009oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
8oooool3o`0004Cooooo00?o0000ooooooooool0@oooool3o`0002Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000cooooo00?o0000ooooooooool08Ooo
ool2o`0004Oooooo00?o0000ooooooooool0A_ooool2o`0002;ooooo00?o0000ooooooooool02ooo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07_ooool3
o`0004Wooooo00?o0000ooooooooool0B?ooool3o`0001kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01cooooo0_l0001<ooooo`03o`000?oooooooooo04_ooooo0_l0000Looooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Jooooo`;o0000C_ooool00ol0003oooooooooo`1=ooooo`;o00006_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool05_ooool3o`00053ooooo00?o0000ooooooooool0Coooool3o`0001Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01?ooooo0ol0001Cooooo`03o`000?oooooooooo05;ooooo0ol0
000Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`;o0000E_ooool00ol0003oooooooooo`1E
ooooo`;o00004Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool2o`0005Sooooo00?o0000oooo
ooooool0Eoooool2o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08oooo
o`007_ooool2o`0000oooooo00?o0000ooooooooool02oooool2o`0005[ooooo00?o0000oooooooo
ool0FOooool2o`0000cooooo00?o0000ooooooooool03_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02?ooool2o`0005cooooo00?o0000ooooooooool0
Foooool2o`0000[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo0_l0001Nooooo`03o`000?oo
oooooooo05gooooo0_l00008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`02o`00067ooooo00?o0000ooooooooool0H?ooool2o`0000Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`08ooooo`005_ooool3o`0000Gooooo00?o0000oooooooo
ool04oooool2o`0006?ooooo00?o0000ooooooooool0H_ooool4o`0001?ooooo00?o0000oooooooo
ool02?ooool001Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Tooooo`;o00004oooool00ol0003o
ooooooooo`08ooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo0_l0
0002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_l0000:ooooo`006Oooool0
0ol0003oooooooooo`02ooooooSo00002_ooool001Gooooo00Go0000ooooooooooooooooo`00003o
ooooo`Oooooo000Fooooo`?o0000ooooool8ooooo`00oooooolQooooo`00c?ooool3o`00057ooooo
003=ooooo`03o`000?oooooooooo053ooooo001Qooooo`03o`000?oooooo000000?ooooo1?l00003
ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`?o00000oooool3o`0000Cooooo0ol00002
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l0
0002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000
ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000
ooooool000000oooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00001@ooooo`00H?ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo0ol00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000053ooooo001Pooooo`05
o`000?oooooo0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`?o00000oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00;ooooo1?l00002ooooo`Co00002_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003
ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_oo
ool2o`000003ooooool0003o000004oooooo001Pooooo`05o`000?oooooo0000ooooool000005?oo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo001Pooooo`Ko00004_oo
ool5o`0001Cooooo00?o0000ooooooooool02?ooool5o`0000Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-21.8857, 1.99908, 0.142131, \
0.00612997}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 0.0147151 0.0116083 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1308 -12 -4.5 ]
[-0.0125 .1308 0 4.5 ]
[-0.0125 .24688 -12 -4.5 ]
[-0.0125 .24688 0 4.5 ]
[-0.0125 .36296 -12 -4.5 ]
[-0.0125 .36296 0 4.5 ]
[-0.0125 .47905 -12 -4.5 ]
[-0.0125 .47905 0 4.5 ]
[-0.0125 .59513 -12 -4.5 ]
[-0.0125 .59513 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1308 m
.00625 .1308 L
s
[(10)] -0.0125 .1308 1 0 Mshowa
0 .24688 m
.00625 .24688 L
s
[(20)] -0.0125 .24688 1 0 Mshowa
0 .36296 m
.00625 .36296 L
s
[(30)] -0.0125 .36296 1 0 Mshowa
0 .47905 m
.00625 .47905 L
s
[(40)] -0.0125 .47905 1 0 Mshowa
0 .59513 m
.00625 .59513 L
s
[(50)] -0.0125 .59513 1 0 Mshowa
.125 Mabswid
0 .03793 m
.00375 .03793 L
s
0 .06115 m
.00375 .06115 L
s
0 .08437 m
.00375 .08437 L
s
0 .10758 m
.00375 .10758 L
s
0 .15402 m
.00375 .15402 L
s
0 .17723 m
.00375 .17723 L
s
0 .20045 m
.00375 .20045 L
s
0 .22367 m
.00375 .22367 L
s
0 .2701 m
.00375 .2701 L
s
0 .29331 m
.00375 .29331 L
s
0 .31653 m
.00375 .31653 L
s
0 .33975 m
.00375 .33975 L
s
0 .38618 m
.00375 .38618 L
s
0 .4094 m
.00375 .4094 L
s
0 .43261 m
.00375 .43261 L
s
0 .45583 m
.00375 .45583 L
s
0 .50226 m
.00375 .50226 L
s
0 .52548 m
.00375 .52548 L
s
0 .5487 m
.00375 .5487 L
s
0 .57191 m
.00375 .57191 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1308 m
1 .1308 L
s
.99375 .24688 m
1 .24688 L
s
.99375 .36296 m
1 .36296 L
s
.99375 .47905 m
1 .47905 L
s
.99375 .59513 m
1 .59513 L
s
.125 Mabswid
.99625 .03793 m
1 .03793 L
s
.99625 .06115 m
1 .06115 L
s
.99625 .08437 m
1 .08437 L
s
.99625 .10758 m
1 .10758 L
s
.99625 .15402 m
1 .15402 L
s
.99625 .17723 m
1 .17723 L
s
.99625 .20045 m
1 .20045 L
s
.99625 .22367 m
1 .22367 L
s
.99625 .2701 m
1 .2701 L
s
.99625 .29331 m
1 .29331 L
s
.99625 .31653 m
1 .31653 L
s
.99625 .33975 m
1 .33975 L
s
.99625 .38618 m
1 .38618 L
s
.99625 .4094 m
1 .4094 L
s
.99625 .43261 m
1 .43261 L
s
.99625 .45583 m
1 .45583 L
s
.99625 .50226 m
1 .50226 L
s
.99625 .52548 m
1 .52548 L
s
.99625 .5487 m
1 .5487 L
s
.99625 .57191 m
1 .57191 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94697 .58474 Mdot
.91743 .55331 Mdot
.88759 .51189 Mdot
.85748 .46316 Mdot
.82714 .40964 Mdot
.79658 .35362 Mdot
.76584 .29721 Mdot
.73494 .24229 Mdot
.70389 .19055 Mdot
.67272 .14347 Mdot
.64146 .1023 Mdot
.6101 .06811 Mdot
.57869 .04173 Mdot
.54723 .02379 Mdot
.51575 .01472 Mdot
.48425 .01472 Mdot
.45277 .02379 Mdot
.42131 .04173 Mdot
.3899 .06811 Mdot
.35854 .1023 Mdot
.32728 .14347 Mdot
.29611 .19055 Mdot
.26506 .24229 Mdot
.23416 .29721 Mdot
.20342 .35362 Mdot
.17286 .40964 Mdot
.14252 .46316 Mdot
.11241 .51189 Mdot
.08257 .55331 Mdot
.05303 .58474 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03837 .59406 L
.04579 .58935 L
.04987 .58675 L
.05187 .58548 L
.05372 .58401 L
.05574 .58185 L
.05794 .57952 L
.06178 .57543 L
.06929 .56744 L
.08634 .54808 L
.11681 .50478 L
.1461 .45685 L
.17729 .40153 L
.20731 .34649 L
.23922 .28821 L
.26996 .23412 L
.29953 .18538 L
.331 .13857 L
.36129 .0993 L
.39349 .06509 L
.40964 .05153 L
.42451 .0399 L
.43994 .0311 L
.44748 .02681 L
.45077 .02493 L
.45167 .02442 L
.45251 .02394 L
.45338 .02361 L
.45435 .02333 L
.45623 .02279 L
.45796 .02229 L
.46138 .02131 L
.46892 .01913 L
.47672 .01689 L
.48097 .01566 L
.48203 .01535 L
.48304 .01506 L
.48394 .0148 L
.48492 .01472 L
.48583 .01472 L
.4868 .01472 L
.48762 .01472 L
.48853 .01472 L
.48949 .01472 L
.49003 .01472 L
.49052 .01472 L
.49148 .01472 L
.49238 .01472 L
.49337 .01472 L
Mistroke
.49391 .01472 L
.49441 .01472 L
.49538 .01472 L
.49629 .01472 L
.49681 .01472 L
.49736 .01472 L
.49834 .01472 L
.49888 .01472 L
.49939 .01472 L
.49995 .01472 L
.50055 .01472 L
.50151 .01472 L
.50239 .01472 L
.50337 .01472 L
.50386 .01472 L
.5044 .01472 L
.50531 .01472 L
.50628 .01472 L
.5072 .01472 L
.50805 .01472 L
.50887 .01472 L
.50964 .01472 L
.51048 .01472 L
.51137 .01472 L
.51232 .01472 L
.51321 .01472 L
.51401 .01472 L
.51487 .01472 L
.51583 .01474 L
.51671 .01499 L
.51867 .01556 L
.52222 .01658 L
.53029 .01891 L
.53876 .02135 L
.54248 .02242 L
.54446 .02299 L
.5455 .02329 L
.54659 .0236 L
.54751 .02395 L
.54852 .02452 L
.55028 .02553 L
.55375 .0275 L
.56135 .03184 L
.56976 .03664 L
.57742 .041 L
.58521 .0472 L
.59258 .05339 L
.60879 .06701 L
.63855 .09913 L
.6702 .14015 L
Mistroke
.70068 .1857 L
.72999 .23404 L
.7612 .28895 L
.79123 .34379 L
.82316 .40235 L
.85392 .45688 L
.8835 .50528 L
.91498 .54992 L
.92955 .56621 L
.93721 .57435 L
.94529 .58296 L
.94925 .58619 L
.95358 .58895 L
.96121 .59379 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:oooool3o`0000?ooooo0ol0000Jooooo`?o00001?ooool2o`0001gooooo0ol0000Noooo
o`;o00008Oooool3o`0001gooooo0ol00004ooooo`;o00006_ooool3o`0000?ooooo0ol0000Loooo
o`00;?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`00
000Looooo`04o`000?ooooooooooo`0001oooooo00Go0000ooooooooooooooooo`00000Mooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool06Oooool002Cooooo1Ol00003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Eooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`04o`000?oooooo
ooooo`0002?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`00;?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo
00008oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo000/ooooo`04
o`000?ooooooooooooooo`Co00006oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0001_ooooo1?l0000Mooooo`04o`000?ooooooooooo`0001oooooo1?l0000Nooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00006_ooool01?l0003oooooooooooooool4o`0001co
oooo000[ooooo`;o00000oooool00ol0003oooooooooo`0Kooooo`;o00001?ooool01?l0003ooooo
ooooool0000Kooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00007oooool00ol0
003oooooooooo`0Nooooo`;o00001?ooool01?l0003oooooooooool0000Iooooo`;o00000oooool0
0ol0003oooooooooo`0Mooooo`00;?ooool01?l0003oooooooooooooool5o`0001[ooooo00?o0000
ooooooooool00oooool2o`0001cooooo1Ol0000Mooooo`;o00008?ooool5o`0001gooooo00?o0000
ooooooooool00oooool2o`0001_ooooo00Co0000oooooooooooooooo1Ol0000Kooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006ooooooho`0000gooooo000D
ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000=ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`;o0000MOooool:o`0007Gooooo0_l0000=ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo073ooooo1_l00002ooooo`04o`000?ooooooooooooooo`Ko
0000L_ooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo06cooooo1?l00008ooooo`03o`000?oooooooooo00Oooooo0ol0001_ooooo`03
o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0Joooool3o`0000[ooooo00?o0000ooooooooool02?ooool4o`0006gooooo00?o0000oooooooo
ool02oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool2o`0006[ooooo00?o0000ooooooooool02oooool001_ooooo0_l0001Xooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool2o`0006Oooooo0_l0000=ooooo`006oooool00ol0
003oooooooooo`1Tooooo`?o00004Oooool00ol0003oooooooooo`0@ooooo`?o0000I_ooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Sooooo`?o00004_ooool00ol0003o
ooooooooo`0@ooooo`;o000000?oooooo`000?ooool0I?ooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`;o0000Hooo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`;o0000H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0G_ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo05go
oooo0_l0000Iooooo`03o`000?oooooooooo01Sooooo0_l0001Oooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo05gooooo0_l0000Iooooo`03o`000?oooooooooo01Sooooo
0_l0001Oooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o
0000F_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0F?ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
05Gooooo0_l0000Qooooo`03o`000?oooooooooo023ooooo0_l0001Gooooo`03o`000?oooooooooo
00_ooooo000Kooooo`;o0000E_ooool2o`00027ooooo00?o0000ooooooooool08?ooool2o`0005Ko
oooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool000gooooo0ol00004
ooooo`;o00001Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo000>oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00_ooooo000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00_ooooo000>oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool2o`0005;ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04oooooo0_l0000=
ooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`0;ooooo`003Oooool2o`0000Cooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00_ooooo000>oooo
o`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo04gooooo0ol0000Xoooo
o`03o`000?oooooooooo02Oooooo0_l0001@ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03
o`000?oooooooooo04gooooo0_l0000Yooooo`03o`000?oooooooooo02Oooooo0ol0001?ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
2oooool001_ooooo0_l0001=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1;ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0004[ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool0AOooool3o`00033ooooo00?o0000ooooooooool0;oooool2o`0004Sooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0AOooool2o`00037ooooo00?o0000ooooooooool0
;oooool2o`0004Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0004Kooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Cooooo0_l0000=ooooo`006oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02oooool001_ooooo0_l00013oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11oooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00_ooooo000<ooooo`Go00000ooo
ool2o`0000Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
?_ooool3o`0003Oooooo00?o0000ooooooooool0=oooool2o`00043ooooo00?o0000ooooooooool0
2oooool000kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03kooooo0_l0000hooooo`03o`000?oooooooooo03Oooooo0_l00010ooooo`03o`00
0?oooooooooo00_ooooo000?ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`;o0000?oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0?Oooool2o`0000gooooo000<ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool02oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0003cooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03[ooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02ooo
ool001_ooooo0_l0000iooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0gooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0=_ooool2o`00
043ooooo00?o0000ooooooooool0?oooool2o`0003Sooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool0=_ooool2o`00043ooooo00?o0000ooooooooool0?oooool2o`0003So
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool001_ooooo0_l0000eoooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0doooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00_ooooo000Kooooo`;o0000<_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0<Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0;ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02kooooo0_l00018
ooooo`03o`000?oooooooooo04Kooooo0_l0000aooooo`03o`000?oooooooooo00_ooooo000<oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo02kooooo0_l00018ooooo`03o`000?oooooooooo04Kooooo0_l0000aooooo`03o`000?oo
oooooooo00_ooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool2o`0002oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo02kooooo0_l0000=ooooo`003_ooool2o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo000@ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00_ooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool001_ooooo0_l0000/oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0[oooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00_ooooo000Kooooo`;o0000:?ooool2o`0004oooooo00?o0000ooooooooool0C_ooool2o`0002So
oooo0_l0000=ooooo`006oooool00ol0003oooooooooo`0Wooooo`;o0000Coooool00ol0003ooooo
ooooo`1>ooooo`;o0000:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000
9_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
9?ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02oooool001_ooooo0_l0000Sooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Qooooo`;o00003Oooool001_ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0O
ooooo`?o0000E_ooool00ol0003oooooooooo`1Eooooo`;o00008_ooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0Oooooo`;o0000Eoooool00ol0003oooooooooo`1Eoooo
o`;o00008_ooool00ol0003oooooooooo`0;ooooo`003_ooool3o`0000?ooooo0_l00005ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool000oooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0;ooooo`003?ooool5o`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0001oo
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01go
oooo0_l0000=ooooo`003?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0;ooooo`003_ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo000?ooooo`03o`000?oooooooooo00;o
oooo0_l00005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0001_ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01[ooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo01Sooooo0_l0001Nooooo`03o`000?oooooooooo05cooooo0ol0000Joooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo01Sooooo0_l0001Nooooo`03
o`000?oooooooooo05gooooo0_l0000Jooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0001Oooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Kooooo0_l0000=ooooo`006oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo000K
ooooo`;o00004oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool04_ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo017ooooo0_l0001Uoooo
o`03o`000?oooooooooo06Cooooo0_l0000Cooooo`03o`000?oooooooooo00_ooooo000Kooooo`03
o`000?oooooooooo017ooooo0_l0001Uooooo`03o`000?oooooooooo06Cooooo0_l0000Cooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00003_ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03?ooool2o`00
00gooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo00Wooooo0_l0001]ooooo`03o`000?oooooooooo06_ooooo0_l0
000<ooooo`03o`000?oooooooooo00_ooooo000<ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo1?l0001]ooooo`03o`00
0?oooooooooo06_ooooo1?l0000:ooooo`03o`000?oooooooooo00_ooooo000@ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool0Koooool2o`0000Sooooo00?o0000ooooooooool0
2oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000
1_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
1?ooool2o`0000gooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0001cooooo`03o`000?oooooooooo07;ooooo0_l00005ooooo`03o`00
0?oooooooooo00_ooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`02ooooo`;o0000M?ooool00ol0003oooooooooo`1booooo`;o0000
1Oooool00ol0003oooooooooo`0;ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000=ooooo`006ooo
oooho`0000gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000]ooooo`?o0000
R_ooool00ol0003oooooooooo`0[ooooo`?o00005Oooool00ol0003oooooooooo`0Mooooo`00;_oo
ool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Looooo`00:?ooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5
o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4
o`0000?ooooo0_l00002ooooo`Ko00001_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003
o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3
o`000004ooooool0003o0000ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_oo
ool5o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o0000
0_ooool:o`0000Gooooo00?o0000ooooooooool06oooool002Oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00000<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
0004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooooooo
o`Go00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003oooooooooool0003o
ooooo`0000Gooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003ooooo
o`000002ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go00000oooool01?l0003ooooo
ooooooooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00?o0000ooooooooool0
6oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003o
ooooooooool00005ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003ooooooooo
o`0Kooooo`009oooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo
0ol00004ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`00
0?ooool00ol00004ooooo`Co00000_ooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000000_ooool3o`0000;ooooo1?l00003ooooo`?o00000oooool3o`0000Wooooo00?o0000oooo
ooooool00_ooool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002oooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003oooo
o`?o00000oooool4o`0000Cooooo00?o0000ooooooooool06oooool002Oooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Xooooo`?o00002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool0
0ol0003oooooooooo`02ooooo`;o00002_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2
o`0000Cooooo0_l0000^ooooo`03o`000?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooo
oooo00;ooooo0_l0000;ooooo`03o`000?oooooooooo01gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-21.4593, -5.4815, 0.142131, \
0.34853}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{\(ComponentNumber \[Rule] 2\), ",", \(Energy \[Rule] 100.`\), 
          ",", \(Offset \[Rule] 155.23249973805085`\), ",", 
          RowBox[{"OpticalLengthFunction", "\[Rule]", 
            
            TagBox[\(InterpolatingFunction[{{\(-16.728633726259073`\), 
                    16.728633726259073`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"OpticalPathDifference", "\[Rule]", 
            
            TagBox[\(InterpolatingFunction[{{\(-16.728633726259073`\), 
                    16.728633726259073`}}, "<>"]\),
              False,
              Editable->False]}], 
          ",", \(OpticalPathRange \[Rule] {155.23249973805085`, 
              155.2594749592117`}\), ",", 
          RowBox[{"OutputGraphics", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"OpticalLengthFunction", "\[Rule]", 
                  RowBox[{"(", 
                    
                    TagBox[\(\[SkeletonIndicator]  
                        Graphics  \[SkeletonIndicator]\),
                      False,
                      Editable->False], ")"}]}], ",", 
                RowBox[{"WaveFrontIntensity", "\[Rule]", 
                  RowBox[{"(", 
                    
                    TagBox[\(\[SkeletonIndicator]  
                        Graphics  \[SkeletonIndicator]\),
                      False,
                      Editable->False], ")"}]}], ",", 
                RowBox[{"OpticalPathDifference", "\[Rule]", 
                  RowBox[{"(", 
                    
                    TagBox[\(\[SkeletonIndicator]  
                        Graphics  \[SkeletonIndicator]\),
                      False,
                      Editable->False], ")"}]}]}], "}"}]}], 
          ",", \(RayBoundary \[Rule] {\(-16.728633726259073`\), 
              16.728633726259073`}\), 
          ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
          ",", \(Source \[Rule] 1\), ",", \(SpatialScale \[Rule] 1\), 
          ",", \(SurfaceNumber \[Rule] 1\), ",", \(WaveFrontID \[Rule] 1\), 
          ",", 
          RowBox[{"WaveFrontIntensity", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{\(-20.876444774042767`\), 
                    20.135689522592383`}}, "<>"]\),
              False,
              Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
          ",", \(WaveTilt \[Rule] WaveTilt\)}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here is the same calculation with ",
  StyleBox["RayTracePrecision->50", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["wav = FindWaveFronts[sys,RayTracePrecision->50]", "Input"],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 2, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 2, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 -3387.18 21.8202 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06927 -42 -4.5 ]
[-0.0125 .06927 0 4.5 ]
[-0.0125 .17837 -36 -4.5 ]
[-0.0125 .17837 0 4.5 ]
[-0.0125 .28747 -42 -4.5 ]
[-0.0125 .28747 0 4.5 ]
[-0.0125 .39657 -36 -4.5 ]
[-0.0125 .39657 0 4.5 ]
[-0.0125 .50567 -42 -4.5 ]
[-0.0125 .50567 0 4.5 ]
[-0.0125 .61478 -36 -4.5 ]
[-0.0125 .61478 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06927 m
.00625 .06927 L
s
[(155.235)] -0.0125 .06927 1 0 Mshowa
0 .17837 m
.00625 .17837 L
s
[(155.24)] -0.0125 .17837 1 0 Mshowa
0 .28747 m
.00625 .28747 L
s
[(155.245)] -0.0125 .28747 1 0 Mshowa
0 .39657 m
.00625 .39657 L
s
[(155.25)] -0.0125 .39657 1 0 Mshowa
0 .50567 m
.00625 .50567 L
s
[(155.255)] -0.0125 .50567 1 0 Mshowa
0 .61478 m
.00625 .61478 L
s
[(155.26)] -0.0125 .61478 1 0 Mshowa
.125 Mabswid
0 .09109 m
.00375 .09109 L
s
0 .11291 m
.00375 .11291 L
s
0 .13473 m
.00375 .13473 L
s
0 .15655 m
.00375 .15655 L
s
0 .20019 m
.00375 .20019 L
s
0 .22201 m
.00375 .22201 L
s
0 .24383 m
.00375 .24383 L
s
0 .26565 m
.00375 .26565 L
s
0 .30929 m
.00375 .30929 L
s
0 .33111 m
.00375 .33111 L
s
0 .35293 m
.00375 .35293 L
s
0 .37475 m
.00375 .37475 L
s
0 .41839 m
.00375 .41839 L
s
0 .44021 m
.00375 .44021 L
s
0 .46203 m
.00375 .46203 L
s
0 .48385 m
.00375 .48385 L
s
0 .52749 m
.00375 .52749 L
s
0 .54932 m
.00375 .54932 L
s
0 .57114 m
.00375 .57114 L
s
0 .59296 m
.00375 .59296 L
s
0 .04745 m
.00375 .04745 L
s
0 .02563 m
.00375 .02563 L
s
0 .00381 m
.00375 .00381 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06927 m
1 .06927 L
s
.99375 .17837 m
1 .17837 L
s
.99375 .28747 m
1 .28747 L
s
.99375 .39657 m
1 .39657 L
s
.99375 .50567 m
1 .50567 L
s
.99375 .61478 m
1 .61478 L
s
.125 Mabswid
.99625 .09109 m
1 .09109 L
s
.99625 .11291 m
1 .11291 L
s
.99625 .13473 m
1 .13473 L
s
.99625 .15655 m
1 .15655 L
s
.99625 .20019 m
1 .20019 L
s
.99625 .22201 m
1 .22201 L
s
.99625 .24383 m
1 .24383 L
s
.99625 .26565 m
1 .26565 L
s
.99625 .30929 m
1 .30929 L
s
.99625 .33111 m
1 .33111 L
s
.99625 .35293 m
1 .35293 L
s
.99625 .37475 m
1 .37475 L
s
.99625 .41839 m
1 .41839 L
s
.99625 .44021 m
1 .44021 L
s
.99625 .46203 m
1 .46203 L
s
.99625 .48385 m
1 .48385 L
s
.99625 .52749 m
1 .52749 L
s
.99625 .54932 m
1 .54932 L
s
.99625 .57114 m
1 .57114 L
s
.99625 .59296 m
1 .59296 L
s
.99625 .04745 m
1 .04745 L
s
.99625 .02563 m
1 .02563 L
s
.99625 .00381 m
1 .00381 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06927 m
1 .06927 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94697 .58474 Mdot
.91743 .55331 Mdot
.88759 .51189 Mdot
.85748 .46316 Mdot
.82714 .40964 Mdot
.79658 .35362 Mdot
.76584 .29721 Mdot
.73494 .24229 Mdot
.70389 .19055 Mdot
.67272 .14347 Mdot
.64146 .1023 Mdot
.6101 .06811 Mdot
.57869 .04173 Mdot
.54723 .02379 Mdot
.51575 .01472 Mdot
.48425 .01472 Mdot
.45277 .02379 Mdot
.42131 .04173 Mdot
.3899 .06811 Mdot
.35854 .1023 Mdot
.32728 .14347 Mdot
.29611 .19055 Mdot
.26506 .24229 Mdot
.23416 .29721 Mdot
.20342 .35362 Mdot
.17286 .40964 Mdot
.14252 .46316 Mdot
.11241 .51189 Mdot
.08257 .55331 Mdot
.05303 .58474 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03837 .59406 L
.04579 .58935 L
.04987 .58675 L
.05187 .58548 L
.05372 .58401 L
.05574 .58185 L
.05794 .57952 L
.06178 .57543 L
.06929 .56744 L
.08634 .54808 L
.11681 .50478 L
.1461 .45685 L
.17729 .40153 L
.20731 .34649 L
.23922 .28821 L
.26996 .23412 L
.29953 .18538 L
.331 .13857 L
.36129 .0993 L
.39349 .06509 L
.40964 .05153 L
.42451 .0399 L
.43994 .0311 L
.44748 .02681 L
.45077 .02493 L
.45167 .02442 L
.45251 .02394 L
.45338 .02361 L
.45435 .02333 L
.45623 .02279 L
.45796 .02229 L
.46138 .02131 L
.46892 .01913 L
.47672 .01689 L
.48097 .01566 L
.48203 .01535 L
.48304 .01506 L
.48394 .0148 L
.48492 .01472 L
.48583 .01472 L
.4868 .01472 L
.48853 .01472 L
.49238 .01472 L
.50055 .01472 L
.50803 .01472 L
.51131 .01472 L
.51303 .01472 L
.51398 .01472 L
.51487 .01472 L
Mistroke
.51589 .01476 L
.51682 .01502 L
.51862 .01554 L
.52218 .01657 L
.53003 .01883 L
.53679 .02078 L
.54421 .02292 L
.5461 .02346 L
.54665 .02362 L
.54716 .02377 L
.54813 .0243 L
.55178 .02638 L
.55978 .03094 L
.57409 .0391 L
.60381 .06282 L
.63542 .09572 L
.66586 .13443 L
.69513 .17731 L
.72629 .22788 L
.75628 .28022 L
.78818 .33819 L
.81889 .39452 L
.84844 .44721 L
.87988 .49941 L
.91015 .54321 L
.92559 .562 L
.94232 .57979 L
.95845 .59204 L
.97331 .60149 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00??ooool3o`0000?ooooo0ol0000Jooooo`?o00001?ooool2o`0001co
oooo0ol0000Mooooo`;o00008?ooool3o`0001cooooo0ol00004ooooo`;o00006_ooool3o`0000?o
oooo0ol0000?ooooo`00?Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooo
ooooooooooooo`00000Kooooo`04o`000?ooooooooooo`0001kooooo00Go0000oooooooooooooooo
o`00000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool03?ooool003Gooooo1Ol00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool5o`0000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Dooooo`Go00001Oooool00ol0003oooooooooo`0Ioooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`00?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo01Wooooo00Co
0000oooooooooooo00008_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00co
oooo000mooooo`04o`000?ooooooooooooooo`Co00006oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0001[ooooo1?l0000Looooo`04o`000?ooooooooooo`0001kooooo1?l0000M
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool01?l0003ooooooooo
ooooool4o`0000oooooo000looooo`;o00000oooool00ol0003oooooooooo`0Kooooo`;o00001?oo
ool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo
00007_ooool00ol0003oooooooooo`0Mooooo`;o00001?ooool01?l0003oooooooooool0000Ioooo
o`;o00000oooool00ol0003oooooooooo`0@ooooo`00?Oooool01?l0003oooooooooooooool5o`00
01[ooooo00?o0000ooooooooool00oooool2o`0001_ooooo1Ol0000Looooo`;o00007oooool5o`00
01cooooo00?o0000ooooooooool00oooool2o`0001_ooooo00Co0000oooooooooooooooo1Ol0000>
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00;Oooooob
o`00007ooooo000]ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00001
ooooo`00;Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00kooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo07Kooooo0Ol00001ooooo`00
;Oooool00ol0003oooooooooo`1_ooooo`ko0000LOooool1o`00007ooooo000]ooooo`03o`000?oo
oooooooo06cooooo0ol00002ooooo`;o00000_ooool01?l0003oooooooooooooool2o`0000;ooooo
0ol0001^ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0JOooool3o`0000Wooooo00?o
0000ooooooooool02?ooool2o`0006_ooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1X
ooooo`?o00002_ooool00ol0003oooooooooo`08ooooo`Co0000J_ooool1o`00007ooooo000]oooo
o`03o`000?oooooooooo06Kooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo0_l0001Xoooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0I?ooool2o`0000oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Uooooo`7o00000Oooool002gooooo00?o0000ooooooooool0
H_ooool2o`00017ooooo00?o0000ooooooooool03oooool3o`0006Cooooo0Ol00001ooooo`00;Ooo
ool00ol0003oooooooooo`1Rooooo`;o00004Oooool00ol0003oooooooooo`0@ooooo`;o0000I?oo
ool1o`00007ooooo000]ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Booooo`;o0000HOooool2o`00007ooooo000]ooooo`03o`000?oooooooooo
05oooooo0_l0000Dooooo`03o`000?oooooooooo01Cooooo0_l0001Pooooo`7o00000Oooool002go
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0GOooool1o`00007ooooo00001?oooooo0000o`000?l00003ooooo`?o
00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00000oooool3o`00
00Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0G?ooool1o`00007ooooo0002ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Jooooo`?o00006?ooool00ol0003oooooooooo`0Gooooo`;o0000GOoo
ool1o`00007ooooo0002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02oooooo;o00000Oooool000;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool2o`00
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Jooooo`7o00000Oooool000;o
oooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo0Ol00001
ooooo`0000?oooooo`000?l000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Hooooo`7o00000Oooool000;ooooo00Co0000oooooooooooooooo1Ol0
00000ooooooo0000o`000003o`0000Sooooo0ol00003ooooo`?o00000_ooool5o`0000Cooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0Eoooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Gooooo0_l00001
ooooo`00;Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Eooooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0EOooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05?ooooo0_l0000Pooooo`03o`00
0?oooooooooo01oooooo0_l0001Eooooo`7o00000Oooool002gooooo00?o0000ooooooooool0Dooo
ool2o`00023ooooo00?o0000ooooooooool07oooool2o`0005Gooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1Booooo`7o00000Oooool002gooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0D?ooool2o`00
007ooooo000]ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo057ooooo0Ol00001ooooo`00;Oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1@ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Coooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo04kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<oooo
o`;o00000Oooool002gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0COooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo04_ooooo0ol0000Wooooo`03o`000?oooooooooo02Oooooo0_l0001=ooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool0Boooool2o`0002Sooooo00?o0000ooooooooool09ooo
ool2o`0004gooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1;ooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0BOooool2o`00007ooooo000]ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Wo
oooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`7o00000Oooool000Oooooo0ol0
0003ooooo`?o00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00003ooooo`?o0000
1?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`18ooooo`7o00000Oooool000Sooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Aoooool1o`00007o
oooo0008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0004Sooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`00
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0A_ooool1o`00007ooooo0008ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000So
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0AOooool1o`00007ooooo0007ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`;o00001Oooool00ol0
003oooooooooo`13ooooo`?o0000;oooool00ol0003oooooooooo`0^ooooo`;o0000A_ooool1o`00
007ooooo0008ooooo`04o`000?ooooooooooooooo`Go000000?oooooo`000?l000000ol00008oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo0_l0000`oooo
o`03o`000?oooooooooo02kooooo0_l00016ooooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0@oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04;ooooo0_l00001ooooo`00;Ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`12ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0@_ooool1
o`00007ooooo000]ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo047ooooo0Ol00001ooooo`00;Oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`10ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0?oooool2o`00007ooooo
000]ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0o
ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0?_ooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo03kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0looooo`;o0000
=oooool00ol0003oooooooooo`0fooooo`;o0000?Oooool2o`00007ooooo000]ooooo`03o`000?oo
oooooooo03cooooo0_l0000gooooo`03o`000?oooooooooo03Kooooo0_l0000nooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0??ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
03_ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0kooooo`7o00000Oooool002gooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0>_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Wooooo0_l0
0001ooooo`00;Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0iooooo`7o00000Oooool00004ooooool0003o0000
o`0000?ooooo0ol00003ooooo`?o00001?ooool01?l0003oooooooooooooool5o`0000?ooooo0ol0
0002ooooo`?o00001Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0iooooo`7o00000Oooool000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0hooooo`7o00000Oooool000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
oooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>?ooool1o`00007o
oooo0002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`;o0000=oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0=_ooool2o`00007ooooo0002ooooo`04o`000?ooooooooooooooo`Co
00000_ooool4o`0000Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000
00;ooooo1?l00005ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo03Oooooo0Ol00001ooooo`0000?oooooo`000?l0
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Cooooo0_l0000oooooo`03o`000?oooooooooo03gooooo0_l0000gooooo`7o00000Oooool000;o
oooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`0000Sooooo0ol00005oooo
o`03o`000?oooooooooo00Go00001?ooool00ol0003oooooooooo`0dooooo`;o0000?oooool00ol0
003oooooooooo`0mooooo`;o0000=oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Go
oooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0cooooo`;o00000Oooool002gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0=?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03?ooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0cooooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0<_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo033ooooo0_l00001ooooo`00;Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0aooooo`7o00000Oooool002gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<?ooool1
o`00007ooooo000]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo033ooooo0Ol00001ooooo`00;Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0_ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0;oooool1o`00007ooooo
000]ooooo`03o`000?oooooooooo02gooooo0_l00016ooooo`03o`000?oooooooooo04Cooooo0_l0
000_ooooo`;o00000Oooool002gooooo00?o0000ooooooooool0;Oooool2o`0004Kooooo00?o0000
ooooooooool0A?ooool3o`0002oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0]oooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0;?ooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo02cooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Zooooo`;o00000Ooo
ool002gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0:oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
02[ooooo0Ol00001ooooo`001oooool3o`0000?ooooo0ol00003ooooo`?o00001?ooool01?l0003o
ooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo0Ol00001oooo
o`002?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo02Wooooo0Ol00001ooooo`002?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo0_l0000Yooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Wooooo`;o00000Oooool000Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02Sooooo0Ol00001oooo
o`002?ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00008ooooo`06o`000?oooooooooo
ooooool0003ooooo1?l00005ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Oooooo0Ol00001ooooo`001oooool2
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`07o`000?oooooo
ooooooooool0003oooooo`000008ooooo`03o`000?oooooooooo02Kooooo0_l0001=ooooo`03o`00
0?oooooooooo04cooooo0_l0000Xooooo`7o00000Oooool000Sooooo00Co0000oooooooooooooooo
1Ol000000ooooooo0000o`000003o`0000Sooooo0ol00002ooooo`Go00001?ooool00ol0003ooooo
ooooo`0Vooooo`;o0000COooool00ol0003oooooooooo`1<ooooo`;o0000:?ooool1o`00007ooooo
000]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo02Cooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0U
ooooo`7o00000Oooool002gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool09?ooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo02Cooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool08_ooool1o`00007ooooo000]ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo027ooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Qooooo`7o00000Oooool002go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool08Oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo023ooooo
0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0Pooooo`7o00000Oooool002gooooo00?o0000
ooooooooool07_ooool3o`0005Cooooo00?o0000ooooooooool0Doooool2o`00023ooooo0_l00001
ooooo`00;Oooool00ol0003oooooooooo`0Nooooo`;o0000EOooool00ol0003oooooooooo`1Coooo
o`;o00008Oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01kooooo0Ol00001ooooo`00
;Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`0Mooooo`7o00000Oooool002gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07Ooo
ool1o`00007ooooo000]ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01_ooooo0_l00001ooooo`00;Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`0Looooo`7o00000Oooool002gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool06oooool1o`00007o
oooo00001?oooooo0000o`000?l00003ooooo`?o00000oooool3o`0000Cooooo00Co0000oooooooo
oooooooo1Ol00002ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool06oooool1o`00
007ooooo0002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Jooooo`7o00000Ooo
ool000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool06_ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool06?ooool2o`00
007ooooo0002ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000Sooooo00Ko0000oooo
ooooooooooooo`000?ooool4o`0000;ooooo1?l00005ooooo`03o`000?oooooooooo01Oooooo0_l0
001Looooo`03o`000?oooooooooo05_ooooo0_l0000Iooooo`7o00000Oooool00003ooooool0003o
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`07o`000?oooooo
ooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5oooool2o`0005cooooo00?o0000ooooooooool0Foooool2o`0001Wooooo0Ol00001ooooo`000_oo
ool01?l0003oooooooooooooool5o`000003ooooool0003o000000?o00002?ooool3o`0000;ooooo
1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool05oooool1o`00007ooooo
000]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo01Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0D
ooooo`;o00000Oooool002gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool05Oooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo01Cooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Cooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool04_ooool1o`00007ooooo000]ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo017ooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0@ooooo`;o0000Hoooool00ol0
003oooooooooo`1Rooooo`;o00004_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo013o
oooo0_l0001Sooooo`03o`000?oooooooooo06;ooooo0_l0000Booooo`7o00000Oooool002gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool03oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00oooooo0Ol0
0001ooooo`00;Oooool00ol0003oooooooooo`0<ooooo`;o0000Ioooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00gooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0=oooo
o`7o00000Oooool002gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool03?ooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo00Wooooo0_l0001Zooooo`03o`000?oooooooooo06Sooooo0ol0000;ooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool02Oooool2o`0006[ooooo00?o0000ooooooooool0JOoo
ool3o`0000[ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`07ooooo`;o0000K?ooool0
0ol0003oooooooooo`1/ooooo`;o00002?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo
00Gooooo0_l0001^ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool2o`00
007ooooo000]ooooo`03o`000?oooooooooo00?ooooo0_l0001`ooooo`03o`000?oooooooooo06oo
oooo00?o0000ooooooooool01?ooool1o`00007ooooo0007ooooo`?o00000oooool3o`0000?ooooo
0ol00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000Gooooo00?o0000oooooooo
ool00_ooool2o`00077ooooo00?o0000ooooooooool0L?ooool2o`0000Cooooo0Ol00001ooooo`00
2?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo0_l0001aooooo`03o`000?oooooooooo073ooooo0_l00004
ooooo`7o00000Oooool000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0>ooooo`7o00000Oooool0
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01?l00005ooooo`;o000000?oooooo`000?ooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02o`00007ooooo0008ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`00
00Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000Soooool_l00001ooooo`001oooool2
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`3hooooo`002?ooool01?l0003ooooooooooooo
ool5o`000003ooooool0003o000000?o00002?ooool3o`0000Cooooo0_l0003hooooo`00oooooolQ
ooooo`00=_ooool3o`0005Sooooo0ol0000Gooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool02?ooool003Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool01oooool0037ooooo0ol00003ooooo`?o0000
1?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4o`000003ooooool0003o000000?o0000
1oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Kooooo1Ol00002ooooo`?o0000
0_ooool3o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo1_l00007ooooo`03
o`000?oooooooooo00?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo1?l00003ooooo`?o
00000_ooool5o`0000?ooooo0_l000001?oooooo0000ooooooooool2o`0000?ooooo0ol00009oooo
o`Co000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000Cooooo0_l00003oooo
o`Co000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000o`0000?ooooo0ol0
0005ooooo`03o`000?oooooooooo00Kooooo000`ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00006ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00002oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
0002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool01_ooool0033ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool00oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`Go00001oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`06
o`000?ooooooooooo`000?oooooo00001Oooool5o`0000Cooooo00?o0000ooooooooool01_ooool0
033ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool00000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`06o`000?oooooo
ooooo`000?oooooo00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo000`ooooo`06o`000?ooooooooooooooool0003ooooo1?l0
0002ooooo`Co00000_ooool3o`0000Cooooo0ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Wooooo
00?o0000ooooooooool00oooool3o`0000;ooooo1?l00003ooooo`Wo00000oooool3o`0000Wooooo
00?o0000ooooooooool00oooool2o`0000Cooooo0ol00003ooooo`Co00000_ooool3o`0000Cooooo
00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00009oooo
o`?o00000_ooool3o`0000Cooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00003oooo
o`Co00000oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo000`ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01oooool0037ooooo0ol00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo
00;ooooo0_l0000:ooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o00003Oooool00ol0
003oooooooooo`06ooooo`;o00004?ooool3o`0000[ooooo00?o0000ooooooooool04?ooool2o`00
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Sooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.1051, 155.229, 0.145256, \
0.000189494}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 -1.36833 0.66001 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0837 -18 -4.5 ]
[-0.0125 .0837 0 4.5 ]
[-0.0125 .2157 -18 -4.5 ]
[-0.0125 .2157 0 4.5 ]
[-0.0125 .3477 -18 -4.5 ]
[-0.0125 .3477 0 4.5 ]
[-0.0125 .4797 -18 -4.5 ]
[-0.0125 .4797 0 4.5 ]
[-0.0125 .6117 -6 -4.5 ]
[-0.0125 .6117 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0837 m
.00625 .0837 L
s
[(2.2)] -0.0125 .0837 1 0 Mshowa
0 .2157 m
.00625 .2157 L
s
[(2.4)] -0.0125 .2157 1 0 Mshowa
0 .3477 m
.00625 .3477 L
s
[(2.6)] -0.0125 .3477 1 0 Mshowa
0 .4797 m
.00625 .4797 L
s
[(2.8)] -0.0125 .4797 1 0 Mshowa
0 .6117 m
.00625 .6117 L
s
[(3)] -0.0125 .6117 1 0 Mshowa
.125 Mabswid
0 .1167 m
.00375 .1167 L
s
0 .1497 m
.00375 .1497 L
s
0 .1827 m
.00375 .1827 L
s
0 .2487 m
.00375 .2487 L
s
0 .2817 m
.00375 .2817 L
s
0 .3147 m
.00375 .3147 L
s
0 .3807 m
.00375 .3807 L
s
0 .4137 m
.00375 .4137 L
s
0 .4467 m
.00375 .4467 L
s
0 .5127 m
.00375 .5127 L
s
0 .5457 m
.00375 .5457 L
s
0 .5787 m
.00375 .5787 L
s
0 .0507 m
.00375 .0507 L
s
0 .01769 m
.00375 .01769 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0837 m
1 .0837 L
s
.99375 .2157 m
1 .2157 L
s
.99375 .3477 m
1 .3477 L
s
.99375 .4797 m
1 .4797 L
s
.99375 .6117 m
1 .6117 L
s
.125 Mabswid
.99625 .1167 m
1 .1167 L
s
.99625 .1497 m
1 .1497 L
s
.99625 .1827 m
1 .1827 L
s
.99625 .2487 m
1 .2487 L
s
.99625 .2817 m
1 .2817 L
s
.99625 .3147 m
1 .3147 L
s
.99625 .3807 m
1 .3807 L
s
.99625 .4137 m
1 .4137 L
s
.99625 .4467 m
1 .4467 L
s
.99625 .5127 m
1 .5127 L
s
.99625 .5457 m
1 .5457 L
s
.99625 .5787 m
1 .5787 L
s
.99625 .0507 m
1 .0507 L
s
.99625 .01769 m
1 .01769 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .0837 m
1 .0837 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .03562 m
.03837 .29638 L
.05372 .49288 L
.05761 .54273 L
.05815 .54961 L
.05874 .55708 L
.05929 .56414 L
.0598 .56548 L
.06076 .56665 L
.06178 .5679 L
.06929 .57704 L
.0775 .58705 L
.08203 .59257 L
.08634 .59782 L
.08817 .60004 L
.08917 .60127 L
.09012 .60234 L
.09066 .60206 L
.09124 .60175 L
.09225 .60122 L
.09424 .60019 L
.10146 .59643 L
.11563 .58905 L
.14738 .57247 L
.17795 .5583 L
.20735 .54646 L
.23864 .53551 L
.26876 .5265 L
.30079 .51836 L
.33163 .51186 L
.36131 .50676 L
.39288 .50239 L
.40856 .50074 L
.42328 .49936 L
.43735 .49835 L
.45251 .49743 L
.45609 .49721 L
.45704 .49715 L
.45806 .49709 L
.45903 .49704 L
.45992 .49702 L
.46212 .49696 L
.46412 .4969 L
.46802 .4968 L
.47646 .49656 L
.48059 .49645 L
.48436 .49635 L
.48608 .4963 L
.48795 .49625 L
.48881 .49623 L
Mistroke
.48972 .49621 L
.49058 .49621 L
.49136 .49622 L
.49888 .49626 L
.50721 .4963 L
.51086 .49632 L
.51486 .49634 L
.51668 .49635 L
.51768 .49636 L
.51862 .49636 L
.5195 .49637 L
.52046 .49638 L
.52133 .49641 L
.52213 .49645 L
.52979 .49674 L
.53812 .49705 L
.54592 .49735 L
.54932 .49748 L
.55015 .49751 L
.55103 .49755 L
.552 .49762 L
.5529 .49768 L
.55681 .49796 L
.5604 .49822 L
.57636 .49936 L
.60853 .50257 L
.63953 .5068 L
.66935 .51198 L
.70107 .5187 L
.73161 .52649 L
.76098 .5353 L
.79226 .54619 L
.82235 .55833 L
.85435 .57319 L
.88517 .58972 L
.89926 .59569 L
.90728 .59875 L
.91121 .60025 L
.91482 .60162 L
.91668 .60233 L
.9184 .60299 L
.91927 .60332 L
.92021 .60131 L
.92074 .59956 L
.92124 .5979 L
.92218 .5948 L
.93011 .5686 L
.93801 .54254 L
.94233 .52828 L
.94637 .51493 L
Mistroke
.94819 .50892 L
.94909 .50596 L
.94992 .50321 L
.95087 .49095 L
.95138 .48148 L
.95191 .47139 L
.95374 .4371 L
.96185 .28455 L
.97613 .01593 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;_ooool3o`0000?ooooo0ol0000Jooooo`?o00001?ooool2o`0001gooooo0ol0000Noooo
o`;o00008Oooool3o`0001gooooo0ol00004ooooo`;o00006_ooool3o`0000?ooooo0ol0000Ioooo
o`00;oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`00
000Looooo`04o`000?ooooooooooo`0001oooooo00Go0000ooooooooooooooooo`00000Mooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool05_ooool002Oooooo1Ol00003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Eooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`04o`000?oooooo
ooooo`0002?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`00;ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo
00008oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo000_ooooo`04
o`000?ooooooooooooooo`Co00006oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0001_ooooo1?l0000Mooooo`04o`000?ooooooooooo`0001oooooo1?l0000Nooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00006_ooool01?l0003oooooooooooooool4o`0001Wo
oooo000^ooooo`;o00000oooool00ol0003oooooooooo`0Kooooo`;o00001?ooool01?l0003ooooo
ooooool0000Kooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00007oooool00ol0
003oooooooooo`0Nooooo`;o00001?ooool01?l0003oooooooooool0000Iooooo`;o00000oooool0
0ol0003oooooooooo`0Jooooo`00;oooool01?l0003oooooooooooooool5o`0001[ooooo00?o0000
ooooooooool00oooool2o`0001cooooo1Ol0000Mooooo`;o00008?ooool5o`0001gooooo00?o0000
ooooooooool00oooool2o`0001_ooooo00Co0000oooooooooooooooo1Ol0000Hooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`007_oooooho`0000[ooooo000N
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000[ooooo
000Nooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0007Wooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo1Ol00003ooooo`04o`000?oooooo
ooooooooo`Go00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01?oooooho`0000[ooooo000<ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool000[ooooo0ol00009ooooo`?o00001Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000
1Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
0oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001_ooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?oo
ool000Wooooo1Ol00003ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
00_ooooo00?o0000ooooooooool01oooool5o`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`003?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00
00Gooooo0_l00006ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`04ooooo`;o00002_ooool000Wooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`002Oooool01Ol0003ooooooooooooooooo000000Wooooo0_l00005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool000[ooooo0ol0000;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o
00001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool01Oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo0_l00007
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Oooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool000Wooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oo
oooooooo00Kooooo1?l00005ooooo`;o00002?ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01_ooool2o`0000[ooooo0009ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`002_ooool3
o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool01oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000:ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`07ooooo`;o00002_ooool001kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool01Ol0003o
oooooooooooooooo000000Cooooo0_l0000;ooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`08ooooo`;o00002_ooool000cooooo00?o0000oooooooo
ool01oooool3o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`00
2Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo000:ooooo`?o00002Oooool3o`0000Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Roooooa?o0000I_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Doooool?o`0000Wooooo00?o0000ooooooooool01oooool>o`0005Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo04gooooo1_l0000Hooooo`03o`000?oooooooooo01Gooooo2?l0001@ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`16ooooo`Oo00007_ooool00ol0003oooooooooo`0Mooooo`So0000Aooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00002oooool0
0ol0003oooooooooo`10ooooo`Ko00009Oooool00ol0003oooooooooo`0Uooooo`Go0000@_ooool0
0ol0003oooooooooo`09ooooo`;o00002_ooool001kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0looooo`Co0000:oooool00ol0003oooooooooo`0Zooooo`Co0000?_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0=oooool4o`0002oooooo00?o0000ooooooooool0;_ooool4o`0003[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo03?ooooo1?l0000cooooo`03o`000?oooooooooo03;ooooo
1?l0000eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0_ooooo`Co0000=oooool00ol0003ooooooooo
o`0fooooo`Co0000<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;?ooool3o`0003_ooooo00?o0000
ooooooooool0>_ooool3o`0002kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0000noooo
o`03o`000?oooooooooo03gooooo0ol0000[ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`?o
0000@Oooool00ol0003oooooooooo`10ooooo`?o00009oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
8oooool3o`0004Cooooo00?o0000ooooooooool0@oooool3o`0002Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000cooooo00?o0000ooooooooool08Ooo
ool2o`0004Oooooo00?o0000ooooooooool0A_ooool2o`0002;ooooo00?o0000ooooooooool02ooo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07_ooool3
o`0004Wooooo00?o0000ooooooooool0B?ooool3o`0001kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01cooooo0_l0001<ooooo`03o`000?oooooooooo04_ooooo0_l0000Looooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Jooooo`;o0000C_ooool00ol0003oooooooooo`1=ooooo`;o00006_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool05_ooool3o`00053ooooo00?o0000ooooooooool0Coooool3o`0001Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01?ooooo0ol0001Cooooo`03o`000?oooooooooo05;ooooo0ol0
000Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`;o0000E_ooool00ol0003oooooooooo`1E
ooooo`;o00004Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool2o`0005Sooooo00?o0000oooo
ooooool0Eoooool2o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08oooo
o`007_ooool2o`0000oooooo00?o0000ooooooooool02oooool2o`0005[ooooo00?o0000oooooooo
ool0FOooool2o`0000cooooo00?o0000ooooooooool03_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02?ooool2o`0005cooooo00?o0000ooooooooool0
Foooool2o`0000[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo0_l0001Nooooo`03o`000?oo
oooooooo05gooooo0_l00008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`02o`00067ooooo00?o0000ooooooooool0H?ooool2o`0000Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`08ooooo`005_ooool3o`0000Gooooo00?o0000oooooooo
ool04oooool2o`0006?ooooo00?o0000ooooooooool0H_ooool4o`0001?ooooo00?o0000oooooooo
ool02?ooool001Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Tooooo`;o00004oooool00ol0003o
ooooooooo`08ooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo0_l0
0002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_l0000:ooooo`006Oooool0
0ol0003oooooooooo`02ooooooSo00002_ooool001Gooooo00Go0000ooooooooooooooooo`00003o
ooooo`Oooooo000Fooooo`?o0000ooooool8ooooo`00oooooolQooooo`00c?ooool3o`00057ooooo
003=ooooo`03o`000?oooooooooo053ooooo001Qooooo`03o`000?oooooo000000?ooooo1?l00003
ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`?o00000oooool3o`0000Cooooo0ol00002
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l0
0002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000
ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000
ooooool000000oooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00001@ooooo`00H?ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo0ol00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000053ooooo001Pooooo`05
o`000?oooooo0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`?o00000oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00;ooooo1?l00002ooooo`Co00002_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003
ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_oo
ool2o`000003ooooool0003o000004oooooo001Pooooo`05o`000?oooooo0000ooooool000005?oo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo001Pooooo`Ko00004_oo
ool5o`0001Cooooo00?o0000ooooooooool02?ooool5o`0000Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-21.8857, 1.99908, 0.142131, \
0.00612997}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 0.0147151 0.0116083 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1308 -12 -4.5 ]
[-0.0125 .1308 0 4.5 ]
[-0.0125 .24688 -12 -4.5 ]
[-0.0125 .24688 0 4.5 ]
[-0.0125 .36296 -12 -4.5 ]
[-0.0125 .36296 0 4.5 ]
[-0.0125 .47905 -12 -4.5 ]
[-0.0125 .47905 0 4.5 ]
[-0.0125 .59513 -12 -4.5 ]
[-0.0125 .59513 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1308 m
.00625 .1308 L
s
[(10)] -0.0125 .1308 1 0 Mshowa
0 .24688 m
.00625 .24688 L
s
[(20)] -0.0125 .24688 1 0 Mshowa
0 .36296 m
.00625 .36296 L
s
[(30)] -0.0125 .36296 1 0 Mshowa
0 .47905 m
.00625 .47905 L
s
[(40)] -0.0125 .47905 1 0 Mshowa
0 .59513 m
.00625 .59513 L
s
[(50)] -0.0125 .59513 1 0 Mshowa
.125 Mabswid
0 .03793 m
.00375 .03793 L
s
0 .06115 m
.00375 .06115 L
s
0 .08437 m
.00375 .08437 L
s
0 .10758 m
.00375 .10758 L
s
0 .15402 m
.00375 .15402 L
s
0 .17723 m
.00375 .17723 L
s
0 .20045 m
.00375 .20045 L
s
0 .22367 m
.00375 .22367 L
s
0 .2701 m
.00375 .2701 L
s
0 .29331 m
.00375 .29331 L
s
0 .31653 m
.00375 .31653 L
s
0 .33975 m
.00375 .33975 L
s
0 .38618 m
.00375 .38618 L
s
0 .4094 m
.00375 .4094 L
s
0 .43261 m
.00375 .43261 L
s
0 .45583 m
.00375 .45583 L
s
0 .50226 m
.00375 .50226 L
s
0 .52548 m
.00375 .52548 L
s
0 .5487 m
.00375 .5487 L
s
0 .57191 m
.00375 .57191 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1308 m
1 .1308 L
s
.99375 .24688 m
1 .24688 L
s
.99375 .36296 m
1 .36296 L
s
.99375 .47905 m
1 .47905 L
s
.99375 .59513 m
1 .59513 L
s
.125 Mabswid
.99625 .03793 m
1 .03793 L
s
.99625 .06115 m
1 .06115 L
s
.99625 .08437 m
1 .08437 L
s
.99625 .10758 m
1 .10758 L
s
.99625 .15402 m
1 .15402 L
s
.99625 .17723 m
1 .17723 L
s
.99625 .20045 m
1 .20045 L
s
.99625 .22367 m
1 .22367 L
s
.99625 .2701 m
1 .2701 L
s
.99625 .29331 m
1 .29331 L
s
.99625 .31653 m
1 .31653 L
s
.99625 .33975 m
1 .33975 L
s
.99625 .38618 m
1 .38618 L
s
.99625 .4094 m
1 .4094 L
s
.99625 .43261 m
1 .43261 L
s
.99625 .45583 m
1 .45583 L
s
.99625 .50226 m
1 .50226 L
s
.99625 .52548 m
1 .52548 L
s
.99625 .5487 m
1 .5487 L
s
.99625 .57191 m
1 .57191 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94697 .58474 Mdot
.91743 .55331 Mdot
.88759 .51189 Mdot
.85748 .46316 Mdot
.82714 .40964 Mdot
.79658 .35362 Mdot
.76584 .29721 Mdot
.73494 .24229 Mdot
.70389 .19055 Mdot
.67272 .14347 Mdot
.64146 .1023 Mdot
.6101 .06811 Mdot
.57869 .04173 Mdot
.54723 .02379 Mdot
.51575 .01472 Mdot
.48425 .01472 Mdot
.45277 .02379 Mdot
.42131 .04173 Mdot
.3899 .06811 Mdot
.35854 .1023 Mdot
.32728 .14347 Mdot
.29611 .19055 Mdot
.26506 .24229 Mdot
.23416 .29721 Mdot
.20342 .35362 Mdot
.17286 .40964 Mdot
.14252 .46316 Mdot
.11241 .51189 Mdot
.08257 .55331 Mdot
.05303 .58474 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03837 .59406 L
.04579 .58935 L
.04987 .58675 L
.05187 .58548 L
.05372 .58401 L
.05574 .58185 L
.05794 .57952 L
.06178 .57543 L
.06929 .56744 L
.08634 .54808 L
.11681 .50478 L
.1461 .45685 L
.17729 .40153 L
.20731 .34649 L
.23922 .28821 L
.26996 .23412 L
.29953 .18538 L
.331 .13857 L
.36129 .0993 L
.39349 .06509 L
.40964 .05153 L
.42451 .0399 L
.43994 .0311 L
.44748 .02681 L
.45077 .02493 L
.45167 .02442 L
.45251 .02394 L
.45338 .02361 L
.45435 .02333 L
.45623 .02279 L
.45796 .02229 L
.46138 .02131 L
.46892 .01913 L
.47672 .01689 L
.48097 .01566 L
.48203 .01535 L
.48304 .01506 L
.48394 .0148 L
.48492 .01472 L
.48583 .01472 L
.4868 .01472 L
.48762 .01472 L
.48853 .01472 L
.48949 .01472 L
.49003 .01472 L
.49052 .01472 L
.49148 .01472 L
.49238 .01472 L
.49337 .01472 L
Mistroke
.49391 .01472 L
.49441 .01472 L
.49538 .01472 L
.49629 .01472 L
.49681 .01472 L
.49736 .01472 L
.49834 .01472 L
.49888 .01472 L
.49939 .01472 L
.49995 .01472 L
.50055 .01472 L
.50151 .01472 L
.50239 .01472 L
.50337 .01472 L
.50386 .01472 L
.5044 .01472 L
.50531 .01472 L
.50628 .01472 L
.5072 .01472 L
.50805 .01472 L
.50887 .01472 L
.50964 .01472 L
.51048 .01472 L
.51137 .01472 L
.51232 .01472 L
.51321 .01472 L
.51401 .01472 L
.51487 .01472 L
.51583 .01474 L
.51671 .01499 L
.51867 .01556 L
.52222 .01658 L
.53029 .01891 L
.53876 .02135 L
.54248 .02242 L
.54446 .02299 L
.5455 .02329 L
.54659 .0236 L
.54751 .02395 L
.54852 .02452 L
.55028 .02553 L
.55375 .0275 L
.56135 .03184 L
.56976 .03664 L
.57742 .041 L
.58521 .0472 L
.59258 .05339 L
.60879 .06701 L
.63855 .09913 L
.6702 .14015 L
Mistroke
.70068 .1857 L
.72999 .23404 L
.7612 .28895 L
.79123 .34379 L
.82316 .40235 L
.85392 .45688 L
.8835 .50528 L
.91498 .54992 L
.92955 .56621 L
.93721 .57435 L
.94529 .58296 L
.94925 .58619 L
.95358 .58895 L
.96121 .59379 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:oooool3o`0000?ooooo0ol0000Jooooo`?o00001?ooool2o`0001gooooo0ol0000Noooo
o`;o00008Oooool3o`0001gooooo0ol00004ooooo`;o00006_ooool3o`0000?ooooo0ol0000Loooo
o`00;?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`00
000Looooo`04o`000?ooooooooooo`0001oooooo00Go0000ooooooooooooooooo`00000Mooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool06Oooool002Cooooo1Ol00003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Eooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`04o`000?oooooo
ooooo`0002?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`00;?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo
00008oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo000/ooooo`04
o`000?ooooooooooooooo`Co00006oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0001_ooooo1?l0000Mooooo`04o`000?ooooooooooo`0001oooooo1?l0000Nooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00006_ooool01?l0003oooooooooooooool4o`0001co
oooo000[ooooo`;o00000oooool00ol0003oooooooooo`0Kooooo`;o00001?ooool01?l0003ooooo
ooooool0000Kooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00007oooool00ol0
003oooooooooo`0Nooooo`;o00001?ooool01?l0003oooooooooool0000Iooooo`;o00000oooool0
0ol0003oooooooooo`0Mooooo`00;?ooool01?l0003oooooooooooooool5o`0001[ooooo00?o0000
ooooooooool00oooool2o`0001cooooo1Ol0000Mooooo`;o00008?ooool5o`0001gooooo00?o0000
ooooooooool00oooool2o`0001_ooooo00Co0000oooooooooooooooo1Ol0000Kooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006ooooooho`0000gooooo000D
ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000=ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`;o0000MOooool:o`0007Gooooo0_l0000=ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo073ooooo1_l00002ooooo`04o`000?ooooooooooooooo`Ko
0000L_ooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo06cooooo1?l00008ooooo`03o`000?oooooooooo00Oooooo0ol0001_ooooo`03
o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0Joooool3o`0000[ooooo00?o0000ooooooooool02?ooool4o`0006gooooo00?o0000oooooooo
ool02oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool2o`0006[ooooo00?o0000ooooooooool02oooool001_ooooo0_l0001Xooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool2o`0006Oooooo0_l0000=ooooo`006oooool00ol0
003oooooooooo`1Tooooo`?o00004Oooool00ol0003oooooooooo`0@ooooo`?o0000I_ooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Sooooo`?o00004_ooool00ol0003o
ooooooooo`0@ooooo`;o000000?oooooo`000?ooool0I?ooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`;o0000Hooo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`;o0000H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0G_ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo05go
oooo0_l0000Iooooo`03o`000?oooooooooo01Sooooo0_l0001Oooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo05gooooo0_l0000Iooooo`03o`000?oooooooooo01Sooooo
0_l0001Oooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o
0000F_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0F?ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
05Gooooo0_l0000Qooooo`03o`000?oooooooooo023ooooo0_l0001Gooooo`03o`000?oooooooooo
00_ooooo000Kooooo`;o0000E_ooool2o`00027ooooo00?o0000ooooooooool08?ooool2o`0005Ko
oooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool000gooooo0ol00004
ooooo`;o00001Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo000>oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00_ooooo000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00_ooooo000>oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool2o`0005;ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04oooooo0_l0000=
ooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`0;ooooo`003Oooool2o`0000Cooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00_ooooo000>oooo
o`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo04gooooo0ol0000Xoooo
o`03o`000?oooooooooo02Oooooo0_l0001@ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03
o`000?oooooooooo04gooooo0_l0000Yooooo`03o`000?oooooooooo02Oooooo0ol0001?ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
2oooool001_ooooo0_l0001=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1;ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0004[ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool0AOooool3o`00033ooooo00?o0000ooooooooool0;oooool2o`0004Sooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0AOooool2o`00037ooooo00?o0000ooooooooool0
;oooool2o`0004Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0004Kooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Cooooo0_l0000=ooooo`006oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02oooool001_ooooo0_l00013oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11oooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00_ooooo000<ooooo`Go00000ooo
ool2o`0000Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
?_ooool3o`0003Oooooo00?o0000ooooooooool0=oooool2o`00043ooooo00?o0000ooooooooool0
2oooool000kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03kooooo0_l0000hooooo`03o`000?oooooooooo03Oooooo0_l00010ooooo`03o`00
0?oooooooooo00_ooooo000?ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`;o0000?oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0?Oooool2o`0000gooooo000<ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool02oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0003cooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03[ooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02ooo
ool001_ooooo0_l0000iooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0gooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0=_ooool2o`00
043ooooo00?o0000ooooooooool0?oooool2o`0003Sooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool0=_ooool2o`00043ooooo00?o0000ooooooooool0?oooool2o`0003So
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool001_ooooo0_l0000eoooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0doooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00_ooooo000Kooooo`;o0000<_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0<Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0;ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02kooooo0_l00018
ooooo`03o`000?oooooooooo04Kooooo0_l0000aooooo`03o`000?oooooooooo00_ooooo000<oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo02kooooo0_l00018ooooo`03o`000?oooooooooo04Kooooo0_l0000aooooo`03o`000?oo
oooooooo00_ooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool2o`0002oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo02kooooo0_l0000=ooooo`003_ooool2o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo000@ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00_ooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool001_ooooo0_l0000/oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0[oooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00_ooooo000Kooooo`;o0000:?ooool2o`0004oooooo00?o0000ooooooooool0C_ooool2o`0002So
oooo0_l0000=ooooo`006oooool00ol0003oooooooooo`0Wooooo`;o0000Coooool00ol0003ooooo
ooooo`1>ooooo`;o0000:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000
9_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
9?ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02oooool001_ooooo0_l0000Sooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Qooooo`;o00003Oooool001_ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0O
ooooo`?o0000E_ooool00ol0003oooooooooo`1Eooooo`;o00008_ooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0Oooooo`;o0000Eoooool00ol0003oooooooooo`1Eoooo
o`;o00008_ooool00ol0003oooooooooo`0;ooooo`003_ooool3o`0000?ooooo0_l00005ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool000oooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0;ooooo`003?ooool5o`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0001oo
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01go
oooo0_l0000=ooooo`003?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0;ooooo`003_ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo000?ooooo`03o`000?oooooooooo00;o
oooo0_l00005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0001_ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01[ooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo01Sooooo0_l0001Nooooo`03o`000?oooooooooo05cooooo0ol0000Joooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo01Sooooo0_l0001Nooooo`03
o`000?oooooooooo05gooooo0_l0000Jooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0001Oooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Kooooo0_l0000=ooooo`006oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo000K
ooooo`;o00004oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool04_ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo017ooooo0_l0001Uoooo
o`03o`000?oooooooooo06Cooooo0_l0000Cooooo`03o`000?oooooooooo00_ooooo000Kooooo`03
o`000?oooooooooo017ooooo0_l0001Uooooo`03o`000?oooooooooo06Cooooo0_l0000Cooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00003_ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03?ooool2o`00
00gooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo00Wooooo0_l0001]ooooo`03o`000?oooooooooo06_ooooo0_l0
000<ooooo`03o`000?oooooooooo00_ooooo000<ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo1?l0001]ooooo`03o`00
0?oooooooooo06_ooooo1?l0000:ooooo`03o`000?oooooooooo00_ooooo000@ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool0Koooool2o`0000Sooooo00?o0000ooooooooool0
2oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000
1_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
1?ooool2o`0000gooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0001cooooo`03o`000?oooooooooo07;ooooo0_l00005ooooo`03o`00
0?oooooooooo00_ooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`02ooooo`;o0000M?ooool00ol0003oooooooooo`1booooo`;o0000
1Oooool00ol0003oooooooooo`0;ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000=ooooo`006ooo
oooho`0000gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000]ooooo`?o0000
R_ooool00ol0003oooooooooo`0[ooooo`?o00005Oooool00ol0003oooooooooo`0Mooooo`00;_oo
ool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Looooo`00:?ooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5
o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4
o`0000?ooooo0_l00002ooooo`Ko00001_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003
o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3
o`000004ooooool0003o0000ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_oo
ool5o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o0000
0_ooool:o`0000Gooooo00?o0000ooooooooool06oooool002Oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00000<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
0004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooooooo
o`Go00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003oooooooooool0003o
ooooo`0000Gooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003ooooo
o`000002ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go00000oooool01?l0003ooooo
ooooooooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00?o0000ooooooooool0
6oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003o
ooooooooool00005ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003ooooooooo
o`0Kooooo`009oooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo
0ol00004ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`00
0?ooool00ol00004ooooo`Co00000_ooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000000_ooool3o`0000;ooooo1?l00003ooooo`?o00000oooool3o`0000Wooooo00?o0000oooo
ooooool00_ooool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002oooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003oooo
o`?o00000oooool4o`0000Cooooo00?o0000ooooooooool06oooool002Oooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Xooooo`?o00002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool0
0ol0003oooooooooo`02ooooo`;o00002_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2
o`0000Cooooo0_l0000^ooooo`03o`000?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooo
oooo00;ooooo0_l0000;ooooo`03o`000?oooooooooo01gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-21.4593, -5.4815, 0.142131, \
0.34853}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{\(ComponentNumber \[Rule] 2\), 
          ",", \(Energy \[Rule] 100.`50. \), 
          ",", \(Offset \[Rule] 
            155.232499727024594002667499459903634207016133168371541783173`47.\
94171342391833\), ",", 
          RowBox[{"OpticalLengthFunction", "\[Rule]", 
            
            TagBox[\(InterpolatingFunction[{{\(-16.\
728633720145081219934402865050045527860452786852293190867`42.51444412797383\),\
 16.728633720145081219934402865050045527860452786852293190867`42.\
51444412797383}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"OpticalPathDifference", "\[Rule]", 
            
            TagBox[\(InterpolatingFunction[{{\(-16.\
728633720145081219934402865050045527860452786852293190867`42.06837975365413\),\
 16.728633720145081219934402865050045527860452786852293190867`42.\
06837975365413}}, "<>"]\),
              False,
              Editable->False]}], 
          ",", \(OpticalPathRange \[Rule] \
{155.232499727024594002667499459903634207016133168371541783173`47.\
94171342391833, 
              155.259474947573901666175818636139183393839888978834732853702`\
47.875917318972164}\), ",", 
          RowBox[{"OutputGraphics", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"OpticalLengthFunction", "\[Rule]", 
                  RowBox[{"(", 
                    
                    TagBox[\(\[SkeletonIndicator]  
                        Graphics  \[SkeletonIndicator]\),
                      False,
                      Editable->False], ")"}]}], ",", 
                RowBox[{"WaveFrontIntensity", "\[Rule]", 
                  RowBox[{"(", 
                    
                    TagBox[\(\[SkeletonIndicator]  
                        Graphics  \[SkeletonIndicator]\),
                      False,
                      Editable->False], ")"}]}], ",", 
                RowBox[{"OpticalPathDifference", "\[Rule]", 
                  RowBox[{"(", 
                    
                    TagBox[\(\[SkeletonIndicator]  
                        Graphics  \[SkeletonIndicator]\),
                      False,
                      Editable->False], ")"}]}]}], "}"}]}], 
          ",", \(RayBoundary \[Rule] \
{\(-16.728633720145081219934402865050045527860452786852293190867`44.\
32007016464757\), 
              16.728633720145081219934402865050045527860452786852293190867`44.\
32007016464757}\), ",", \(RayTracePrecision \[Rule] 50\), 
          ",", \(RefractiveIndex \[Rule] 
            1.0002694512365696004467895412063041991436523985939083668628192318\
714`50.30102025365448\), ",", \(Source \[Rule] 1\), 
          ",", \(SpatialScale \[Rule] 1\), ",", \(SurfaceNumber \[Rule] 1\), 
          ",", \(WaveFrontID \[Rule] 1\), ",", 
          RowBox[{"WaveFrontIntensity", "\[Rule]", 
            
            TagBox[\(InterpolatingFunction[{{\(-20.876444766719427`\), 
                    20.13568951492658`}}, "<>"]\),
              False,
              Editable->False]}], 
          ",", \(WaveLength \[Rule] 
            0.5320000000000000000000000000000000000000000000000000000000000000\
155`50. \), ",", \(WaveTilt \[Rule] WaveTilt\)}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(OpticalPathDifference/.wav[[1]])[15]", "Input"],

Cell[BoxData[
    \(47.273225331494707638360887575166965069981638886736478015552`41.\
42436196017378\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindWaveFronts in two dimensions", "SubsubsectionIcon"],

Cell[TextData[{
  "The previous example used a two-dimensional ",
  StyleBox["WedgeOfRays", "Input"],
  " source. Internally, this used an ",
  StyleBox["InterpolatingFunction", "Input"],
  " to model the wavefront behavior. When three-dimensional sources are used \
instead, ",
  StyleBox["FindWaveFronts", "Input"],
  " uses a Zernike-polynomial fit of the wavefront. Here is an optical system \
with the three-dimensional ",
  StyleBox["PointOfRays", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
sys2D = \
{PointOfRays[{15,15}],Move[PlanoConvexLens[100,50,10,CurvatureDirection->Back]\
,90],Move[Screen[{50,50}],150]}\
\>", "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox[
            TagBox[\(PointOfRays[{15, 15}]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            
            TagBox[\(Move[
                PlanoConvexLens[100, 50, 
                  10, {CurvatureDirection \[Rule] Back}], 90.`]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            TagBox[\(Move[Screen[{50, 50}], 150.`]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm]}], "}"}]], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[sys2D];", "Input",
  CellLabel->"In[17]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67912 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0224888 1.02249 -0.150431 1.02249 [
[ 0 0 0 0 ]
[ 1 .67912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .67912 L
0 .67912 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.11741 .4797 m
.53388 .24101 L
s
.11741 .4797 m
.59883 .31716 L
s
.11741 .4797 m
.5351 .3549 L
s
.11741 .4797 m
.60172 .4294 L
s
0 g
.62394 .34325 m
.613 .30737 L
s
.613 .30737 m
.63144 .30143 L
s
.613 .30737 m
.59908 .27326 L
s
.63124 .37875 m
.62394 .34325 L
s
.62394 .34325 m
.64242 .3374 L
s
.59908 .27326 m
.61754 .26723 L
s
.59908 .27326 m
.58301 .24299 L
s
.63144 .30143 m
.64242 .3374 L
s
.61754 .26723 m
.63144 .30143 L
s
.64242 .3374 m
.6498 .37297 L
s
.63124 .37875 m
.6498 .37297 L
s
.60152 .23685 m
.61754 .26723 L
s
.58301 .24299 m
.60152 .23685 L
s
.656 .751 .92 r
.61275 .38687 m .65312 .40599 L .63444 .41172 L F
0 g
.63326 .4401 m
.63444 .41172 L
s
.63124 .37875 m
.63296 .39644 L
s
.656 .751 .92 r
.61275 .38687 m .65099 .37496 L .65312 .40599 L F
0 g
.65209 .43439 m
.65312 .40599 L
s
.6498 .37297 m
.65003 .37526 L
s
.63444 .41172 m
.65312 .40599 L
s
.039 .916 .04 r
.59883 .31716 m
.6365 .30465 L
s
.544 .324 .532 r
.56574 .21847 m .60459 .24413 L .56644 .25675 L F
.56574 .21847 m .58434 .21221 L .60459 .24413 L F
0 g
.58434 .21221 m
.60152 .23685 L
s
.56574 .21847 m
.58434 .21221 L
s
.54831 .20135 m
.56574 .21847 L
s
.039 .916 .04 r
.6365 .30465 m
.92599 .21162 L
s
0 0 0 r
2.5 Mabswid
.6365 .30465 Mdot
0 g
.5 Mabswid
.56705 .19499 m
.58434 .21221 L
s
.62767 .46196 m
.63326 .4401 L
s
.63326 .4401 m
.65209 .43439 L
s
.65209 .43439 m
.64667 .45625 L
s
.656 .751 .92 r
.59057 .36146 m .65099 .37496 L .61275 .38687 L F
0 g
.61275 .38687 m
.63444 .41172 L
s
.544 .324 .532 r
.56644 .25675 m .61677 .2796 L .56716 .29575 L F
.56644 .25675 m .60459 .24413 L .61677 .2796 L F
.039 .916 .04 r
.11741 .4797 m
.56686 .27921 L
s
0 g
.56574 .21847 m
.56644 .25675 L
s
.58434 .21221 m
.60459 .24413 L
s
.54831 .20135 m
.56705 .19499 L
s
.54831 .20135 m
.53185 .19296 L
s
.94767 .19408 m
.97441 .43595 L
s
.82983 .01827 m
.94767 .19408 L
s
.656 .751 .92 r
.59057 .36146 m .64025 .34578 L .65099 .37496 L F
.039 .916 .04 r
.11741 .4797 m
.59998 .37224 L
s
0 g
.65099 .37496 m
.65312 .40599 L
s
.55075 .18651 m
.56705 .19499 L
s
.6179 .47571 m
.62767 .46196 L
s
.62767 .46196 m
.64667 .45625 L
s
.039 .916 .04 r
.56686 .27921 m
.61151 .26112 L
s
0 g
.64667 .45625 m
.63709 .46997 L
s
.656 .751 .92 r
.5679 .33548 m .64025 .34578 L .59057 .36146 L F
.039 .916 .04 r
.59998 .37224 m
.64673 .36043 L
s
0 g
.59057 .36146 m
.61275 .38687 L
s
.039 .916 .04 r
.64673 .36043 m
.93255 .27132 L
s
0 0 0 r
2.5 Mabswid
.64673 .36043 Mdot
.544 .324 .532 r
.56716 .29575 m .62162 .31828 L .5679 .33548 L F
.56716 .29575 m .61677 .2796 L .62162 .31828 L F
0 g
.5 Mabswid
.56644 .25675 m
.56716 .29575 L
s
.60459 .24413 m
.61677 .2796 L
s
.039 .916 .04 r
.61151 .26112 m
.89648 .16699 L
s
0 0 0 r
2.5 Mabswid
.61151 .26112 Mdot
0 g
.5 Mabswid
.53185 .19296 m
.55075 .18651 L
s
.53185 .19296 m
.51749 .19413 L
s
.53657 .18761 m
.55075 .18651 L
s
.656 .751 .92 r
.5679 .33548 m .62162 .31828 L .64025 .34578 L F
0 g
.64025 .34578 m
.65099 .37496 L
s
.60448 .48014 m
.6179 .47571 L
s
.6179 .47571 m
.63709 .46997 L
s
.039 .916 .04 r
.60172 .4294 m
.64059 .42275 L
s
0 0 0 r
2.5 Mabswid
.60172 .4294 Mdot
0 g
.5 Mabswid
.63709 .46997 m
.62386 .47434 L
s
.544 .324 .532 r
.5679 .33548 m .61921 .36004 L .56864 .37595 L F
.5679 .33548 m .62162 .31828 L .61921 .36004 L F
.656 .751 .92 r
.54471 .30891 m .62162 .31828 L .5679 .33548 L F
0 0 0 r
2.5 Mabswid
.5679 .33548 Mdot
.039 .916 .04 r
.5 Mabswid
.11741 .4797 m
.5679 .33548 L
s
0 g
.56716 .29575 m
.56746 .31168 L
s
.039 .916 .04 r
.64059 .42275 m
.9386 .33174 L
s
0 0 0 r
2.5 Mabswid
.64059 .42275 Mdot
.039 .916 .04 r
.5 Mabswid
.53388 .24101 m
.56922 .22383 L
s
0 0 0 r
2.5 Mabswid
.53388 .24101 Mdot
0 g
.5 Mabswid
.51749 .19413 m
.50629 .20511 L
s
.53657 .18761 m
.51749 .19413 L
s
.52555 .19854 m
.53657 .18761 L
s
.656 .751 .92 r
.54471 .30891 m .5952 .29251 L .62162 .31828 L F
0 0 0 r
2.5 Mabswid
.62162 .31828 Mdot
.039 .916 .04 r
.5 Mabswid
.62162 .31828 m
.90255 .22834 L
s
.5679 .33548 m
.62162 .31828 L
s
0 g
.61677 .2796 m
.62162 .31828 L
s
.62162 .31828 m
.64025 .34578 L
s
.58821 .47462 m
.60448 .48014 L
s
.60448 .48014 m
.62386 .47434 L
s
.039 .916 .04 r
.56922 .22383 m
.86627 .12427 L
s
0 0 0 r
2.5 Mabswid
.56922 .22383 Mdot
.544 .324 .532 r
.56864 .37595 m .60903 .40496 L .5694 .4172 L F
.56864 .37595 m .61921 .36004 L .60903 .40496 L F
.039 .916 .04 r
.5 Mabswid
.11741 .4797 m
.56896 .39326 L
s
0 g
.5679 .33548 m
.56864 .37595 L
s
.61921 .36004 m
.62162 .31828 L
s
.62386 .47434 m
.60776 .46875 L
s
.96066 .31159 m
.94173 .28448 L
s
.96066 .31159 m
.96066 .31159 L
s
.656 .751 .92 r
.52099 .28173 m .5952 .29251 L .54471 .30891 L F
0 g
.54471 .30891 m
.5679 .33548 L
s
.039 .916 .04 r
.11741 .4797 m
.53477 .29752 L
s
0 0 0 r
2.5 Mabswid
.92599 .21162 Mdot
.039 .916 .04 r
.5 Mabswid
.56896 .39326 m
.61505 .38252 L
s
0 0 0 r
2.5 Mabswid
.56896 .39326 Mdot
0 g
.5 Mabswid
.50629 .20511 m
.52555 .19854 L
s
.50629 .20511 m
.49915 .22544 L
s
.89076 .10918 m
.89076 .10918 L
s
.89076 .10918 m
.89462 .14814 L
s
0 0 0 r
2.5 Mabswid
.53477 .29752 Mdot
0 g
.5 Mabswid
.51859 .21886 m
.52555 .19854 L
s
.656 .751 .92 r
.52099 .28173 m .5605 .26871 L .5952 .29251 L F
0 g
.5952 .29251 m
.62162 .31828 L
s
.58821 .47462 m
.60776 .46875 L
s
.544 .324 .532 r
.5694 .4172 m .58987 .45327 L .57018 .45924 L F
0 g
.57018 .45924 m
.58821 .47462 L
s
.544 .324 .532 r
.5694 .4172 m .60903 .40496 L .58987 .45327 L F
0 g
.56864 .37595 m
.5694 .4172 L
s
.5694 .4172 m
.57018 .45924 L
s
.60903 .40496 m
.61921 .36004 L
s
.039 .916 .04 r
.61505 .38252 m
.9088 .29154 L
s
0 0 0 r
2.5 Mabswid
.61505 .38252 Mdot
0 g
.5 Mabswid
.58987 .45327 m
.60776 .46875 L
s
.94173 .28448 m
.92237 .25673 L
s
.656 .751 .92 r
.49672 .25392 m .5605 .26871 L .52099 .28173 L F
0 g
.52099 .28173 m
.54471 .30891 L
s
.039 .916 .04 r
.53477 .29752 m
.57862 .28012 L
s
.57862 .28012 m
.87145 .18379 L
s
0 0 0 r
2.5 Mabswid
.57862 .28012 Mdot
0 g
.5 Mabswid
.58987 .45327 m
.60903 .40496 L
s
.89854 .18785 m
.89462 .14814 L
s
.51859 .21886 m
.49915 .22544 L
s
0 0 0 r
2.5 Mabswid
.93255 .27132 Mdot
.656 .751 .92 r
.49672 .25392 m .51633 .24736 L .5605 .26871 L F
0 g
.5 Mabswid
.51633 .24736 m
.5605 .26871 L
s
.49672 .25392 m
.49915 .22544 L
s
.5605 .26871 m
.5952 .29251 L
s
.49672 .25392 m
.52099 .28173 L
s
.51633 .24736 m
.51859 .21886 L
s
.55165 .43482 m
.57018 .45924 L
s
.57018 .45924 m
.58987 .45327 L
s
.039 .916 .04 r
.5351 .3549 m
.57152 .34375 L
s
0 0 0 r
2.5 Mabswid
.5351 .3549 Mdot
.89648 .16699 Mdot
0 g
.5 Mabswid
.57146 .42874 m
.58987 .45327 L
s
.92237 .25673 m
.90255 .22834 L
s
.49672 .25392 m
.51633 .24736 L
s
.49672 .25392 m
.4993 .28862 L
s
.89854 .18785 m
.90255 .22834 L
s
.039 .916 .04 r
.57152 .34375 m
.87755 .24616 L
s
0 0 0 r
2.5 Mabswid
.57152 .34375 Mdot
0 g
.5 Mabswid
.53403 .40302 m
.55165 .43482 L
s
.55165 .43482 m
.57146 .42874 L
s
.51633 .24736 m
.51904 .28211 L
s
.97441 .43595 m
.85121 .26732 L
s
.57146 .42874 m
.5539 .39682 L
s
.4993 .28862 m
.51904 .28211 L
s
.4993 .28862 m
.5068 .327 L
s
0 0 0 r
2.5 Mabswid
.9386 .33174 Mdot
0 g
.5 Mabswid
.51868 .36614 m
.53403 .40302 L
s
.53403 .40302 m
.5539 .39682 L
s
.52663 .32058 m
.51904 .28211 L
s
.5068 .327 m
.51868 .36614 L
s
.52663 .32058 m
.5068 .327 L
s
.51868 .36614 m
.53855 .35982 L
s
.5539 .39682 m
.53855 .35982 L
s
0 0 0 r
2.5 Mabswid
.90255 .22834 Mdot
0 g
.5 Mabswid
.90663 .26962 m
.90255 .22834 L
s
.90255 .22834 m
.88226 .19927 L
s
.53855 .35982 m
.52663 .32058 L
s
0 0 0 r
2.5 Mabswid
.86627 .12427 Mdot
0 g
.5 Mabswid
.85121 .26732 m
.82983 .01827 L
s
.90663 .26962 m
.91079 .31173 L
s
.88226 .19927 m
.86148 .1695 L
s
0 0 0 r
2.5 Mabswid
.9088 .29154 Mdot
.87145 .18379 Mdot
0 g
.5 Mabswid
.91504 .35469 m
.91079 .31173 L
s
.86148 .1695 m
.8402 .13901 L
s
.91504 .35469 m
.91504 .35469 L
s
0 0 0 r
2.5 Mabswid
.87755 .24616 Mdot
0 g
.5 Mabswid
.8402 .13901 m
.8402 .13901 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[17]:=",
  ImageSize->{708.25, 481},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;40001hB000`400?l00000o`00003ooooooooo
ooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo
003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003ooooooooo
ooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool0
0?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooC?ooool00ol0003ooooo
ooooo`1gooooo`00ooooooooooooodcooooo00?o0000ooooooooool0Moooool00?oooooooooooom<
ooooo`;o0000N?ooool00?oooooooooooom<ooooo`03o`000?oooooo000007Oooooo003ooooooooo
ooooC?ooool00ol0003oooooo`00001gooooo`00ooooooooooooodcooooo00Co0000oooooooooooo
0000M_ooool00?oooooooooooom<ooooo`05o`000?ooooooooooooooool00000MOooool00?oooooo
oooooom=ooooo`04o`000?ooooooooooo`0007Gooooo003oooooooooooooCOooool01Ol0003ooooo
oooooooooooo000007Cooooo003oooooooooooooCOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo077ooooo003oooooooooooooCOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo077ooooo003oooooooooooooCOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo073ooooo003oooooooooooooCOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
06oooooo003oooooooooooooCOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06oo
oooo003oooooooooooooCOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06kooooo
003oooooooooooooCOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06gooooo003o
ooooooooooooCOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06gooooo003ooooo
ooooooooCOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06cooooo003ooooooooo
ooooCOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06_ooooo003ooooooooooooo
C_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06_ooooo003oooooooooooooC_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06[ooooo003oooooooooooooC_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Wooooo003oooooooooooooC_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo06Wooooo003oooooooooooooC_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo06Sooooo003oooooooooooooC_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo06Oooooo003oooooooooooooC_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo06Oooooo003oooooooooooooC_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo06Kooooo003oooooooooooooC_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo06Gooooo003oooooooooooooC_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo06Gooooo003oooooooooooooC_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo06Cooooo003oooooooooooooCoooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo06?ooooo003oooooooooooooCoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06?ooooo003oooooooooooooCoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
06;ooooo003oooooooooooooCoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo067o
oooo003oooooooooooooCoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo063ooooo
003oooooooooooooCoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo063ooooo003o
ooooooooooooCoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05oooooo003ooooo
ooooooooCoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05kooooo003ooooooooo
ooooCoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05kooooo003ooooooooooooo
Coooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05gooooo003oooooooooooooCooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05cooooo003oooooooooooooCoooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05cooooo003oooooooooooooD?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo05_ooooo003oooooooooooooD?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo05[ooooo003oooooooooooooD?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo05[ooooo003oooooooooooooD?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo05Wooooo003oooooooooooooD?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo05Sooooo003oooooooooooooD?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo05Sooooo003oooooooooooooD?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo05Oooooo003oooooooooooooD?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo05Kooooo003oooooooooooooD?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo05Kooooo003oooooooooooooD?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo05Gooooo003oooooooooooooD?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
05Cooooo003oooooooooooooD?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Co
oooo003oooooooooooooDOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05?ooooo
003oooooooooooooDOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05;ooooo003o
ooooooooooooDOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05;ooooo003ooooo
ooooooooDOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo057ooooo003ooooooooo
ooooDOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo053ooooo003ooooooooooooo
DOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo053ooooo003oooooooooooooDOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oooooo003oooooooooooooDOooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04kooooo003oooooooooooooDOooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo04kooooo003oooooooooooooDOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo04gooooo003oooooooooooooDOooool00ol0003ooooo
ooooo`0Sooooo`;o0000COooool00?oooooooooooomAooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0C?ooool00?oooooooooooomBooooo`03o`000?oooooooooo02;ooooo0_l0001=
ooooo`00oooooooooooooe;ooooo00?o0000ooooooooool08_ooool00ol0003oooooo`00001<oooo
o`00oooooooooooooe;ooooo00?o0000ooooooooool08_ooool00ol0003oooooo`00001<ooooo`00
oooooooooooooe;ooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0001;ooooo`00
oooooooooooooe;ooooo00?o0000ooooooooool08oooool01?l0003oooooooooool0001:ooooo`00
oooooooooooooe;ooooo00?o0000ooooooooool08oooool01?l0003oooooooooool0001:ooooo`00
oooooooooooooe;ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000004Wo
oooo003oooooooooooooD_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0A_ooool00?oooooooooooomBooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`16ooooo`00oooooooooooooe;ooooo00?o0000
ooooooooool04?ooool2o`00017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15
ooooo`00oooooooooooooe;ooooo00?o0000ooooooooool03Oooool3o`WZ2P;o00004Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo003oooooooooooooDoooool00ol0003o
ooooooooo`09ooooo`?o2NX:5_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Co
oooo003oooooooooooooDoooool00ol0003oooooooooo`06ooooo`?o2NX:6Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04?ooooo003oooooooooooooDoooool00ol0003ooooooooo
o`03ooooo`?o2NX:7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04;ooooo003o
ooooooooooooDoooool00ol0003oooooooooo`03o`WZ2R3ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`12ooooo`00oooooooooooooe?ooooo00?o0000o`WZ2_l9jPX08oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo003oooooooooooooD?ooool3o`WZ2P03
o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`10ooooo`00
ooooooooooooodgooooo0ol9jPX3ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`10ooooo`00oooooooooooood[ooooo0ol9jPX6ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0oooooo`00oooooooo
ooooodOooooo0ol9jPX9ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0nooooo`00ooooooooooooodCooooo0ol9jPX<ooooo`;o00009?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03kooooo003ooooooooooooo@Oooool3o`WZ2Poo
oooo0_l0000Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0?Oooool00?oooooo
oooooolnooooo`?o2NX:4_ooool00ol0003oooooo`00000Tooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0??ooool00?oooooooooooolkooooo`?o2NX:5_ooool00ol0003oooooo`00
000Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0??ooool00?oooooooooooolh
ooooo`?o2NX:6Oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>oooool00?ooooooooooooleooooo`?o2NX:7?ooool01?l0003oooooooooool0
000Rooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>_ooool00?oooooooooooolb
ooooo`?o2NX:7oooool01Ol0003ooooooooooooooooo0000027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0jooooo`00oooooooooooooboooooo0ol9jPXRooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo03Wooooo003ooooooooooooo;?ooool3o`WZ2RGooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>?ooool00?oo
oooooooooolYooooo`?o2NX::?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0gooooo`00ooooooooooooobKooooo
0ol9jPX[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03Oooooo003ooooooooooooo8oooool3o`WZ2Rkooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0=_ooool00?oooooooooooolPooooo`?o2NX:<Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0e
ooooo`00oooooooooooooakooooo0_l9jPXdooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Gooooo003ooooooooo
oooo6oooool3o`WZ2SKooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0=?ooool00?oooooooooooolHooooo`?o2NX:
>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0cooooo`00oooooooooooooaGooooo0ol9jPXmooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo03?ooooo003ooooooooooooo4_ooool3o`WZ2T3ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<_ooool0
0?ooooooooooool?ooooo`?o2NX:@oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0aooooo`00ooooooooooooo`co
oooo0ol9jPY6ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool2o`0001Go
oooo00?o0000ooooooooool0<Oooool00?ooooooooooool9ooooo`?o2NX:BOooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Cooooo0_l9jPX2o`0001Kooooo00?o0000ooooooooool0
<?ooool00?ooooooooooool6ooooo`?o2NX:C?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo013ooooo0ol9jPX3ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;ooo
ool00?ooooooooooool3ooooo`?o2NX:Coooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00gooooo0ol9jPX6ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;oooool0
0?ooooooooooool3o`WZ2U;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09oooo
o`?o2NX:2Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02kooooo003oooooooco
oooo0ol9jPYEooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool3o`WZ2Pco
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0]ooooo`00oooooooiooooo`?o2NX:
F?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0ol9jPX?ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0;Oooool00?oooooom_ooool3o`WZ2Ucooooo00?o
0000ooooooooool03Oooool01?l0003o2NX:o`WZ2_l9jPXBooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0;?ooool00?ooooooloooool3o`WZ2Uoooooo00?o0000ooooooooool02ooo
ool3o`WZ2P03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0[ooooo`00ooooooo`ooooo`?o2NX:H_ooool00ol0003oooooooooo`08ooooo`?o2NX:0oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:oooool0
0?ooooookOooool3o`WZ2VGooooo00?o0000ooooooooool01Oooool3o`WZ2POooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02[ooooo003oooooon[o
oooo0ol9jPYXooooo`03o`000?oooooooooo00;ooooo0ol9jPX;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`00oooooooWooooo`?o2NX:
Joooool00ol0003oooooo`WZ2P02o`WZ2Pgooooo00?o2NX:o`000?l000004_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo02Wooooo003oooooonCooooo0ol9jPY]ooooo`03o`WZ2_l0
003o2NX:00gooooo0ol9jPX00ooooooo0000o`00000Booooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0:?ooool00?ooooooPOooool7o`0005Wooooo0ol9jPY]ooooo`?o2NX:00?ooooo
o`000?ooool02_ooool3o`WZ2PKooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo02Oooooo003oooooog_ooooo1_l000001?oooooo0000o`000?l00003
ooooo`;o0000E?ooool3o`WZ2Vgooooo0ol9jPX4ooooo`03o`000?oooooooooo00Kooooo0ol9jPX9
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0W
ooooo`00oooooomhooooo`Co00000oooool3o`0000Sooooo0_l0001?ooooo`?o2NX:KOooool3o`WZ
2POooooo00?o0000ooooooooool00oooool3o`WZ2Pgooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo003oooooogGooooo0ol00002ooooo`03
o`000?oooooooooo00;o00003Oooool2o`0004_ooooo0_l9jPY]ooooo`?o2NX:2_ooool00ol0003o
ooooooooo`03o`WZ2Q7ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Gooooo003oooooog;ooooo0ol00004ooooo`Co00004Oooool2o`0004Kooooo
0ol9jPY/ooooo`?o2NX:3Oooool00ol0003o2NX:o`WZ2P0Dooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`00oooooom_ooooo`?o00000_oo
ool7o`0001Gooooo0_l00011ooooo`?o2NX:K?ooool3o`WZ2Pgooooo0ol9jPX00ooooooo0000oooo
o`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Tooooo`00oooooom^ooooo`Ko00000oooool01?l0003oooooooooooooool2o`0001Cooooo0_l0
000mooooo`?o2NX:K?ooool3o`WZ2Pgooooo0ol9jPX4ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo003o
ooooofgooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`;o00003oooool3
o`0000;ooooo00?o0000ooooooooool0=oooool3o`WZ2Vcooooo0ol9jPX=ooooo`?o2NX:1oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Sooooo`00oooooom/ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`?o00001_ooool00ol0003oooooooooo`0coooo
o`?o2NX:K?ooool3o`WZ2Pgooooo0ol9jPX:ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo003oooooof_o
oooo00?o0000ooooooooool01?ooool3o`0000_ooooo0_l00006ooooo`?o00002_ooool00ol0003o
ooooooooo`0_ooooo`?o2NX:Joooool4o`WZ2Pgooooo0ol9jPX=ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?o
oooo003oooooof[ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo00?o0000ooooooooool0
2oooool2o`000004ooooool0003o0000o`0000kooooo00?o0000ooooooooool0:oooool3o`WZ2V_o
oooo0ol9jPX>ooooo`?o2NX:4?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`00oooooomYooooo`03o`00
0?oooooooooo00?o00001?ooool00ol0003oooooooooo`0>ooooo`;o00004Oooool00ol0003ooooo
ooooo`0Wooooo`?o2NX:Joooool3o`WZ2Pkooooo0ol9jPXCooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo
003oooooofSooooo1?l00007ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Sooooo`?o2NX:Joooool3o`WZ2Pkooooo0ol9jPXFooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo02;ooooo003oooooofOooooo0_l0000:ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Oooooo`?o2NX:Joooool3o`WZ2Pkooooo0ol9jPXI
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02;ooooo003oooooofOooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool3o`WZ
2V_ooooo0ol9jPX>ooooo`?o2NX:7?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`00oooooomVooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Oooooo0ol9jPY[ooooo`?o2NX:3_ooool3o`WZ2Qoooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool08_ooool00?ooooooI_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`?o2NX:Joooool3o`WZ2Pkooooo
0ol9jPXRooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02;ooooo003oooooofKooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool3o`WZ2V_ooooo0ol9jPX>ooooo`?o2NX:9_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Rooooo`00oooooomU
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>
ooooo`;o00003Oooool3o`WZ2V_ooooo0ol9jPX>ooooo`?o2NX::Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol9jP[o0000o`00000@
ooooo`03o`000?oooooooooo02;ooooo003oooooofGooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo0ol000000on;DXSo0000ooooo`09oooo
o`?o2NX:Joooool3o`WZ2Pkooooo0ol9jPX/ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`09ooooo`?o2NX:00?oooooo`000?l000004?ooool00ol0
003oooooooooo`0Rooooo`00oooooomUooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`06ooooo`?o00001On;DXP00ol0003oooooooooo`04ooooo`?o
2NX:Joooool3o`WZ2Pkooooo0ol9jPX_ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`?o2NX:5_ooool00ol0003oooooooooo`0Rooooo`00
oooooomTooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`03ooooo`;o00002On;DXP00ol0003oooooooooo`03o`WZ2V_ooooo0ol9jPX=ooooo`Co2NX:
<_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool3o`WZ2Q[ooooo00?o0000ooooooooool08Oooool00?ooooooI?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool000000_l0000;oh]BR0?o2NX:Jooo
ool3o`WZ2Pgooooo0ol9jPXfooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03o`WZ2Qgooooo00?o0000ooooooooool08Oooool00?ooooooI?ooool0
0ol0003oooooooooo`07ooooo`;o00008Oooool00ol0003oRe:8oh]BR009oh]BR0?o2NX:00?oRe:8
o`000?ooool0J?ooool3o`WZ2Pgooooo0ol9jPXiooooo`03o`000?oooooooooo023ooooo00Go0000
ooooooooooooooooo`000002o`WZ2R3ooooo00?o0000ooooooooool08Oooool00?ooooooHoooool0
0ol0003oooooooooo`05ooooo`?o000000?oooooo`000?ooool08?ooool00ol0003oRe:8oh]BR006
oh]BR0?o2NX:1?n;DXP2o`0006Gooooo0ol9jPX=ooooo`?o2NX:??ooool00ol0003oooooooooo`0P
ooooo`05o`000?l9jP[o2NX:o`WZ2_l000008_ooool00ol0003oooooooooo`0Qooooo`00oooooomS
ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo01oooooo00?o0000
oh]BR?n;DXP00on;DXP3o`WZ2PSoRe:800?o0000ooooooooool0H?ooool3o`WZ2Pgooooo0ol9jPXo
ooooo`03o`000?oooooooooo01kooooo0ol9jPX01?l0003oooooooooool0000Rooooo`03o`000?oo
oooooooo027ooooo003oooooof?ooooo00?o0000ooooooooool00_l00007ooooo`03o`000?oooooo
oooo01oooooo0ol00003o`WZ2PcoRe:800?o0000ooooooooool0G?ooool3o`WZ2Pgooooo0ol9jPY2
ooooo`03o`000?oooooooooo01_ooooo0ol9jPX4ooooo`04o`000?ooooooooooo`00027ooooo00?o
0000ooooooooool08Oooool00?ooooooH_ooool4o`0000Wooooo00?o0000ooooooooool07oooool3
o`0000ooRe:80_l0001Jooooo`?o2NX:3Oooool3o`WZ2TGooooo00?o0000ooooooooool06?ooool3
o`WZ2PSooooo00?o0000ooooool000008Oooool00ol0003oooooooooo`0Qooooo`00oooooomRoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool2o`WZ2Q;oRe:800?o0000oooo
ooooool0EOooool3o`WZ2Pgooooo0ol9jPY8ooooo`03o`000?oooooooooo01Gooooo0ol9jPX;oooo
o`03o`000?oooooo0000027ooooo00?o0000ooooooooool08Oooool00?ooooooH_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01cooooo0_l9jPX00ooooooo0000oh]BR00Aoh]BR0;o
0000Doooool3o`WZ2Pgooooo0ol9jPY<ooooo`03o`000?oooooooooo013ooooo1?l9jPX?ooooo`;o
00008Oooool00ol0003oooooooooo`0Qooooo`00oooooomRooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06_ooool2o`WZ2P?ooooo00?o0000oh]BR?n;DXP04On;DXP2o`0004oooooo
0ol9jPX=ooooo`?o2NX:Coooool00ol0003oooooooooo`0=ooooo`?o2NX:4_ooool00ol9jP[o0000
o`00000Qooooo`03o`000?oooooooooo027ooooo003oooooof;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Hooooo`;o2NX:1Oooool00ol0003oRe:8oh]BR00Boh]BR003o`000?oo
oooooooo04Wooooo1?l9jPX=ooooo`?o2NX:D_ooool00ol0003oooooooooo`0:ooooo`?o2NX:4_oo
ool3o`WZ2P03ooooool0003o000002;ooooo00?o0000ooooooooool08?ooool00?ooooooH_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo0_l9jPX7ooooo`03o`000?n;DXSo
Re:801;oRe:80_l00017ooooo`?o2NX:3_ooool3o`WZ2UGooooo00?o0000ooooooooool01oooool3
o`WZ2Q;ooooo0ol9jPX5ooooo`;o00008Oooool00ol0003oooooooooo`0Pooooo`00oooooomRoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool3o`WZ2PWooooo00?o0000oh]B
R?n;DXP04on;DXP2o`0004?ooooo0ol9jPX>ooooo`?o2NX:F?ooool00ol0003oooooooooo`04oooo
o`?o2NX:4_ooool3o`WZ2PSooooo00?o0000ooooool000008?ooool00ol0003oooooooooo`0Poooo
o`00oooooomQooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool2o`WZ2Pco
oooo00?o0000oh]BR?n;DXP04on;DXP2o`00043ooooo0ol9jPX>ooooo`?o2NX:Foooool01?l0003o
ooooooooooooool3o`WZ2Q;ooooo0ol9jPX;ooooo`03o`000?oooooo0000023ooooo00?o0000oooo
ooooool08?ooool00?ooooooHOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013o
oooo0_l9jPX>ooooo`03o`000?n;DXSoRe:801CoRe:80_l0000looooo`?o2NX:3_ooool3o`WZ2Uko
oooo00Co0000o`WZ2_l9jP[o2NX:4_ooool3o`WZ2Pkooooo00Co0000oooooooooooo00007oooool0
0ol0003oooooooooo`0Pooooo`00oooooomQooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03_ooool2o`WZ2Q3ooooo00?o0000oh]BR?n;DXP05On;DXP2o`0003Sooooo0ol9jPX>oooo
o`?o2NX:Goooool2o`WZ2P03o`000?oooooooooo00oooooo1?l9jPXBooooo`04o`000?oooooooooo
o`0001kooooo00?o0000ooooooooool08?ooool00?ooooooHOooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00cooooo0_l9jPXBooooo`03o`000?n;DXSoRe:801GoRe:80_l0000eoooo
o`?o2NX:3_ooool3o`WZ2Uoooooo0ol9jPX2ooooo`03o`000?oooooooooo00cooooo0ol9jPXFoooo
o`05o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`0Pooooo`00oooooomQoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool2o`WZ2QCooooo00?o0000oh]B
R?n;DXP05_n;DXP2o`00037ooooo0ol9jPX>ooooo`?o2NX:Goooool3o`WZ2PGooooo00?o0000oooo
ooooool02Oooool3o`WZ2QWooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooo
oooo023ooooo003oooooof7ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`;o00005_ooool00ol0003oRe:8oh]BR00Foh]BR0;o0000;_ooool3o`WZ2Pkooooo0ol9jPYOoooo
o`?o2NX:2?ooool00ol0003oooooooooo`06ooooo`?o2NX:7?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool00?ooooooHOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo0_l9jPX2o`0001Kooooo00?o0000oh]BR?n;
DXP05on;DXP2o`0002[ooooo0ol9jPX>ooooo`?o2NX:G_ooool4o`WZ2Pcooooo00?o0000oooooooo
ool00_ooool3o`WZ2Qoooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01oooooo003oooooof7ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`05ooooo`03o`WZ2_oooooooooo01Sooooo00?o0000oh]BR?n;DXP06?n;DXP00ol0003ooooo
ooooo`0Uooooo`?o2NX:3_ooool3o`WZ2Ukooooo0ol9jPX@ooooo`03o`000?oooooo2NX:00;o2NX:
8_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7oooool00?ooooooHOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_l9
jPXKooooo`03o`000?n;DXSoRe:801SoRe:80_l0000Sooooo`?o2NX:3_ooool3o`WZ2Ukooooo0ol9
jPXBooooo`03o`WZ2_l0003o2NX:013ooooo00?o2NX:o`000?l000004_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07oooool00?ooooooHOooool0
0ol0003oooooooooo`09ooooo`?o00000_ooool2o`WZ2Qgooooo00?o0000oh]BR?n;DXP06On;DXP0
0ol0003oooooooooo`0Nooooo`?o2NX:3Oooool4o`WZ2Ukooooo0ol9jPXAooooo`Co2NX:00?ooooo
o`000?ooool03Oooool3o`WZ2P03ooooool0003o000001;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo003oooooof3ooooo00?o0000oooo
ooooool01oooool3o`000003ojO0jol0003oYl3[00;o00007oooool00ol0003oRe:8oh]BR00Ioh]B
R0;o00007?ooool3o`WZ2Pgooooo0ol9jPYOooooo`?o2NX:4Oooool3o`WZ2PGooooo00?o0000oooo
ooooool02Oooool3o`WZ2QSooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01oooooo003oooooof3ooooo00?o0000ooooooooool01?ooool3o`0000Co
Yl3[00Co0000ojO0jonW`>_oYl3[0_l0000Mooooo`03o`000?n;DXSoRe:801WoRe:80_l0000Ioooo
o`?o2NX:3Oooool3o`WZ2Uoooooo0ol9jPXAooooo`?o2NX:2?ooool00ol0003oooooooooo`06oooo
o`?o2NX:7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool07oooool00?ooooooH?ooool01?l0003oooooooooooooool3o`0000OoYl3[00?o0000ojO0
jonW`>/00onW`>/2o`0001_ooooo00?o0000oh]BR?n;DXP06_n;DXP2o`0001Gooooo0ol9jPX=oooo
o`?o2NX:Goooool3o`WZ2Q7ooooo0ol9jPX;ooooo`03o`000?oooooooooo00?ooooo0ol9jPXOoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Ooooo
o`00oooooomPooooo`Co00002_nW`>/00ol0003oYl3[ojO0j`05ojO0j`;o00006Oooool00ol0003o
Re:8oh]BR00Joh]BR003o`000?oooooo0000017ooooo0ol9jPX=ooooo`?o2NX:Goooool3o`WZ2Q7o
oooo0ol9jPX>ooooo`03o`000?oooooooooo00?o2NX:8_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool07oooool00?ooooooH?ooool00ol0003oYl3[
ojO0j`0;ojO0j`03o`000?nW`>_oYl3[00OoYl3[0_l0000Gooooo`03o`000?n;DXSoRe:801[oRe:8
00?o0000ooooool000003_ooool3o`WZ2Pgooooo0ol9jPYOooooo`?o2NX:4Oooool3o`WZ2Q7ooooo
00?o0000o`WZ2_l9jPX09Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool07oooool00?ooooooH?ooool00ol0003oYl3[ojO0j`0;ojO0j`03o`000?nW
`>_oYl3[00WoYl3[0_l0000Eooooo`03o`000?n;DXSoRe:801_oRe:800?o0000ooooool000002_oo
ool3o`WZ2Pgooooo0ol9jPYOooooo`?o2NX:4?ooool4o`WZ2Q7ooooo0ol9jPX00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Oooooo`00oooooomPooooo`;o00003OnW`>/00ol0003oYl3[ojO0j`0:ojO0j`?o00004_ooool0
0ol0003oRe:8oh]BR00Koh]BR003o`000?oooooo000000Oooooo0ol9jPX=ooooo`?o2NX:Goooool3
o`WZ2Q3ooooo0ol9jPXAooooo`Co2NX:0oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Nooooo`00oooooomPoooo
o`03o`000?oooooo000000coYl3[00?o0000ojO0jonW`>/03OnW`>/2o`00013ooooo00?o0000oh]B
R?n;DXP06on;DXP01?l0003oooooooooool00003ooooo`?o2NX:3Oooool3o`WZ2Ukooooo1?l9jPX@
ooooo`?o2NX:4Oooool3o`WZ2POooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07_ooool00?ooooooH?ooool01?l0
003oooooooooool0000;ojO0j`03o`000?nW`>_oYl3[00ooYl3[0_l0000>ooooo`03o`000?n;DXSo
Re:801coRe:800?o0000ooooool000000ol9jPX=ooooo`?o2NX:G_ooool3o`WZ2Q7ooooo0ol9jPXA
ooooo`?o2NX:2oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Nooooo`00oooooomPooooo`05o`000?l9jP[o2NX:
ooooool000002_nW`>/00ol0003oYl3[ojO0j`0AojO0j`;o00003?ooool00ol0003oRe:8oh]BR00L
oh]BR0;o000000?o2NX:o`000?ooool02oooool3o`WZ2Ukooooo0ol9jPXAooooo`?o2NX:4Oooool3
o`WZ2Pkooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool07_ooool00?ooooooGoooool00ol9jP[o0000ooooo`03oooo
o`03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/04onW`>/2o`0000[ooooo00?o0000oh]B
R?n;DXP06On;DXP3o`WZ2P;o000000?oooooo`000?ooool02?ooool3o`WZ2Ukooooo0ol9jPXAoooo
o`?o2NX:4Oooool3o`WZ2Q7ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07_ooool00?ooooooGOooool2o`WZ2P;o
oooo00?o0000ooooooooool00_ooool00ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>_oYl3[01Go
Yl3[0_l00008ooooo`03o`000?n;DXSoRe:801OoRe:80_l9jPX4oh]BR004o`000?ooooooooooo`00
00Gooooo0ol9jPYNooooo`?o2NX:4?ooool4o`WZ2Q7ooooo0ol9jPXDooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01kooooo003ooooooecooooo00?o2NX:ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/05onW`>/2o`0000Kooooo00?o0000oh]BR?n;
DXP05?n;DXP3o`WZ2PKoRe:800Co0000oooooooooooo00000_ooool3o`WZ2Ukooooo0ol9jPX@oooo
o`?o2NX:4_ooool3o`WZ2QOooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00?ooooooF_ooool2o`WZ2PGo
oooo00?o0000ooooooooool00oooool00ol0003oYl3[ojO0j`05ojO0j`03o`000?nW`>_oYl3[01Wo
Yl3[0_l00004ooooo`03o`000?n;DXSoRe:801;oRe:80_l9jPX:oh]BR003o`000?oooooo2NX:00;o
2NX:G_ooool3o`WZ2Q3ooooo0ol9jPXAooooo`Co2NX:6_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Nooooo`00
oooooomHooooo`;o2NX:1oooool00ol0003oooooooooo`04ooooo`03o`000?nW`>_oYl3[00CoYl3[
00?o0000ojO0jonW`>/06onW`>/2o`0000;ooooo00?o0000oh]BR?n;DXP03on;DXP3o`WZ2P_oRe:8
0ol9jPX00ooooooo0000ooooo`1Kooooo`?o2NX:4?ooool3o`WZ2Q7ooooo0ol9jPXNooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01kooooo003ooooooeKooooo0_l9jPX9ooooo`03o`000?oooooooooo00Gooooo00?o
0000ojO0jonW`>/00onW`>/00ol0003oYl3[ojO0j`0MojO0j`03o`000?oooooo000000ooRe:80_l9
jPX;oh]BR0?o2NX:00?oRe:8o`000?ooool00_ooool00ol0003oooooooooo`1Fooooo`?o2NX:4?oo
ool3o`WZ2Q7ooooo0ol9jPXRooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo003ooooooeGooooo00?o2NX:
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?nW`>_oYl3[00;oYl3[00?o0000
ojO0jonW`>/07_nW`>/2o`0000goRe:80_l9jPX:oh]BR0?o2NX:1On;DXP01?l0003oooooooooool0
001Eooooo`?o2NX:4?ooool3o`WZ2Q7ooooo0ol9jPXVooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool03Oooool00ol9jP[o0000o`00000@ooooo`03o`000?oooooooooo01gooooo003o
oooooe?ooooo0_l9jPX<ooooo`03o`000?oooooooooo00Oooooo00Go0000ojO0jonW`>_oYl3[o`00
000RojO0j`03o`000?n;DXSoRe:800OoRe:80ol9jPX9oh]BR0?o2NX:2?n;DXP01?l0003ooooooooo
ool0001Booooo`?o2NX:3oooool4o`WZ2Q7ooooo0ol9jPXZooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02_ooool3o`WZ2P03ooooool0003o0000013ooooo00?o0000ooooooooool0
7Oooool00?ooooooDOooool2o`WZ2Pkooooo00?o0000ooooooooool01oooool01Ol0003oYl3[ojO0
jonW`>_o000002?oYl3[00?o0000oh]BR?n;DXP01?n;DXP2o`WZ2PWoRe:80ol9jPX;oh]BR005o`00
0?ooooooooooooooool00000COooool4o`WZ2Poooooo0ol9jPXBooooo`?o2NX:;Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo0ol9jPX5ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool07Oooool00?ooooooCoooool2o`WZ2Q3ooooo00?o0000ooooooooool0
2?ooool01Ol0003oYl3[ojO0jonW`>_o000002?oYl3[0_l000001?n;DXSo2NX:o`WZ2_l9jPX8oh]B
R0?o2NX:3on;DXP01?l0003oooooooooool0001:ooooo`?o2NX:4?ooool3o`WZ2Q;ooooo0ol9jPXa
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool3o`WZ2PWooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`00oooooom>ooooo`03o`WZ2_oooooooooo
013ooooo00?o0000ooooooooool02Oooool01?l0003oYl3[ojO0jol0000UojO0j`03o`000?n;DXSo
Re:800KoRe:80ol9jPXBoh]BR005o`000?ooooooooooooooool00000A_ooool3o`WZ2Q3ooooo0ol9
jPXBooooo`?o2NX:=Oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooooooo`?o2NX:
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo003oooooodcooooo0_l9
jPXCooooo`03o`000?oooooooooo00[ooooo00?o0000ojO0jol000009_nW`>/2o`0000?oRe:80ol9
jPXEoh]BR005o`000?ooooooooooooooool00000@oooool3o`WZ2Q3ooooo0ol9jPXAooooo`Co2NX:
>?ooool00ol0003oooooooooo`0Pooooo`04o`000?l9jP[o2NX:o`WZ2Q3ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Mooooo`00oooooom:ooooo`;o2NX:5Oooool00ol0003ooooo
ooooo`0;ooooo`;o0000:?nW`>/2o`000003o`WZ2_n;DXSoRe:801OoRe:800Co0000oooooooooooo
0000@?ooool3o`WZ2Q3ooooo0ol9jPXAooooo`?o2NX:?Oooool00ol0003oooooooooo`0Looooo`?o
2NX:00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01go
oooo003oooooodSooooo0_l9jPXHooooo`03o`000?oooooooooo00_ooooo00?o0000ojO0jonW`>/0
8onW`>/3o`WZ2P;o00006_n;DXP01Ol0003ooooooooooooooooo000003cooooo0ol9jPX@ooooo`?o
2NX:4Oooool3o`WZ2T7ooooo00?o0000ooooooooool06?ooool3o`WZ2PCooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo003oooooodOooooo
00?o2NX:ooooooooool06?ooool00ol0003oooooooooo`09ooooo`Co00008_nW`>/2o`WZ2PGoYl3[
0_l0000Hoh]BR005o`000?ooooooooooooooool00000>Oooool3o`WZ2Poooooo1?l9jPXAooooo`?o
2NX:AOooool00ol0003oooooooooo`0Dooooo`?o2NX:1oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00?ooooooAOooool2o`WZ2Q_ooooo
00?o0000ooooooooool01_ooool3o`0000;ooooo0_l0000PojO0j`;o2NX:2OnW`>/00ol0003oRe:8
oh]BR00Eoh]BR003o`000?oooooooooo00;ooooo00?o0000ooooooooool0<oooool3o`WZ2Poooooo
0ol9jPXBooooo`?o2NX:B?ooool00ol0003oooooooooo`0Aooooo`?o2NX:2_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool00?oooooo@ooo
ool2o`WZ2Qgooooo00?o0000ooooooooool00_ooool4o`0000Gooooo00?o0000ooooool000007?nW
`>/3o`WZ2PcoYl3[0_l0000Eoh]BR003o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?oo
ool3o`WZ2Poooooo0ol9jPXBooooo`?o2NX:C?ooool00ol0003oooooooooo`0<ooooo`Co2NX:3Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?oo
ool00?oooooo@Oooool2o`WZ2Qoooooo00?o0000ooooool000000_l00009ooooo`04o`000?oooooo
ooooo`0001WoYl3[0_l9jPXAojO0j`03o`000?n;DXSoRe:801?oRe:800Go0000oooooooooooooooo
o`00000_ooooo`?o2NX:3oooool3o`WZ2Q;ooooo0ol9jPY@ooooo`03o`000?oooooooooo00Sooooo
0ol9jPXAooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Looooo`00oooooom0ooooo`03o`WZ2_oooooooooo01oooooo0_l0000=ooooo`04o`000?oo
ooooooooo`0001GoYl3[0ol9jPXDojO0j`03o`000?n;DXSoRe:801;oRe:800?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Yooooo`?o2NX:3oooool3o`WZ2Q;ooooo0ol9jPYDooooo`03o`00
0?oooooooooo00Cooooo0ol9jPXDooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Looooo`00oooooolnooooo`;o2NX:8_ooool00ol0003ooooooooo
o`0<ooooo`05o`000?ooooooooooooooool000004_nW`>/2o`WZ2QSoYl3[0_l0000Boh]BR003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool09Oooool4o`WZ2Poooooo0ol9jPXAooooo`Co2NX:
Eoooool01?l0003oooooooooooooool3o`WZ2QOooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01cooooo003ooooooccooooo0_l9jPXTooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oYl3[ojO0j`0=ojO0j`;o2NX:
7?nW`>/00ol0003oRe:8oh]BR00?oh]BR003o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8Oooool3o`WZ2Poooooo1?l9jPXAooooo`?o2NX:G?ooool00ol0003o2NX:o`WZ2P0Iooooo`;o0000
6Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo003ooooooc_ooooo00?o
2NX:ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ojO0jonW`>/02OnW`>/3o`WZ2QooYl3[0_l0000?oh]BR003o`000?oooooooooo00?ooooo00?o
0000ooooooooool07_ooool3o`WZ2Poooooo0ol9jPXBooooo`?o2NX:Foooool4o`WZ2P03ooooool0
003ooooo01Sooooo00?o2NX:o`000?l000006Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01cooooo003oooooocWooooo0_l9jPXXooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01?ooool00ol0003oYl3[ojO0j`06ojO0j`;o2NX:9?nW`>/00ol0003oRe:8oh]BR00<
oh]BR003o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool3o`WZ2Poooooo0ol9jPXB
ooooo`?o2NX:Foooool3o`WZ2PGooooo00?o0000ooooooooool05?ooool3o`WZ2P;ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo003ooooo
ocOooooo0_l9jPXZooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool2o`WZ
2P03o`000?nW`>_oYl3[00?oYl3[0_l9jPXWojO0j`03o`000?n;DXSoRe:800_oRe:800?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Gooooo`?o2NX:3oooool3o`WZ2Q;ooooo0ol9jPYKoooo
o`?o2NX:2Oooool00ol0003oooooooooo`0@ooooo`?o2NX:1Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00?oooooo=Oooool2o`WZ2Rco
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02o`WZ2P?ooooo00?o0000ojO0jol9
jPX00_l9jPXZojO0j`03o`000?n;DXSoRe:800[oRe:800?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Dooooo`?o2NX:3oooool3o`WZ2Q;ooooo0ol9jPYKooooo`?o2NX:3Oooool00ol0003o
ooooooooo`0<ooooo`?o2NX:2?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06oooool00?oooooo=?ooool00ol9jP[oooooooooo`0/ooooo`03o`00
0?oooooooooo00cooooo00?o0000o`WZ2_l9jPX01Oooool00ol0003o2NX:ojO0j`0]ojO0j`03o`00
0?n;DXSoRe:800WoRe:800?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`?o2NX:
3oooool3o`WZ2Q;ooooo0ol9jPYJooooo`Co2NX:4Oooool00ol0003oooooooooo`07ooooo`Co2NX:
2oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6oooool00?oooooo<_ooool2o`WZ2Roooooo00?o0000ooooooooool02oooool00ol9jP[o0000oooo
o`04ooooo`;o2NX:0_l0000_ojO0j`03o`000?n;DXSoRe:800WoRe:800?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`?o2NX:3_ooool4o`WZ2Q7ooooo1?l9jPYJooooo`?o2NX:5Ooo
ool00ol0003oooooooooo`04ooooo`?o2NX:3oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06oooool00?oooooo<?ooool2o`WZ2S;ooooo00?o0000
ooooooooool01oooool3o`WZ2P04ooooool0003oooooooooo`?o2NX:1?ooool00ol0003oYl3[ojO0
j`0]ojO0j`03o`000?n;DXSoRe:800SoRe:800?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`?o2NX:3_ooool3o`WZ2Q;ooooo0ol9jPYKooooo`?o2NX:6Oooool00ol0003ooooooooo
o`03o`WZ2Q;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01_ooooo003oooooobkooooo0_l9jPXdooooo`03o`000?oooooooooo00Gooooo0_l9jPX5
ooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ojO0jonW`>/0;OnW`>/00ol0003oRe:8oh]BR007
oh]BR003o`000?oooooooooo00?ooooo0ol00008ooooo`?o2NX:3_ooool3o`WZ2Q;ooooo0ol9jPYK
ooooo`?o2NX:7?ooool00ol9jP[o0000o`WZ2P0Fooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`00ooooool]ooooo`03o`WZ2_oooooooooo
03Cooooo00?o0000ooooooooool00oooool2o`WZ2PGooooo0_l9jPX00ol0003oooooooooo`08oooo
o`03o`000?nW`>_oYl3[02goYl3[00?o0000oh]BR?n;DXP01_n;DXP00ol0003oooooooooo`03o`00
00;ooooo00?o0000ooooooooool00oooool3o`WZ2Pkooooo0ol9jPXBooooo`?o2NX:Foooool3o`WZ
2Q_ooooo1?l9jPX00ooooooo0000ooooo`0Fooooo`03o`000?oooooooooo01cooooo00Go0000oooo
ooooooooooooo`00000Mooooo`00ooooool[ooooo`;o2NX:=oooool01?l0003oooooooooooooool2
o`WZ2PCooooo0ol9jPX2ooooo`03o`000?oooooooooo00Wooooo00?o0000ojO0jonW`>/0;OnW`>/0
0ol0003oRe:8oh]BR005oh]BR0?o00001Oooool00ol0003oooooooooo`02o`000003o`WZ2_oooooo
oooo00cooooo0ol9jPXBooooo`?o2NX:F_ooool4o`WZ2Q_ooooo0ol9jPX6ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0000Mooooo`00oooooolY
ooooo`;o2NX:>Oooool01?l0003o2NX:o`WZ2_l9jPX4ooooo`;o2NX:1Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?nW`>_oYl3[02goYl3[00?o0000oh]BR?n;DXP01?n;DXP00ol0003ooooooooo
o`05ooooo`?o2NX:0_l0000<ooooo`?o2NX:4_ooool3o`WZ2U[ooooo0ol9jPXLooooo`?o2NX:2_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooool000007Ooo
ool00?oooooo9oooool2o`WZ2S[ooooo00?o2NX:o`000?ooool01?ooool2o`WZ2POooooo00?o0000
ooooooooool02oooool00ol0003oYl3[ojO0j`0]ojO0j`03o`000?n;DXSoRe:800?oRe:800?o0000
ooooooooool00_ooool3o`WZ2P03ooooool0003ooooo00_ooooo0ol9jPXBooooo`?o2NX:F_ooool3
o`WZ2Qcooooo0ol9jPX>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooo`00000Mooooo`00oooooolVooooo`03o`WZ2_oooooooooo03Sooooo0_l9jPX2oooo
o`03o`000?oooooooooo00;o2NX:2Oooool00ol0003oooooooooo`0<ooooo`03o`000?nW`>_oYl3[
02goYl3[00?o0000oh]BR?n;DXP00_n;DXP00ol0003oooooo`WZ2P02o`WZ2PCooooo00?o0000oooo
ooooool01_ooool4o`WZ2Q;ooooo0ol9jPYJooooo`?o2NX:6oooool4o`WZ2Q7ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Oooooo`;o00007Oooool00?oooooo9?ooool2o`WZ2SWo
oooo0_l9jPX4ooooo`03o`000?l9jP[o2NX:00cooooo00?o0000ooooooooool02oooool00ol0003o
Yl3[ojO0j`0^ojO0j`06o`000?n;DXSoRe:8oh]BR?l0003o2NX:2?ooool00ol0003oooooooooo`02
ooooo`?o2NX:4_ooool4o`WZ2U[ooooo0ol9jPXKooooo`?o2NX:5_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo023ooooo0_l0000Looooo`00oooooolRooooo`;o2NX:>Oooool2o`WZ
2PCooooo0_l9jPX00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ojO0
jonW`>/0;_nW`>/01Ol0003oRe:8oh]BR?n;DXSo000000Sooooo00?o0000ooooool9jPX00_l9jPXB
ooooo`?o2NX:F_ooool4o`WZ2Q_ooooo0ol9jPXJooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Jooooo`00oooooolPooooo`;o2NX:>?ooool3o`WZ
2PCooooo0_l9jPX2ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oYl3[ojO0j`0^ojO0j`04o`000?n;DXSoRe:8o`0000Oooooo0ol9jPXBooooo`?o2NX:F_ooool3
o`WZ2Qcooooo0ol9jPXNooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Jooooo`00oooooolOooooo`03o`WZ2_oooooooooo03Kooooo0_l9jPX4oooo
o`?o2NX:1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000ojO0
jonW`>/0;_nW`>/00ol0003oRe:8o`000004ooooo`?o2NX:0_ooool00ol0003oooooooooo`0=oooo
o`?o2NX:F_ooool3o`WZ2Q_ooooo1?l9jPXQooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Jooooo`00oooooolMooooo`;o2NX:=oooool2o`WZ2PCo
oooo0_l9jPX7ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003o
Yl3[ojO0j`0^ojO0j`;o000000Coooooo`WZ2_l9jP[o2NX:1Oooool00ol0003oooooooooo`0:oooo
o`?o2NX:F_ooool3o`WZ2Q_ooooo0ol9jPXVooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Jooooo`00oooooolKooooo`;o2NX:=oooool2o`WZ2PCo
oooo0_l9jPX:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003o
Yl3[ojO0j`0]ojO0j`03o`WZ2_l0003o2NX:00Sooooo00?o0000ooooooooool01oooool3o`WZ2U[o
oooo0ol9jPXKooooo`?o2NX::_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool06_ooool00?oooooo6Oooool2o`WZ2SKooooo0ol9jPX4ooooo`;o2NX:
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ojO0jonW`>/0
:_nW`>/3o`WZ2P;o00002_ooool00ol0003oooooooooo`03ooooo`?o2NX:FOooool4o`WZ2Q_ooooo
0ol9jPX]ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Jooooo`00oooooolHooooo`03o`WZ2_oooooooooo03Cooooo0_l9jPX4ooooo`?o2NX:3_oo
ool00ol0003oooooooooo`0;ooooo`;o00004_ooool00ol0003oYl3[ojO0j`0VojO0j`?o2NX:1?n;
DXP2o`0000Wooooo00?o0000ooooooooool00ol9jPYIooooo`?o2NX:6oooool4o`WZ2S7ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01[ooooo003o
oooooaKooooo0_l9jPXeooooo`;o2NX:1?ooool2o`WZ2Q7ooooo00?o0000ooooooooool02?ooool3
o`000003ooooool0003ooooo01;ooooo00?o0000ojO0jonW`>/08_nW`>/3o`WZ2POoRe:800?o0000
ojO0jol000001oooool4o`WZ2UWooooo0ol9jPXKooooo`?o2NX:=_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06_ooool00?oooooo5?ooool2o`WZ
2SGooooo0_l9jPX4ooooo`;o2NX:4oooool00ol0003oooooooooo`05ooooo`?o00001?ooool00ol0
003oooooooooo`0Booooo`03o`000?nW`>_oYl3[01koYl3[0ol9jPX:oh]BR003o`000?nW`>_o0000
00Cooooo0ol9jPX2ooooo`03o`000?oooooooooo05Gooooo0ol9jPXKooooo`?o2NX:>_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06Oooool00?oo
oooo4_ooool2o`WZ2SCooooo0ol9jPX3ooooo`?o2NX:5_ooool01?l0003oooooooooooooool3o`00
00Sooooo00?o0000ooooooooool04_ooool00ol0003oYl3[ojO0j`0JojO0j`?o2NX:3On;DXP01?l0
003oYl3[ojO0jol00003o`WZ2PGooooo00?o0000ooooooooool0D_ooool3o`WZ2Q_ooooo0ol9jPXm
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0I
ooooo`00oooooolAooooo`03o`WZ2_oooooooooo03;ooooo0_l9jPX4ooooo`;o2NX:6Oooool4o`00
00_ooooo00?o0000ooooooooool04oooool00ol0003oYl3[ojO0j`0FojO0j`?o2NX:4?n;DXP01Ol0
003o2NX:o`WZ2_l9jP[o000000Oooooo00?o0000ooooooooool0C_ooool4o`WZ2Q[ooooo1?l9jPY1
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0I
ooooo`00ooooool?ooooo`;o2NX:<oooool2o`WZ2PCooooo0_l9jPXKooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool05?ooool00ol0003oYl3[ojO0j`0BojO0j`?o2NX:4On;DXP3o`WZ
2P?oYl3[00?o0000ooooooooool01_ooool00ol0003oooooooooo`1:ooooo`?o2NX:6oooool3o`WZ
2TKooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01Wooooo003oooooo`gooooo0_l9jPXcooooo`;o2NX:1?ooool2o`WZ2Qgooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?nW`>_oYl3[00ooYl3[0ol9jPXAoh]BR0?o
2NX:00?oRe:8o`000?nW`>/01?nW`>/00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Oo
oooo0ol9jPXKooooo`?o2NX:B_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool06Oooool00?oooooo3?ooool00ol9jP[oooooooooo`0aooooo`;o2NX:
0oooool3o`WZ2Qoooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`;o2NX:
00?o0000ojO0jonW`>/02onW`>/3o`WZ2Q7oRe:80ol9jPX4oh]BR003o`000?nW`>_oYl3[00CoYl3[
00?o0000ooooooooool01?ooool00ol0003oooooooooo`14ooooo`?o2NX:6oooool3o`WZ2Tgooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo
003oooooo`[ooooo0_l9jPXaooooo`?o2NX:0oooool2o`WZ2R?ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0?ooooo`?o2NX:0oooool00ol0003oYl3[ojO0j`07ojO0j`?o2NX:4?n;
DXP4o`WZ2POoRe:800?o0000ojO0jonW`>/01?nW`>/00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo043ooooo0ol9jPXJooooo`Co2NX:DOooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00kooooo00?o2NX:o`000?l000004?ooool00ol0003oooooooooo`0Iooooo`00ooooool8
ooooo`;o2NX:<Oooool2o`WZ2PCooooo0_l9jPXUooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool3o`WZ2POooooo00?o0000ojO0jonW`>/00onW`>/3o`WZ2Q3oRe:80ol9jPX;
oh]BR003o`000?nW`>_oYl3[00GoYl3[00?o0000ooooooooool01?ooool00ol0003oooooooooo`0l
ooooo`Co2NX:6_ooool3o`WZ2UKooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`?o2NX:00?oooooo`000?l000004?ooool00ol0003oooooooooo`0Iooooo`00ooooool6oooo
o`;o2NX:<Oooool2o`WZ2P?ooooo0ol9jPXWooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool3o`WZ2P_ooooo0_l00003o`WZ2Q3oRe:80ol9jPX>oh]BR003o`000?nW`>_oYl3[
00GoYl3[00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`?o2NX:6oooool3o`WZ
2UWooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`?o2NX:5_ooool00ol0
003oooooooooo`0Iooooo`00ooooool5ooooo`03o`WZ2_oooooooooo02oooooo0_l9jPX3ooooo`;o
2NX::oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo0ol9jPX=ooooo`;o
2NX:00?o0000oh]BR?n;DXP03_n;DXP3o`WZ2Q7oRe:800?o0000ojO0jonW`>/01_nW`>/00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Gooooo0ol9jPXKooooo`?o2NX:GOooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo1?l9jPXIooooo`03o`000?oooooooooo01Wo
oooo003oooooo`?ooooo0_l9jPX_ooooo`?o2NX:0oooool2o`WZ2Rgooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`02ooooo`?o2NX:3Oooool3o`WZ2P;ooooo00?o0000oh]BR?n;DXP0
2on;DXP3o`WZ2QCoRe:800?o0000ojO0jonW`>/01onW`>/01?l0003oooooooooooooool3o`0003Co
oooo0ol9jPXJooooo`Co2NX:HOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
2NX:7_ooool00ol0003oooooooooo`0Hooooo`00ooooool1ooooo`;o2NX:;oooool2o`WZ2PCooooo
0_l9jPX_ooooo`03o`000?oooooooooo00gooooo00Co0000o`WZ2_l9jP[o2NX:3Oooool3o`WZ2PGo
oooo00?o0000oh]BR?n;DXP02?n;DXP3o`WZ2QOoRe:800?o0000ojO0jonW`>/01onW`>/4o`0000;o
oooo00?o0000ooooooooool0;_ooool4o`WZ2Q[ooooo0ol9jPYVooooo`03o`000?oooooooooo00Co
oooo00?o0000o`WZ2_l9jPX08Oooool00ol0003oooooooooo`0Hooooo`00o_ooool2o`WZ2Roooooo
0_l9jPX3ooooo`?o2NX:<_ooool00ol0003oooooooooo`0:ooooo`;o2NX:00?o0000ooooooooool0
2oooool3o`WZ2PSooooo00?o0000oh]BR?n;DXP01On;DXP3o`WZ2Q[oRe:800?o0000ojO0jonW`>/0
2?nW`>/00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo0ol9jPXKooooo`?o2NX:
JOooool01?l0003oooooooooooooool3o`WZ2P03o`000?oooooooooo027ooooo00?o0000oooooooo
ool06?ooool00?gooooo00?o2NX:ooooooooool0;Oooool2o`WZ2P?ooooo0_l9jPXeooooo`03o`00
0?oooooooooo00Oooooo0ol9jPX2ooooo`03o`000?oooooooooo00Sooooo0ol9jPX;ooooo`03o`00
0?n;DXSoRe:800;oRe:80ol9jPXMoh]BR003o`000?nW`>_oYl3[00WoYl3[00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Wooooo`?o2NX:6oooool3o`WZ2Vcooooo00Co2NX:o`000?l9jP[o
2NX:0oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Sooooo003kooooo`;o2NX:
;Oooool3o`WZ2P?ooooo0_l9jPXgooooo`03o`000?oooooooooo00Cooooo0ol9jPX5ooooo`03o`00
0?oooooooooo00Gooooo0ol9jPX>ooooo`05o`000?l9jP[o0000o`000?l9jPX08?n;DXP00ol0003o
Yl3[ojO0j`09ojO0j`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool3o`WZ2Q[o
oooo1?l9jPY/ooooo`?o2NX:0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool06?ooool00?Wooooo0_l9jPX]ooooo`;o2NX:0oooool3o`WZ2SWooooo
00Co0000oooooooooooooooo0ol9jPX9ooooo`04o`000?ooooooooooooooo`?o2NX:3oooool3o`WZ
2P03oh]BR?l0003o0000027oRe:800?o0000ojO0jonW`>/02_nW`>/01Ol0003ooooooooooooooooo
000002?ooooo0ol9jPXJooooo`?o2NX:KOooool3o`WZ2PKooooo00Go0000ooooooooooooooooo`00
000Sooooo`03o`000?oooooooooo01Sooooo003gooooo`;o2NX:;Oooool2o`WZ2P?ooooo0_l9jPXm
ooooo`03o`000?l9jP[o2NX:00cooooo00Co0000o`WZ2_l9jP[o2NX:3oooool3o`WZ2P;ooooo00?o
0000oh]BR?n;DXP08_n;DXP00ol0003oYl3[ojO0j`0;ojO0j`04o`000?ooooooooooo`0001oooooo
1?l9jPXJooooo`?o2NX:K?ooool4o`WZ2PWooooo00Go0000ooooooooooooooooo`00000Sooooo`03
o`000?oooooooooo01Sooooo003fooooo`03o`WZ2_oooooooooo02_ooooo0_l9jPX3ooooo`;o2NX:
??ooool3o`WZ2P03o`000?oooooooooo00Wooooo0ol9jPX00ol0003oooooooooo`0=ooooo`?o2NX:
1Oooool00ol0003oRe:8oh]BR00Roh]BR003o`000?nW`>_oYl3[00_oYl3[00Co0000oooooooooooo
00007?ooool3o`WZ2Q_ooooo0ol9jPY/ooooo`?o2NX:3_ooool01?l0003oooooooooool0000Soooo
o`03o`000?oooooooooo01Sooooo003dooooo`;o2NX::oooool3o`WZ2P?ooooo0_l9jPXkooooo`?o
2NX:0oooool00ol0003oooooooooo`06ooooo`?o2NX:1?ooool00ol0003oooooooooo`08ooooo`Co
2NX:2?ooool00ol0003oRe:8oh]BR00Roh]BR003o`000?nW`>_oYl3[00coYl3[00Co0000oooooooo
oooo00006?ooool3o`WZ2Q[ooooo1?l9jPY/ooooo`?o2NX:4_ooool01?l0003oooooooooool0000R
ooooo`03o`000?oooooooooo01Sooooo003booooo`;o2NX::oooool2o`WZ2P?ooooo0ol9jPXkoooo
o`;o2NX:1oooool00ol0003oooooooooo`02ooooo`?o2NX:1oooool00ol0003oooooooooo`05oooo
o`?o2NX:3?ooool00ol0003oRe:8oh]BR00Qoh]BR003o`000?nW`>_oYl3[00goYl3[00Co0000oooo
oooooooo00005Oooool3o`WZ2Q[ooooo0ol9jPY/ooooo`Co2NX:5Oooool01?l0003oooooooooool0
000Sooooo`03o`000?oooooooooo01Oooooo003`ooooo`;o2NX::oooool2o`WZ2P?ooooo0_l9jPXk
ooooo`?o2NX:2Oooool00ol0003oooooo`WZ2P02o`WZ2P[ooooo00?o0000ooooooooool00_ooool3
o`WZ2Poooooo00?o0000oh]BR?n;DXP08On;DXP00ol0003oYl3[ojO0j`0=ojO0j`04o`000?oooooo
ooooo`0001;ooooo0ol9jPXJooooo`?o2NX:K?ooool3o`WZ2Q[ooooo00?o0000ooooool000008ooo
ool00ol0003oooooooooo`0Gooooo`00koooool00ol9jP[oooooooooo`0Yooooo`;o2NX:0oooool2
o`WZ2S[ooooo0ol9jPX;ooooo`03o`WZ2_l0003o2NX:00gooooo00?o0000ooooool9jPX00_l9jPXB
ooooo`03o`000?n;DXSoRe:8027oRe:800?o0000ojO0jonW`>/03_nW`>/00ol0003oooooo`00000>
ooooo`Co2NX:6_ooool3o`WZ2Vcooooo0ol9jPXNooooo`;o00008oooool00ol0003oooooooooo`0G
ooooo`00kOooool2o`WZ2R[ooooo0_l9jPX2ooooo`?o2NX:>Oooool3o`WZ2P_ooooo0ol9jPX00ooo
oooo0000ooooo`0;ooooo`04o`WZ2_l0003o0000o`0001Gooooo00?o0000oh]BR?n;DXP08On;DXP0
0ol0003oYl3[ojO0j`0>ojO0j`03o`000?oooooo000000_ooooo0ol9jPXJooooo`Co2NX:K?ooool3
o`WZ2R;ooooo0_l0000Rooooo`03o`000?oooooooooo01Oooooo003[ooooo`;o2NX::Oooool3o`WZ
2P;ooooo0_l9jPXiooooo`?o2NX:2oooool3o`WZ2PGooooo00?o0000ooooooooool01_ooool3o`WZ
2P04ooooool0003o0000o`0001Gooooo00?o0000oh]BR?n;DXP08On;DXP00ol0003oYl3[ojO0j`0>
ojO0j`04o`000?ooooooooooo`0000Oooooo0ol9jPXJooooo`?o2NX:K?ooool4o`WZ2RGooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`00jOooool2o`WZ2RWooooo0_l9jPX3
ooooo`;o2NX:>?ooool3o`WZ2P_ooooo0ol9jPX8ooooo`03o`000?oooooooooo00?ooooo0ol9jPX6
ooooo`03o`000?oooooooooo01Cooooo00?o0000oh]BR?n;DXP08?n;DXP00ol0003oYl3[ojO0j`0?
ojO0j`03o`000?oooooo000000Cooooo0ol9jPXJooooo`?o2NX:K?ooool3o`WZ2R[ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Gooooo`00j?ooool00ol9jP[oooooooooo`0Woooo
o`;o2NX:0oooool2o`WZ2SOooooo0ol9jPX;ooooo`?o2NX:2oooool00ol0003oooooo`WZ2P03o`WZ
2P[ooooo00?o0000ooooooooool04oooool00ol0003oRe:8oh]BR00Poh]BR003o`000?nW`>_oYl3[
00ooYl3[00Co0000ooooool0003ooooo0ol9jPXJooooo`?o2NX:K?ooool3o`WZ2Rkooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Gooooo`00i_ooool2o`WZ2RSooooo0_l9jPX2oooo
o`?o2NX:=_ooool3o`WZ2P[ooooo1?l9jPX=ooooo`;o2NX:00?o0000ooooooooool02_ooool3o`00
01Gooooo00?o0000oh]BR?n;DXP08?n;DXP00ol0003oYl3[ojO0j`0?ojO0j`04o`WZ2_l0003o0000
o`WZ2QWooooo1?l9jPY[ooooo`Co2NX:<Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01Oooooo003Tooooo`;o2NX:9oooool3o`WZ2P;ooooo0_l9jPXfooooo`?o2NX:2_ooool3o`WZ
2Pkooooo0ol9jPX2ooooo`03o`000?oooooooooo00Oooooo0ol00002ooooo`03o`000?oooooooooo
01?ooooo00?o0000oh]BR?n;DXP08?n;DXP00ol0003oYl3[ojO0j`0;ojO0j`Co2NX:00?oYl3[o`00
0?l000005oooool3o`WZ2Vcooooo0ol9jPXfooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool05oooool00>?ooooo00?o2NX:ooooooooool09Oooool2o`WZ2P?ooooo0_l9jPXeooooo`?o
2NX:2_ooool3o`WZ2Pgooooo1?l9jPX5ooooo`03o`000?oooooooooo00?ooooo1?l00006ooooo`03
o`000?oooooooooo01;ooooo00?o0000oh]BR?n;DXP08?n;DXP00ol0003oYl3[ojO0j`08ojO0j`?o
2NX:1OnW`>/00ol0003oooooo`00000Cooooo`?o2NX:K?ooool3o`WZ2S[ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Gooooo`00hOooool2o`WZ2RKooooo0_l9jPX2ooooo`?o2NX:
=?ooool3o`WZ2P[ooooo0ol9jPX=ooooo`?o2NX:2_ooool00ol0003oooooo`000002o`0000[ooooo
00?o0000ooooooooool04_ooool00ol0003oRe:8oh]BR00Ooh]BR003o`000?nW`>_oYl3[00GoYl3[
1?l9jPX9ojO0j`;o00004?ooool3o`WZ2Vcooooo0ol9jPXnooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool05_ooool00=oooooo0_l9jPXVooooo`;o2NX:0_ooool2o`WZ2SCooooo0ol9
jPX:ooooo`?o2NX:3Oooool3o`WZ2Pgooooo0_l0000=ooooo`03o`000?oooooooooo01;ooooo00?o
0000oh]BR?n;DXP07on;DXP01?l0003oYl3[ojO0jonW`>/4o`WZ2PgoYl3[0_l0000<ooooo`Co2NX:
Joooool4o`WZ2T7ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`00gOoo
ool2o`WZ2RGooooo0ol9jPX2ooooo`;o2NX:<oooool3o`WZ2P[ooooo0ol9jPX=ooooo`?o2NX:4?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000oh]BR?n;DXP07on;
DXP01?l0003o2NX:o`WZ2_l9jPXBojO0j`03o`000?oooooooooo00Oooooo0ol9jPY/ooooo`?o2NX:
A_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Kooooo003Looooo`03o`WZ2_oo
oooooooo02?ooooo0_l9jPX3ooooo`;o2NX:<_ooool3o`WZ2P[ooooo0ol9jPX<ooooo`Co2NX:5?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oh]BR?n;DXP07on;
DXP00ol0003oYl3[ojO0j`0CojO0j`03o`000?oooooooooo00Cooooo0ol9jPY/ooooo`?o2NX:B_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo003Jooooo`;o2NX:9?ooool2
o`WZ2P;ooooo0ol9jPXaooooo`?o2NX:2_ooool3o`WZ2Pcooooo0ol9jPXHooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04?ooool00ol0003oRe:8oh]BR00Ooh]BR003o`000?nW`>_o
Yl3[01?oYl3[0_l00002ooooo`?o2NX:Joooool4o`WZ2Tkooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Fooooo`00f?ooool2o`WZ2RCooooo0_l9jPX2ooooo`;o2NX:<Oooool3o`WZ
2PWooooo1?l9jPX<ooooo`?o2NX:6oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
013ooooo00?o0000oh]BR?n;DXP07_n;DXP00ol0003oYl3[ojO0j`0DojO0j`Co2NX:Joooool3o`WZ
2U;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`00e_ooool2o`WZ2RCo
oooo0_l9jPX2ooooo`;o2NX:<?ooool3o`WZ2PWooooo0ol9jPX<ooooo`Co2NX:7oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000oh]BR?n;DXP07_n;DXP00ol0003o
Yl3[ojO0j`0AojO0j`?o2NX:00?oYl3[o`000?ooool0JOooool3o`WZ2UKooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Fooooo`00eOooool00ol9jP[oooooooooo`0Qooooo`?o2NX:
00Coooooo`WZ2_l9jP[o2NX:;oooool3o`WZ2PWooooo0ol9jPX<ooooo`?o2NX:8oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000oh]BR?n;DXP07_n;DXP00ol0003o
Yl3[ojO0j`0>ojO0j`?o2NX:1?nW`>/00ol0003oooooooooo`1Tooooo`Co2NX:F_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo003Cooooo`;o2NX:8_ooool2o`WZ2P;ooooo
0_l9jPX_ooooo`?o2NX:2Oooool3o`WZ2Pcooooo0ol9jPXWooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03oooool00ol0003oRe:8oh]BR00Noh]BR003o`000?nW`>_oYl3[00_oYl3[
0ol9jPX8ojO0j`03o`000?oooooooooo063ooooo0ol9jPYNooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05_ooool00=7ooooo0_l9jPXRooooo`;o2NX:0_ooool2o`WZ2Rkooooo0ol9
jPX9ooooo`?o2NX:2oooool4o`WZ2R[ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?n;DXSoRe:801goRe:800?o0000ojO0jonW`>/02?nW`>/4o`WZ2P_oYl3[00?o
0000ooooooooool0GOooool3o`WZ2V;ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Eooooo`00coooool2o`WZ2R;ooooo0_l9jPX2ooooo`;o2NX:;Oooool3o`WZ2PWooooo0ol9jPX;
ooooo`?o2NX:;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000
oh]BR?n;DXP07On;DXP00ol0003oYl3[ojO0j`05ojO0j`?o2NX:3onW`>/00ol0003oooooooooo`1J
ooooo`?o2NX:I_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Gooooo003>oooo
o`03o`WZ2_oooooooooo01oooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX/ooooo`?o2NX:2Oooool3
o`WZ2P_ooooo0ol9jPXbooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3
o`WZ2P03o`000?n;DXSoRe:801goRe:800?o0000ojO0jonW`>/00_nW`>/3o`WZ2Q;oYl3[00?o0000
ooooooooool0E_ooool4o`WZ2V[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0E
ooooo`00c?ooool2o`WZ2R3ooooo0_l9jPX2ooooo`;o2NX:;?ooool3o`WZ2PWooooo0ol9jPX:oooo
o`Co2NX:=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo1?l9jPX3oooo
o`03o`000?n;DXSoRe:801goRe:800?o0000ojO0jol9jPX00_l9jPXEojO0j`03o`000?oooooooooo
05?ooooo0ol9jPY^ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00<[o
oooo0_l9jPXPooooo`;o2NX:0_ooool2o`WZ2Rcooooo0_l9jPX9ooooo`?o2NX:2_ooool3o`WZ2S[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05o`WZ2POooooo00?o0000oh]BR?n;
DXP06on;DXP2o`WZ2P;o00006?nW`>/00ol0003oooooooooo`1@ooooo`?o2NX:L_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo0038ooooo`;o2NX:8?ooool2o`WZ2P04oooo
ool9jP[o2NX:o`WZ2R_ooooo0ol9jPX7ooooo`Co2NX:2_ooool3o`WZ2Sgooooo00?o0000oooooooo
ool03?ooool01?l9jP[o0000o`WZ2_l9jPX<ooooo`03o`000?n;DXSoRe:801KoRe:81Ol9jPX01?n;
DXSo0000o`000?l0000HojO0j`03o`000?oooooooooo04cooooo1?l9jPYfooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool05Oooool00<Oooooo00?o2NX:ooooooooool07Oooool3o`WZ
2P03ooooool9jP[o2NX:02_ooooo0ol9jPX7ooooo`?o2NX:2_ooool4o`WZ2T7ooooo00?o0000oooo
ooooool01_ooool5o`WZ2P03ooooool0003ooooo00gooooo00?o0000oh]BR?n;DXP04_n;DXP4o`WZ
2PKoRe:800?o0000ojO0jonW`>/06?nW`>/00ol0003oooooooooo`19ooooo`?o2NX:Noooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo0035ooooo`;o2NX:7_ooool2o`WZ2P;o
oooo0_l9jPXZooooo`?o2NX:1oooool3o`WZ2P[ooooo0ol9jPY5ooooo`03o`000?oooooooooo00;o
oooo1?l9jPX7ooooo`03o`000?oooooooooo00_ooooo00?o0000oh]BR?n;DXP03On;DXP5o`WZ2P[o
Re:800?o0000ojO0jonW`>/06?nW`>/00ol0003oooooooooo`16ooooo`?o2NX:O_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo0033ooooo`;o2NX:7_ooool2o`WZ2P04oooo
ool9jP[o2NX:o`WZ2RWooooo0ol9jPX7ooooo`?o2NX:2_ooool3o`WZ2TSooooo00?o2NX:o`000?l9
jPX00_l9jPX;ooooo`03o`000?oooooooooo00_ooooo00?o0000oh]BR?n;DXP02?n;DXP5o`WZ2Poo
Re:800?o0000ojO0jonW`>/06?nW`>/00ol0003oooooooooo`12ooooo`Co2NX:P_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01Gooooo0031ooooo`;o2NX:7_ooool2o`WZ2P03oooo
ool9jP[o2NX:02Wooooo0ol9jPX7ooooo`?o2NX:2Oooool4o`WZ2TOooooo1?l9jPX00ooooooo0000
ooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000oh]BR?n;DXP01?n;DXP4o`WZ2QCoRe:8
0_l0000IojO0j`03o`000?oooooooooo03oooooo0ol9jPZ7ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool05Oooool00<3ooooo00?o2NX:ooooooooool07?ooool2o`WZ2P03ooooool9
jP[o2NX:02Sooooo0ol9jPX7ooooo`?o2NX:2Oooool3o`WZ2TKooooo1Ol9jPX5ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oRe:8o`WZ2P04o`WZ2QOoRe:800Co
0000oooooooooooo00006OnW`>/00ol0003oooooooooo`0kooooo`?o2NX:R_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01Cooooo002nooooo`;o2NX:7?ooool3o`WZ2P03ooooool9
jP[o2NX:02Oooooo0ol9jPX7ooooo`?o2NX:2Oooool3o`WZ2TGooooo1?l9jPX;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01_ooool2o`WZ2P;o000000?o2NX:oh]BR?n;DXP06_n;
DXP01Ol0003ooooooooooooooooo000001SoYl3[00?o0000ooooooooool0>?ooool3o`WZ2Xkooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`00_?ooool2o`WZ2Qcooooo0_l9
jPX01?oooooo2NX:o`WZ2_l9jPXVooooo`?o2NX:1oooool3o`WZ2PWooooo0ol9jPY3ooooo`Go2NX:
3oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`Go2NX:0_ooool2o`0001go
Re:800?o0000ooooooooool00_ooool00ol0003oYl3[ojO0j`0EojO0j`03o`000?oooooooooo03Co
oooo1?l9jPZBooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00;_ooooo
00?o2NX:ooooooooool06_ooool2o`WZ2P03ooooool9jP[o2NX:02Kooooo0ol9jPX6ooooo`Co2NX:
2?ooool4o`WZ2T;ooooo1?l9jPXEooooo`03o`000?oooooooooo00_ooooo00?o2NX:o`000?l9jPX0
0_l9jPX8ooooo`03o`000?n;DXSoRe:801_oRe:800?o0000ooooooooool00oooool00ol0003oYl3[
ojO0j`0DojO0j`03o`000?oooooooooo037ooooo0ol9jPZGooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05?ooool00;Wooooo0_l9jPXKooooo`;o2NX:00?oooooo`WZ2_l9jPX09Ooo
ool3o`WZ2PKooooo0ol9jPX9ooooo`?o2NX:@Oooool5o`WZ2QWooooo00?o0000ooooooooool01_oo
ool5o`WZ2P?o00002_ooool00ol0003oRe:8oh]BR00Joh]BR003o`000?oooooooooo00Cooooo00?o
0000ojO0jonW`>/01_nW`>/00ol0003oYl3[ojO0j`0;ojO0j`03o`000?oooooooooo02kooooo0ol9
jPZJooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool00;Oooooo0_l9jPXJ
ooooo`Ko2NX:9?ooool3o`WZ2PKooooo0ol9jPX9ooooo`?o2NX:@?ooool4o`WZ2Qoooooo00?o0000
ooooooooool01Ol9jPX2ooooo`?o00000_ooool00ol0003oooooooooo`08ooooo`03o`000?n;DXSo
Re:801[oRe:800?o0000ooooooooool01Oooool00ol0003oYl3[ojO0j`0CojO0j`03o`000?oooooo
oooo02[ooooo1?l9jPZNooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool0
0;Gooooo0_l9jPXJooooo`;o2NX:00?oooooo`WZ2_l9jPX09?ooool3o`WZ2PKooooo0ol9jPX8oooo
o`Co2NX:?oooool4o`WZ2R7ooooo0_l9jPX00ol0003o2NX:o`WZ2P03ooooo`Co00001_ooool00ol0
003oooooooooo`07ooooo`03o`000?n;DXSoRe:801[oRe:800?o0000ooooooooool01_ooool00ol0
003oYl3[ojO0j`0BojO0j`03o`000?oooooooooo02Oooooo0ol9jPZSooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05?ooool00;Cooooo00?o2NX:ooooooooool06?ooool2o`WZ2P03
ooooool9jP[o2NX:02?ooooo0ol9jPX6ooooo`?o2NX:2?ooool3o`WZ2Skooooo1Ol9jPXPooooo`Go
2NX:0_ooool00ol0003oooooooooo`03o`0000[ooooo00?o0000ooooooooool01oooool00ol0003o
Re:8oh]BR00Joh]BR003o`000?oooooooooo00Oooooo00?o0000ojO0jonW`>/04OnW`>/00ol0003o
ooooooooo`0Tooooo`?o2NX:Yoooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Co
oooo002booooo`;o2NX:6Oooool2o`WZ2P03ooooool9jP[o2NX:02;ooooo0ol9jPX6ooooo`?o2NX:
2?ooool3o`WZ2Sgooooo1?l9jPXOooooo`Ko2NX:2?ooool2o`0000kooooo00?o0000ooooooooool0
1_ooool00ol0003oRe:8oh]BR00Joh]BR003o`000?oooooooooo00Sooooo00?o0000ojO0jonW`>/0
4?nW`>/00ol0003oooooooooo`0Qooooo`?o2NX:Z_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Cooooo002`ooooo`;o2NX:6?ooool6o`WZ2R7ooooo0ol9jPX6ooooo`?o2NX:1ooo
ool4o`WZ2S_ooooo1Ol9jPXNooooo`Go2NX:3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000oh]BR?n;DXP06On;DXP00ol0003oooooooooo`0:ooooo`03o`000?nW
`>_oYl3[00ooYl3[00?o0000ooooooooool07Oooool4o`WZ2Zkooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Cooooo`00[_ooool2o`WZ2QSooooo0_l9jPX00ooooooo2NX:o`WZ2P0Q
ooooo`?o2NX:1_ooool3o`WZ2POooooo0ol9jPXkooooo`Co2NX:7_ooool5o`WZ2QCooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?n;DXSoRe:801WoRe:800?o0000
ooooooooool02_ooool00ol0003oYl3[ojO0j`0>ojO0j`;o00007?ooool3o`WZ2[?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Cooooo`00[Oooool00ol9jP[oooooooooo`0Foooo
o`;o2NX:00?oooooo`WZ2_l9jPX08?ooool3o`WZ2PKooooo0ol9jPX7ooooo`?o2NX:>Oooool5o`WZ
2Qgooooo1Ol9jPXIooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0
003oRe:8oh]BR00Ioh]BR003o`000?oooooooooo00_ooooo00?o0000ojO0jonW`>/02_nW`>/3o`00
0003ooooool0003ooooo01Sooooo0ol9jPZfooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04oooool00:_ooooo0_l9jPXGooooo`Go2NX:7oooool3o`WZ2PGooooo1?l9jPX6ooooo`Co
2NX:>?ooool4o`WZ2Qgooooo1Ol9jPXOooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01?ooool00ol0003oRe:8oh]BR00Hoh]BR003o`000?oooooooooo00gooooo00?o0000ojO0jonW
`>/01_nW`>/3o`0000Cooooo00?o0000ooooooooool04oooool4o`WZ2[[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Cooooo`00ZOooool2o`WZ2QOooooo1?l9jPXOooooo`?o2NX:
1Oooool3o`WZ2POooooo0ol9jPXgooooo`Go2NX:7?ooool5o`WZ2RGooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`03ooooo`03o`000?n;DXSoRe:801SoRe:800?o0000ooooooooool0
3_ooool00ol0003oYl3[ojO0j`03ojO0j`;o00001oooool00ol0003oooooooooo`0@ooooo`?o2NX:
_oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo002Wooooo`;o2NX:5_oo
ool5o`WZ2Qkooooo0ol9jPX5ooooo`?o2NX:1oooool3o`WZ2SKooooo1?l9jPXLooooo`Go2NX::_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oh]BR?n;DXP06?n;
DXP00ol0003oooooooooo`0?ooooo`03o`000?nW`>_o000000;o00002Oooool00ol0003ooooooooo
o`0=ooooo`?o2NX:`oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo002V
ooooo`03o`WZ2_oooooooooo01Cooooo0_l9jPX00ooooooo2NX:o`WZ2P0Mooooo`?o2NX:1Oooool3
o`WZ2PKooooo1?l9jPXdooooo`Go2NX:6_ooool6o`WZ2S3ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`03o`000?n;DXSoRe:801OoRe:800?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo1?l9jP[6ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04oooool00:Cooooo0_l9jPXEooooo`Go2NX:7?ooool3o`WZ
2PGooooo0ol9jPX6ooooo`?o2NX:=?ooool4o`WZ2Q[ooooo1Ol9jPXfooooo`03o`000?oooooooooo
00kooooo00Go0000ooooooooooooooooo`00000Ioh]BR003o`000?oooooooooo017ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`?o2NX:boooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01?ooooo002Rooooo`;o2NX:5Oooool4o`WZ2Qgooooo0_l9jPX5oooo
o`?o2NX:1_ooool3o`WZ2S;ooooo1Ol9jPXIooooo`Go2NX:??ooool00ol0003oooooooooo`0=oooo
o`05o`000?ooooooooooooooool000006On;DXP00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool3o`WZ2/oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Cooooo`00X?ooool2o`WZ2QCooooo1Ol9jPXLooooo`?o2NX:1?ooool3o`WZ
2PGooooo1?l9jPXaooooo`Co2NX:6Oooool5o`WZ2T7ooooo00?o0000ooooooooool03_ooool01?l0
003oooooooooool0000Hoh]BR003o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`03o`WZ2];ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`00Woooool00ol9jP[oooooooooo`0Booooo`Go2NX:6oooool3o`WZ2PCooooo0ol9jPX5oooo
o`?o2NX:<?ooool5o`WZ2QSooooo1Ol9jPY7ooooo`03o`000?oooooooooo00gooooo00Co0000oooo
oooooooo00006?n;DXP00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo1?l9jP[F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool009gooooo0_l9jPXCoooo
o`Co2NX:6oooool3o`WZ2P?ooooo1?l9jPX5ooooo`?o2NX:;oooool4o`WZ2QSooooo1Ol9jPY=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooool000005on;DXP00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Kooooo0ol9jPX00ooooooo0000ooooo`3Hooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04_ooool009_ooooo0_l9jPXCooooo`Co2NX:6_ooool3o`WZ2P?o
oooo0ol9jPX6ooooo`?o2NX:;Oooool5o`WZ2QOooooo1Ol9jPYBooooo`03o`000?oooooooooo00go
oooo00?o0000ooooool000005on;DXP00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?o
oooo0ol9jPX4ooooo`03o`000?oooooooooo0=Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Booooo`00VOooool2o`WZ2Q;ooooo1Ol9jPXIooooo`?o2NX:0oooool3o`WZ2PGooooo
1?l9jPX/ooooo`Co2NX:5_ooool6o`WZ2USooooo00?o0000ooooooooool03Oooool2o`0001OoRe:8
00?o0000ooooooooool04oooool01?l0003o2NX:o`WZ2_l9jPX2o`0000Oooooo00?o0000oooooooo
ool0f?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo002Hooooo`03o`WZ
2_oooooooooo013ooooo1Ol9jPXHooooo`?o2NX:0oooool3o`WZ2PGooooo0ol9jPX[ooooo`Go2NX:
5Oooool5o`WZ2Ukooooo00?o0000ooooooooool03Oooool2o`0001KoRe:800?o0000ooooooooool0
4?ooool5o`WZ2P?ooooo0_l00007ooooo`03o`000?oooooooooo0=Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Booooo`00U_ooool2o`WZ2Q7ooooo1?l9jPXHooooo`?o2NX:0ooo
ool3o`WZ2PGooooo0ol9jPXZooooo`Co2NX:5Oooool5o`WZ2VCooooo00?o0000ooooooooool03Ooo
ool00ol0003oRe:8oh]BR00Doh]BR003o`000?oooooooooo00[ooooo1_l9jPX4ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0f_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01;ooooo002Dooooo`;o2NX:4Oooool4o`WZ2QOooooo0ol9jPX3ooooo`?o2NX:1?ooool4
o`WZ2RSooooo1Ol9jPXDooooo`Go2NX:JOooool00ol0003oooooooooo`0=ooooo`;o00005?n;DXP0
0ol0003oooooooooo`06ooooo`Go2NX:2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo0=_ooooo00Go0000ooooooooooooooooo`00000Dooooo`00T_ooool2o`WZ2Q3ooooo1Ol9jPXF
ooooo`?o2NX:0oooool3o`WZ2PCooooo0ol9jPXXooooo`Co2NX:5?ooool5o`WZ2Voooooo00?o0000
ooooooooool03?ooool2o`0001CoRe:800Co0000oooooooooooooooo1Ol9jPX>ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0foooool01Ol0003ooooooooooooooooo000001Cooooo
002Aooooo`03o`WZ2_oooooooooo00kooooo1?l9jPXFooooo`?o2NX:0oooool3o`WZ2PCooooo0ol9
jPXVooooo`Go2NX:4oooool5o`WZ2WCooooo00?o0000ooooooooool03?ooool3o`0001?oRe:80_l0
0002o`WZ2Q?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Looooo`04o`000?oo
ooooooooo`0001Cooooo002?ooooo`;o2NX:3oooool4o`WZ2QGooooo0ol9jPX3ooooo`?o2NX:0ooo
ool4o`WZ2RGooooo1?l9jPXCooooo`Go2NX:N_ooool00ol0003oooooooooo`08ooooo`Co000000?o
Re:8o`000?n;DXP04On;DXP3o`0001Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`3Mooooo`04o`000?ooooooooooo`0001?ooooo002=ooooo`;o2NX:3oooool4o`WZ2QCooooo0ol9
jPX2ooooo`Co2NX:0oooool3o`WZ2RCooooo1Ol9jPXAooooo`Ko2NX:P?ooool00ol0003ooooooooo
o`03ooooo`Co00000_ooool01Ol9jP[o0000oh]BR?n;DXSo0000017oRe:800?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=gooooo00Co0000oooooooooooo
00004oooool008cooooo00?o2NX:ooooooooool03Oooool4o`WZ2Q?ooooo0ol9jPX2ooooo`?o2NX:
1?ooool3o`WZ2R?ooooo1?l9jPXAooooo`Go2NX:Q_ooool00ol0003oooooooooo`03o`0000Ko2NX:
00?oooooo`000?n;DXP00_n;DXP00ol0003oRe:8oh]BR00>oh]BR003o`000?oooooooooo01Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`3Nooooo`03o`000?oooooo000001?ooooo
002:ooooo`;o2NX:3Oooool4o`WZ2Q?ooooo0ol9jPX2ooooo`?o2NX:0oooool4o`WZ2R7ooooo1Ol9
jPX@ooooo`Go2NX:Q?ooool8o`WZ2P;o00002_ooool00ol0003oRe:8oh]BR002oh]BR003o`000?n;
DXSoRe:800coRe:800?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`?o0000hOoo
ool2o`0001?ooooo0028ooooo`;o2NX:3Oooool4o`WZ2Q;ooooo0ol9jPX2ooooo`?o2NX:0oooool3
o`WZ2R7ooooo1?l9jPX@ooooo`Go2NX:P?ooool9o`WZ2PSooooo00?o0000ooooooooool02Oooool0
0ol0003oRe:8oh]BR002oh]BR003o`000?n;DXSoRe:800coRe:800?o0000ooooooooool05_ooool0
0ol0003oooooooooo`06ooooo`?o00000_ooool00ol0003oooooooooo`3Pooooo`03o`000?oooooo
oooo017ooooo0026ooooo`;o2NX:3Oooool4o`WZ2Q7ooooo0ol9jPX2ooooo`?o2NX:0oooool3o`WZ
2Qoooooo1Ol9jPX?ooooo`Go2NX:Noooool:o`WZ2Q;ooooo00?o0000ooooooooool02?ooool00ol0
003oRe:8oh]BR003oh]BR003o`000?n;DXSoRe:800[oRe:800?o0000ooooooooool05oooool00ol0
003oooooooooo`02ooooo`Co00001Oooool00ol0003oooooooooo`3dooooo`00QOooool00ol9jP[o
ooooooooo`0;ooooo`?o2NX:4Oooool3o`WZ2P;ooooo0ol9jPX2ooooo`Co2NX:7_ooool4o`WZ2Poo
oooo1Ol9jPYgooooo`Wo2NX:7Oooool00ol0003oooooooooo`08ooooo`03o`000?n;DXSoRe:800?o
Re:800?o0000oh]BR?n;DXP02On;DXP00ol0003oooooooooo`0Gooooo`03o`000?oooooo000000;o
00002?ooool00ol0003oooooooooo`3eooooo`00Poooool2o`WZ2P_ooooo1?l9jPX@ooooo`?o2NX:
0_ooool3o`WZ2P;ooooo0ol9jPXMooooo`Go2NX:3Oooool6o`WZ2W;ooooo2_l9jPXWooooo`03o`00
0?oooooooooo00Oooooo00?o0000oh]BR?n;DXP01?n;DXP00ol0003oRe:8oh]BR008oh]BR003o`00
0?oooooooooo01Oooooo0_l0000;ooooo`03o`000?oooooooooo0?Gooooo0021ooooo`;o2NX:2ooo
ool4o`WZ2Poooooo0ol9jPX2ooooo`?o2NX:0_ooool3o`WZ2Qcooooo1?l9jPX=ooooo`Go2NX:Kooo
ool9o`WZ2S7ooooo00?o0000ooooooooool01oooool00ol0003oRe:8oh]BR005oh]BR003o`000?n;
DXSoRe:800KoRe:800?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo0?Gooooo001oooooo`;o2NX:2oooool4o`WZ2Pkooooo0ol9jPX00ooooooo2NX:o`WZ2P02
o`WZ2P;ooooo0ol9jPXJooooo`Go2NX:3?ooool5o`WZ2V[ooooo2_l9jPXkooooo`03o`000?oooooo
oooo00Kooooo00?o0000oh]BR?n;DXP01On;DXP00ol0003oRe:8oh]BR006oh]BR003o`000?oooooo
oooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3eooooo`00O_ooool00ol9
jP[oooooooooo`09ooooo`?o2NX:3_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2P;ooooo1?l9jPXI
ooooo`Co2NX:3?ooool5o`WZ2VKooooo2Ol9jPY6ooooo`03o`000?oooooooooo00Gooooo00?o0000
oh]BR?n;DXP01_n;DXP00ol0003oRe:8oh]BR004oh]BR003o`000?oooooooooo01Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`3fooooo`00O?ooool2o`WZ2PWooooo1?l9jPX=oooo
o`?o2NX:00Coooooo`WZ2_l9jP[o2NX:0_ooool3o`WZ2QSooooo1Ol9jPX;ooooo`Go2NX:HOooool:
o`WZ2U3ooooo00?o0000ooooooooool01?ooool00ol0003oRe:8oh]BR007oh]BR003o`000?n;DXSo
Re:800?oRe:800?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo0?Kooooo001jooooo`;o2NX:2Oooool4o`WZ2Pgooooo0_l9jPX01?oooooo2NX:o`WZ2_l9jPX2
ooooo`?o2NX:5oooool4o`WZ2P_ooooo1Ol9jPYMooooo`Wo2NX:Foooool00ol0003oooooooooo`03
ooooo`03o`000?n;DXSoRe:800SoRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0m_ooool007Sooooo0_l9jPX9oooo
o`?o2NX:3Oooool6o`WZ2P03ooooool9jP[o2NX:00;o2NX:5Oooool5o`WZ2P[ooooo1Ol9jPYHoooo
o`[o2NX:I?ooool00ol0003oooooooooo`03ooooo`03o`000?n;DXSoRe:800SoRe:800Go0000oh]B
R?n;DXSoRe:8o`00000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0moooool0
07Oooooo00?o2NX:ooooooooool01oooool3o`WZ2Pcooooo1_l9jPX01?oooooo2NX:o`WZ2_l9jPXE
ooooo`Co2NX:2Oooool6o`WZ2UCooooo2Ol9jPY_ooooo`03o`000?oooooooooo00;ooooo00?o0000
oh]BR?n;DXP02On;DXP01?l0003oRe:8oh]BR?l0000Jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0moooool007Gooooo0_l9jPX8ooooo`?o2NX:2oooool6o`WZ2P04ooooool9jP[o
2NX:o`WZ2Q?ooooo1Ol9jPX8ooooo`Go2NX:D?ooool:o`WZ2WWooooo00Go0000oooooooooooooooo
o`00000<oh]BR003o`000?n;DXSo000001[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`3gooooo`00Loooool2o`WZ2POooooo1?l9jPX:ooooo`[o2NX:4_ooool4o`WZ2PSooooo1Ol9
jPY<ooooo`Wo2NX:Q?ooool01?l0003oooooooooool0000;oh]BR0Co00006_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo0?Oooooo001aooooo`;o2NX:1oooool3o`WZ2P[ooooo2Ol9
jPXBooooo`Co2NX:1oooool5o`WZ2TOooooo2_l9jPZ=ooooo`04o`000?ooooooooooo`0000SoRe:8
0ol00004ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`3hooooo`00L?ooool00ol9jP[oooooooooo`05ooooo`?o2NX:2Oooool9o`WZ2Q3ooooo1Ol9
jPX6ooooo`Go2NX:@oooool9o`WZ2YSooooo00?o0000ooooool000001?n;DXP4o`0000Sooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`?o0000n_ooool006kooooo0_l9jPX6
ooooo`?o2NX:2?ooool9o`WZ2Poooooo1?l9jPX6ooooo`Go2NX:?_ooool:o`WZ2Z;ooooo0_l00000
1?n;DXSo0000o`000?l0000=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Ooo
ool3o`0000;ooooo00?o0000ooooooooool0n?ooool006cooooo0_l9jPX5ooooo`?o2NX:2?ooool8
o`WZ2Pkooooo1Ol9jPX5ooooo`Go2NX:>_ooool9o`WZ2Zgooooo0_l0000Aooooo`03o`000?oooooo
oooo01?ooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo0?Wooooo001Z
ooooo`;o2NX:1Oooool3o`WZ2POooooo2?l9jPX=ooooo`Co2NX:1?ooool6o`WZ2SGooooo2_l9jPZh
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0003oooooo`000002
o`0000Oooooo00?o0000ooooooooool0n_ooool006Wooooo00?o2NX:ooooooooool00oooool3o`WZ
2PKooooo2?l9jPX;ooooo`Go2NX:0oooool5o`WZ2S;ooooo2Ol9jP[3ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04?ooool2o`0000[ooooo00?o0000ooooooooool0n_ooool006Oo
oooo0_l9jPX4ooooo`?o2NX:1Oooool7o`WZ2P_ooooo1?l9jPX3ooooo`Go2NX:;Oooool:o`WZ2/go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0noooool006Gooooo0_l9jPX3ooooo`?o2NX:1Oooool7o`WZ2PWooooo
1Ol9jPX2ooooo`Go2NX::Oooool9o`WZ2]Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0o?ooool006Cooooo00Co
2NX:oooooooooooooooo0ol9jPX4ooooo`Oo2NX:2?ooool4o`WZ2P;ooooo1Ol9jPXTooooo`[o2NX:
h_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`3mooooo`00H_ooool2o`WZ2P;ooooo0ol9jPX3ooooo`Ko2NX:1ooo
ool5o`WZ2P03ooooool9jP[o2NX:00?o2NX:8?ooool9o`WZ2^gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oOoo
ool0063ooooo0_l9jPX2ooooo`;o2NX:0oooool6o`WZ2PKooooo1?l9jPX00ooooooo2NX:o`WZ2P03
o`WZ2Q_ooooo2_l9jP[gooooo`03o`000?oooooooooo00gooooo1Ol00008ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0o_ooool005kooooo0_l9jPX2ooooo`;o2NX:0_ooool6o`WZ
2PCooooo2_l9jPXGooooo`Wo2NX:ooooool3ooooo`03o`000?oooooooooo00Wooooo0ol00005oooo
o`?o00001?ooool00ol0003oooooooooo`06ooooo`?o0000ooooool2ooooo`00GOooool00ol9jP[o
ooooo`WZ2P02o`WZ2P03ooooool9jP[o2NX:00Co2NX:0oooool8o`WZ2Q?ooooo2_l9jP[oooooo`go
oooo00?o0000ooooooooool01?ooool4o`0000_ooooo1?l00006ooooo`Co0000ooooool4ooooo`00
Foooool:o`WZ2P;ooooo2?l9jPX?ooooo`Wo2NX:oooooolHooooo`03o`000?oooooooooo00?o0000
4_ooool8o`000?oooooo1oooool005Wooooo2Ol9jPX00ooooooo2NX:o`WZ2P05o`WZ2P[ooooo2_l9
jP[oooooob;ooooo0ol0000Cooooo`Ko0000ooooool:ooooo`00Eoooool>o`WZ2PKooooo2Ol9jP[o
oooooboooooo0ol0000>ooooo`Co0000ooooool>ooooo`00E_ooool:o`WZ2P03ooooool9jP[o2NX:
00So2NX:oooooolkooooo`?o00002?ooool4o`000?oooooo4Oooool005Cooooo3Ol9jP[oooooodSo
oooo0ol00002ooooo`?o0000oooooolEooooo`00Doooool5o`WZ2_ooooooE?ooool2o`000?oooooo
6?ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?oo
ooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6
ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00oooo
ooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKo
oooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003ooooo
ooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_oo
ool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?oooooo
ooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6oooo
o`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00oooooooo
ooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo
003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003ooooooooo
ooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool0
0?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?oooooooooo
ooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00
ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00oooooooooooo
olKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003o
ooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003ooooooooooooo
a_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?oo
ooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6
ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00oooo
ooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKo
oooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003ooooo
ooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_oo
ool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?oooooo
ooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6oooo
o`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00oooooooo
ooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo
003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003ooooooooo
ooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool0
0?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?oooooooooo
ooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00
ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00oooooooooooo
olKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003o
ooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003ooooooooooooo
a_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?oo
ooooooooooo6ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6
ooooo`00ooooooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00oooo
ooooooooolKooooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKo
oooo003oooooooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo003ooooo
ooooooooa_ooool00?ooooooooooooo6ooooo`00ooooooooooooolKooooo0000\
\>"],
  ImageRangeCache->{{{0, 707.25}, {480, 0}} -> {0.0216759, 0.147119, \
0.00138373, 0.00138373}}]
}, Open  ]],

Cell[TextData[{
  "Once again, the default behavior of ",
  StyleBox["FindWaveFronts", "Input"],
  " is to make its calculation in machine precision:"
}], "Text"],

Cell[CellGroupData[{

Cell["Timing[wav0 = FindWaveFronts[sys2D]]", "Input"],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 2, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 2, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.40312e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.01479 .32352 -36 -2.79172 ]
[.01479 .32352 0 6.20828 ]
[.00179 .40505 -36 -2.86096 ]
[.00179 .40505 0 6.13904 ]
[-0.01191 .49092 -36 -2.9343 ]
[-0.01191 .49092 0 6.0657 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Length \\(absolute distance\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02706 .31887 m
.03319 .31654 L
s
[(155.24)] .01479 .32352 1 -0.37962 Mshowa
.01412 .40055 m
.02028 .39831 L
s
[(155.25)] .00179 .40505 1 -0.36423 Mshowa
.00048 .4866 m
.00668 .48445 L
s
[(155.26)] -0.01191 .49092 1 -0.34793 Mshowa
.125 Mabswid
.02452 .33487 m
.02821 .33348 L
s
.02196 .35104 m
.02565 .34966 L
s
.01937 .36737 m
.02307 .36601 L
s
.01676 .38388 m
.02045 .38252 L
s
.01145 .4174 m
.01515 .41607 L
s
.00875 .43443 m
.01245 .43311 L
s
.00602 .45164 m
.00973 .45032 L
s
.00326 .46903 m
.00698 .46772 L
s
.02957 .30302 m
.03325 .30162 L
s
.03206 .28734 m
.03573 .28592 L
s
.03452 .27181 m
.03819 .27039 L
s
.03695 .25644 m
.04062 .255 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.977 .099 0 r
.38757 .79726 .39809 .80491 .41556 .80118 .40517 .79141 Metetra
.972 .117 0 r
.40517 .79141 .41556 .80118 .4332 .7955 .42294 .78376 Metetra
.961 .161 0 r
.42294 .78376 .4332 .7955 .45097 .78826 .44082 .77472 Metetra
.945 .223 0 r
.44082 .77472 .45097 .78826 .46885 .77985 .45879 .76466 Metetra
.926 .297 0 r
.45879 .76466 .46885 .77985 .48683 .7706 .47684 .75391 Metetra
.904 .375 0 r
.47684 .75391 .48683 .7706 .50488 .76081 .49496 .74278 Metetra
.881 .453 0 r
.49496 .74278 .50488 .76081 .523 .75075 .51312 .73152 Metetra
.858 .527 0 r
.51312 .73152 .523 .75075 .54118 .74066 .53135 .72037 Metetra
.836 .594 0 r
.53135 .72037 .54118 .74066 .55943 .73075 .54963 .70953 Metetra
.815 .653 0 r
.54963 .70953 .55943 .73075 .57776 .72119 .56798 .69917 Metetra
.796 .702 0 r
.56798 .69917 .57776 .72119 .59618 .71213 .58641 .68944 Metetra
.78 .743 0 r
.58641 .68944 .59618 .71213 .61469 .7037 .60493 .68046 Metetra
.762 .767 0 r
.60493 .68046 .61469 .7037 .63331 .696 .62356 .67232 Metetra
.721 .758 0 r
.62356 .67232 .63331 .696 .65207 .6891 .64232 .6651 Metetra
.697 .752 0 r
.64232 .6651 .65207 .6891 .67096 .68304 .66122 .65884 Metetra
.689 .75 0 r
.66122 .65884 .67096 .68304 .69002 .67786 .68028 .65356 Metetra
.697 .752 0 r
.68028 .65356 .69002 .67786 .70925 .67356 .69952 .64929 Metetra
.721 .758 0 r
.69952 .64929 .70925 .67356 .72867 .67013 .71896 .64599 Metetra
.762 .767 0 r
.71896 .64599 .72867 .67013 .74831 .66751 .73862 .64363 Metetra
.78 .743 0 r
.73862 .64363 .74831 .66751 .76816 .66565 .75851 .64215 Metetra
.796 .702 0 r
.75851 .64215 .76816 .66565 .78824 .66446 .77864 .64146 Metetra
.815 .653 0 r
.77864 .64146 .78824 .66446 .80855 .66381 .79902 .64145 Metetra
.836 .594 0 r
.79902 .64145 .80855 .66381 .8291 .66356 .81965 .64197 Metetra
.858 .527 0 r
.81965 .64197 .8291 .66356 .84987 .66353 .84053 .64285 Metetra
.881 .453 0 r
.84053 .64285 .84987 .66353 .87085 .66351 .86165 .6439 Metetra
.904 .375 0 r
.86165 .6439 .87085 .66351 .89202 .66324 .88299 .64486 Metetra
.926 .297 0 r
.88299 .64486 .89202 .66324 .91334 .66245 .90452 .64546 Metetra
.945 .223 0 r
.90452 .64546 .91334 .66245 .93478 .6608 .92621 .64539 Metetra
.961 .161 0 r
.92621 .64539 .93478 .6608 .95627 .65794 .948 .64428 Metetra
.972 .117 0 r
.948 .64428 .95627 .65794 .97774 .65345 .96981 .64172 Metetra
.977 .099 0 r
.96981 .64172 .97774 .65345 .99909 .64688 .99158 .63727 Metetra
.972 .117 0 r
.37699 .78759 .38757 .79726 .40517 .79141 .39474 .77976 Metetra
.96 .165 0 r
.39474 .77976 .40517 .79141 .42294 .78376 .41262 .7703 Metetra
.942 .235 0 r
.41262 .7703 .42294 .78376 .44082 .77472 .43061 .75959 Metetra
.92 .318 0 r
.43061 .75959 .44082 .77472 .45879 .76466 .44868 .74802 Metetra
.895 .407 0 r
.44868 .74802 .45879 .76466 .47684 .75391 .4668 .7359 Metetra
.868 .496 0 r
.4668 .7359 .47684 .75391 .49496 .74278 .48498 .72353 Metetra
.841 .58 0 r
.48498 .72353 .49496 .74278 .51312 .73152 .50319 .71117 Metetra
.814 .657 0 r
.50319 .71117 .51312 .73152 .53135 .72037 .52146 .69905 Metetra
.788 .725 0 r
.52146 .69905 .53135 .72037 .54963 .70953 .53977 .68736 Metetra
.746 .764 0 r
.53977 .68736 .54963 .70953 .56798 .69917 .55814 .67628 Metetra
.656 .742 0 r
.55814 .67628 .56798 .69917 .58641 .68944 .57659 .66593 Metetra
.583 .724 0 r
.57659 .66593 .58641 .68944 .60493 .68046 .59512 .65644 Metetra
.527 .71 0 r
.59512 .65644 .60493 .68046 .62356 .67232 .61375 .6479 Metetra
.487 .699 0 r
.61375 .6479 .62356 .67232 .64232 .6651 .63251 .64038 Metetra
.463 .693 0 r
.63251 .64038 .64232 .6651 .66122 .65884 .65141 .63392 Metetra
.455 .691 0 r
.65141 .63392 .66122 .65884 .68028 .65356 .67048 .62855 Metetra
.463 .693 0 r
.67048 .62855 .68028 .65356 .69952 .64929 .68972 .62428 Metetra
.487 .699 0 r
.68972 .62428 .69952 .64929 .71896 .64599 .70918 .6211 Metetra
.527 .71 0 r
.70918 .6211 .71896 .64599 .73862 .64363 .72885 .61896 Metetra
.583 .724 0 r
.72885 .61896 .73862 .64363 .75851 .64215 .74876 .6178 Metetra
.656 .742 0 r
.74876 .6178 .75851 .64215 .77864 .64146 .76893 .61755 Metetra
.746 .764 0 r
.76893 .61755 .77864 .64146 .79902 .64145 .78936 .6181 Metetra
.788 .725 0 r
.78936 .6181 .79902 .64145 .81965 .64197 .81006 .61931 Metetra
.814 .657 0 r
.81006 .61931 .81965 .64197 .84053 .64285 .83103 .62101 Metetra
.841 .58 0 r
.83103 .62101 .84053 .64285 .86165 .6439 .85227 .62301 Metetra
.868 .496 0 r
.85227 .62301 .86165 .6439 .88299 .64486 .87376 .62508 Metetra
.895 .407 0 r
.87376 .62508 .88299 .64486 .90452 .64546 .89547 .62694 Metetra
.92 .318 0 r
.89547 .62694 .90452 .64546 .92621 .64539 .91738 .62829 Metetra
.942 .235 0 r
.91738 .62829 .92621 .64539 .948 .64428 .93943 .62877 Metetra
.96 .165 0 r
.93943 .62877 .948 .64428 .96981 .64172 .96156 .62797 Metetra
.972 .117 0 r
.96156 .62797 .96981 .64172 .99158 .63727 .98368 .62547 Metetra
.961 .161 0 r
.36636 .77628 .37699 .78759 .39474 .77976 .38424 .76664 Metetra
.942 .235 0 r
.38424 .76664 .39474 .77976 .41262 .7703 .40225 .7555 Metetra
.918 .325 0 r
.40225 .7555 .41262 .7703 .43061 .75959 .42034 .74327 Metetra
.89 .423 0 r
.42034 .74327 .43061 .75959 .44868 .74802 .4385 .73031 Metetra
.86 .522 0 r
.4385 .73031 .44868 .74802 .4668 .7359 .4567 .71694 Metetra
.828 .616 0 r
.4567 .71694 .4668 .7359 .48498 .72353 .47494 .70344 Metetra
.797 .702 0 r
.47494 .70344 .48498 .72353 .50319 .71117 .49321 .69009 Metetra
.754 .766 0 r
.49321 .69009 .50319 .71117 .52146 .69905 .51151 .67708 Metetra
.632 .737 0 r
.51151 .67708 .52146 .69905 .53977 .68736 .52986 .66462 Metetra
.527 .71 0 r
.52986 .66462 .53977 .68736 .55814 .67628 .54826 .65287 Metetra
.439 .686 0 r
.54826 .65287 .55814 .67628 .57659 .66593 .56672 .64196 Metetra
.369 .666 0 r
.56672 .64196 .57659 .66593 .59512 .65644 .58526 .632 Metetra
.315 .65 0 r
.58526 .632 .59512 .65644 .61375 .6479 .6039 .62309 Metetra
.277 .638 0 r
.6039 .62309 .61375 .6479 .63251 .64038 .62266 .61529 Metetra
.254 .631 0 r
.62266 .61529 .63251 .64038 .65141 .63392 .64156 .60865 Metetra
.247 .629 0 r
.64156 .60865 .65141 .63392 .67048 .62855 .66063 .60319 Metetra
.254 .631 0 r
.66063 .60319 .67048 .62855 .68972 .62428 .67988 .59891 Metetra
.277 .638 0 r
.67988 .59891 .68972 .62428 .70918 .6211 .69933 .59581 Metetra
.315 .65 0 r
.69933 .59581 .70918 .6211 .72885 .61896 .71902 .59386 Metetra
.369 .666 0 r
.71902 .59386 .72885 .61896 .74876 .6178 .73895 .59298 Metetra
.439 .686 0 r
.73895 .59298 .74876 .6178 .76893 .61755 .75915 .59312 Metetra
.527 .71 0 r
.75915 .59312 .76893 .61755 .78936 .6181 .77962 .59415 Metetra
.632 .737 0 r
.77962 .59415 .78936 .6181 .81006 .61931 .80038 .59597 Metetra
.754 .766 0 r
.80038 .59597 .81006 .61931 .83103 .62101 .82143 .59839 Metetra
.797 .702 0 r
.82143 .59839 .83103 .62101 .85227 .62301 .84276 .60124 Metetra
.828 .616 0 r
.84276 .60124 .85227 .62301 .87376 .62508 .86437 .6043 Metetra
.86 .522 0 r
.86437 .6043 .87376 .62508 .89547 .62694 .88624 .60729 Metetra
.89 .423 0 r
.88624 .60729 .89547 .62694 .91738 .62829 .90834 .60991 Metetra
.918 .325 0 r
.90834 .60991 .91738 .62829 .93943 .62877 .93062 .61182 Metetra
.942 .235 0 r
.93062 .61182 .93943 .62877 .96156 .62797 .95302 .61263 Metetra
.961 .161 0 r
.95302 .61263 .96156 .62797 .98368 .62547 .97547 .6119 Metetra
.945 .223 0 r
.35566 .7637 .36636 .77628 .38424 .76664 .37369 .7524 Metetra
.92 .318 0 r
.37369 .7524 .38424 .76664 .40225 .7555 .39181 .73974 Metetra
.89 .423 0 r
.39181 .73974 .40225 .7555 .42034 .74327 .41001 .72612 Metetra
.857 .531 0 r
.41001 .72612 .42034 .74327 .4385 .73031 .42826 .71189 Metetra
.822 .634 0 r
.42826 .71189 .4385 .73031 .4567 .71694 .44654 .69738 Metetra
.786 .729 0 r
.44654 .69738 .4567 .71694 .47494 .70344 .46485 .68287 Metetra
.689 .75 0 r
.46485 .68287 .47494 .70344 .49321 .69009 .48317 .6686 Metetra
.552 .716 0 r
.48317 .6686 .49321 .69009 .51151 .67708 .50152 .65479 Metetra
.432 .684 0 r
.50152 .65479 .51151 .67708 .52986 .66462 .5199 .64163 Metetra
.33 .655 0 r
.5199 .64163 .52986 .66462 .54826 .65287 .53832 .62927 Metetra
.247 .629 0 r
.53832 .62927 .54826 .65287 .56672 .64196 .5568 .61785 Metetra
.181 .607 0 r
.5568 .61785 .56672 .64196 .58526 .632 .57536 .60747 Metetra
.132 .59 0 r
.57536 .60747 .58526 .632 .6039 .62309 .59401 .59822 Metetra
.097 .577 0 r
.59401 .59822 .6039 .62309 .62266 .61529 .61277 .59016 Metetra
.077 .57 0 r
.61277 .59016 .62266 .61529 .64156 .60865 .63168 .58334 Metetra
.07 .567 0 r
.63168 .58334 .64156 .60865 .66063 .60319 .65074 .57778 Metetra
.077 .57 0 r
.65074 .57778 .66063 .60319 .67988 .59891 .66999 .5735 Metetra
.097 .577 0 r
.66999 .5735 .67988 .59891 .69933 .59581 .68946 .57046 Metetra
.132 .59 0 r
.68946 .57046 .69933 .59581 .71902 .59386 .70915 .56866 Metetra
.181 .607 0 r
.70915 .56866 .71902 .59386 .73895 .59298 .7291 .56802 Metetra
.247 .629 0 r
.7291 .56802 .73895 .59298 .75915 .59312 .74931 .56849 Metetra
.33 .655 0 r
.74931 .56849 .75915 .59312 .77962 .59415 .76982 .56995 Metetra
.432 .684 0 r
.76982 .56995 .77962 .59415 .80038 .59597 .79062 .57229 Metetra
.552 .716 0 r
.79062 .57229 .80038 .59597 .82143 .59839 .81174 .57535 Metetra
.689 .75 0 r
.81174 .57535 .82143 .59839 .84276 .60124 .83315 .57895 Metetra
.786 .729 0 r
.83315 .57895 .84276 .60124 .86437 .6043 .85487 .58287 Metetra
.822 .634 0 r
.85487 .58287 .86437 .6043 .88624 .60729 .87688 .58687 Metetra
.857 .531 0 r
.87688 .58687 .88624 .60729 .90834 .60991 .89914 .59063 Metetra
.89 .423 0 r
.89914 .59063 .90834 .60991 .93062 .61182 .92162 .59383 Metetra
.92 .318 0 r
.92162 .59383 .93062 .61182 .95302 .61263 .94427 .59608 Metetra
.945 .223 0 r
.94427 .59608 .95302 .61263 .97547 .6119 .96701 .59694 Metetra
.926 .297 0 r
.3449 .75018 .35566 .7637 .37369 .7524 .36306 .73737 Metetra
.895 .407 0 r
.36306 .73737 .37369 .7524 .39181 .73974 .38131 .72333 Metetra
.86 .522 0 r
.38131 .72333 .39181 .73974 .41001 .72612 .39962 .70845 Metetra
.822 .634 0 r
.39962 .70845 .41001 .72612 .42826 .71189 .41796 .69308 Metetra
.782 .738 0 r
.41796 .69308 .42826 .71189 .44654 .69738 .43632 .67754 Metetra
.657 .743 0 r
.43632 .67754 .44654 .69738 .46485 .68287 .4547 .6621 Metetra
.503 .704 0 r
.4547 .6621 .46485 .68287 .48317 .6686 .47308 .64701 Metetra
.369 .666 0 r
.47308 .64701 .48317 .6686 .50152 .65479 .49148 .63248 Metetra
.255 .631 0 r
.49148 .63248 .50152 .65479 .5199 .64163 .5099 .61869 Metetra
.16 .6 0 r
.5099 .61869 .5199 .64163 .53832 .62927 .52835 .60578 Metetra
.084 .572 0 r
.52835 .60578 .53832 .62927 .5568 .61785 .54685 .5939 Metetra
.025 .549 0 r
.54685 .5939 .5568 .61785 .57536 .60747 .56542 .58313 Metetra
0 .53 .019 r
.56542 .58313 .57536 .60747 .59401 .59822 .58408 .57357 Metetra
0 .517 .048 r
.58408 .57357 .59401 .59822 .61277 .59016 .60286 .56527 Metetra
0 .509 .066 r
.60286 .56527 .61277 .59016 .63168 .58334 .62177 .55828 Metetra
0 .506 .071 r
.62177 .55828 .63168 .58334 .65074 .57778 .64083 .55263 Metetra
0 .509 .066 r
.64083 .55263 .65074 .57778 .66999 .5735 .66009 .54831 Metetra
0 .517 .048 r
.66009 .54831 .66999 .5735 .68946 .57046 .67955 .54533 Metetra
0 .53 .019 r
.67955 .54533 .68946 .57046 .70915 .56866 .69925 .54364 Metetra
.025 .549 0 r
.69925 .54364 .70915 .56866 .7291 .56802 .71921 .54321 Metetra
.084 .572 0 r
.71921 .54321 .7291 .56802 .74931 .56849 .73945 .54395 Metetra
.16 .6 0 r
.73945 .54395 .74931 .56849 .76982 .56995 .75998 .54578 Metetra
.255 .631 0 r
.75998 .54578 .76982 .56995 .79062 .57229 .78083 .54857 Metetra
.369 .666 0 r
.78083 .54857 .79062 .57229 .81174 .57535 .80199 .55219 Metetra
.503 .704 0 r
.80199 .55219 .81174 .57535 .83315 .57895 .82348 .55645 Metetra
.657 .743 0 r
.82348 .55645 .83315 .57895 .85487 .58287 .84529 .56114 Metetra
.782 .738 0 r
.84529 .56114 .85487 .58287 .87688 .58687 .86741 .56601 Metetra
.822 .634 0 r
.86741 .56601 .87688 .58687 .89914 .59063 .88982 .57079 Metetra
.86 .522 0 r
.88982 .57079 .89914 .59063 .92162 .59383 .91248 .57513 Metetra
.895 .407 0 r
.91248 .57513 .92162 .59383 .94427 .59608 .93534 .57866 Metetra
.926 .297 0 r
.93534 .57866 .94427 .59608 .96701 .59694 .95833 .58095 Metetra
.904 .375 0 r
.33406 .73602 .3449 .75018 .36306 .73737 .35236 .72185 Metetra
.868 .496 0 r
.35236 .72185 .36306 .73737 .38131 .72333 .37073 .70656 Metetra
.828 .616 0 r
.37073 .70656 .38131 .72333 .39962 .70845 .38915 .69055 Metetra
.786 .729 0 r
.38915 .69055 .39962 .70845 .41796 .69308 .40759 .67415 Metetra
.657 .743 0 r
.40759 .67415 .41796 .69308 .43632 .67754 .42604 .65768 Metetra
.487 .699 0 r
.42604 .65768 .43632 .67754 .4547 .6621 .44448 .64142 Metetra
.338 .657 0 r
.44448 .64142 .4547 .6621 .47308 .64701 .46293 .6256 Metetra
.21 .617 0 r
.46293 .6256 .47308 .64701 .49148 .63248 .48138 .61041 Metetra
.104 .58 0 r
.48138 .61041 .49148 .63248 .5099 .61869 .49984 .59605 Metetra
.019 .546 0 r
.49984 .59605 .5099 .61869 .52835 .60578 .51833 .58265 Metetra
0 .517 .048 r
.51833 .58265 .52835 .60578 .54685 .5939 .53686 .57034 Metetra
0 .492 .099 r
.53686 .57034 .54685 .5939 .56542 .58313 .55545 .55922 Metetra
0 .472 .135 r
.55545 .55922 .56542 .58313 .58408 .57357 .57413 .54937 Metetra
0 .458 .159 r
.57413 .54937 .58408 .57357 .60286 .56527 .59291 .54085 Metetra
0 .45 .173 r
.59291 .54085 .60286 .56527 .62177 .55828 .61183 .53371 Metetra
0 .447 .178 r
.61183 .53371 .62177 .55828 .64083 .55263 .63091 .52796 Metetra
0 .45 .173 r
.63091 .52796 .64083 .55263 .66009 .54831 .65017 .52361 Metetra
0 .458 .159 r
.65017 .52361 .66009 .54831 .67955 .54533 .66964 .52066 Metetra
0 .472 .135 r
.66964 .52066 .67955 .54533 .69925 .54364 .68935 .51907 Metetra
0 .492 .099 r
.68935 .51907 .69925 .54364 .71921 .54321 .70931 .5188 Metetra
0 .517 .048 r
.70931 .5188 .71921 .54321 .73945 .54395 .72957 .51977 Metetra
.019 .546 0 r
.72957 .51977 .73945 .54395 .75998 .54578 .75012 .52191 Metetra
.104 .58 0 r
.75012 .52191 .75998 .54578 .78083 .54857 .771 .5251 Metetra
.21 .617 0 r
.771 .5251 .78083 .54857 .80199 .55219 .79221 .52919 Metetra
.338 .657 0 r
.79221 .52919 .80199 .55219 .82348 .55645 .81376 .53401 Metetra
.487 .699 0 r
.81376 .53401 .82348 .55645 .84529 .56114 .83565 .53937 Metetra
.657 .743 0 r
.83565 .53937 .84529 .56114 .86741 .56601 .85787 .54502 Metetra
.786 .729 0 r
.85787 .54502 .86741 .56601 .88982 .57079 .88041 .55068 Metetra
.828 .616 0 r
.88041 .55068 .88982 .57079 .91248 .57513 .90322 .55603 Metetra
.868 .496 0 r
.90322 .55603 .91248 .57513 .93534 .57866 .92627 .5607 Metetra
.904 .375 0 r
.92627 .5607 .93534 .57866 .95833 .58095 .9495 .56426 Metetra
.881 .453 0 r
.32313 .72149 .33406 .73602 .35236 .72185 .34156 .7061 Metetra
.841 .58 0 r
.34156 .7061 .35236 .72185 .37073 .70656 .36006 .6897 Metetra
.797 .702 0 r
.36006 .6897 .37073 .70656 .38915 .69055 .37859 .67267 Metetra
.689 .75 0 r
.37859 .67267 .38915 .69055 .40759 .67415 .39713 .65535 Metetra
.503 .704 0 r
.39713 .65535 .40759 .67415 .42604 .65768 .41567 .63806 Metetra
.338 .657 0 r
.41567 .63806 .42604 .65768 .44448 .64142 .43419 .62106 Metetra
.196 .612 0 r
.43419 .62106 .44448 .64142 .46293 .6256 .45271 .60457 Metetra
.077 .57 0 r
.45271 .60457 .46293 .6256 .48138 .61041 .47122 .58881 Metetra
0 .53 .019 r
.47122 .58881 .48138 .61041 .49984 .59605 .48973 .57393 Metetra
0 .495 .093 r
.48973 .57393 .49984 .59605 .51833 .58265 .50826 .56009 Metetra
0 .464 .15 r
.50826 .56009 .51833 .58265 .53686 .57034 .52682 .5474 Metetra
0 .438 .191 r
.52682 .5474 .53686 .57034 .55545 .55922 .54544 .53596 Metetra
0 .417 .219 r
.54544 .53596 .55545 .55922 .57413 .54937 .56414 .52585 Metetra
0 .402 .237 r
.56414 .52585 .57413 .54937 .59291 .54085 .58294 .51713 Metetra
0 .393 .247 r
.58294 .51713 .59291 .54085 .61183 .53371 .60187 .50983 Metetra
0 .39 .251 r
.60187 .50983 .61183 .53371 .63091 .52796 .62096 .50399 Metetra
0 .393 .247 r
.62096 .50399 .63091 .52796 .65017 .52361 .64023 .4996 Metetra
0 .402 .237 r
.64023 .4996 .65017 .52361 .66964 .52066 .65971 .49666 Metetra
0 .417 .219 r
.65971 .49666 .66964 .52066 .68935 .51907 .67943 .49514 Metetra
0 .438 .191 r
.67943 .49514 .68935 .51907 .70931 .5188 .69941 .495 Metetra
0 .464 .15 r
.69941 .495 .70931 .5188 .72957 .51977 .71968 .49617 Metetra
0 .495 .093 r
.71968 .49617 .72957 .51977 .75012 .52191 .74026 .49857 Metetra
0 .53 .019 r
.74026 .49857 .75012 .52191 .771 .5251 .76116 .50209 Metetra
.077 .57 0 r
.76116 .50209 .771 .5251 .79221 .52919 .78242 .50658 Metetra
.196 .612 0 r
.78242 .50658 .79221 .52919 .81376 .53401 .80402 .51189 Metetra
.338 .657 0 r
.80402 .51189 .81376 .53401 .83565 .53937 .82598 .51783 Metetra
.503 .704 0 r
.82598 .51783 .83565 .53937 .85787 .54502 .84829 .52414 Metetra
.689 .75 0 r
.84829 .52414 .85787 .54502 .88041 .55068 .87094 .53058 Metetra
.797 .702 0 r
.87094 .53058 .88041 .55068 .90322 .55603 .89389 .5368 Metetra
.841 .58 0 r
.89389 .5368 .90322 .55603 .92627 .5607 .91711 .54246 Metetra
.881 .453 0 r
.91711 .54246 .92627 .5607 .9495 .56426 .94054 .54713 Metetra
.858 .527 0 r
.31209 .70684 .32313 .72149 .34156 .7061 .33067 .69036 Metetra
.814 .657 0 r
.33067 .69036 .34156 .7061 .36006 .6897 .34929 .67297 Metetra
.754 .766 0 r
.34929 .67297 .36006 .6897 .37859 .67267 .36794 .65504 Metetra
.552 .716 0 r
.36794 .65504 .37859 .67267 .39713 .65535 .38658 .63691 Metetra
.369 .666 0 r
.38658 .63691 .39713 .65535 .41567 .63806 .40521 .61888 Metetra
.21 .617 0 r
.40521 .61888 .41567 .63806 .43419 .62106 .42382 .60122 Metetra
.077 .57 0 r
.42382 .60122 .43419 .62106 .45271 .60457 .44241 .58415 Metetra
0 .525 .031 r
.44241 .58415 .45271 .60457 .47122 .58881 .46098 .56787 Metetra
0 .484 .115 r
.46098 .56787 .47122 .58881 .48973 .57393 .47955 .55253 Metetra
0 .447 .178 r
.47955 .55253 .48973 .57393 .50826 .56009 .49813 .53829 Metetra
0 .414 .223 r
.49813 .53829 .50826 .56009 .52682 .5474 .51673 .52526 Metetra
0 .387 .254 r
.51673 .52526 .52682 .5474 .54544 .53596 .53539 .51354 Metetra
0 .366 .274 r
.53539 .51354 .54544 .53596 .56414 .52585 .55412 .50319 Metetra
0 .35 .286 r
.55412 .50319 .56414 .52585 .58294 .51713 .57294 .49427 Metetra
0 .341 .292 r
.57294 .49427 .58294 .51713 .60187 .50983 .59189 .48684 Metetra
0 .338 .294 r
.59189 .48684 .60187 .50983 .62096 .50399 .61099 .4809 Metetra
0 .341 .292 r
.61099 .4809 .62096 .50399 .64023 .4996 .63028 .47646 Metetra
0 .35 .286 r
.63028 .47646 .64023 .4996 .65971 .49666 .64977 .47353 Metetra
0 .366 .274 r
.64977 .47353 .65971 .49666 .67943 .49514 .6695 .47206 Metetra
0 .387 .254 r
.6695 .47206 .67943 .49514 .69941 .495 .6895 .47202 Metetra
0 .414 .223 r
.6895 .47202 .69941 .495 .71968 .49617 .70978 .47335 Metetra
0 .447 .178 r
.70978 .47335 .71968 .49617 .74026 .49857 .73039 .47596 Metetra
0 .484 .115 r
.73039 .47596 .74026 .49857 .76116 .50209 .75132 .47974 Metetra
0 .525 .031 r
.75132 .47974 .76116 .50209 .78242 .50658 .77261 .48458 Metetra
.077 .57 0 r
.77261 .48458 .78242 .50658 .80402 .51189 .79427 .4903 Metetra
.21 .617 0 r
.79427 .4903 .80402 .51189 .82598 .51783 .81629 .49672 Metetra
.369 .666 0 r
.81629 .49672 .82598 .51783 .84829 .52414 .83868 .50361 Metetra
.552 .716 0 r
.83868 .50361 .84829 .52414 .87094 .53058 .86143 .5107 Metetra
.754 .766 0 r
.86143 .5107 .87094 .53058 .89389 .5368 .8845 .51768 Metetra
.814 .657 0 r
.8845 .51768 .89389 .5368 .91711 .54246 .90787 .5242 Metetra
.858 .527 0 r
.90787 .5242 .91711 .54246 .94054 .54713 .93148 .52983 Metetra
.836 .594 0 r
.30094 .69226 .31209 .70684 .33067 .69036 .31965 .67483 Metetra
.788 .725 0 r
.31965 .67483 .33067 .69036 .34929 .67297 .33841 .65657 Metetra
.632 .737 0 r
.33841 .65657 .34929 .67297 .36794 .65504 .35717 .63784 Metetra
.432 .684 0 r
.35717 .63784 .36794 .65504 .38658 .63691 .37592 .619 Metetra
.255 .631 0 r
.37592 .619 .38658 .63691 .40521 .61888 .39465 .60033 Metetra
.104 .58 0 r
.39465 .60033 .40521 .61888 .42382 .60122 .41335 .58209 Metetra
0 .53 .019 r
.41335 .58209 .42382 .60122 .44241 .58415 .43202 .5645 Metetra
0 .484 .115 r
.43202 .5645 .44241 .58415 .46098 .56787 .45066 .54775 Metetra
0 .441 .186 r
.45066 .54775 .46098 .56787 .47955 .55253 .46929 .53202 Metetra
0 .402 .237 r
.46929 .53202 .47955 .55253 .49813 .53829 .48793 .51742 Metetra
0 .369 .271 r
.48793 .51742 .49813 .53829 .51673 .52526 .50658 .50409 Metetra
0 .341 .292 r
.50658 .50409 .51673 .52526 .53539 .51354 .52528 .4921 Metetra
0 .319 .304 r
.52528 .4921 .53539 .51354 .55412 .50319 .54404 .48154 Metetra
0 .296 .303 r
.54404 .48154 .55412 .50319 .57294 .49427 .5629 .47245 Metetra
0 .274 .293 r
.5629 .47245 .57294 .49427 .59189 .48684 .58187 .46488 Metetra
0 .267 .29 r
.58187 .46488 .59189 .48684 .61099 .4809 .601 .45884 Metetra
0 .274 .293 r
.601 .45884 .61099 .4809 .63028 .47646 .6203 .45436 Metetra
0 .296 .303 r
.6203 .45436 .63028 .47646 .64977 .47353 .63982 .45141 Metetra
0 .319 .304 r
.63982 .45141 .64977 .47353 .6695 .47206 .65956 .44997 Metetra
0 .341 .292 r
.65956 .44997 .6695 .47206 .6895 .47202 .67958 .45 Metetra
0 .369 .271 r
.67958 .45 .6895 .47202 .70978 .47335 .69989 .45145 Metetra
0 .402 .237 r
.69989 .45145 .70978 .47335 .73039 .47596 .72052 .45423 Metetra
0 .441 .186 r
.72052 .45423 .73039 .47596 .75132 .47974 .74148 .45824 Metetra
0 .484 .115 r
.74148 .45824 .75132 .47974 .77261 .48458 .76281 .46336 Metetra
0 .53 .019 r
.76281 .46336 .77261 .48458 .79427 .4903 .78451 .46942 Metetra
.104 .58 0 r
.78451 .46942 .79427 .4903 .81629 .49672 .8066 .47624 Metetra
.255 .631 0 r
.8066 .47624 .81629 .49672 .83868 .50361 .82906 .48361 Metetra
.432 .684 0 r
.82906 .48361 .83868 .50361 .86143 .5107 .8519 .49126 Metetra
.632 .737 0 r
.8519 .49126 .86143 .5107 .8845 .51768 .87508 .49888 Metetra
.788 .725 0 r
.87508 .49888 .8845 .51768 .90787 .5242 .89859 .50612 Metetra
.836 .594 0 r
.89859 .50612 .90787 .5242 .93148 .52983 .92236 .51258 Metetra
.815 .653 0 r
.28965 .67793 .30094 .69226 .31965 .67483 .3085 .65968 Metetra
.746 .764 0 r
.3085 .65968 .31965 .67483 .33841 .65657 .32739 .64066 Metetra
.527 .71 0 r
.32739 .64066 .33841 .65657 .35717 .63784 .34627 .62125 Metetra
.33 .655 0 r
.34627 .62125 .35717 .63784 .37592 .619 .36514 .60179 Metetra
.16 .6 0 r
.36514 .60179 .37592 .619 .39465 .60033 .38397 .58255 Metetra
.019 .546 0 r
.38397 .58255 .39465 .60033 .41335 .58209 .40277 .56381 Metetra
0 .495 .093 r
.40277 .56381 .41335 .58209 .43202 .5645 .42152 .54577 Metetra
0 .447 .178 r
.42152 .54577 .43202 .5645 .45066 .54775 .44024 .52862 Metetra
0 .402 .237 r
.44024 .52862 .45066 .54775 .46929 .53202 .45895 .51253 Metetra
0 .363 .276 r
.45895 .51253 .46929 .53202 .48793 .51742 .47764 .49762 Metetra
0 .328 .299 r
.47764 .49762 .48793 .51742 .50658 .50409 .49635 .48401 Metetra
0 .289 .299 r
.49635 .48401 .50658 .50409 .52528 .4921 .5151 .47179 Metetra
0 .239 .276 r
.5151 .47179 .52528 .4921 .54404 .48154 .53391 .46103 Metetra
0 .206 .26 r
.53391 .46103 .54404 .48154 .5629 .47245 .5528 .45178 Metetra
0 .187 .25 r
.5528 .45178 .5629 .47245 .58187 .46488 .57182 .44408 Metetra
0 .181 .247 r
.57182 .44408 .58187 .46488 .601 .45884 .59097 .43796 Metetra
0 .187 .25 r
.59097 .43796 .601 .45884 .6203 .45436 .6103 .43341 Metetra
0 .206 .26 r
.6103 .43341 .6203 .45436 .63982 .45141 .62984 .43044 Metetra
0 .239 .276 r
.62984 .43044 .63982 .45141 .65956 .44997 .64962 .42901 Metetra
0 .289 .299 r
.64962 .42901 .65956 .44997 .67958 .45 .66965 .4291 Metetra
0 .328 .299 r
.66965 .4291 .67958 .45 .69989 .45145 .68999 .43063 Metetra
0 .363 .276 r
.68999 .43063 .69989 .45145 .72052 .45423 .71064 .43354 Metetra
0 .402 .237 r
.71064 .43354 .72052 .45423 .74148 .45824 .73165 .43772 Metetra
0 .447 .178 r
.73165 .43772 .74148 .45824 .76281 .46336 .75301 .44306 Metetra
0 .495 .093 r
.75301 .44306 .76281 .46336 .78451 .46942 .77476 .4494 Metetra
.019 .546 0 r
.77476 .4494 .78451 .46942 .8066 .47624 .7969 .45656 Metetra
.16 .6 0 r
.7969 .45656 .8066 .47624 .82906 .48361 .81943 .46432 Metetra
.33 .655 0 r
.81943 .46432 .82906 .48361 .8519 .49126 .84235 .47242 Metetra
.527 .71 0 r
.84235 .47242 .8519 .49126 .87508 .49888 .86564 .48057 Metetra
.746 .764 0 r
.86564 .48057 .87508 .49888 .89859 .50612 .88927 .48842 Metetra
.815 .653 0 r
.88927 .48842 .89859 .50612 .92236 .51258 .91319 .49556 Metetra
.796 .702 0 r
.27821 .66402 .28965 .67793 .3085 .65968 .2972 .64507 Metetra
.656 .742 0 r
.2972 .64507 .3085 .65968 .32739 .64066 .31622 .6254 Metetra
.439 .686 0 r
.31622 .6254 .32739 .64066 .34627 .62125 .33523 .60541 Metetra
.247 .629 0 r
.33523 .60541 .34627 .62125 .36514 .60179 .35422 .58541 Metetra
.084 .572 0 r
.35422 .58541 .36514 .60179 .38397 .58255 .37316 .56569 Metetra
0 .517 .048 r
.37316 .56569 .38397 .58255 .40277 .56381 .39205 .54651 Metetra
0 .464 .15 r
.39205 .54651 .40277 .56381 .42152 .54577 .4109 .52807 Metetra
0 .414 .223 r
.4109 .52807 .42152 .54577 .44024 .52862 .42971 .51058 Metetra
0 .369 .271 r
.42971 .51058 .44024 .52862 .45895 .51253 .44849 .49417 Metetra
0 .328 .299 r
.44849 .49417 .45895 .51253 .47764 .49762 .46726 .47899 Metetra
0 .274 .293 r
.46726 .47899 .47764 .49762 .49635 .48401 .48604 .46514 Metetra
0 .213 .263 r
.48604 .46514 .49635 .48401 .5151 .47179 .50484 .45271 Metetra
0 .169 .24 r
.50484 .45271 .5151 .47179 .53391 .46103 .52371 .44177 Metetra
0 .141 .223 r
.52371 .44177 .53391 .46103 .5528 .45178 .54265 .43238 Metetra
0 .125 .213 r
.54265 .43238 .5528 .45178 .57182 .44408 .5617 .42456 Metetra
0 .12 .209 r
.5617 .42456 .57182 .44408 .59097 .43796 .5809 .41834 Metetra
0 .125 .213 r
.5809 .41834 .59097 .43796 .6103 .43341 .60027 .41373 Metetra
0 .141 .223 r
.60027 .41373 .6103 .43341 .62984 .43044 .61984 .41072 Metetra
0 .169 .24 r
.61984 .41072 .62984 .43044 .64962 .42901 .63964 .40929 Metetra
0 .213 .263 r
.63964 .40929 .64962 .42901 .66965 .4291 .65972 .4094 Metetra
0 .274 .293 r
.65972 .4094 .66965 .4291 .68999 .43063 .68008 .411 Metetra
0 .328 .299 r
.68008 .411 .68999 .43063 .71064 .43354 .70077 .414 Metetra
0 .369 .271 r
.70077 .414 .71064 .43354 .73165 .43772 .72181 .41832 Metetra
0 .414 .223 r
.72181 .41832 .73165 .43772 .75301 .44306 .74321 .42382 Metetra
0 .464 .15 r
.74321 .42382 .75301 .44306 .77476 .4494 .76501 .43037 Metetra
0 .517 .048 r
.76501 .43037 .77476 .4494 .7969 .45656 .78721 .43779 Metetra
.084 .572 0 r
.78721 .43779 .7969 .45656 .81943 .46432 .8098 .44586 Metetra
.247 .629 0 r
.8098 .44586 .81943 .46432 .84235 .47242 .8328 .45433 Metetra
.439 .686 0 r
.8328 .45433 .84235 .47242 .86564 .48057 .85619 .46291 Metetra
.656 .742 0 r
.85619 .46291 .86564 .48057 .88927 .48842 .87993 .47124 Metetra
.796 .702 0 r
.87993 .47124 .88927 .48842 .91319 .49556 .90398 .47894 Metetra
.78 .743 0 r
.2666 .65064 .27821 .66402 .2972 .64507 .28573 .6311 Metetra
.584 .724 0 r
.28573 .6311 .2972 .64507 .31622 .6254 .30489 .61091 Metetra
.369 .666 0 r
.30489 .61091 .31622 .6254 .33523 .60541 .32403 .59042 Metetra
.181 .607 0 r
.32403 .59042 .33523 .60541 .35422 .58541 .34314 .56997 Metetra
.025 .549 0 r
.34314 .56997 .35422 .58541 .37316 .56569 .36219 .54985 Metetra
0 .492 .099 r
.36219 .54985 .37316 .56569 .39205 .54651 .3812 .53029 Metetra
0 .438 .191 r
.3812 .53029 .39205 .54651 .4109 .52807 .40015 .51153 Metetra
0 .387 .254 r
.40015 .51153 .4109 .52807 .42971 .51058 .41905 .49373 Metetra
0 .341 .292 r
.41905 .49373 .42971 .51058 .44849 .49417 .43792 .47706 Metetra
0 .289 .299 r
.43792 .47706 .44849 .49417 .46726 .47899 .45677 .46164 Metetra
0 .213 .263 r
.45677 .46164 .46726 .47899 .48604 .46514 .47562 .44758 Metetra
0 .158 .233 r
.47562 .44758 .48604 .46514 .50484 .45271 .49449 .43496 Metetra
0 .12 .209 r
.49449 .43496 .50484 .45271 .52371 .44177 .51342 .42386 Metetra
0 .096 .192 r
.51342 .42386 .52371 .44177 .54265 .43238 .53242 .41433 Metetra
0 .082 .182 r
.53242 .41433 .54265 .43238 .5617 .42456 .55153 .40639 Metetra
0 .078 .178 r
.55153 .40639 .5617 .42456 .5809 .41834 .57077 .40009 Metetra
0 .082 .182 r
.57077 .40009 .5809 .41834 .60027 .41373 .59018 .39541 Metetra
0 .096 .192 r
.59018 .39541 .60027 .41373 .61984 .41072 .6098 .39236 Metetra
0 .12 .209 r
.6098 .39236 .61984 .41072 .63964 .40929 .62964 .39091 Metetra
0 .158 .233 r
.62964 .39091 .63964 .40929 .65972 .4094 .64975 .39102 Metetra
0 .213 .263 r
.64975 .39102 .65972 .4094 .68008 .411 .67016 .39265 Metetra
0 .289 .299 r
.67016 .39265 .68008 .411 .70077 .414 .69088 .39571 Metetra
0 .341 .292 r
.69088 .39571 .70077 .414 .72181 .41832 .71196 .40011 Metetra
0 .387 .254 r
.71196 .40011 .72181 .41832 .74321 .42382 .73342 .40574 Metetra
0 .438 .191 r
.73342 .40574 .74321 .42382 .76501 .43037 .75526 .41245 Metetra
0 .492 .099 r
.75526 .41245 .76501 .43037 .78721 .43779 .77751 .42006 Metetra
.025 .549 0 r
.77751 .42006 .78721 .43779 .8098 .44586 .80018 .42836 Metetra
.181 .607 0 r
.80018 .42836 .8098 .44586 .8328 .45433 .82325 .43711 Metetra
.369 .666 0 r
.82325 .43711 .8328 .45433 .85619 .46291 .84673 .44601 Metetra
.584 .724 0 r
.84673 .44601 .85619 .46291 .87993 .47124 .87057 .45472 Metetra
.78 .743 0 r
.87057 .45472 .87993 .47124 .90398 .47894 .89474 .46284 Metetra
.762 .767 0 r
.2548 .63789 .2666 .65064 .28573 .6311 .27408 .61789 Metetra
.527 .71 0 r
.27408 .61789 .28573 .6311 .30489 .61091 .29337 .59726 Metetra
.315 .65 0 r
.29337 .59726 .30489 .61091 .32403 .59042 .31264 .57638 Metetra
.132 .59 0 r
.31264 .57638 .32403 .59042 .34314 .56997 .33188 .55557 Metetra
0 .53 .019 r
.33188 .55557 .34314 .56997 .36219 .54985 .35106 .53511 Metetra
0 .472 .135 r
.35106 .53511 .36219 .54985 .3812 .53029 .37018 .51525 Metetra
0 .417 .219 r
.37018 .51525 .3812 .53029 .40015 .51153 .38924 .49621 Metetra
0 .366 .274 r
.38924 .49621 .40015 .51153 .41905 .49373 .40824 .47816 Metetra
0 .319 .304 r
.40824 .47816 .41905 .49373 .43792 .47706 .42721 .46125 Metetra
0 .239 .276 r
.42721 .46125 .43792 .47706 .45677 .46164 .44615 .44563 Metetra
0 .169 .24 r
.44615 .44563 .45677 .46164 .47562 .44758 .46508 .43138 Metetra
0 .12 .209 r
.46508 .43138 .47562 .44758 .49449 .43496 .48403 .41861 Metetra
0 .087 .185 r
.48403 .41861 .49449 .43496 .51342 .42386 .50303 .40736 Metetra
0 .066 .168 r
.50303 .40736 .51342 .42386 .53242 .41433 .5221 .3977 Metetra
0 .055 .157 r
.5221 .3977 .53242 .41433 .55153 .40639 .54127 .38966 Metetra
0 .051 .154 r
.54127 .38966 .55153 .40639 .57077 .40009 .56057 .38327 Metetra
0 .055 .157 r
.56057 .38327 .57077 .40009 .59018 .39541 .58004 .37852 Metetra
0 .066 .168 r
.58004 .37852 .59018 .39541 .6098 .39236 .5997 .37541 Metetra
0 .087 .185 r
.5997 .37541 .6098 .39236 .62964 .39091 .6196 .37393 Metetra
0 .12 .209 r
.6196 .37393 .62964 .39091 .64975 .39102 .63975 .37403 Metetra
0 .169 .24 r
.63975 .37403 .64975 .39102 .67016 .39265 .6602 .37566 Metetra
0 .239 .276 r
.6602 .37566 .67016 .39265 .69088 .39571 .68098 .37874 Metetra
0 .319 .304 r
.68098 .37874 .69088 .39571 .71196 .40011 .70211 .3832 Metetra
0 .366 .274 r
.70211 .3832 .71196 .40011 .73342 .40574 .72361 .3889 Metetra
0 .417 .219 r
.72361 .3889 .73342 .40574 .75526 .41245 .74551 .3957 Metetra
0 .472 .135 r
.74551 .3957 .75526 .41245 .77751 .42006 .76782 .40344 Metetra
0 .53 .019 r
.76782 .40344 .77751 .42006 .80018 .42836 .79055 .4119 Metetra
.132 .59 0 r
.79055 .4119 .80018 .42836 .82325 .43711 .8137 .42084 Metetra
.315 .65 0 r
.8137 .42084 .82325 .43711 .84673 .44601 .83726 .42997 Metetra
.527 .71 0 r
.83726 .42997 .84673 .44601 .87057 .45472 .8612 .43895 Metetra
.762 .767 0 r
.8612 .43895 .87057 .45472 .89474 .46284 .88549 .44737 Metetra
.721 .758 0 r
.2428 .62586 .2548 .63789 .27408 .61789 .26222 .60551 Metetra
.487 .699 0 r
.26222 .60551 .27408 .61789 .29337 .59726 .28165 .58455 Metetra
.277 .638 0 r
.28165 .58455 .29337 .59726 .31264 .57638 .30106 .56336 Metetra
.097 .577 0 r
.30106 .56336 .31264 .57638 .33188 .55557 .32043 .54226 Metetra
0 .517 .048 r
.32043 .54226 .33188 .55557 .35106 .53511 .33973 .52154 Metetra
0 .458 .159 r
.33973 .52154 .35106 .53511 .37018 .51525 .35898 .50144 Metetra
0 .402 .237 r
.35898 .50144 .37018 .51525 .38924 .49621 .37815 .48217 Metetra
0 .35 .286 r
.37815 .48217 .38924 .49621 .40824 .47816 .39727 .46392 Metetra
0 .296 .303 r
.39727 .46392 .40824 .47816 .42721 .46125 .41634 .44683 Metetra
0 .206 .26 r
.41634 .44683 .42721 .46125 .44615 .44563 .43538 .43103 Metetra
0 .141 .223 r
.43538 .43103 .44615 .44563 .46508 .43138 .45441 .41662 Metetra
0 .096 .192 r
.45441 .41662 .46508 .43138 .48403 .41861 .47345 .4037 Metetra
0 .066 .168 r
.47345 .4037 .48403 .41861 .50303 .40736 .49252 .39233 Metetra
0 .048 .15 r
.49252 .39233 .50303 .40736 .5221 .3977 .51167 .38256 Metetra
0 .038 .139 r
.51167 .38256 .5221 .3977 .54127 .38966 .53091 .37442 Metetra
0 .035 .136 r
.53091 .37442 .54127 .38966 .56057 .38327 .55028 .36793 Metetra
0 .038 .139 r
.55028 .36793 .56057 .38327 .58004 .37852 .56981 .36311 Metetra
0 .048 .15 r
.56981 .36311 .58004 .37852 .5997 .37541 .58954 .35994 Metetra
0 .066 .168 r
.58954 .35994 .5997 .37541 .6196 .37393 .60949 .35841 Metetra
0 .096 .192 r
.60949 .35841 .6196 .37393 .63975 .37403 .62971 .35847 Metetra
0 .141 .223 r
.62971 .35847 .63975 .37403 .6602 .37566 .65021 .36008 Metetra
0 .206 .26 r
.65021 .36008 .6602 .37566 .68098 .37874 .67104 .36316 Metetra
0 .296 .303 r
.67104 .36316 .68098 .37874 .70211 .3832 .69222 .36763 Metetra
0 .35 .286 r
.69222 .36763 .70211 .3832 .72361 .3889 .71378 .37335 Metetra
0 .402 .237 r
.71378 .37335 .72361 .3889 .74551 .3957 .73574 .38021 Metetra
0 .458 .159 r
.73574 .38021 .74551 .3957 .76782 .40344 .75812 .38801 Metetra
0 .517 .048 r
.75812 .38801 .76782 .40344 .79055 .4119 .78092 .39656 Metetra
.097 .577 0 r
.78092 .39656 .79055 .4119 .8137 .42084 .80414 .40561 Metetra
.277 .638 0 r
.80414 .40561 .8137 .42084 .83726 .42997 .82778 .41487 Metetra
.487 .699 0 r
.82778 .41487 .83726 .42997 .8612 .43895 .85182 .42401 Metetra
.721 .758 0 r
.85182 .42401 .8612 .43895 .88549 .44737 .87621 .43262 Metetra
.697 .752 0 r
.23058 .6146 .2428 .62586 .26222 .60551 .25014 .59401 Metetra
.463 .693 0 r
.25014 .59401 .26222 .60551 .28165 .58455 .26971 .57282 Metetra
.254 .631 0 r
.26971 .57282 .28165 .58455 .30106 .56336 .28926 .55141 Metetra
.077 .57 0 r
.28926 .55141 .30106 .56336 .32043 .54226 .30876 .53011 Metetra
0 .509 .066 r
.30876 .53011 .32043 .54226 .33973 .52154 .3282 .50919 Metetra
0 .45 .173 r
.3282 .50919 .33973 .52154 .35898 .50144 .34757 .48891 Metetra
0 .393 .247 r
.34757 .48891 .35898 .50144 .37815 .48217 .36687 .46947 Metetra
0 .341 .292 r
.36687 .46947 .37815 .48217 .39727 .46392 .38611 .45105 Metetra
0 .274 .293 r
.38611 .45105 .39727 .46392 .41634 .44683 .40529 .43381 Metetra
0 .187 .25 r
.40529 .43381 .41634 .44683 .43538 .43103 .42444 .41787 Metetra
0 .125 .213 r
.42444 .41787 .43538 .43103 .45441 .41662 .44357 .40334 Metetra
0 .082 .182 r
.44357 .40334 .45441 .41662 .47345 .4037 .46271 .3903 Metetra
0 .055 .157 r
.46271 .3903 .47345 .4037 .49252 .39233 .48188 .37881 Metetra
0 .038 .139 r
.48188 .37881 .49252 .39233 .51167 .38256 .50112 .36893 Metetra
0 .029 .129 r
.50112 .36893 .51167 .38256 .53091 .37442 .52044 .3607 Metetra
0 .026 .125 r
.52044 .3607 .53091 .37442 .55028 .36793 .53989 .35412 Metetra
0 .029 .129 r
.53989 .35412 .55028 .36793 .56981 .36311 .5595 .34922 Metetra
0 .038 .139 r
.5595 .34922 .56981 .36311 .58954 .35994 .57929 .34598 Metetra
0 .055 .157 r
.57929 .34598 .58954 .35994 .60949 .35841 .59932 .34439 Metetra
0 .082 .182 r
.59932 .34439 .60949 .35841 .62971 .35847 .6196 .3444 Metetra
0 .125 .213 r
.6196 .3444 .62971 .35847 .65021 .36008 .64017 .34596 Metetra
0 .187 .25 r
.64017 .34596 .65021 .36008 .67104 .36316 .66106 .34901 Metetra
0 .274 .293 r
.66106 .34901 .67104 .36316 .69222 .36763 .6823 .35345 Metetra
0 .341 .292 r
.6823 .35345 .69222 .36763 .71378 .37335 .70393 .35916 Metetra
0 .393 .247 r
.70393 .35916 .71378 .37335 .73574 .38021 .72595 .36601 Metetra
0 .45 .173 r
.72595 .36601 .73574 .38021 .75812 .38801 .7484 .37382 Metetra
0 .509 .066 r
.7484 .37382 .75812 .38801 .78092 .39656 .77127 .38239 Metetra
.077 .57 0 r
.77127 .38239 .78092 .39656 .80414 .40561 .79457 .39146 Metetra
.254 .631 0 r
.79457 .39146 .80414 .40561 .82778 .41487 .8183 .40077 Metetra
.463 .693 0 r
.8183 .40077 .82778 .41487 .85182 .42401 .84242 .40995 Metetra
.697 .752 0 r
.84242 .40995 .85182 .42401 .87621 .43262 .86692 .41863 Metetra
.689 .75 0 r
.21812 .60413 .23058 .6146 .25014 .59401 .23782 .58341 Metetra
.455 .691 0 r
.23782 .58341 .25014 .59401 .26971 .57282 .25753 .5621 Metetra
.247 .629 0 r
.25753 .5621 .26971 .57282 .28926 .55141 .27722 .54057 Metetra
.07 .567 0 r
.27722 .54057 .28926 .55141 .30876 .53011 .29686 .51914 Metetra
0 .506 .071 r
.29686 .51914 .30876 .53011 .3282 .50919 .31644 .49809 Metetra
0 .447 .178 r
.31644 .49809 .3282 .50919 .34757 .48891 .33595 .47769 Metetra
0 .39 .251 r
.33595 .47769 .34757 .48891 .36687 .46947 .35538 .45813 Metetra
0 .338 .294 r
.35538 .45813 .36687 .46947 .38611 .45105 .37474 .43959 Metetra
0 .267 .29 r
.37474 .43959 .38611 .45105 .40529 .43381 .39405 .42224 Metetra
0 .181 .247 r
.39405 .42224 .40529 .43381 .42444 .41787 .41332 .40619 Metetra
0 .12 .209 r
.41332 .40619 .42444 .41787 .44357 .40334 .43256 .39155 Metetra
0 .078 .178 r
.43256 .39155 .44357 .40334 .46271 .3903 .45181 .37841 Metetra
0 .051 .154 r
.45181 .37841 .46271 .3903 .48188 .37881 .47108 .36683 Metetra
0 .035 .136 r
.47108 .36683 .48188 .37881 .50112 .36893 .49042 .35685 Metetra
0 .026 .125 r
.49042 .35685 .50112 .36893 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .026 .125 r
.52938 .34187 .53989 .35412 .5595 .34922 .54907 .33688 Metetra
0 .035 .136 r
.54907 .33688 .5595 .34922 .57929 .34598 .56895 .33356 Metetra
0 .051 .154 r
.56895 .33356 .57929 .34598 .59932 .34439 .58905 .33189 Metetra
0 .078 .178 r
.58905 .33189 .59932 .34439 .6196 .3444 .60941 .33183 Metetra
0 .12 .209 r
.60941 .33183 .6196 .3444 .64017 .34596 .63005 .33333 Metetra
0 .181 .247 r
.63005 .33333 .64017 .34596 .66106 .34901 .65102 .33631 Metetra
0 .267 .29 r
.65102 .33631 .66106 .34901 .6823 .35345 .67233 .34068 Metetra
0 .338 .294 r
.67233 .34068 .6823 .35345 .70393 .35916 .69403 .34634 Metetra
0 .39 .251 r
.69403 .34634 .70393 .35916 .72595 .36601 .71613 .35313 Metetra
0 .447 .178 r
.71613 .35313 .72595 .36601 .7484 .37382 .73864 .36088 Metetra
0 .506 .071 r
.73864 .36088 .7484 .37382 .77127 .38239 .76159 .3694 Metetra
.07 .567 0 r
.76159 .3694 .77127 .38239 .79457 .39146 .78498 .37843 Metetra
.247 .629 0 r
.78498 .37843 .79457 .39146 .8183 .40077 .80879 .38768 Metetra
.455 .691 0 r
.80879 .38768 .8183 .40077 .84242 .40995 .833 .39681 Metetra
.689 .75 0 r
.833 .39681 .84242 .40995 .86692 .41863 .85759 .40544 Metetra
.697 .752 0 r
.20541 .59447 .21812 .60413 .23782 .58341 .22524 .57374 Metetra
.463 .693 0 r
.22524 .57374 .23782 .58341 .25753 .5621 .2451 .5524 Metetra
.254 .631 0 r
.2451 .5524 .25753 .5621 .27722 .54057 .26493 .53083 Metetra
.077 .57 0 r
.26493 .53083 .27722 .54057 .29686 .51914 .28471 .50935 Metetra
0 .509 .066 r
.28471 .50935 .29686 .51914 .31644 .49809 .30443 .48825 Metetra
0 .45 .173 r
.30443 .48825 .31644 .49809 .33595 .47769 .32408 .46778 Metetra
0 .393 .247 r
.32408 .46778 .33595 .47769 .35538 .45813 .34365 .44816 Metetra
0 .341 .292 r
.34365 .44816 .35538 .45813 .37474 .43959 .36315 .42955 Metetra
0 .274 .293 r
.36315 .42955 .37474 .43959 .39405 .42224 .38259 .41212 Metetra
0 .187 .25 r
.38259 .41212 .39405 .42224 .41332 .40619 .40198 .396 Metetra
0 .125 .213 r
.40198 .396 .41332 .40619 .43256 .39155 .42135 .38128 Metetra
0 .082 .182 r
.42135 .38128 .43256 .39155 .45181 .37841 .44072 .36805 Metetra
0 .055 .157 r
.44072 .36805 .45181 .37841 .47108 .36683 .46011 .35638 Metetra
0 .038 .139 r
.46011 .35638 .47108 .36683 .49042 .35685 .47955 .34633 Metetra
0 .029 .129 r
.47955 .34633 .49042 .35685 .50984 .34853 .49908 .33792 Metetra
0 .026 .125 r
.49908 .33792 .50984 .34853 .52938 .34187 .51872 .33117 Metetra
0 .029 .129 r
.51872 .33117 .52938 .34187 .54907 .33688 .53851 .3261 Metetra
0 .038 .139 r
.53851 .3261 .54907 .33688 .56895 .33356 .55848 .32269 Metetra
0 .055 .157 r
.55848 .32269 .56895 .33356 .58905 .33189 .57867 .32093 Metetra
0 .082 .182 r
.57867 .32093 .58905 .33189 .60941 .33183 .59912 .32078 Metetra
0 .125 .213 r
.59912 .32078 .60941 .33183 .63005 .33333 .61985 .32218 Metetra
0 .187 .25 r
.61985 .32218 .63005 .33333 .65102 .33631 .6409 .32507 Metetra
0 .274 .293 r
.6409 .32507 .65102 .33631 .67233 .34068 .6623 .32934 Metetra
0 .341 .292 r
.6623 .32934 .67233 .34068 .69403 .34634 .68407 .33489 Metetra
0 .393 .247 r
.68407 .33489 .69403 .34634 .71613 .35313 .70625 .34158 Metetra
0 .45 .173 r
.70625 .34158 .71613 .35313 .73864 .36088 .72885 .34922 Metetra
0 .509 .066 r
.72885 .34922 .73864 .36088 .76159 .3694 .75188 .35761 Metetra
.077 .57 0 r
.75188 .35761 .76159 .3694 .78498 .37843 .77535 .36651 Metetra
.254 .631 0 r
.77535 .36651 .78498 .37843 .80879 .38768 .79924 .37562 Metetra
.463 .693 0 r
.79924 .37562 .80879 .38768 .833 .39681 .82355 .38459 Metetra
.697 .752 0 r
.82355 .38459 .833 .39681 .85759 .40544 .84823 .39305 Metetra
.721 .758 0 r
.19244 .58559 .20541 .59447 .22524 .57374 .2124 .56497 Metetra
.487 .699 0 r
.2124 .56497 .22524 .57374 .2451 .5524 .23239 .54371 Metetra
.277 .638 0 r
.23239 .54371 .2451 .5524 .26493 .53083 .25236 .52219 Metetra
.097 .577 0 r
.25236 .52219 .26493 .53083 .28471 .50935 .27229 .50075 Metetra
0 .517 .048 r
.27229 .50075 .28471 .50935 .30443 .48825 .29216 .47966 Metetra
0 .458 .159 r
.29216 .47966 .30443 .48825 .32408 .46778 .31195 .45919 Metetra
0 .402 .237 r
.31195 .45919 .32408 .46778 .34365 .44816 .33167 .43955 Metetra
0 .35 .286 r
.33167 .43955 .34365 .44816 .36315 .42955 .35131 .42092 Metetra
0 .296 .303 r
.35131 .42092 .36315 .42955 .38259 .41212 .37089 .40345 Metetra
0 .206 .26 r
.37089 .40345 .38259 .41212 .40198 .396 .39042 .38728 Metetra
0 .141 .223 r
.39042 .38728 .40198 .396 .42135 .38128 .40993 .37251 Metetra
0 .096 .192 r
.40993 .37251 .42135 .38128 .44072 .36805 .42942 .35922 Metetra
0 .066 .168 r
.42942 .35922 .44072 .36805 .46011 .35638 .44894 .34749 Metetra
0 .048 .15 r
.44894 .34749 .46011 .35638 .47955 .34633 .4685 .33736 Metetra
0 .038 .139 r
.4685 .33736 .47955 .34633 .49908 .33792 .48815 .32887 Metetra
0 .035 .136 r
.48815 .32887 .49908 .33792 .51872 .33117 .5079 .32203 Metetra
0 .038 .139 r
.5079 .32203 .51872 .33117 .53851 .3261 .5278 .31687 Metetra
0 .048 .15 r
.5278 .31687 .53851 .3261 .55848 .32269 .54788 .31337 Metetra
0 .066 .168 r
.54788 .31337 .55848 .32269 .57867 .32093 .56817 .31151 Metetra
0 .096 .192 r
.56817 .31151 .57867 .32093 .59912 .32078 .58871 .31124 Metetra
0 .141 .223 r
.58871 .31124 .59912 .32078 .61985 .32218 .60954 .31253 Metetra
0 .206 .26 r
.60954 .31253 .61985 .32218 .6409 .32507 .63068 .31529 Metetra
0 .296 .303 r
.63068 .31529 .6409 .32507 .6623 .32934 .65217 .31943 Metetra
0 .35 .286 r
.65217 .31943 .6623 .32934 .68407 .33489 .67404 .32483 Metetra
0 .402 .237 r
.67404 .32483 .68407 .33489 .70625 .34158 .69631 .33135 Metetra
0 .458 .159 r
.69631 .33135 .70625 .34158 .72885 .34922 .71899 .33882 Metetra
0 .517 .048 r
.71899 .33882 .72885 .34922 .75188 .35761 .74211 .34701 Metetra
.097 .577 0 r
.74211 .34701 .75188 .35761 .77535 .36651 .76567 .3557 Metetra
.277 .638 0 r
.76567 .3557 .77535 .36651 .79924 .37562 .78965 .36456 Metetra
.487 .699 0 r
.78965 .36456 .79924 .37562 .82355 .38459 .81404 .37328 Metetra
.721 .758 0 r
.81404 .37328 .82355 .38459 .84823 .39305 .83881 .38143 Metetra
.762 .767 0 r
.17919 .57746 .19244 .58559 .2124 .56497 .19927 .55706 Metetra
.527 .71 0 r
.19927 .55706 .2124 .56497 .23239 .54371 .21939 .53599 Metetra
.315 .65 0 r
.21939 .53599 .23239 .54371 .25236 .52219 .23951 .51462 Metetra
.132 .59 0 r
.23951 .51462 .25236 .52219 .27229 .50075 .25959 .49329 Metetra
0 .53 .019 r
.25959 .49329 .27229 .50075 .29216 .47966 .2796 .4723 Metetra
0 .472 .135 r
.2796 .4723 .29216 .47966 .31195 .45919 .29955 .45189 Metetra
0 .417 .219 r
.29955 .45189 .31195 .45919 .33167 .43955 .31941 .43229 Metetra
0 .366 .274 r
.31941 .43229 .33167 .43955 .35131 .42092 .33921 .41368 Metetra
0 .319 .304 r
.33921 .41368 .35131 .42092 .37089 .40345 .35894 .39621 Metetra
0 .239 .276 r
.35894 .39621 .37089 .40345 .39042 .38728 .37861 .38003 Metetra
0 .169 .24 r
.37861 .38003 .39042 .38728 .40993 .37251 .39826 .36523 Metetra
0 .12 .209 r
.39826 .36523 .40993 .37251 .42942 .35922 .4179 .3519 Metetra
0 .087 .185 r
.4179 .3519 .42942 .35922 .44894 .34749 .43755 .34011 Metetra
0 .066 .168 r
.43755 .34011 .44894 .34749 .4685 .33736 .45724 .32992 Metetra
0 .055 .157 r
.45724 .32992 .4685 .33736 .48815 .32887 .47702 .32135 Metetra
0 .051 .154 r
.47702 .32135 .48815 .32887 .5079 .32203 .4969 .31444 Metetra
0 .055 .157 r
.4969 .31444 .5079 .32203 .5278 .31687 .51692 .30918 Metetra
0 .066 .168 r
.51692 .30918 .5278 .31687 .54788 .31337 .53711 .30557 Metetra
0 .087 .185 r
.53711 .30557 .54788 .31337 .56817 .31151 .55752 .30359 Metetra
0 .12 .209 r
.55752 .30359 .56817 .31151 .58871 .31124 .57817 .3032 Metetra
0 .169 .24 r
.57817 .3032 .58871 .31124 .60954 .31253 .59911 .30434 Metetra
0 .239 .276 r
.59911 .30434 .60954 .31253 .63068 .31529 .62035 .30694 Metetra
0 .319 .304 r
.62035 .30694 .63068 .31529 .65217 .31943 .64195 .3109 Metetra
0 .366 .274 r
.64195 .3109 .65217 .31943 .67404 .32483 .66391 .31611 Metetra
0 .417 .219 r
.66391 .31611 .67404 .32483 .69631 .33135 .68628 .32242 Metetra
0 .472 .135 r
.68628 .32242 .69631 .33135 .71899 .33882 .70906 .32964 Metetra
0 .53 .019 r
.70906 .32964 .71899 .33882 .74211 .34701 .73227 .33757 Metetra
.132 .59 0 r
.73227 .33757 .74211 .34701 .76567 .3557 .75592 .34595 Metetra
.315 .65 0 r
.75592 .34595 .76567 .3557 .78965 .36456 .77999 .35449 Metetra
.527 .71 0 r
.77999 .35449 .78965 .36456 .81404 .37328 .80448 .36282 Metetra
.762 .767 0 r
.80448 .36282 .81404 .37328 .83881 .38143 .82934 .37056 Metetra
.78 .743 0 r
.16565 .57001 .17919 .57746 .19927 .55706 .18585 .54996 Metetra
.584 .724 0 r
.18585 .54996 .19927 .55706 .21939 .53599 .2061 .52918 Metetra
.369 .666 0 r
.2061 .52918 .21939 .53599 .23951 .51462 .22635 .50806 Metetra
.181 .607 0 r
.22635 .50806 .23951 .51462 .25959 .49329 .24657 .48693 Metetra
.025 .549 0 r
.24657 .48693 .25959 .49329 .2796 .4723 .26674 .4661 Metetra
0 .492 .099 r
.26674 .4661 .2796 .4723 .29955 .45189 .28684 .44583 Metetra
0 .438 .191 r
.28684 .44583 .29955 .45189 .31941 .43229 .30686 .42632 Metetra
0 .387 .254 r
.30686 .42632 .31941 .43229 .33921 .41368 .32681 .40778 Metetra
0 .341 .292 r
.32681 .40778 .33921 .41368 .35894 .39621 .3467 .39036 Metetra
0 .289 .299 r
.3467 .39036 .35894 .39621 .37861 .38003 .36653 .3742 Metetra
0 .213 .263 r
.36653 .3742 .37861 .38003 .39826 .36523 .38633 .3594 Metetra
0 .158 .233 r
.38633 .3594 .39826 .36523 .4179 .3519 .40612 .34605 Metetra
0 .12 .209 r
.40612 .34605 .4179 .3519 .43755 .34011 .42592 .33423 Metetra
0 .096 .192 r
.42592 .33423 .43755 .34011 .45724 .32992 .44576 .32398 Metetra
0 .082 .182 r
.44576 .32398 .45724 .32992 .47702 .32135 .46567 .31535 Metetra
0 .078 .178 r
.46567 .31535 .47702 .32135 .4969 .31444 .48568 .30835 Metetra
0 .082 .182 r
.48568 .30835 .4969 .31444 .51692 .30918 .50584 .30299 Metetra
0 .096 .192 r
.50584 .30299 .51692 .30918 .53711 .30557 .52616 .29927 Metetra
0 .12 .209 r
.52616 .29927 .53711 .30557 .55752 .30359 .5467 .29715 Metetra
0 .158 .233 r
.5467 .29715 .55752 .30359 .57817 .3032 .56747 .29661 Metetra
0 .213 .263 r
.56747 .29661 .57817 .3032 .59911 .30434 .58852 .29758 Metetra
0 .289 .299 r
.58852 .29758 .59911 .30434 .62035 .30694 .60989 .29999 Metetra
0 .341 .292 r
.60989 .29999 .62035 .30694 .64195 .3109 .63159 .30373 Metetra
0 .387 .254 r
.63159 .30373 .64195 .3109 .66391 .31611 .65367 .3087 Metetra
0 .438 .191 r
.65367 .3087 .66391 .31611 .68628 .32242 .67614 .31473 Metetra
0 .492 .099 r
.67614 .31473 .68628 .32242 .70906 .32964 .69903 .32165 Metetra
.025 .549 0 r
.69903 .32165 .70906 .32964 .73227 .33757 .72234 .32923 Metetra
.181 .607 0 r
.72234 .32923 .73227 .33757 .75592 .34595 .74609 .33722 Metetra
.369 .666 0 r
.74609 .33722 .75592 .34595 .77999 .35449 .77026 .34532 Metetra
.584 .724 0 r
.77026 .34532 .77999 .35449 .80448 .36282 .79483 .35317 Metetra
.78 .743 0 r
.79483 .35317 .80448 .36282 .82934 .37056 .81978 .36035 Metetra
.796 .702 0 r
.15183 .56315 .16565 .57001 .18585 .54996 .17213 .54358 Metetra
.656 .742 0 r
.17213 .54358 .18585 .54996 .2061 .52918 .1925 .52321 Metetra
.439 .686 0 r
.1925 .52321 .2061 .52918 .22635 .50806 .21288 .50244 Metetra
.247 .629 0 r
.21288 .50244 .22635 .50806 .24657 .48693 .23325 .48161 Metetra
.084 .572 0 r
.23325 .48161 .24657 .48693 .26674 .4661 .25356 .46102 Metetra
0 .517 .048 r
.25356 .46102 .26674 .4661 .28684 .44583 .27382 .44094 Metetra
0 .464 .15 r
.27382 .44094 .28684 .44583 .30686 .42632 .294 .42159 Metetra
0 .414 .223 r
.294 .42159 .30686 .42632 .32681 .40778 .31411 .40317 Metetra
0 .369 .271 r
.31411 .40317 .32681 .40778 .3467 .39036 .33416 .38584 Metetra
0 .328 .299 r
.33416 .38584 .3467 .39036 .36653 .3742 .35416 .36973 Metetra
0 .274 .293 r
.35416 .36973 .36653 .3742 .38633 .3594 .37412 .35496 Metetra
0 .213 .263 r
.37412 .35496 .38633 .3594 .40612 .34605 .39406 .34162 Metetra
0 .169 .24 r
.39406 .34162 .40612 .34605 .42592 .33423 .41402 .32978 Metetra
0 .141 .223 r
.41402 .32978 .42592 .33423 .44576 .32398 .43402 .31949 Metetra
0 .125 .213 r
.43402 .31949 .44576 .32398 .46567 .31535 .45408 .3108 Metetra
0 .12 .209 r
.45408 .3108 .46567 .31535 .48568 .30835 .47424 .30372 Metetra
0 .125 .213 r
.47424 .30372 .48568 .30835 .50584 .30299 .49454 .29825 Metetra
0 .141 .223 r
.49454 .29825 .50584 .30299 .52616 .29927 .51501 .2944 Metetra
0 .169 .24 r
.51501 .2944 .52616 .29927 .5467 .29715 .53568 .29214 Metetra
0 .213 .263 r
.53568 .29214 .5467 .29715 .56747 .29661 .55659 .29142 Metetra
0 .274 .293 r
.55659 .29142 .56747 .29661 .58852 .29758 .57777 .29219 Metetra
0 .328 .299 r
.57777 .29219 .58852 .29758 .60989 .29999 .59926 .29437 Metetra
0 .369 .271 r
.59926 .29437 .60989 .29999 .63159 .30373 .62109 .29786 Metetra
0 .414 .223 r
.62109 .29786 .63159 .30373 .65367 .3087 .64329 .30253 Metetra
0 .464 .15 r
.64329 .30253 .65367 .3087 .67614 .31473 .66588 .30822 Metetra
0 .517 .048 r
.66588 .30822 .67614 .31473 .69903 .32165 .68888 .31476 Metetra
.084 .572 0 r
.68888 .31476 .69903 .32165 .72234 .32923 .7123 .32192 Metetra
.247 .629 0 r
.7123 .32192 .72234 .32923 .74609 .33722 .73615 .32942 Metetra
.439 .686 0 r
.73615 .32942 .74609 .33722 .77026 .34532 .76042 .33698 Metetra
.656 .742 0 r
.76042 .33698 .77026 .34532 .79483 .35317 .78509 .34421 Metetra
.796 .702 0 r
.78509 .34421 .79483 .35317 .81978 .36035 .81011 .3507 Metetra
.815 .653 0 r
.13771 .55676 .15183 .56315 .17213 .54358 .1581 .53779 Metetra
.746 .764 0 r
.1581 .53779 .17213 .54358 .1925 .52321 .17858 .51796 Metetra
.527 .71 0 r
.17858 .51796 .1925 .52321 .21288 .50244 .19909 .49764 Metetra
.33 .655 0 r
.19909 .49764 .21288 .50244 .23325 .48161 .21959 .4772 Metetra
.16 .6 0 r
.21959 .4772 .23325 .48161 .25356 .46102 .24006 .45695 Metetra
.019 .546 0 r
.24006 .45695 .25356 .46102 .27382 .44094 .26047 .43714 Metetra
0 .495 .093 r
.26047 .43714 .27382 .44094 .294 .42159 .28081 .41802 Metetra
0 .447 .178 r
.28081 .41802 .294 .42159 .31411 .40317 .30109 .39977 Metetra
0 .402 .237 r
.30109 .39977 .31411 .40317 .33416 .38584 .32131 .38258 Metetra
0 .363 .276 r
.32131 .38258 .33416 .38584 .35416 .36973 .34147 .36657 Metetra
0 .328 .299 r
.34147 .36657 .35416 .36973 .37412 .35496 .36161 .35186 Metetra
0 .289 .299 r
.36161 .35186 .37412 .35496 .39406 .34162 .38172 .33855 Metetra
0 .239 .276 r
.38172 .33855 .39406 .34162 .41402 .32978 .40184 .32671 Metetra
0 .206 .26 r
.40184 .32671 .41402 .32978 .43402 .31949 .422 .31639 Metetra
0 .187 .25 r
.422 .31639 .43402 .31949 .45408 .3108 .44223 .30764 Metetra
0 .181 .247 r
.44223 .30764 .45408 .3108 .47424 .30372 .46255 .30047 Metetra
0 .187 .25 r
.46255 .30047 .47424 .30372 .49454 .29825 .48301 .2949 Metetra
0 .206 .26 r
.48301 .2949 .49454 .29825 .51501 .2944 .50363 .29091 Metetra
0 .239 .276 r
.50363 .29091 .51501 .2944 .53568 .29214 .52445 .28848 Metetra
0 .289 .299 r
.52445 .28848 .53568 .29214 .55659 .29142 .54551 .28756 Metetra
0 .328 .299 r
.54551 .28756 .55659 .29142 .57777 .29219 .56683 .2881 Metetra
0 .363 .276 r
.56683 .2881 .57777 .29219 .59926 .29437 .58846 .29001 Metetra
0 .402 .237 r
.58846 .29001 .59926 .29437 .62109 .29786 .61043 .29319 Metetra
0 .447 .178 r
.61043 .29319 .62109 .29786 .64329 .30253 .63275 .2975 Metetra
0 .495 .093 r
.63275 .2975 .64329 .30253 .66588 .30822 .65547 .3028 Metetra
.019 .546 0 r
.65547 .3028 .66588 .30822 .68888 .31476 .67859 .30888 Metetra
.16 .6 0 r
.67859 .30888 .68888 .31476 .7123 .32192 .70213 .31552 Metetra
.33 .655 0 r
.70213 .31552 .7123 .32192 .73615 .32942 .72609 .32245 Metetra
.527 .71 0 r
.72609 .32245 .73615 .32942 .76042 .33698 .75046 .32934 Metetra
.746 .764 0 r
.75046 .32934 .76042 .33698 .78509 .34421 .77522 .33583 Metetra
.815 .653 0 r
.77522 .33583 .78509 .34421 .81011 .3507 .80033 .34149 Metetra
.836 .594 0 r
.12331 .55067 .13771 .55676 .1581 .53779 .14377 .53247 Metetra
.788 .725 0 r
.14377 .53247 .1581 .53779 .17858 .51796 .16434 .51329 Metetra
.632 .737 0 r
.16434 .51329 .17858 .51796 .19909 .49764 .18496 .49355 Metetra
.432 .684 0 r
.18496 .49355 .19909 .49764 .21959 .4772 .2056 .47361 Metetra
.255 .631 0 r
.2056 .47361 .21959 .4772 .24006 .45695 .22621 .45377 Metetra
.104 .58 0 r
.22621 .45377 .24006 .45695 .26047 .43714 .24678 .43432 Metetra
0 .53 .019 r
.24678 .43432 .26047 .43714 .28081 .41802 .26728 .41549 Metetra
0 .484 .115 r
.26728 .41549 .28081 .41802 .30109 .39977 .28773 .39748 Metetra
0 .441 .186 r
.28773 .39748 .30109 .39977 .32131 .38258 .30812 .38047 Metetra
0 .402 .237 r
.30812 .38047 .32131 .38258 .34147 .36657 .32846 .3646 Metetra
0 .369 .271 r
.32846 .3646 .34147 .36657 .36161 .35186 .34877 .34998 Metetra
0 .341 .292 r
.34877 .34998 .36161 .35186 .38172 .33855 .36906 .33673 Metetra
0 .319 .304 r
.36906 .33673 .38172 .33855 .40184 .32671 .38936 .32491 Metetra
0 .296 .303 r
.38936 .32491 .40184 .32671 .422 .31639 .4097 .31458 Metetra
0 .274 .293 r
.4097 .31458 .422 .31639 .44223 .30764 .4301 .30577 Metetra
0 .267 .29 r
.4301 .30577 .44223 .30764 .46255 .30047 .45059 .29852 Metetra
0 .274 .293 r
.45059 .29852 .46255 .30047 .48301 .2949 .47122 .29283 Metetra
0 .296 .303 r
.47122 .29283 .48301 .2949 .50363 .29091 .492 .28869 Metetra
0 .319 .304 r
.492 .28869 .50363 .29091 .52445 .28848 .51298 .28607 Metetra
0 .341 .292 r
.51298 .28607 .52445 .28848 .54551 .28756 .5342 .28493 Metetra
0 .369 .271 r
.5342 .28493 .54551 .28756 .56683 .2881 .55568 .2852 Metetra
0 .402 .237 r
.55568 .2852 .56683 .2881 .58846 .29001 .57746 .2868 Metetra
0 .441 .186 r
.57746 .2868 .58846 .29001 .61043 .29319 .59957 .28962 Metetra
0 .484 .115 r
.59957 .28962 .61043 .29319 .63275 .2975 .62204 .29352 Metetra
0 .53 .019 r
.62204 .29352 .63275 .2975 .65547 .3028 .64489 .29835 Metetra
.104 .58 0 r
.64489 .29835 .65547 .3028 .67859 .30888 .66814 .30389 Metetra
.255 .631 0 r
.66814 .30389 .67859 .30888 .70213 .31552 .6918 .30992 Metetra
.432 .684 0 r
.6918 .30992 .70213 .31552 .72609 .32245 .71587 .31615 Metetra
.632 .737 0 r
.71587 .31615 .72609 .32245 .75046 .32934 .74035 .32226 Metetra
.788 .725 0 r
.74035 .32226 .75046 .32934 .77522 .33583 .7652 .32787 Metetra
.836 .594 0 r
.7652 .32787 .77522 .33583 .80033 .34149 .79039 .33254 Metetra
.858 .527 0 r
.10864 .54471 .12331 .55067 .14377 .53247 .12914 .52741 Metetra
.814 .657 0 r
.12914 .52741 .14377 .53247 .16434 .51329 .14979 .50904 Metetra
.754 .766 0 r
.14979 .50904 .16434 .51329 .18496 .49355 .17051 .49 Metetra
.552 .716 0 r
.17051 .49 .18496 .49355 .2056 .47361 .19127 .47066 Metetra
.369 .666 0 r
.19127 .47066 .2056 .47361 .22621 .45377 .21202 .45134 Metetra
.21 .617 0 r
.21202 .45134 .22621 .45377 .24678 .43432 .23273 .43233 Metetra
.077 .57 0 r
.23273 .43233 .24678 .43432 .26728 .41549 .2534 .41386 Metetra
0 .525 .031 r
.2534 .41386 .26728 .41549 .28773 .39748 .27402 .39616 Metetra
0 .484 .115 r
.27402 .39616 .28773 .39748 .30812 .38047 .29459 .37939 Metetra
0 .447 .178 r
.29459 .37939 .30812 .38047 .32846 .3646 .31511 .3637 Metetra
0 .414 .223 r
.31511 .3637 .32846 .3646 .34877 .34998 .3356 .34922 Metetra
0 .387 .254 r
.3356 .34922 .34877 .34998 .36906 .33673 .35607 .33605 Metetra
0 .366 .274 r
.35607 .33605 .36906 .33673 .38936 .32491 .37656 .32427 Metetra
0 .35 .286 r
.37656 .32427 .38936 .32491 .4097 .31458 .39708 .31394 Metetra
0 .341 .292 r
.39708 .31394 .4097 .31458 .4301 .30577 .41766 .3051 Metetra
0 .338 .294 r
.41766 .3051 .4301 .30577 .45059 .29852 .43834 .29776 Metetra
0 .341 .292 r
.43834 .29776 .45059 .29852 .47122 .29283 .45914 .29195 Metetra
0 .35 .286 r
.45914 .29195 .47122 .29283 .492 .28869 .4801 .28764 Metetra
0 .366 .274 r
.4801 .28764 .492 .28869 .51298 .28607 .50126 .28481 Metetra
0 .387 .254 r
.50126 .28481 .51298 .28607 .5342 .28493 .52264 .28341 Metetra
0 .414 .223 r
.52264 .28341 .5342 .28493 .55568 .2852 .54429 .28338 Metetra
0 .447 .178 r
.54429 .28338 .55568 .2852 .57746 .2868 .56623 .28462 Metetra
0 .484 .115 r
.56623 .28462 .57746 .2868 .59957 .28962 .5885 .28702 Metetra
0 .525 .031 r
.5885 .28702 .59957 .28962 .62204 .29352 .61112 .29044 Metetra
.077 .57 0 r
.61112 .29044 .62204 .29352 .64489 .29835 .63412 .29472 Metetra
.21 .617 0 r
.63412 .29472 .64489 .29835 .66814 .30389 .6575 .29963 Metetra
.369 .666 0 r
.6575 .29963 .66814 .30389 .6918 .30992 .68129 .30494 Metetra
.552 .716 0 r
.68129 .30494 .6918 .30992 .71587 .31615 .70549 .31037 Metetra
.754 .766 0 r
.70549 .31037 .71587 .31615 .74035 .32226 .73007 .31556 Metetra
.814 .657 0 r
.73007 .31556 .74035 .32226 .7652 .32787 .75502 .32014 Metetra
.858 .527 0 r
.75502 .32014 .7652 .32787 .79039 .33254 .78029 .32367 Metetra
.881 .453 0 r
.0937 .53866 .10864 .54471 .12914 .52741 .11423 .52243 Metetra
.841 .58 0 r
.11423 .52243 .12914 .52741 .14979 .50904 .13493 .505 Metetra
.797 .702 0 r
.13493 .505 .14979 .50904 .17051 .49 .15574 .48678 Metetra
.689 .75 0 r
.15574 .48678 .17051 .49 .19127 .47066 .1766 .46817 Metetra
.503 .704 0 r
.1766 .46817 .19127 .47066 .21202 .45134 .19748 .44947 Metetra
.338 .657 0 r
.19748 .44947 .21202 .45134 .23273 .43233 .21834 .43099 Metetra
.196 .612 0 r
.21834 .43099 .23273 .43233 .2534 .41386 .23916 .41298 Metetra
.077 .57 0 r
.23916 .41298 .2534 .41386 .27402 .39616 .25995 .39565 Metetra
0 .53 .019 r
.25995 .39565 .27402 .39616 .29459 .37939 .28069 .37918 Metetra
0 .495 .093 r
.28069 .37918 .29459 .37939 .31511 .3637 .3014 .36373 Metetra
0 .464 .15 r
.3014 .36373 .31511 .3637 .3356 .34922 .32207 .34943 Metetra
0 .438 .191 r
.32207 .34943 .3356 .34922 .35607 .33605 .34274 .33638 Metetra
0 .417 .219 r
.34274 .33638 .35607 .33605 .37656 .32427 .36342 .32466 Metetra
0 .402 .237 r
.36342 .32466 .37656 .32427 .39708 .31394 .38413 .31434 Metetra
0 .393 .247 r
.38413 .31434 .39708 .31394 .41766 .3051 .40491 .30546 Metetra
0 .39 .251 r
.40491 .30546 .41766 .3051 .43834 .29776 .42578 .29805 Metetra
0 .393 .247 r
.42578 .29805 .43834 .29776 .45914 .29195 .44677 .2921 Metetra
0 .402 .237 r
.44677 .2921 .45914 .29195 .4801 .28764 .46792 .28761 Metetra
0 .417 .219 r
.46792 .28761 .4801 .28764 .50126 .28481 .48926 .28454 Metetra
0 .438 .191 r
.48926 .28454 .50126 .28481 .52264 .28341 .51082 .28285 Metetra
0 .464 .15 r
.51082 .28285 .52264 .28341 .54429 .28338 .53265 .28247 Metetra
0 .495 .093 r
.53265 .28247 .54429 .28338 .56623 .28462 .55476 .2833 Metetra
0 .53 .019 r
.55476 .2833 .56623 .28462 .5885 .28702 .5772 .28522 Metetra
.077 .57 0 r
.5772 .28522 .5885 .28702 .61112 .29044 .59998 .28809 Metetra
.196 .612 0 r
.59998 .28809 .61112 .29044 .63412 .29472 .62313 .29173 Metetra
.338 .657 0 r
.62313 .29173 .63412 .29472 .6575 .29963 .64666 .29592 Metetra
.503 .704 0 r
.64666 .29592 .6575 .29963 .68129 .30494 .67059 .3004 Metetra
.689 .75 0 r
.67059 .3004 .68129 .30494 .70549 .31037 .6949 .30489 Metetra
.797 .702 0 r
.6949 .30489 .70549 .31037 .73007 .31556 .7196 .30903 Metetra
.841 .58 0 r
.7196 .30903 .73007 .31556 .75502 .32014 .74464 .31243 Metetra
.881 .453 0 r
.74464 .31243 .75502 .32014 .78029 .32367 .76998 .31463 Metetra
.904 .375 0 r
.07854 .53225 .0937 .53866 .11423 .52243 .09906 .51725 Metetra
.868 .496 0 r
.09906 .51725 .11423 .52243 .13493 .505 .11979 .50092 Metetra
.828 .616 0 r
.11979 .50092 .13493 .505 .15574 .48678 .14065 .48368 Metetra
.786 .729 0 r
.14065 .48368 .15574 .48678 .1766 .46817 .1616 .46592 Metetra
.657 .743 0 r
.1616 .46592 .1766 .46817 .19748 .44947 .18259 .44796 Metetra
.487 .699 0 r
.18259 .44796 .19748 .44947 .21834 .43099 .20359 .43011 Metetra
.338 .657 0 r
.20359 .43011 .21834 .43099 .23916 .41298 .22457 .41264 Metetra
.21 .617 0 r
.22457 .41264 .23916 .41298 .25995 .39565 .24551 .39575 Metetra
.104 .58 0 r
.24551 .39575 .25995 .39565 .28069 .37918 .26643 .37965 Metetra
.019 .546 0 r
.26643 .37965 .28069 .37918 .3014 .36373 .28732 .36449 Metetra
0 .517 .048 r
.28732 .36449 .3014 .36373 .32207 .34943 .30819 .35041 Metetra
0 .492 .099 r
.30819 .35041 .32207 .34943 .34274 .33638 .32905 .33752 Metetra
0 .472 .135 r
.32905 .33752 .34274 .33638 .36342 .32466 .34993 .3259 Metetra
0 .458 .159 r
.34993 .3259 .36342 .32466 .38413 .31434 .37084 .31561 Metetra
0 .45 .173 r
.37084 .31561 .38413 .31434 .40491 .30546 .39181 .3067 Metetra
0 .447 .178 r
.39181 .3067 .40491 .30546 .42578 .29805 .41288 .2992 Metetra
0 .45 .173 r
.41288 .2992 .42578 .29805 .44677 .2921 .43408 .29311 Metetra
0 .458 .159 r
.43408 .29311 .44677 .2921 .46792 .28761 .45542 .28842 Metetra
0 .472 .135 r
.45542 .28842 .46792 .28761 .48926 .28454 .47696 .28509 Metetra
0 .492 .099 r
.47696 .28509 .48926 .28454 .51082 .28285 .49872 .28307 Metetra
0 .517 .048 r
.49872 .28307 .51082 .28285 .53265 .28247 .52073 .28229 Metetra
.019 .546 0 r
.52073 .28229 .53265 .28247 .55476 .2833 .54303 .28265 Metetra
.104 .58 0 r
.54303 .28265 .55476 .2833 .5772 .28522 .56564 .28403 Metetra
.21 .617 0 r
.56564 .28403 .5772 .28522 .59998 .28809 .58859 .28626 Metetra
.338 .657 0 r
.58859 .28626 .59998 .28809 .62313 .29173 .6119 .28917 Metetra
.487 .699 0 r
.6119 .28917 .62313 .29173 .64666 .29592 .63559 .29252 Metetra
.657 .743 0 r
.63559 .29252 .64666 .29592 .67059 .3004 .65965 .29606 Metetra
.786 .729 0 r
.65965 .29606 .67059 .3004 .6949 .30489 .6841 .29947 Metetra
.828 .616 0 r
.6841 .29947 .6949 .30489 .7196 .30903 .7089 .3024 Metetra
.868 .496 0 r
.7089 .3024 .7196 .30903 .74464 .31243 .73404 .30445 Metetra
.904 .375 0 r
.73404 .30445 .74464 .31243 .76998 .31463 .75945 .30514 Metetra
.926 .297 0 r
.06319 .52517 .07854 .53225 .09906 .51725 .08366 .51159 Metetra
.895 .407 0 r
.08366 .51159 .09906 .51725 .11979 .50092 .10438 .49653 Metetra
.86 .522 0 r
.10438 .49653 .11979 .50092 .14065 .48368 .12528 .48041 Metetra
.822 .634 0 r
.12528 .48041 .14065 .48368 .1616 .46592 .1463 .46363 Metetra
.782 .738 0 r
.1463 .46363 .1616 .46592 .18259 .44796 .16738 .44654 Metetra
.657 .743 0 r
.16738 .44654 .18259 .44796 .20359 .43011 .1885 .42944 Metetra
.503 .704 0 r
.1885 .42944 .20359 .43011 .22457 .41264 .20961 .4126 Metetra
.369 .666 0 r
.20961 .4126 .22457 .41264 .24551 .39575 .23072 .39625 Metetra
.255 .631 0 r
.23072 .39625 .24551 .39575 .26643 .37965 .25181 .38059 Metetra
.16 .6 0 r
.25181 .38059 .26643 .37965 .28732 .36449 .27288 .36578 Metetra
.084 .572 0 r
.27288 .36578 .28732 .36449 .30819 .35041 .29393 .35197 Metetra
.025 .549 0 r
.29393 .35197 .30819 .35041 .32905 .33752 .31499 .33927 Metetra
0 .53 .019 r
.31499 .33927 .32905 .33752 .34993 .3259 .33607 .32777 Metetra
0 .517 .048 r
.33607 .32777 .34993 .3259 .37084 .31561 .35719 .31753 Metetra
0 .509 .066 r
.35719 .31753 .37084 .31561 .39181 .3067 .37837 .30861 Metetra
0 .506 .071 r
.37837 .30861 .39181 .3067 .41288 .2992 .39965 .30102 Metetra
0 .509 .066 r
.39965 .30102 .41288 .2992 .43408 .29311 .42105 .29477 Metetra
0 .517 .048 r
.42105 .29477 .43408 .29311 .45542 .28842 .44261 .28986 Metetra
0 .53 .019 r
.44261 .28986 .45542 .28842 .47696 .28509 .46435 .28624 Metetra
.025 .549 0 r
.46435 .28624 .47696 .28509 .49872 .28307 .48631 .28385 Metetra
.084 .572 0 r
.48631 .28385 .49872 .28307 .52073 .28229 .50852 .28262 Metetra
.16 .6 0 r
.50852 .28262 .52073 .28229 .54303 .28265 .53101 .28245 Metetra
.255 .631 0 r
.53101 .28245 .54303 .28265 .56564 .28403 .55381 .2832 Metetra
.369 .666 0 r
.55381 .2832 .56564 .28403 .58859 .28626 .57694 .28471 Metetra
.503 .704 0 r
.57694 .28471 .58859 .28626 .6119 .28917 .60042 .28678 Metetra
.657 .743 0 r
.60042 .28678 .6119 .28917 .63559 .29252 .62426 .28918 Metetra
.782 .738 0 r
.62426 .28918 .63559 .29252 .65965 .29606 .64848 .29163 Metetra
.822 .634 0 r
.64848 .29163 .65965 .29606 .6841 .29947 .67305 .29383 Metetra
.86 .522 0 r
.67305 .29383 .6841 .29947 .7089 .3024 .69797 .29539 Metetra
.895 .407 0 r
.69797 .29539 .7089 .3024 .73404 .30445 .72319 .2959 Metetra
.926 .297 0 r
.72319 .2959 .73404 .30445 .75945 .30514 .74867 .29489 Metetra
.945 .223 0 r
.0477 .51709 .06319 .52517 .08366 .51159 .06807 .50512 Metetra
.92 .318 0 r
.06807 .50512 .08366 .51159 .10438 .49653 .08875 .49149 Metetra
.89 .423 0 r
.08875 .49149 .10438 .49653 .12528 .48041 .10965 .47666 Metetra
.857 .531 0 r
.10965 .47666 .12528 .48041 .1463 .46363 .13071 .46102 Metetra
.822 .634 0 r
.13071 .46102 .1463 .46363 .16738 .44654 .15186 .44492 Metetra
.786 .729 0 r
.15186 .44492 .16738 .44654 .1885 .42944 .17308 .42868 Metetra
.689 .75 0 r
.17308 .42868 .1885 .42944 .20961 .4126 .19432 .41258 Metetra
.552 .716 0 r
.19432 .41258 .20961 .4126 .23072 .39625 .21557 .39685 Metetra
.432 .684 0 r
.21557 .39685 .23072 .39625 .25181 .38059 .23682 .38171 Metetra
.33 .655 0 r
.23682 .38171 .25181 .38059 .27288 .36578 .25807 .36732 Metetra
.247 .629 0 r
.25807 .36732 .27288 .36578 .29393 .35197 .27931 .35384 Metetra
.181 .607 0 r
.27931 .35384 .29393 .35197 .31499 .33927 .30057 .34138 Metetra
.132 .59 0 r
.30057 .34138 .31499 .33927 .33607 .32777 .32185 .33003 Metetra
.097 .577 0 r
.32185 .33003 .33607 .32777 .35719 .31753 .34318 .31986 Metetra
.077 .57 0 r
.34318 .31986 .35719 .31753 .37837 .30861 .36458 .31093 Metetra
.07 .567 0 r
.36458 .31093 .37837 .30861 .39965 .30102 .38607 .30325 Metetra
.077 .57 0 r
.38607 .30325 .39965 .30102 .42105 .29477 .40768 .29684 Metetra
.097 .577 0 r
.40768 .29684 .42105 .29477 .44261 .28986 .42945 .29168 Metetra
.132 .59 0 r
.42945 .29168 .44261 .28986 .46435 .28624 .45141 .28773 Metetra
.181 .607 0 r
.45141 .28773 .46435 .28624 .48631 .28385 .47358 .28493 Metetra
.247 .629 0 r
.47358 .28493 .48631 .28385 .50852 .28262 .496 .28319 Metetra
.33 .655 0 r
.496 .28319 .50852 .28262 .53101 .28245 .51869 .28241 Metetra
.432 .684 0 r
.51869 .28241 .53101 .28245 .55381 .2832 .54168 .28245 Metetra
.552 .716 0 r
.54168 .28245 .55381 .2832 .57694 .28471 .565 .28313 Metetra
.689 .75 0 r
.565 .28313 .57694 .28471 .60042 .28678 .58866 .28426 Metetra
.786 .729 0 r
.58866 .28426 .60042 .28678 .62426 .28918 .61267 .28558 Metetra
.822 .634 0 r
.61267 .28558 .62426 .28918 .64848 .29163 .63703 .28681 Metetra
.857 .531 0 r
.63703 .28681 .64848 .29163 .67305 .29383 .66174 .28762 Metetra
.89 .423 0 r
.66174 .28762 .67305 .29383 .69797 .29539 .68677 .28763 Metetra
.92 .318 0 r
.68677 .28763 .69797 .29539 .72319 .2959 .71208 .28642 Metetra
.945 .223 0 r
.71208 .28642 .72319 .2959 .74867 .29489 .73761 .28349 Metetra
.961 .161 0 r
.03213 .50762 .0477 .51709 .06807 .50512 .05236 .49744 Metetra
.942 .235 0 r
.05236 .49744 .06807 .50512 .08875 .49149 .07295 .48544 Metetra
.918 .325 0 r
.07295 .48544 .08875 .49149 .10965 .47666 .09382 .47206 Metetra
.89 .423 0 r
.09382 .47206 .10965 .47666 .13071 .46102 .11487 .4577 Metetra
.86 .522 0 r
.11487 .4577 .13071 .46102 .15186 .44492 .13607 .44274 Metetra
.828 .616 0 r
.13607 .44274 .15186 .44492 .17308 .42868 .15736 .42749 Metetra
.797 .702 0 r
.15736 .42749 .17308 .42868 .19432 .41258 .17871 .41224 Metetra
.754 .766 0 r
.17871 .41224 .19432 .41258 .21557 .39685 .20009 .39724 Metetra
.632 .737 0 r
.20009 .39724 .21557 .39685 .23682 .38171 .22149 .38271 Metetra
.527 .71 0 r
.22149 .38271 .23682 .38171 .25807 .36732 .24291 .36881 Metetra
.439 .686 0 r
.24291 .36881 .25807 .36732 .27931 .35384 .26434 .35571 Metetra
.369 .666 0 r
.26434 .35571 .27931 .35384 .30057 .34138 .28579 .34353 Metetra
.315 .65 0 r
.28579 .34353 .30057 .34138 .32185 .33003 .30727 .33237 Metetra
.277 .638 0 r
.30727 .33237 .32185 .33003 .34318 .31986 .32881 .3223 Metetra
.254 .631 0 r
.32881 .3223 .34318 .31986 .36458 .31093 .35042 .31337 Metetra
.247 .629 0 r
.35042 .31337 .36458 .31093 .38607 .30325 .37213 .3056 Metetra
.254 .631 0 r
.37213 .3056 .38607 .30325 .40768 .29684 .39397 .29901 Metetra
.277 .638 0 r
.39397 .29901 .40768 .29684 .42945 .29168 .41596 .29358 Metetra
.315 .65 0 r
.41596 .29358 .42945 .29168 .45141 .28773 .43814 .28926 Metetra
.369 .666 0 r
.43814 .28926 .45141 .28773 .47358 .28493 .46053 .28599 Metetra
.439 .686 0 r
.46053 .28599 .47358 .28493 .496 .28319 .48316 .28368 Metetra
.527 .71 0 r
.48316 .28368 .496 .28319 .51869 .28241 .50606 .28222 Metetra
.632 .737 0 r
.50606 .28222 .51869 .28241 .54168 .28245 .52926 .28145 Metetra
.754 .766 0 r
.52926 .28145 .54168 .28245 .565 .28313 .55277 .2812 Metetra
.797 .702 0 r
.55277 .2812 .565 .28313 .58866 .28426 .57661 .28125 Metetra
.828 .616 0 r
.57661 .28125 .58866 .28426 .61267 .28558 .60079 .28135 Metetra
.86 .522 0 r
.60079 .28135 .61267 .28558 .63703 .28681 .6253 .2812 Metetra
.89 .423 0 r
.6253 .2812 .63703 .28681 .66174 .28762 .65014 .28046 Metetra
.918 .325 0 r
.65014 .28046 .66174 .28762 .68677 .28763 .67528 .27874 Metetra
.942 .235 0 r
.67528 .27874 .68677 .28763 .71208 .28642 .70067 .2756 Metetra
.961 .161 0 r
.70067 .2756 .71208 .28642 .73761 .28349 .72625 .27055 Metetra
.972 .117 0 r
.01657 .4963 .03213 .50762 .05236 .49744 .0366 .48812 Metetra
.96 .165 0 r
.0366 .48812 .05236 .49744 .07295 .48544 .05705 .47794 Metetra
.942 .235 0 r
.05705 .47794 .07295 .48544 .09382 .47206 .07782 .46619 Metetra
.92 .318 0 r
.07782 .46619 .09382 .47206 .11487 .4577 .09885 .45329 Metetra
.895 .407 0 r
.09885 .45329 .11487 .4577 .13607 .44274 .12005 .43961 Metetra
.868 .496 0 r
.12005 .43961 .13607 .44274 .15736 .42749 .14139 .42549 Metetra
.841 .58 0 r
.14139 .42549 .15736 .42749 .17871 .41224 .16282 .41122 Metetra
.814 .657 0 r
.16282 .41122 .17871 .41224 .20009 .39724 .18431 .39705 Metetra
.788 .725 0 r
.18431 .39705 .20009 .39724 .22149 .38271 .20585 .38321 Metetra
.746 .764 0 r
.20585 .38321 .22149 .38271 .24291 .36881 .22742 .36989 Metetra
.656 .742 0 r
.22742 .36989 .24291 .36881 .26434 .35571 .24902 .35724 Metetra
.583 .724 0 r
.24902 .35724 .26434 .35571 .28579 .34353 .27066 .34539 Metetra
.527 .71 0 r
.27066 .34539 .28579 .34353 .30727 .33237 .29234 .33445 Metetra
.487 .699 0 r
.29234 .33445 .30727 .33237 .32881 .3223 .31409 .3245 Metetra
.463 .693 0 r
.31409 .3245 .32881 .3223 .35042 .31337 .33592 .31558 Metetra
.455 .691 0 r
.33592 .31558 .35042 .31337 .37213 .3056 .35785 .30773 Metetra
.463 .693 0 r
.35785 .30773 .37213 .3056 .39397 .29901 .37991 .30094 Metetra
.487 .699 0 r
.37991 .30094 .39397 .29901 .41596 .29358 .40213 .2952 Metetra
.527 .71 0 r
.40213 .2952 .41596 .29358 .43814 .28926 .42453 .29047 Metetra
.583 .724 0 r
.42453 .29047 .43814 .28926 .46053 .28599 .44715 .28668 Metetra
.656 .742 0 r
.44715 .28668 .46053 .28599 .48316 .28368 .47 .28372 Metetra
.746 .764 0 r
.47 .28372 .48316 .28368 .50606 .28222 .49312 .28149 Metetra
.788 .725 0 r
.49312 .28149 .50606 .28222 .52926 .28145 .51653 .27981 Metetra
.814 .657 0 r
.51653 .27981 .52926 .28145 .55277 .2812 .54024 .27851 Metetra
.841 .58 0 r
.54024 .27851 .55277 .2812 .57661 .28125 .56426 .27736 Metetra
.868 .496 0 r
.56426 .27736 .57661 .28125 .60079 .28135 .58861 .27609 Metetra
.895 .407 0 r
.58861 .27609 .60079 .28135 .6253 .2812 .61328 .27439 Metetra
.92 .318 0 r
.61328 .27439 .6253 .2812 .65014 .28046 .63825 .27192 Metetra
.942 .235 0 r
.63825 .27192 .65014 .28046 .67528 .27874 .66349 .26826 Metetra
.96 .165 0 r
.66349 .26826 .67528 .27874 .70067 .2756 .68895 .26298 Metetra
.972 .117 0 r
.68895 .26298 .70067 .2756 .72625 .27055 .71457 .25558 Metetra
.977 .099 0 r
.0011 .48266 .01657 .4963 .0366 .48812 .02087 .47669 Metetra
.972 .117 0 r
.02087 .47669 .0366 .48812 .05705 .47794 .04112 .46851 Metetra
.961 .161 0 r
.04112 .46851 .05705 .47794 .07782 .46619 .06176 .45858 Metetra
.945 .223 0 r
.06176 .45858 .07782 .46619 .09885 .45329 .0827 .44731 Metetra
.926 .297 0 r
.0827 .44731 .09885 .45329 .12005 .43961 .10387 .43508 Metetra
.904 .375 0 r
.10387 .43508 .12005 .43961 .14139 .42549 .12522 .42223 Metetra
.881 .453 0 r
.12522 .42223 .14139 .42549 .16282 .41122 .1467 .40906 Metetra
.858 .527 0 r
.1467 .40906 .16282 .41122 .18431 .39705 .16827 .39584 Metetra
.836 .594 0 r
.16827 .39584 .18431 .39705 .20585 .38321 .18992 .38279 Metetra
.815 .653 0 r
.18992 .38279 .20585 .38321 .22742 .36989 .21163 .37013 Metetra
.796 .702 0 r
.21163 .37013 .22742 .36989 .24902 .35724 .23339 .358 Metetra
.78 .743 0 r
.23339 .358 .24902 .35724 .27066 .34539 .25521 .34654 Metetra
.762 .767 0 r
.25521 .34654 .27066 .34539 .29234 .33445 .27708 .33587 Metetra
.721 .758 0 r
.27708 .33587 .29234 .33445 .31409 .3245 .29904 .32606 Metetra
.697 .752 0 r
.29904 .32606 .31409 .3245 .33592 .31558 .32108 .31716 Metetra
.689 .75 0 r
.32108 .31716 .33592 .31558 .35785 .30773 .34323 .30921 Metetra
.697 .752 0 r
.34323 .30921 .35785 .30773 .37991 .30094 .36552 .30221 Metetra
.721 .758 0 r
.36552 .30221 .37991 .30094 .40213 .2952 .38797 .29614 Metetra
.762 .767 0 r
.38797 .29614 .40213 .2952 .42453 .29047 .4106 .29095 Metetra
.78 .743 0 r
.4106 .29095 .42453 .29047 .44715 .28668 .43344 .28657 Metetra
.796 .702 0 r
.43344 .28657 .44715 .28668 .47 .28372 .45652 .28289 Metetra
.815 .653 0 r
.45652 .28289 .47 .28372 .49312 .28149 .47986 .27979 Metetra
.836 .594 0 r
.47986 .27979 .49312 .28149 .51653 .27981 .50348 .2771 Metetra
.858 .527 0 r
.50348 .2771 .51653 .27981 .54024 .27851 .52739 .27462 Metetra
.881 .453 0 r
.52739 .27462 .54024 .27851 .56426 .27736 .55161 .27212 Metetra
.904 .375 0 r
.55161 .27212 .56426 .27736 .58861 .27609 .57613 .26932 Metetra
.926 .297 0 r
.57613 .26932 .58861 .27609 .61328 .27439 .60095 .2659 Metetra
.945 .223 0 r
.60095 .2659 .61328 .27439 .63825 .27192 .62604 .26149 Metetra
.961 .161 0 r
.62604 .26149 .63825 .27192 .66349 .26826 .65138 .2557 Metetra
.972 .117 0 r
.65138 .2557 .66349 .26826 .68895 .26298 .67691 .24806 Metetra
.977 .099 0 r
.67691 .24806 .68895 .26298 .71457 .25558 .70256 .23807 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00/_ooool3o`0000Cooooo0_l0
001Uooooo`00/oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0006Cooooo002c
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000I?ooool00;?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Cooooo`;o0000Coooool00;?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000@ooooo`?o000000?oooooo`000?ooool0C_oo
ool00;;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000kooooo0_l00004ooooo`;o0000C_oo
ool00;?ooooo00?o0000ooooooooool00oooool2o`0000cooooo0ol00002ooooo`07o`000?oooooo
ooooooooool0003oooooo`00001=ooooo`00aOooool2o`0000Wooooo00Co0000ooooool0003o0000
C?ooool00<;ooooo0ol0000;ooooo`04o`000?ooooooooooo`0004cooooo002oooooo`?o00003_oo
ool01Ol0003ooooooooooooooooo000004_ooooo002mooooo`;o00004Oooool01Ol0003ooooooooo
oooooooo000004_ooooo002jooooo`Co00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00_ooooo0ol00004ooooo`;o0000=?ooool00;Sooooo0_l00004ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000<oooool00;Gooooo0ol0000Iooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool5o`0000?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000cooooo`00/oooool2o`0001cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<ooo
ool00;3ooooo0ol0000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003?ooooo002^ooooo`;o00008Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`04o`000?oooooo
ooooo`0003?ooooo002[ooooo`?o00000_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Cooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo0_l0000dooooo`00ZOooool2o`00
02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`00Y_ooool3o`0002So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`00Y?ooool2o`0002_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`12ooooo`00XOooool3o`0002gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`12ooooo`00W_ooool3o`0000;ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo002Loooo
o`;o0000<oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo043ooooo002Iooooo`?o
0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo043ooooo002Gooooo`;o0000
>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03oooooo001eooooo`;o00007Ooo
ool3o`0003[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0nooooo`00M?ooool0
1?l0003oooooooooool0000Jooooo`;o000000?oooooo`000?ooool0>oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo03kooooo001dooooo`04o`000?ooooooooooo`0001Oooooo0ol0
0010ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?Oooool007Cooooo00Co0000
oooooooooooo00005Oooool2o`0004?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0looooo`00M?ooool01?l0003oooooooooool0000Booooo`?o0000AOooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03cooooo001dooooo`04o`000?ooooooooooo`00013ooooo0_l0
0018ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>oooool007Gooooo0_l0000>
ooooo`Co0000BOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03[ooooo0023oooo
o`;o0000COooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03[ooooo0020ooooo`?o
0000Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo001mooooo`?o0000
D_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo001kooooo`;o0000EOoo
ool00ol0003oooooooooo`0@ooooo`;o0000>Oooool007Sooooo1?l0001Fooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0=oooool007Kooooo0_l00004ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`00Loooool3o`0005co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0fooooo`00LOooool2o`0005oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0eooooo`00K_ooool3o`00067ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0eooooo`00K?ooool2o`000003ooooool0003o
oooo06;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0dooooo`00JOooool3o`00
06Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0cooooo`00Ioooool2o`0006[o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0cooooo`00I?ooool3o`0006cooooo
00?o0000ooooooooool05?ooool2o`0003Cooooo001Rooooo`;o0000Koooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo037ooooo001Oooooo`?o000000?oooooo`000?ooool0K_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo037ooooo001Looooo`?o0000M?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo033ooooo001Jooooo`;o0000Moooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02oooooo000booooo`?o00001?ooool2o`0001cooooo
0ol0001iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;oooool003?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`;o0000O?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo02kooooo000[ooooo`Go00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001Kooooo0ol00002ooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0]ooooo`00<oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001Cooooo0_l00021ooooo`03o`000?oooooooooo01[ooooo
0_l0000^ooooo`00<oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00017ooooo
0ol00023ooooo`03o`000?oooooooooo01[ooooo0_l0000^ooooo`00<_ooool2o`0000Cooooo00Co
0000oooooooooooo00003oooool2o`0008Kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0[ooooo`00<oooool00ol0003oooooooooo`03ooooo`;o00003Oooool4o`0008Oooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0[ooooo`00A_ooool2o`0008cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`06ooooo`;o00008_ooool004?ooooo0ol0002>oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Q
ooooo`00@Oooool2o`00097ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`00027ooooo000nooooo`?o0000Toooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00008Oooool003_ooooo0ol00002oooo
o`03o`000?oooooooooo097ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`00027ooooo000iooooo`;o0000Uoooool3o`00023ooooo0ol00003oooo
o`04o`000?ooooooooooo`00027ooooo000fooooo`?o0000U_ooool3o`0000;onQT000?o0000oooo
ooooool08?ooool00ol0003oooooooooo`02ooooo`;o00008_ooool003Cooooo0_l0002Fooooo`?o
00001?oj6@03o`00027ooooo00?o0000ooooooooool09_ooool0037ooooo1?l0002Dooooo`?o0000
00Con1d0o`000?oj6@3onQT00ol000001?oj6@3o0000ooXI0?l0000Qooooo`03o`000?oooooooooo
02Gooooo000`ooooo`;o0000U?ooool3o`0000Con1d00ol00005ooXI00?o00008Oooool00ol0003o
ooooooooo`0Tooooo`00<?ooool00ol0003oooooo`00002@ooooo`?o00000_of:@000ol0003on1d0
o`000002o`0000;on1d000?o0000ooXI0?oj6@000ol000000ooh7@3o0000o`00000Qooooo`03o`00
0?oooooooooo02Cooooo000`ooooo`04o`000?ooooooooooo`0008[ooooo1Ol00004ooHY00?o0000
0ooh7@05o`0000Gon1d00_l0000Qooooo`03o`000?oooooooooo02?ooooo000`ooooo`05o`000?oo
ooooooooooooool00000Poooool6o`0000GolCT02_l00004ooDZ0003o`000?oh7@3on1d000?on1d0
00?o0000ooPM0?l000008Oooool00ol0003oooooooooo`0Rooooo`00;oooool2o`0000Cooooo00?o
0000ooooooooool0Loooool=o`0000GokD`000Co0000oo4i0?oa>@3olCT01_l00004oo4l0003o`00
0?oe:P3omBX000ComBX000?o0000ooPM0?oh7@000_oh7@04o`00023ooooo0_l0000Sooooo`00;ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo1Ol00005on5c00;o00000ooW
G`0<o`0000Goje4000?o0000oo4l0?oa?0000ooa?0001?l0003omBX0ooDZ0?oe:P07o`0000;omRT0
0_l0000Qooooo`03o`000?oooooooooo027ooooo000_ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0H?oooolKo`0000GogWh01?l00002onEX0004o`000?o[D@3oje40on]A00co0000
1?oa?0000ol0003omRT0ooHY0002ooHY0003o`000?of:@3o0000027ooooo00?o0000ooooooooool0
8?ooool002oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Ioooooc3o00001OoS
K0000ol0003oje<0on]C0003on]C0003o`000?oa?03olC`000?olC`000Co0000ooHY0?of:@3omRT0
1?l0000Pooooo`03o`000?oooooooooo023ooooo000^ooooo`;o00002Oooool00ol0003ooooooooo
o`1Coooood[o00000_oa>@000ol0003olCT0o`00000Pooooo`03o`000?oooooooooo01oooooo000_
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0C?oooolEo`0000?o04]=1Ol00002
o`0mAR;o000000?ofhL0o`000?oSK0001OoSK0000ol0003oje40on]A0003on]A0007o`000?oa>@3o
lCT0oo4i0?l0003olCT0o`00000Pooooo`03o`000?oooooooooo01kooooo000^ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0AooooolEo`000003o`16Bol0003o000000Co00000_l0
=485o`0000Co02/m00Co0000o`0f@ol0=T?o03I31_l000000ol0AT_o0000o`1CC00Wo`0001oooooo
00?o0000ooooooooool07_ooool002kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`13oooooaWo00000ol0;cl5o`0000?o02@i2_l00004o`0X>`03o`000?l0=T?o000001co000000?o
g8D0o`000?oUJ0001?oUJ0001?l0003okD`0one<0?l00002one<0003o`000?oooooooooo01gooooo
00?o0000ooooooooool07Oooool002kooooo0_l0000=ooooo`03o`000?oooooooooo043ooooo0ol0
00000omf/@3o0000o`000008o`000003o`1S@?l0003o000000Ko00000ol0;Sl4o`0000?o01lf1Ol0
0004o`0H<@?o000000?o01heo`000?l000003ol00002o`1GBQoo000000?okD`0o`000?ooool07Ooo
ool2o`0001kooooo000^ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??oooolI
o`000004o`0^?ol0003o0000o`0000?o01he1?l00004o`0D;P03o`000?l0637o000000Ko00001?l0
5Rl00ol0003o01heo`0N=@02o`0N=@03o`000?l0:cgo02/m00;o02/m00?o0000o`0mA_l000001?l0
00000ol0Ed[o0000o`1S@@0>o`0000;oc;<01_l000000ooNOP3o0000onMO0004o`0001kooooo00?o
0000ooooooooool07?ooool002kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0g
oooooaWo00000ol0;cl4o`000004o`0N=Ol0003o0000o`0000?o01<]00Co0000o`0D;_l052ko01@^
1Ol00004o`0@:`04o`000?l05Roo01H_o`0F;a7o000000?o055=o`000?l000002ol000000olXV@3o
0000o`000005o`000004olbc0?l0003oei@0omND00Ko000000?oiel0o`000?ooool07Oooool00ol0
003oooooooooo`0Kooooo`00;Oooool3o`00013ooooo00?o0000ooooooooool0<_ooool:o`000003
oa>A0?l0003o000000oo000000Co02loo`000?l0003o00000ol07cH3o`0000Go01<]1?l00004o`0>
:0Wo00000ol042/00ol0003o01Pao`0H<@02o`0H<@05o`000?l093Wo02@io`0T>Ol000000ol0=486
o`0000;o05e62_l000000olXV@3o0000o`000009o`000003omND0?l0003ohG<000Co00007?ooool0
0ol0003oooooooooo`0Kooooo`00;Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02oooooo1Ol000000omf/@3o0000o`00000?o`0000;o04]=00Co0000o`0d@_l0=4;o03A21?l00000
1?l07cKo0000o`000?l00003o`0D;P03o`000?l04bgo000000?o00000_l03BL00ol0003o00hXo`00
0002o`000003o`098ol0003o00`V00Co00`V00Co0000o`0@:ol042_o010[3?l00004o`0d@P03o`00
0?l0Bdgo04]=00Go000000?o05e6o`000?l000002ol000001?nQ_03o0000o`000?l00002om2X00Ko
000000?ohG<0o`000?ooool06oooool00ol0003oooooooooo`0Jooooo`001oooool3o`0000?ooooo
0ol00003ooooo`?o00001?ooool01?l0003oooooooooooooool5o`0000?ooooo0ol00004ooooo`03
o`000?oooooooooo01;ooooo0_l0000]ooooo`Wo000000?o69<0o`000?l000003?l00002o`1;C@05
o`000?l0=4;o03A2o`0d@_l000000ol093T3o`0000Go01@^1?l00003o`0=9`?o00001Ol02B<01?l0
003o00`Vo`0<9_l032H5o`0000?o00hX00?o0000o`0D;_l052h00_l052h00ol0003o01lfo`0O=P0:
o`000003o`1;COl0003o05U900Co000000Co06Xho`000?l0003o07dI3_l000001?o@Z03o0000om^6
0?oKQP03o`0001cooooo00?o0000ooooooooool06Oooool000Sooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Xooooo`Co000000?oO;80o`000?l000002Ol000001?l0JSSo0000o`000?l0GDH2o`00
00Co055=1?l000001?l0=4;o0000o`0T>Ol093T2o`0000?o01Pa00?o0000o`0D;_l000000_l00003
o`0>:0Co00000ol022801?l0003o00TSo`098ol02B<5o`0000?o00TS00?o0000o`0>:?l03RP00ol0
3RP00ol0003o01@^o`0D;P02o`0D;P03o`000?l07cKo01lf00;o01lf00Go0000o`0_?ol0;coo02lo
o`000002o`16B`Co000000?o05U9o`000?l0IS`01_l00002o`J<00Go000000?oQ[D0o`000?l00000
2?l000000ooKQP3o0000ooooo`0Jooooo`03o`000?oooooooooo01Wooooo0008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`04o`000?oo
ooooooooooooo`Go00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo
0ol000000onh`P3o0000o`000006o`0000;o08L40ol00002o`1Z>004o`000?l0GDKo05e6o`0000Co
055=0_l00003o`0mAP?o000000?o02@io`000?l063401?l06344o`000006o`0>:?l0003o0000o`00
0?l02B?o00001Ol02284o`0000Co00LQ00?o0000o`098ol02B<00_l02B<01?l0003o00hXo`0>:?l0
3RPAo`0000?o04I;00?o0000o`1GB_l000000_l00003o`1V?0Ko000000?o1X`0o`000?l^V`001Ol0
00000on6]@3o0000o`000003o`000003omJH0?l0003o000000;o00006_ooool2o`0001Wooooo0008
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0001Sooooo00?o
0000ooooooooool08Oooool7o`000003oe2V0?l0003o000000;o00000ol0Q`@;o`0000;o055=00Co
0000o`0mA_l0?DKo03e60_l00002o`0[?@Co000000Co01Pao`000?l0003o00000ol042/2o`0000Go
00TS00?o0000o`088_l000000_l00002o`067`03o`000?l01b7o00LQ00?o00LQ2Ol00002o`0=9`03
o`000?l04bgo01<]00;o01<]00?o0000o`0N=Ol07SD00_l07SD01?l0003o02hoo`0^?ol0;Sl6o`00
00?o05M:0ol000000ol0ISco0000o`1e:006o`0000?o;Y/03?l000000ooFV03o0000ooooo`0Hoooo
o`;o00006Oooool000Sooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002?ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01kooooo0_l000000oo3a03o0000o`00000=o`000003o`1`<?l0003o
000000;o06=100?o0000o`1GB_l0EdX00_l0EdX4o`000003o`0mA_l0003o02/m00;o02/m00?o0000
o`0N=Ol07SD01?l00003o`0@:`;o00000_l032H00ol0003o00TSo`098`02o`098`?o00001Ol01Ql0
0ol0003o00LQo`000002o`000003o`067ol0003o00PR00?o00PR00?o0000o`0=9ol03BL00ol03BL0
0ol0003o01<]o`0C;@02o`0C;@03o`000?l07SGo01he00;o01he00Go0000o`0^?ol0;Soo02hoo`00
0003o`14BPCo000000?o05M:o`000?l0I3l00ol00003o`1e:0;o000000Oo08L4o`000?l0003o0000
objK0?l0003oGZX000Oo00000_o@Y`03o`0001Wooooo00?o0000ooooooooool05oooool000Oooooo
0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00004ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06oooool:o`000003objK0?l0003o000000;o1X`00ol00002o`1`<005o`000?l0Hd7o06=1o`1S
@Ol000000ol0EdX2o`0000?o04U<1?l000000ol0:cgo0000o`000003o`0000?o01H_00?o0000o`0@
:ol000001Ol032H01?l0003o00TSo`000?l00003o`078@04o`000?l01Qoo00HOo`067`?o00001Ol0
1Ql00ol0003o00PRo`088P02o`088P04o`000?l03BOo00dWo`0=9`co00001?l0;Sl00ol0003o04A:
o`14BP02o`14BP03o`000?l0ET_o000000;o00000ol0I3l8o`000004ob6G0?l0003o0000o`0000?o
GZX00ol000001_nW_@3o0000o`000?l0003od:L0o`0001[ooooo00?o0000ooooooooool05_ooool0
00Sooooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`0000Sooooo0ol00005
ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`03o`000?oooooooooo01Sooooo1?l00002
oiFi00;o000000GoGZX0o`000?l0003o;Y/0o`000002o`J<00Wo000000?o06=1o`000?l0EdX00_l0
EdX01?l0003o04U<o`19C?l0BD`2o`0000?o03I30ol000000ol07SGo0000o`0F;`04o`0F;`?o0000
1Ol032H2o`0000Go00LQ1?l00003o`057P03o`000?l01Qoo00HO00;o00HO2Ol00002o`0>:003o`00
0?l052ko01@^00;o01@^00Co0000o`0O=_l07cKo01lf2_l000000ol0A4[o0000o`1FB`02o`1FB`Go
00000_l0Lb`7o`000005ob6G0?l0003o0000o`000?mNZP001Ol000001?o;/`3o0000o`000?l0000J
ooooo`03o`000?oooooooooo01Gooooo000/ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool05Oooool2o`000003olNn0?l0003oUKT000;oUKT000?o0000oejZ0?mNZP002Ol00002o`1f
9P04o`000?l0JCWo06Tio`1Y>@So000000Co04U<o`000?l0=T?o03I30ol00002o`0X>`?o00000ol0
5Rl2o`0000?o010[00?o0000o`0<9_l000000_l00002o`098`03o`000?l01b7o000000;o00000_l0
1Ql00ol0003o00DNo`057P03o`057P06o`000?l01Qoo0000o`000?l01b7o00001Ol02B<00ol0003o
00hXo`0>:002o`0>:003o`000?l052ko01@^00;o01@^00?o0000o`0O=_l07cH00_l07cH01Ol0003o
02loo`0_?ol0;coo000000?o04I;1?l000000ol0ET_o0000o`1S@002o`1S@0Co000000?o07</o`00
0?l0PQ001_l000000om@YP3o0000o`000002o`0000;oUKT00ol000000oo;/`3o0000o`00000Hoooo
o`03o`000?oooooooooo01Gooooo000/ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool04oooool=o`000003oaFB0?l0003o000000;o08@<00Co0000o`1f9_l0MRKo00000_l0JCT2o`00
00?o05i500Co0000o`1CC?l0Ddco05=<1_l00003o`0X>`07o`000?l07SGo01heo`0N=Ol0003o01H_
o`000005o`0@:`;o00001Ol02B<2o`0000Ko00HO00Co0000o`057_l01Ako00DN0ol00004o`078@03
o`000?l02B?o00TS00?o00TS00?o0000o`0>:?l03RP00_l03RP00ol0003o01@^o`0D;P02o`0D;P03
o`000?l07cKo01lf00;o01lf00Go0000o`0_?ol0;coo02loo`000004o`16B`03o`000?l0Ed[o0000
00;o00000ol0Hd000ol0003o078]o`1b;@03o`0000?o088@0_l000001OlHT`3o0000o`000?l0003o
D:H000?o000000?oUKT0o`000?o7_P001?l0000Hooooo`03o`000?oooooooooo01Cooooo000/oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool4o`0000;oYkd00_l000001Om`
[`3o0000o`000?loX@3o000000;o5I8000Go0000o`243?l0Q0co08@<o`000002o`1f9P04o`000?l0
JCWo06Tio`0000Co05i500?o0000o`1CC?l0Dd`01?l000000ol0AT_o0000o`000002o`000003o`0X
>ol0003o01he00?o01he0ol00003o`0@:`;o00000_l03RP01Ol0003o00TSo`098ol02B?o000000;o
00PR00?o0000o`067ol01Ql00ol01Ql4o`0000;o00HO00?o0000o`078Ol01b400ol01b401?l0003o
00TSo`098ol02B<Fo`0000Co04I;00Co0000o`1GB_l0Ed[o05M:0_l00002o`1S@003o`000?l0LRgo
078]00;o078]0_l000000ol0PQ3o0000oa>A0003o`000005odJS0?l0003o0000o`000?n6]@000ol0
0003olNn00;o00006?ooool00ol0003oooooooooo`0Cooooo`00:oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00gooooo0_l000001?o;/`3o0000ojNm0?nW_@02o`0000;oL:l04ol0
0002o`1NA@03o`000?l0Ddco000000;o00000ol0AT/01?l0003o03I3o`0f@ol0=T<3o`0000?o01he
00Oo0000o`0H<Ol0637o01Pao`000?l042_o000000Go00hX00?o0000o`098ol000001?l022800ol0
003o00HOo`000002o`000003o`078Ol0003o00HO00Co00HO00Co0000o`078Ol01b7o00LQ1Ol00002
o`0<9P03o`000?l042_o010[00;o010[00?o0000o`0H<Ol063400_l063400ol0003o02@io`0T>@02
o`0T>@04o`000?l0=4;o03A2o`0d@PKo00000ol0EdX00ol0003o06@oo`000002o`0000Co078]00?o
0000o`214_l000000_l00002oa>A00;o00000om6X`03o`000006ohJe0?l0003o0000o`000?o7_P3o
00006?ooool2o`0001Cooooo000[ooooo`;o00008Oooool00ol0003oooooooooo`0;ooooo`go0000
0_lXV@001Ol0003o18/0o`B;0?l4R`3o000000;o07hG00Co0000o`1b;Ol0LRgo00001?l0IS`6o`00
00?o04I;00Go0000o`0f@ol0=T?o03I3o`000003o`0[?@03o`000?l07SGo000000Co01Pa0_l00006
o`0>:0;o00001Ol02282o`0000Go00LQ00?o0000o`067ol01Ql00_l01Ql4o`0000;o00TS00?o0000
o`0<9_l032H00ol032H00ol0003o010[o`0@:`02o`0@:`03o`000?l0637o01Pa00;o01Pa00?o0000
o`0T>Ol093T00_l093T01Ol0003o03A2o`0d@_l0=4;o000000?o04]=1_l00003o`1T?`Co000000?o
078]o`000?l0PA800_l0PA82o`0000;o4i400ol000000om6X`3o0000ogbb0003o`000004ol?40?l0
003o0000o`0001Sooooo00?o0000ooooooooool04_ooool002_ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`08ooooo`Co00000_nn``000ol0003oQ[D0ohJe0002o`0000;oE:L000Co
0000obRI0?lXV@3o00000ol4R`001?l0003o07hGo`1n5ol00002o`1b;@03o`000?l0ISco06Hl00;o
06Hl1?l00003o`1CC003o`000?l0AT_o000000?o03I300?o0000o`0[?Ol0:cd00_l0:cd2o`0000?o
01Pa0_l00002o`0D;P04o`000?l03RSo00hXo`0>:0;o000000?o00dWo`000?l022800_l02282o`00
0003o`098ol0003o00LQ00Co00LQ00?o0000o`067ol000000_l000000ol022;o0000o`098`04o`09
8`03o`000?l032Ko00`V00;o00`V00Co0000o`0@:ol042_o010[1ol00004o`0T>@03o`000?l0=4;o
03A200;o03A200Go0000o`1;COl0Bdgo04]=o`000003o`1IB@Co000000Co06@oo`000?l0Lbco07</
1?l000000ol0PA;o0000oa6A0003o`0000;o@J400ol00003ogbb00?o000000?o`l@0o`000?ooool0
5oooool00ol0003oooooooooo`05ooooo`?o00001?ooool2o`0000?ooooo000[ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool01Oooool2o`000003om2W0?l0003o000000;o_/<000Co
0000ohJe0?n6]@3o00000omDY`001?l0003o:9T0obRI0?l00003o`B;0004o`000?l0OQOo07hGo`00
00;o078]00?o0000o`1V??l0IS`00ol00002o`1LAP03o`000?l0Ddco05=<00;o05=<1?l000000ol0
=T?o0000o`0[?@03o`0[?@06o`000?l093Wo02@io`000?l0637o00001Ol052h00ol0003o00hXo`00
0004o`0=9`03o`000?l022;o000000Co00TS00?o0000o`078Ol01b400_l01b42o`0000Go00PR00?o
0000o`098ol02B<00_l02B<01?l0003o00`Vo`0<9_l032H5o`0000;o01H_00Co0000o`0N=Ol07SGo
01he2ol00004o`1;C@05o`000?l0FDWo05U9o`1IBOl000000_l0IS`3o`0000?o07</00?o0000o`22
4?l000000_l00002oa6A00;o00000om1X@04o`000003ogbb0?l0003o^<8000?o00005oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
02_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`;o00000_o@Y`001?l0
003o_/<0okk30?nn``0Ho`000005o`1V??l0003o05a6o`1LA_l000001?l0Dd`01?l0003o04U<o`19
C?l0BD`3o`0000?o02/m00?o0000o`0T>Ol093T00_l093T00ol0003o01@^o`0D;P04o`0D;P;o0000
1Ol03BL2o`0000Ko00TS00Co0000o`078Ol0003o00000_l02B<00ol0003o00PRo`088P03o`088P03
o`000?l02B?o00TS00Go00000_l042/00ol0003o01H_o`0F;`03o`0F;`05o`000?l07SGo01heo`0N
=Ol000001?l0:cd01?l0003o03e6o`0mA_l0?DH5o`000003o`1;COl0003o05U900;o05U900?o0000
o`1V??l0IS`00_l0IS`2o`0000;o07</00?o0000o`224?l0PQ000_l00003oa6A00?o000000Co@J40
o`000?mf/@3oM[400ol00003okS20003o`000?oooooooooo01Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo000[ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooool000002ol00003ofj_0004o`000?m1X@3o@J40o`0000?o6Y@0
00Co0000o`271?l0Q`Co00000_l0Nad3o`0000;o070_1_l00003o`1CC005o`000?l0BDco04U<o`19
C?l000000ol0?DH00ol0003o02/mo`000004o`0T>@03o`000?l07cKo000000?o01@^0_l00002o`0C
;@05o`000?l03BOo00dWo`0=9ol000000_l03RP00ol0003o00TSo`098`03o`098`;o00001Ol02B<0
1?l0003o00PRo`088_l02284o`0000;o00hX00?o0000o`0@:ol042/00ol042/00ol0003o01H_o`0F
;`03o`0F;`05o`000?l07SGo01heo`0N=Ol000001?l0:cd01Ol0003o03e6o`0mA_l0?DKo000000?o
055=1ol00003o`1V?003o`000?l0MBSo000000;o00001?l0PQ02o`000004oa6A0?l0003o?j40ocnQ
00?o00001?mf/@03o`000003okS20?l0003ooooo01Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo000Zooooo`03o`000?oooooooooo
02Gooooo0_l00002omJH00;o00000_o9^@02o`0000;oXK`000?o0000ofj_0?m^[`000_l00002od6Q
0005o`000?lJU03o6Y@0oaZD0?l000000_l0Q`@4o`0000Co070_00Go0000o`1V??l0ISco06Hlo`00
0002o`1NA@03o`000?l0Ddco000000?o04U<00?o0000o`0mA_l0?DH00_l0?DH3o`0000?o02@i00Oo
0000o`0O=_l07cKo01lfo`000?l052ko000000Go01<]00?o0000o`0=9ol000001?l03RP00ol0003o
00TSo`000002o`000003o`0<9_l0003o00TS00Co00TS1?l00002o`0=9`03o`000?l03RSo00hX00;o
00hX00?o0000o`0@:ol042/00ol042/00ol0003o01H_o`0F;`02o`0F;`03o`000?l07SGo01he00;o
01he00?o0000o`0[?Ol0:cd00_l0:cd01Ol0003o03e6o`0mA_l0?DKo000000Co055=00Co0000o`1M
A_l0GDKo05e60ol00002o`1V?004o`000?l0MBSo07DXo`1e:0?o000000?o088@o`000?lCT@000ol0
0003ocnQ00Co000000CoM[40o`000?nb`03o//000ol0000Fooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`00:_ooool00ol0003ooooo
ooooo`0Tooooo`05o`000?oFV03oeYP0omJH0?l000000oo9^@001Ol0003oXK`0oj6l0?nQ_03o0000
00;oKZl000Go0000od6Q0?m1X@3o@J40o`000003oaZD0003o`000?l0Q`Co000000;o000000?o07/M
o`000?l0L2l00ol0L2l01Ol0003o06Hlo`1V??l0ISco000000?o05i51?l000000ol0BDco0000o`0m
AP03o`0mAP07o`000?l0=4;o03A2o`0d@_l0003o02@io`000004o`0O=P;o00001_l04bd2o`0000Go
00hX0_l00005o`0<9P03o`000?l02B?o000000;o000000?o00hXo`000?l03BL01?l03BL00ol0003o
00hXo`0>:002o`0>:004o`000?l042_o010[o`0@:aKo00001?l0DDd01_l0003o05e6o`1MA_l0GDKo
0000o`1Z>0?o00000ol0MBP00ol0003o08@<o`243003o`0000?o4i400ol000001?loX@3o0000ogB`
0?md/003o`0000Co//0000?o0000ooooooooool04oooool2o`0000Cooooo0_l00004ooooo`04o`00
0?ooooooooooo`0000;ooooo000Zooooo`;o00008ooooolQo`0000;o070_00Go0000o`1V??l0ISco
06Hlo`000003o`1NA@04o`000?l0Ed[o05M:o`1GBP?o00000ol0?DH00ol0003o03A2o`0d@P02o`0d
@P;o00000ol07cH2o`0000;o01he00Co0000o`0C;Ol04bgo01<]0_l000000ol052ko0000o`0>:002
o`0>:0;o000000?o010[o`000?l032H01?l032H2o`0000Go00hX00?o0000o`0=9ol03BL00_l03BL0
1?l0003o00hXo`0>:?l03RP5o`0000;o01Pa00?o0000o`0N=Ol07SD00_l07SD00ol0003o02Pko`0X
>`02o`0X>`03o`000?l0=T?o03I300;o03I300Co0000o`19C?l0BDco04U<1_l00004o`1MAP04o`00
0?l0JSSo06Xho`1Z>0?o000000?o07DXo`000?l0Q0`00ol0Q0`3o`000003oa>A0?l0003o@J4000?o
00001?md/003o`000003ok;00?l0003ooooo01Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`;o00000oooool002[ooooo00?o0000ooooooooool08?ooool2o`0000?ofhH0
00Go0000om2X0?o@Z03od:P0o`000003ol740004o`000?n=]`3oSKL0o`0000?oGZX000?o0000ocFM
0?leW@000ol000000olCT@3o0000o`261`02o`261`04o`000?l0Nago07/Mo`1k7@Co000000?o06Hl
o`000?l0GTD00_l0GTD01Ol0003o05M:o`1GB_l0Ed[o000000?o055=00?o0000o`0mA_l000001?l0
=4801_l0003o02loo`0_?ol0003o01lfo`0000Go01he00?o0000o`0C;Ol000001?l052h00ol0003o
00hXo`000004o`0@:`03o`000?l032Ko00`V00;o000000?o010[o`000?l03RP01?l03RP01?l0003o
00dWo`0=9ol03BL5o`0000;o01@^00?o0000o`0H<Ol063400ol063400ol0003o01heo`0N=@02o`0N
=@03o`000?l0:3_o02Pk00;o02Pk00?o0000o`0f@ol0=T<00_l0=T<01Ol0003o04U<o`19C?l0BDco
000000?o05M:1_l00003o`1Z>003o`000?l0N2;o07PR00?o00000ol0Q0`00ol0003o69<0oaRC0003
o`0000;o@J401?l000001?md/03o0000ok2o0?n`_`03o`0001Kooooo00?o0000ooooooooool03Ooo
ool000Cooooo0ol00003ooooo`?o00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0002ooooo`?o00001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oKQP3ofhH000;ofhH000Go
0000om2X0?o@Z03od:P0o`000002ol7400;o00000_n=]`001?l0003oGZX0oejZ0?mNZP05o`0000;o
4i4000Go0000o`261ol0QPOo08H7o`000003o`1k7@04o`000?l0LRgo078]o`1b;@Co000000?o05i5
o`000?l0EdX00_l0EdX00ol0003o055=o`1AC@02o`1AC@?o00000ol0=4800ol0003o02loo`0_?`02
o`0_?`03o`000?l07SGo01he00Co01he0_l00005o`0D;P;o00001Ol042/00ol0003o00`Vo`000004
o`0@:`03o`000?l03RSo00hX00;o00hX1?l00002o`0C;@03o`000?l052ko01@^00?o01@^00?o0000
o`0H<Ol063400_l063400ol0003o01heo`0N=@02o`0N=@03o`000?l0:3_o02Pk00;o02Pk00?o0000
o`0f@ol0=T<00_l0=T<00ol0003o04U<o`19C002o`19C005o`000?l0Ed[o05M:o`1GB_l000000ol0
Hd44o`000003o`1Z>?l0003o07PR00?o07PR0_l00002o`243003o`000?lHT`3o69<000;o69<00_l0
00001?m1X@3o0000ogJa0?mf/@03o`0000Co/;l000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo1?l00002om^60005o`000?o@Z03od:P0
om2X0?l000000_o1a0001Ol0003oSKL0ohfg0?n=]`3o000000?oGZX00_l000000oleW@3o0000oa>A
0002oa>A0005o`000?l0QPOo08H7o`261ol000000ol0Nad01Ol0003o078]o`1b;Ol0LRgo000000?o
06Ti1?l000000ol0Ed[o0000o`1AC@03o`1AC@07o`000?l0Bdgo04]=o`1;COl0003o03A2o`000004
o`0_?`03o`000?l0;Soo000000?o01he0_l000000ol07cKo0000o`0D;P02o`0D;P;o000000?o01Pa
o`000?l042/01?l042/2o`0000Ko010[00Ko0000o`0>:?l0003o0000o`0D;_l00005o`0C;@03o`00
0?l052ko01@^00;o01@^00?o0000o`0H<Ol063400_l063401?l0003o01heo`0N=Ol07SD<o`0000Co
04U<00?o0000o`1GB_l0EdX00_l0EdX01Ol0003o06=1o`1S@Ol0Hd7o000000;o070`0ol00003o`1h
8P03o`000?l0Q`Co000000;o00001?lHT`000ol0003oAZ<0o`000002o`0000CoM[400_l00002ok2o
0003o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000001kooooo0_l00004on5c01[o000000?o08H7o`00
0?l0Nad00_l0Nad01Ol0003o078]o`1b;Ol0LRgo000000?o06Ti00?o0000o`1S@Ol0Hd400_l0Hd42
o`0000?o055=00?o0000o`1;COl0Bdd00_l0Bdd3o`0000?o02lo00Oo0000o`0^?ol0;Soo02hoo`00
0?l07SGo000000Co01lf00?o0000o`0D;_l000001?l063401ol0003o010[o`0@:ol042_o0000o`0F
;ol000001_l042/2o`0000Co01@^00?o0000o`0C;Ol04bd00ol04bd00ol0003o01@^o`0D;P0:o`00
00;o02/m00?o0000o`0f@ol0=T<00_l0=T<01?l0003o04I;o`16Bol0AT/;o`0000Co06=100?o0000
o`1`<?l0L3000_l0L302o`0000;o07PR00Co0000o`271?l0Q`Co08L40ol00002oaRC0003o`000?m6
X`3oAZ<000;o00000omf/@001_l0003o//00o`000?l0003o/;l0o`0001Kooooo00?o0000oooooooo
ool02oooool000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0001_o
oooo0_l00004on5c00;o00000ooGU0001?l0003oc;<0olbc0?l00003ok2o00Go00000omFZ0001Ol0
003o<Y`0oc:L0?lbW03o000000;o4i402?l000000ol0LRgo0000o`1Y>@02o`1Y>@03o`000?l0Hd7o
06=100;o06=100Ko0000o`1MA_l0GDKo0000o`1ACOl00004o`1;C@07o`000?l0AT_o04I;o`16Bol0
003o02loo`000004o`0^?`;o00001_l07cH00ol0003o01Pao`0H<@04o`0H<@03o`000?l042_o0000
00?o01H_00Co0000o`0@:ol042_o010[0_l000000ol0637o0000o`0D;P04o`0D;P03o`000?l04bgo
01<]00;o01<]0ol00002o`0O=P03o`000?l093Wo02@i00;o02@i00?o0000o`0[?Ol0:cd00ol0:cd0
0ol0003o03I3o`0f@`02o`0f@`05o`000?l0AT_o04I;o`16Bol000001?l0Dd`01?l0003o05i5o`1N
AOl0GTD4o`0000;o06=100Ko0000o`1`<?l0L33o070`o`000?l0OAT3o`0000?o08L400?o0000ob6G
0?lQU`000ol00003odJS00?o00000_mf/@000ol0003o//00ok;00002o`0001Oooooo00?o0000oooo
ooooool02_ooool000Gooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002?ooool01_l0
003ooooooooooooooooo0000ooooo`Co00001?ooool00ol0003oooooooooo`0Hooooo`Co00000_oQ
L`02o`0000?oei@00_l00002olbc0003o`000?n`_`3o/;l000?o00000_n0]0001Ol0003oEZP0oeJX
0?mFZ03o000000?o<Y`000Co0000oa>A0?lCT@3o00001?l0Q`@01?l0003o07hGo`1n5ol0OQL3o`00
0003o`1Y>Ol0003o06=100?o06=100?o0000o`1MA_l0GDH00_l0GDH2o`0000?o04]=00?o0000o`16
Bol0AT/00ol0AT/00ol0003o02hoo`0^?`02o`0^?`03o`000?l0;coo000000Go01lf0_l00006o`0H
<@;o00001Ol05Rl00ol0003o010[o`000004o`0H<@03o`000?l052ko01@^00;o01@^00?o0000o`0C
;Ol000000_l000000ol07SGo0000o`0O=P03o`0O=P03o`000?l093Wo02@i00;o02@i00?o0000o`0[
?Ol0:cd00ol0:cd00ol0003o03I3o`0f@`02o`0f@`05o`000?l0AT_o04I;o`16Bol000001?l0Dd`0
1Ol0003o05i5o`1NAOl0GTGo000000;o06Ti0ol00004o`1`<004o`000?l0OAWo07dIo`1m6@?o0000
00?o08L4o`000?lQU`000olQU`03o`000003odJS0?l0003oO;8000?o00001?nb`0000ol0003ooooo
ooooo`0Dooooo`;o00002oooool000Cooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool01ol0003ooooooooooooooooo0000ooooool000001oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oWG`3oiel000;oiel01?l00002omND0004o`000?o</`3oc;<0olbc
00Go00000on0]0001Ol0003oEZP0oeJX0?mFZ03o000000?o<Y`000Co0000oa>A0?lCT@3o00001?l0
Q`@01Ol0003o07hGo`1n5ol0OQOo000000?o07HV0_l00003o`1S@@03o`000?l0GDKo05e600;o05e6
00Ko0000o`1IBOl0FDWo0000o`1;COl00005o`16B`;o00000ol0;Sl01Ol0003o02loo`0_?ol0;coo
000000?o01lf00Co0000o`0T>Ol093Wo00000ol06342o`000003o`0N=Ol0003o01H_00Co01H_0_l0
0005o`0H<@03o`000?l052ko01@^00;o01@^0_l00005o`0N=@03o`000?l07cKo01lf00;o01lf00?o
0000o`0T>Ol093T00_l093T00ol0003o02/mo`0[?@02o`0[?@03o`000?l0=T?o03I300;o03I300?o
0000o`16Bol0AT/00_l0AT/00ol0003o05=<o`1CC002o`1CC005o`000?l0GTGo05i5o`1NAOl00000
1?l0JCT5o`0000?o07dI00?o0000o`J<0?l6S0000ol00003ob6G0003o`000?m@YP3oD:H000?o0000
0oml/P03o`000003ok;00?l0003ooooo01Kooooo00?o0000ooooooooool02Oooool000Gooooo00Co
0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`0000Sooooo0ol00002ooooo`Go0000
0oooool00ol0003oooooooooo`0Fooooo`03o`000?oWG`3oiel000;oiel000?o0000omin0?oNOP00
0_oNOP0@o`000003oeJX0?l0003o<Y`000;o<Y`000Co0000oa>A0?lCT@3o00001?l0Q`@01Ol0003o
07hGo`1n5ol0OQOo000000?o07HV00Ko0000o`1`<?l0L33o0000o`1S@Ol00004o`1MAP03o`000?l0
FDWo05U900;o05U900?o0000o`16Bol0AT/00ol0AT/01_l0003o04A:o`14B_l0003o02hoo`0000Go
02lo00?o0000o`0O=_l000001?l093T00ol0003o01Pao`000004o`0N=@03o`000?l05Roo01H_00;o
000000?o01heo`000?l063401?l063400ol0003o01@^o`000002o`000003o`0O=_l0003o01he00Co
01he00?o0000o`0O=_l07cH00_l07cH01?l0003o02@io`0T>Ol093TFo`0000Co05i500Go0000o`1Y
>Ol0JCWo06Tio`000003o`1f9PCo000000?o07dIo`000?l6S0000ol6S002o`0000;o8IL000Co0000
oe2V0?m@YP3oD:H00ol000001?ml/P3o0000okS20?nh`P03o`0001Gooooo0ol0000:ooooo`00:?oo
ool3o`0001Kooooo00?o0000onMO0?oWG`000_oWG`001?l0003ogWh0omin0?oNOP02o`000004om>M
0?l0003o0000o`0000?obKX000Go0000ojRn0?nX_P3oZ;h0o`000003ogbb00_o00000_l0Q`@01Ol0
003o07hGo`1n5ol0OQOo000000?o07HV00?o0000o`1`<?l0L3000_l0L302o`0000?o05e600?o0000
o`1IBOl0FDT00_l0FDT00ol0003o05M:o`000003o`16B`03o`000?l0A4[o04A:00;o04A:00?o0000
o`0_?ol0;cl01?l0;cl2o`0000Go02@i0_l00005o`0N=@03o`000?l05Roo000000Co01he00?o0000
o`0H<Ol063400_l06342o`0000Go01lf00?o0000o`0N=Ol07SD00_l07SD01?l0003o01lfo`0O=_l0
7cH5o`0000;o03A200?o0000o`0mA_l0?DH00_l0?DH00ol0003o04U<o`19C002o`19C003o`000?l0
Ddco05=<00;o05=<00Co0000o`1LA_l0G4Ko05a61_l00004o`1Y>@05o`000?l0MRKo07HVo`1f9_l0
00000_l0Q0`3o`0000?o1X`000?o0000objK0?l000000_l00004oe2V0003o`000?n6]@3o000000;o
00001?nh`P000ol0003oooooooooo`0?ooooo`?o00000_ooool00ol0003oooooooooo`08ooooo`00
:?ooool00ol0003oooooooooo`0Dooooo`Co00000_oWG`001?l0003ogWh0omin0?oNOP04o`000003
om>M0?l0003obKX000;obKX000Go0000ojRn0?nX_P3oZ;h0o`000003ogbb0003o`000?mFZ03oEZP0
00;oEZP000Co0000ocFM0?leW@3o00000olJU004o`000003o`1n5ol0003o07HV00;o07HV00?o0000
o`1`<?l0L3000_l0L3001_l0003o06Xho`1Z>?l0003o05e6o`0000Co05U900Oo0000o`1GB_l0Ed[o
05M:o`000?l0AT_o000000Co04A:00?o0000o`16Bol000000ol0;cl2o`000003o`0d@_l0003o02@i
00;o02@i0_l000000ol0:cgo0000o`0N=@04o`0N=@;o00001_l07SD01_l0003o01Pao`000?l0003o
02@io`0000Go01lf00?o0000o`0N=Ol07SD00_l07SD4o`0000;o02lo00?o0000o`0d@_l0=4800ol0
=4800ol0003o03e6o`0mAP02o`0mAP03o`000?l0BDco04U<00;o04U<00?o0000o`1CC?l0Dd`00_l0
Dd`01Ol0003o05a6o`1LA_l0G4Ko000000?o06Hl0ol00002o`1Y>@03o`000?l0MRKo07HV00;o07HV
00?o0000o`243?l0Q0`00_l0Q0`2o`0000;o1X`000Co0000objK0?l^V`3o;Y/00ol00002oe2V0003
o`000?n6]@3oQ[D000;o00000onh`P000ol0003oooooooooo`0<ooooo`?o00001Oooool00ol0003o
ooooooooo`08ooooo`00:?ooool00ol0003oooooooooo`0Booooo`;o00001?o]C008o`0000;odid0
00Go0000olVj0?o9^P3obKX0o`000003ojRn0005o`000?ml/P3oO;80ogbb0?l000001?mFZ0001?l0
003o=Id0ocFM0?l00004oaZD0004o`000?l4R`3o18/0o`B;00?o000000?o07HVo`000?l0L3000ol0
L3000ol0003o06Xho`1Z>002o`1Z>0;o00000ol0FDT00ol0003o05M:o`1GBP02o`1GBP?o00000ol0
A4X01ol0003o04I;o`16Bol0AT_o0000o`0_?ol000001?l0=4800ol0003o02@io`000004o`0[?@07
o`000?l07SGo01heo`0N=Ol0003o02Pko`000006o`0N=@;o00001?l093T00ol0003o01lfo`0O=P02
o`0O=P03o`000?l07SGo000000;o000000?o02hoo`000?l0;cl01?l0;cl00ol0003o03A2o`0d@P02
o`0d@P03o`000?l0?DKo03e600;o03e600?o0000o`19C?l0BD`00_l0BD`00ol0003o05=<o`1CC002
o`1CC003o`000?l0G4Ko05a600;o05a600Ko0000o`1V??l0ISco06Hlo`000?l0LRd3o`0000Co07HV
00?o0000o`243?l0Q0`00_l0Q0`00ol0003o5I80o`000002o`0000?o;Y/000?o0000oejZ0?mNZP00
1?l00003ohJe00?o000000?o^<80o`000?ooool02?ooool4o`0000Sooooo00?o0000ooooooooool0
2?ooool002Sooooo00?o0000ooooooooool04Oooool00ol0003okD`0one<0002one<00;o000000Co
iFP0o`000?l0003o00001?oLQ@08o`000003ojRn0?l0003oO;8000;oO;8000?o0000oeJX0?mFZ000
0_mFZ0001?l0003o=Id0ocFM0?l00004oaZD0005o`000?l4R`3o18/0o`B;0?l000000ol0Q0`2o`00
00?o070`00?o0000o`1Z>?l0JSP00_l0JSP01_l0003o06Hlo`1V??l0003o05U9o`0000Co05M:00Oo
0000o`1FBol0ET_o05I;o`000?l0A4[o000000Go04I;00?o0000o`0d@_l0=4801?l0=4800ol0003o
02/mo`0[?@04o`0[?@03o`000?l07SGo000000?o02Pk00Co0000o`0N=Ol07SGo01he0_l000000ol0
:cgo0000o`0T>@04o`0T>@04o`000?l07cKo01lfo`0O=P;o00001Ol0;Sl00ol0003o02loo`0_?`02
o`0_?`03o`000?l0=4;o03A200;o03A200?o0000o`0mA_l0?DH00_l0?DH00ol0003o04U<o`19C002
o`19C003o`000?l0Ddco05=<00;o05=<00?o0000o`1LA_l0G4H00_l0G4H00ol0003o06Hlo`1V?002
o`1V?004o`000?l0LRgo078]o`1b;@Go00001Ol0Q0`01?l0003o5I80oaFB0?lETP03o`000003objK
0?l0003oGZX000?oGZX00ol000001?n6]@3o0000ol?40?o3a003o`0000Gooooo0ol0000=ooooo`03
o`000?oooooooooo00Oooooo000Xooooo`;o00004?ooool4o`0000;okD`000Ko0000onEX0?l0003o
0000onEX0?l00004omb50003o`000?oBXP3odZ8000;odZ8000?o0000olRl0?o8_0002?l00002oeJX
0004o`000?leW@3o=Id0o`0000Co6Y@000Go0000o`B;0?l4R`3o18/0o`000003o`243006o`000?l0
OAWo07dIo`000?l0L33o00001?l0JSP00ol0003o06Hlo`1V?002o`1V?0;o00000ol0EdX00ol0003o
05I;o`1FB`03o`1FB`03o`000?l0AT_o04I;00?o04I;0_l00005o`0d@P;o00001_l0:cd2o`0000Go
02Pk00?o0000o`0N=Ol000001?l0:cd00ol0003o02@io`0T>@02o`0T>@06o`000?l07cKo0000o`00
0?l0;coo00001_l0;Sl01Ol0003o02loo`0_?ol0;coo000000Go03A200?o0000o`0mA_l0?DH02ol0
00000ol0Ddco0000o`1LAP02o`1LAP03o`000?l0ISco06Hl00;o06Hl00Go0000o`1b;Ol0LRgo078]
o`000003o`1n5`Co00000_l0Q0`01Ol0003o5I80oaFB0?lETP3o000000;o?j400ol00003oejZ00;o
000000CoUKT0o`000?l0003o00001?o3a0000ol0003oooooo`000002o`00013ooooo00?o0000oooo
ooooool01oooool002Sooooo00?o0000ooooooooool03?ooool3o`0000ColCT01?l00002onEX0003
o`000?oLQ@3og8D000;og8D000?o0000om:R0?oBXP000_oBXP001?l0003ob;`0olRl0?l00004ojRn
0004o`000?n0]03oP;@0oh2d00Oo00000_lJU0001Ol0003o18/0o`B;0?l4R`3o000000?o08@<00?o
0000o`1m6Ol0OAT00_l0OAT2o`0000?o06Xh00?o0000o`1V??l0IS`00_l0IS`01_l0003o06@oo`1T
?ol0003o05M:o`0000Go05I;0_l00004o`16B`04o`000?l0Bdgo04]=o`0000?o03A200Co0000o`0m
A_l0?DKo00000ol0:cd2o`000003o`0f@ol0003o02Pk00Co02Pk0_l00005o`0[?@03o`000?l093Wo
02@i00;o02@i0_l00004o`0_?`03o`000?l0;Soo02ho00?o02ho00?o0000o`0_?ol0;cl02_l00002
o`1AC@03o`000?l0Ed[o05M:00;o05M:00Co0000o`1NAOl0GTGo05i52ol00004o`1b;@05o`000?l0
OQOo07hGo`1n5ol000000_l4R`03o`0000Co5I8000?o0000ocnQ0?loX@000_loX@03o`000003oejZ
0?l0003o000000?oUKT00ol000000oo3a03o0000o`00000Cooooo`03o`000?oooooooooo00Oooooo
000Wooooo`03o`000?oooooooooo00_ooooo0ol00004oo4i00?o00000oo[D@04o`0000;og8D000?o
0000om:R0?oBXP000_oBXP001?l0003ob;`0olRl0?l00004ojRn0005o`000?n0]03oP;@0oh2d0?l0
00000omNZP001?l0003o@J40od6Q0?m1X@04o`000003o`B;0?l0003o08@<00;o08@<00?o0000o`1m
6Ol0OAT00_l0OAT01_l0003o07PRo`1h8_l0003o06Xho`0000Co06Hl00?o0000o`1T?ol0I3l00_l0
I3l00ol0003o05I;o`1FB`03o`1FB`04o`000?l0Ed[o05M:o`0000;o04I;00?o0000o`1;COl0Bdd0
0_l0Bdd00ol0003o03A2o`000004o`0mAP03o`000?l0:cgo000000Co03I300?o0000o`0X>ol0:3/0
0_l000000ol0=T?o0000o`0[?@04o`0[?@03o`000?l093Wo000000;o000000?o03A2o`000?l0;cl0
1?l0;cl00ol0003o02hoo`0^?`02o`0^?`?o00000_l0AT/00ol0003o04]=o`1;C@02o`1;C@03o`00
0?l0DDgo055=00?o055=00?o0000o`1GB_l0EdX00_l0EdX01Ol0003o05i5o`1NAOl0GTGo000000Co
06Hl00Co0000o`1`;ol0L2oo070_1?l00002o`1b;@05o`000?l0OQOo07hGo`1n5ol000001?l4R`02
o`0000;o5I8000?o0000ocnQ0?loX@000_loX@000ol0003oL:l0og2_0004o`0000;oUKT000?o0000
olNn0?o7_P000ol0000Cooooo`03o`000?oooooooooo00Oooooo000Wooooo`03o`000?oooooooooo
00Wooooo0_l00003ooHY00Co00001Oo[D@000ol0003ohf`0on=/0002on=/00Co00000_oBXP001?l0
003ob;`0olRl0?l00004ojRn0005o`000?n0]03oP;@0oh2d0?l000000omNZP000ol0003o@J40od6Q
0002od6Q0004o`000?lXV@3o:9T0obRI00?o000000?o08@<o`000?l0OAT00ol0OAT00ol0003o07PR
o`1h8P02o`1h8P;o00000ol0IS`00ol0003o06@oo`1T?`02o`1T?`03o`000?l0Hd3o000000?o05I;
00Oo0000o`1GB_l0Ed[o05M:o`000?l0AT_o000000Go04]=0_l00005o`0mAP;o00001Ol0=T<00ol0
003o02Pko`000004o`0f@`03o`000?l0:cgo02/m00;o02/m0_l00005o`0d@P03o`000?l0;coo02lo
00;o02lo00?o0000o`0^?ol000000_l000000ol0A4[o0000o`16B`03o`16B`03o`000?l0Bdgo04]=
00;o04]=00?o0000o`1ACOl0DDd00_l0DDd00ol0003o05M:o`1GBP02o`1GBP03o`000?l0GTGo05i5
00;o05i500?o0000o`1V??l0IS`00_l0IS`01Ol0003o070_o`1`;ol0L2oo000000;o07/M0ol00004
o`1n5`06o`000?l4R`3o18/0o`B;0?l0003o:9T00ol00005ocnQ0003o`000?m`[`3oL:l000;oL:l0
0_l00002oiFi0003o`000?o7_P3oakh000;oakh000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`07ooooo`009oooool00ol0003oooooooooo`08ooooo`04o`000?of:@3omRT0ooHY00Ko0000
1?o[D@000ol0003ohf`0on=/0002on=/0003o`000?oKQ`3ofhL000;ofhL01ol00002ojRn0005o`00
0?n0]03oP;@0oh2d0?l000000omNZP000ol0003o@J40od6Q0002od6Q0005o`000?lXV@3o:9T0obRI
0?l000000olETP02o`0000?o07dI00?o0000o`1h8_l0N2800_l0N2801_l0003o07DXo`1e:?l0003o
06Hlo`0000Co06@o00Oo0000o`1S@?l0Hd3o06=0o`000?l0ET_o000000Go05M:00?o0000o`1;COl0
Bdd00ol0Bdd00ol0003o055=o`000004o`0mAP03o`000?l0BDco000000Go03I30_l00005o`0f@`03
o`000?l0:cgo02/m00;o000000?o03e6o`000?l0=4801?l0=4800ol0003o02loo`0_?`02o`0_?`;o
00001Ol0A4X01Ol0003o04I;o`16Bol0AT_o000000Go04]=00?o0000o`1ACOl0DDd00_l0DDd01Ol0
003o05M:o`1GB_l0Ed[o000000Co05i500?o0000o`1V??l0IS`00_l0IS`00ol0003o070_o`1`;`02
o`1`;`03o`000?l0Nago07/M00;o07/M1Ol00004o`B;0004o`000?lXV@3o:9T0obRI00?o00000_lo
X@000ol0003oL:l0og2_0002og2_00Go00001?o7_P000ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Oooooo000Wooooo`;o00001oooool6o`000003ooHY0?l0003o000000?olC`00_l00000
0oo[D@3o0000on=/0002on=/00;o00001?oKQ`001Ol0003odZ80om:R0?oBXP3o000000?obKX02?l0
00000omNZP3o0000od6Q0003od6Q0005o`000?lXV@3o:9T0obRI0?l000000olETP001_l0003o1X`0
o`J<0?l0003o07dIo`0000Co07PR00?o0000o`1e:?l0MBP00_l0MBP2o`0000?o06@o00?o0000o`1S
@?l0Hd000ol0Hd000ol0003o05M:o`1GBP03o`1GBP03o`000?l0FDWo000000?o04]=00Go0000o`1A
COl0DDgo055=o`000002o`0mAP05o`000?l0BDco04U<o`19C?l000000ol0=T<00ol0003o04I;o`00
0005o`0f@`03o`000?l0:cgo000000Co03e600?o0000o`0d@_l0=4800_l0=4800ol0003o02loo`00
0002o`000003o`16Bol0003o04A:00Co04A:00?o0000o`16Bol0AT/00_l0AT/00ol0003o04]=o`1;
C@02o`1;C@03o`000?l0DDgo055=00;o055=00?o0000o`1GB_l0EdX00_l0EdX01Ol0003o05i5o`1N
AOl0GTGo000000Go06Hl00Go0000o`1`;ol0L2oo070_o`000004o`1k7@04o`000?l0Q`Co08L4o`27
10?o00000_l4R`001Ol0003o:9T0obRI0?lXV@3o000000;oE:L00ol00005og2_00;o00000_nW_@03
o`0000;oakh000?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`009oooool00ol0
003oooooooooo`03ooooo`So000000?omRT0o`000?oa?0001Ooa?004o`000003on=/0?l0003ofhL0
00?ofhL00_l00003om:R0005o`000?o9^P3obKX0olVj0?l000000on`_`000ol0003oSKL0ohfg0002
ohfg00?o00000_m1X@001Ol0003o:9T0obRI0?lXV@3o000000?o5I8000?o0000o`J<0?l6S0000_l6
S002o`0000?o07PR00?o0000o`1e:?l0MBP00ol0MBP01Ol0003o07</o`000?l0I3oo000000Go06=0
00?o0000o`1T?ol000000ol0EdX01ol0003o05U9o`1IBOl0FDWo0000o`1;COl000001?l0DDd00ol0
003o03e6o`000005o`19C003o`000?l0=T?o000000?o04I;00?o0000o`0f@ol0=T<00_l0=T<2o`00
00Ko03e600Co0000o`0d@_l0=4;o03A20_l00005o`16B`03o`000?l0A4[o04A:00;o04A:00?o0000
o`16Bol0AT/00_l0AT/01?l0003o04]=o`1;COl0BddDo`000003o`1V??l0003o070_00?o070_00?o
0000o`1k7Ol0Nad00_l0Nad01_l0003o08L4o`271?l0Q`Co0000oaZD00?o00001?lXV@000ol0003o
E:L0oeBW0002oeBW00?o00000_m`[`001Ol0003oYkd0o`000?nW_@3o000000;obk<00ol0000Boooo
o`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Ko00001?oh7@03o`0000Co
lC`00_l00003on]C00Co00000_oKQ`000ol0003odZ80om:R0002om:R0005o`000?o9^P3obKX0olVj
0?l000000on`_`000ol0003oSKL0ohfg0002ohfg0004o`000?m^[`3oKZl0ofj_00Co000000?o:9T0
o`000?lETP000_lETP000ol0003o1X`0o`J<0002o`J<0006o`000?l0Q`Co08L4o`000?l0N2;o0000
1Ol0MBP01Ol0003o07</o`1c;?l0Lbco000000Go06=000Oo0000o`1T?ol0I3oo06@oo`000?l0Ed[o
000000Go05U900?o0000o`1ACOl0DDd01?l0DDd00ol0003o04U<o`19C004o`19C0;o00001Ol0AT/0
1_l0003o03I3o`0f@ol0003o04U<o`0000Ko03e600Ko0000o`0d@_l0003o0000o`1;COl00005o`16
B`03o`000?l0A4[o04A:00?o04A:00?o0000o`16Bol0AT/01Ol00002o`1IB@03o`000?l0GDKo05e6
00;o05e600Go0000o`1S@Ol0Hd7o06=1o`000004o`1Y>@04o`000?l0LRgo078]o`1b;@Oo00001?l0
Nad00ol0003o08L4o`271002o`271004o`000?lJU03o6Y@0oaZD00?o00000_lXV@001Ol0003oE:L0
oeBW0?mDY`3o000000;oQ[D00ol000001OnW_@3o0000ojNm0?nW_@3o000000Cobk<000?o0000oooo
ooooool03oooool00ol0003oooooooooo`06ooooo`009_ooool8o`0000Con1d00_l00003ooDZ0004
o`000?oa?03o0000o`0000?oje<00_l00004on=/00Co00000_oBXP001Ol0003obKX0olVj0?o9^P3o
000000?o/;l000?o0000ohfg0?n=]`000_n=]`000ol0003oKZl0ofj_0002ofj_0004o`000?mDY`3o
E:L0oeBW00?o000000?o5I80o`000?l6S0000ol6S0000ol0003o08L4o`271002o`2710;o00001?l0
MBP01ol0003o07</o`1c;?l0Lbco0000o`1b;Ol000000ol0Hd000ol0003o06@oo`1T?`03o`1T?`03
o`000?l0FDWo05U900?o05U90_l00005o`1AC@;o00001Ol0BD`00ol0003o05=<o`000005o`16B`03
o`000?l0=T?o000000?o04U<00?o0000o`0mA_l0?DH00ol0?DH2o`0000Co04]=00?o0000o`16Bol0
AT/00_l0AT/01?l0003o04A:o`14B_l0A4X5o`0000;o05M:00?o0000o`1IBOl0FDT00ol0FDT00ol0
003o05e6o`1MAP02o`1MAP05o`000?l0Hd7o06=1o`1S@Ol000001?l0JCT00ol0003o078]o`1b;@02
o`1b;@04o`000?l0Nago07/Mo`1k7@Ko00001?l0Q`@01Ol0003o6Y@0oaZD0?lJU03o000000;o@J40
0ol00004oeBW0003o`000?n6]@3oQ[D000;oQ[D00ol00002ojNm0005o`000?o;/`3obk<0ol^c0?l0
00004Oooool00ol0003oooooooooo`06ooooo`009_ooool4o`0000ConQT000Co0000ooPM0?l0003o
00001Ooe:P04o`0000;oje<000?o0000on=/0?oSK0000ooSK0000ol0003og8D0omb50002omb500So
000000?o/;l0o`000?n=]`000on=]`000ol0003oKZl0ofj_0002ofj_0005o`000?mDY`3oE:L0oeBW
0?l000000oloX@02o`0000?o1X`000?o0000o`271?l0Q`@00ol0Q`@01_l0003o08@<o`000?l0003o
07DXo`0000?o07</00Oo0000o`1b;Ol0LRgo078]o`000?l0Hd3o000000Go06@o0_l00004o`1IB@04
o`000?l0GDKo05e6o`0000?o055=00Co0000o`1GB_l0Ed[o00000ol0BD`01Ol0003o05=<o`1CC?l0
Ddco000000Co04I;0_l00005o`19C003o`000?l0?DKo03e600;o000000?o055=o`000?l0Bdd01?l0
Bdd01?l0003o04I;o`16Bol0AT/4o`0000;o05I;00?o0000o`1GB_l0EdX00ol0EdX00ol0003o05U9
o`1IB@02o`1IB@03o`000?l0GDKo05e600;o05e600?o0000o`1S@Ol0Hd400_l0Hd401Ol0003o06Ti
o`1Y>Ol0JCWo000000Go078]00Go0000o`1k7Ol0Nago07/Mo`000003o`261`Ko00001?lJU0000ol0
003o@J40od6Q0002od6Q00Go00001?n6]@000ol0003o_/<0okk30003o`0000Cobk<000?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`0000Coooooo`000?l0003o00000oooool3o`00
00?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000Cooooo0_l00000
0ooooooo0000ooXI0003ooXI00?o00001?oe:P02o`0000ColC`00ol00004on=/0003o`000?oLQ@3o
g8D000;og8D000?o0000om>M0?oCW@000_oCW@001?l0003oc;<0olbc0?o</`03o`0000;oSKL000?o
0000ofj_0?m^[`000_m^[`001Ol0003oE:L0oeBW0?mDY`3o000000Co?j4000Go0000objK0?l0003o
1X`0o`000005o`271003o`000?l0Q0co08@<00;o08@<00Go0000o`1c;?l0Lbco07</o`000005o`1b
;@03o`000?l0I3oo06@o00?o06@o00Co0000o`1V??l0ISco00000_l0FDT00ol0003o05e6o`1MAP02
o`1MAP03o`000?l0DDgo000000Co05M:00?o0000o`19C?l000001?l0Dd`00ol0003o04I;o`16B`02
o`000003o`1CC?l0003o04U<00Co04U<00?o0000o`0mA_l000001?l0DDd00ol0003o04]=o`1;C@02
o`1;C@06o`000?l0AT_o0000o`000?l0Ed[o00001Ol0ET/00ol0003o05M:o`1GBP02o`1GBP03o`00
0?l0FDWo05U900;o05U900?o0000o`1MA_l0GDH00_l0GDH00ol0003o06=1o`1S@@02o`1S@@03o`00
0?l0JCWo06Ti00;o06Ti00?o0000o`1b;Ol0LRd00_l0LRd00ol0003o07/Mo`1k7@02o`1k7@05o`00
0?l0QPOo08H7o`261ol000000olCT@04o`0000;o6Y@000Go0000od6Q0?m1X@3o@J40o`000003ofj_
00Co00000_n6]@000ol0003o_/<0o`000002okk300Co000000?obk<0o`000?ooool03_ooool00ol0
003oooooooooo`06ooooo`000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000ooXI00;o00000ooh7@02o`000003ooDZ
0?l0003olC`000ColC`000Co0000on]A0?o[D@3oje400_l000000ooSK03o0000omb50003omb50003
o`000?oCW@3odid000;odid000Go0000olbc0?o</`3oc;<0o`000003ol7400Co00000_m^[`001Ol0
003oE:L0oeBW0?mDY`3o000000Co?j4000Co0000objK0?l^V`3o;Y/00_l00004o`271003o`000?l0
Q0co08@<00;o08@<00Go0000o`224?l0003o07</o`000005o`1b;@03o`000?l0Lbco000000?o06@o
00Oo0000o`1V??l0ISco06Hlo`000?l0FDWo000000Go05e60_l00005o`1GBP;o00001Ol0Dd`00ol0
003o04I;o`000004o`1CC003o`000?l0BDco04U<00;o04U<0_l00005o`1AC@03o`000?l0Bdgo04]=
00;o04]=0_l00004o`1GBP03o`000?l0ET_o05I;00;o05I;00?o0000o`1GB_l0EdX00_l0EdX00ol0
003o05U9o`1IB@03o`1IB@03o`000?l0GDKo05e600co00001?l0LRd00ol0003o07/Mo`1k7@02o`1k
7@03o`000?l0QPOo08H700;o08H700Go0000oa>A0?lCT@3o4i40o`000002ocFM00?o00001?m1X@00
1Ol0003oKZl0ofj_0?m^[`3o000000;oXK`00ol00002okk30003o`000?nn``3o000000?od:L00ol0
000>ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000o`0000Gon1d00ol00004oo4l0003o`00
0?o[D@3oje4000?oje401?l00002omb50003o`000?oCW@3odid000;odid000Go0000olbc0?o</`3o
c;<0o`000004ol740004o`000?nQ_03oXK`0oj6l00Co000000?oE:L0o`000?loX@000oloX@001Ol0
003o;Y/0objK0?l^V`3o000000;o8IL00_l000000ol0Q`Co0000o`243003o`243005o`000?l0PQ3o
088@o`224?l000001Ol0LRd01ol0003o07</o`1c;?l0Lbco0000o`1T?ol000001Ol0IS`00ol0003o
05e6o`1MAP03o`1MAP03o`000?l0Hd7o000000Co05M:00?o0000o`1NAOl000001_l0Dd`00ol0003o
05=<o`1CC003o`1CC003o`000?l0BDco04U<00;o000000?o05M:o`000?l0DDd01?l0DDd00ol0003o
04]=o`000002o`000003o`1IBOl0003o05M:00?o05M:00?o0000o`1FBol0ET/00ol0ET/01?l0003o
05M:o`1GB_l0EdX9o`0000;o06Xh00?o0000o`1`<?l0L3000_l0L3001?l0003o07HVo`1f9_l0MRH;
o`0000Co08H700?o0000oa>A0?lCT@000_lCT@000ol0003o=Id0ocFM0002ocFM00Go00001?m^[`00
0ol0003oXK`0oj6l0002oj6l00Co000000?o_/<0o`000?o@Y`000oo@Y`000ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Co00002?ooool01Ol0
003oooooooooool0003on1d000?o00000oof:@02o`000003oo4l0?l0003oje4000?oje400_l00004
onEX00Co00000_oCW@001Ol0003oc;<0olbc0?o</`3o000000Co`L@000Go0000oj6l0?nQ_03oXK`0
o`000004ohJe00;o00000oloX@001Ol0003o;Y/0objK0?l^V`3o000000Go8IL00_l00003o`243003
o`000?l0PQ3o088@00;o088@0_l00003o`1b;@03o`000?l0Lbco07</00?o07</00?o0000o`1V??l0
IS`00ol0IS`00ol0003o06Xho`000003o`1MAP05o`000?l0Hd7o06=1o`1S@Ol000000_l0EdX01Ol0
003o05i5o`1NAOl0GTGo000000Co05=<0_l00005o`1CC003o`000?l0BDco000000Co05M:00?o0000
o`1ACOl0DDd00_l0DDd2o`0000Go05U900?o0000o`1GB_l0EdX00_l0EdX00ol0003o05I;o`1FB`02
o`1FB`06o`000?l0Ed[o0000o`000?l0I3oo00001?l0IS`00ol0003o06Xho`1Z>003o`1Z>003o`00
0?l0L33o070`00;o070`00Go0000o`1f9_l0MRKo07HVo`000004o`1n5`04o`000?l0Q`Co08L4o`27
10Ko00001?lCT@000ol0003o=Id0ocFM0002ocFM0004o`000?mNZP3oGZX0oejZ00Co00000_m^[`00
1Ol0003oXK`0oj6l0?nQ_03o000000;obKT00ol00005om2W0003o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool000;ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002?oo
ool01ol0003ooooooooooooooooo0000ooooool000003?ooool2o`000003ooooool0003o000000Ko
mRT01?l00002on]A0003o`000?oUJ03oiFP000?oiFP000?o0000omin0?oNOP000_oNOP04o`000003
olbc0?l0003o`L@000?o`L@000Go0000oj6l0?nQ_03oXK`0o`000004ohJe0006o`000?m`[`3oL:l0
o`000?loX@3o00000ol^V`000ol0003o8IL0ob6G0003ob6G0006o`000?lHT`3o69<0o`000?l0Q0co
00001?l0PQ001_l0003o084Bo`214_l0003o078]o`0000Go07</00?o0000o`1e:?l000000ol0IS`0
1ol0003o06Xho`1Z>?l0JSSo0000o`1MA_l000001?l0Hd400ol0003o05M:o`000005o`1NA@04o`00
0?l0Ddco05=<o`0000;o05a600?o0000o`1CC?l0Dd`00_l0Dd`2o`0000Go05M:00?o0000o`1ACOl0
DDd00_l000000ol0GDKo0000o`1IB@04o`1IB@03o`000?l0Ed[o05M:00;o05M:00Co0000o`1FBol0
ET_o05I;0ol00004o`1T?`03o`000?l0ISco06Hl00;o06Hl00?o0000o`1Z>?l0JSP00_l0JSP00ol0
003o070`o`1`<002o`1`<003o`000?l0MRKo07HV00;o07HV00?o0000o`1n5ol0OQL00_l0OQL01Ol0
003o08L4o`271?l0Q`Co000000?o4i401?l00002oa>A0003o`000?leW@3o=Id000;o=Id000Go0000
oejZ0?mNZP3oGZX0o`000002ohfg00?o00001?nQ_0001Ol0003obKT0olVi0?l0003obKT000?o0000
0_o@Y`000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00000ooooooo0000o`00
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool00003ooHY00;o
00001?oa>@03o`0000CoiFP000?o0000omin0?oNOP000_oNOP001?l0003oei@0omND0?oGU004o`00
00;o`L@000Go0000oj6l0?nQ_03oXK`0o`000004ohJe0003o`000?m`[`3oL:l000;oL:l00ol00000
0ol^V`3o0000ob6G0004ob6G0003o`000?lHT`3o69<000;o69<00_l00003o`224003o`000?l0PA;o
084B00;o084B00?o0000o`1c;?l0Lb`00ol0Lb`01ol0003o07DXo`1e:?l0MBSo0000o`1V??l00000
1Ol0JSP00ol0003o06=1o`1S@@04o`1S@@03o`000?l0GTGo05i500Co05i500?o0000o`1CC?l00000
1?l0G4H01_l0003o05=<o`1CC?l0003o05i5o`0000Go05M:00?o0000o`1ACOl000001?l0GDH00ol0
003o05U9o`1IB@02o`1IB@03o`000?l0Ed[o05M:00;o05M:1?l00002o`1S@003o`000?l0I3oo06@o
00;o06@o00?o0000o`1V??l0IS`00_l0IS`00ol0003o06Xho`1Z>002o`1Z>003o`000?l0L33o070`
00;o070`00?o0000o`1f9_l0MRH00_l0MRH00ol0003o07hGo`1n5`02o`1n5`03o`000?l0Q`Co08L4
00;o08L400Go0000oa>A0?lCT@3o4i40o`000002oc:L00?o00001?leW@000ol0003oGZX0oejZ0002
oejZ0003o`000?n=]`3oSKL000;oSKL00ol00002oj6l0003o`000?o9^@3obKT000;o00000_oFV003
o`0000kooooo00?o0000ooooooooool01Oooool000;ooooo00Co0000oooooooooooooooo1Ol00000
0ooooooo0000o`000003o`0000Sooooo0ol00004ooooo`;o00003?ooool01_l0003oooooooooool0
003omRT0o`0000GolCT000Co0000one<0?o]C03okD`00_l000000ooUJ03o0000omin0003omin0005
o`000?oGU03oei@0omND0?l000001?o@Z004o`000003oj6l0?l0003oQ[D000?oQ[D000?o0000og2_
0?m`[`000_m`[`001?l0003oGZX0oejZ0?mNZP02o`0000Co8IL000?o0000oaRC0?lHT`000_lHT`00
1_l0003o4i40oa>A0?l0003o088@o`0000Go084B0_l00003o`1c;003o`000?l0MBSo07DX00?o07DX
00?o0000o`1Z>?l0JSP00ol0JSP2o`0000Go06=10_l00006o`1NA@;o00001Ol0G4H00ol0003o05=<
o`000003o`1NA@03o`000?l0Ed[o05M:00;o05M:0_l00005o`1MAP03o`000?l0FDWo05U900?o05U9
1?l000000ol0I3oo0000o`1S@004o`1S@003o`000?l0I3oo06@o00;o06@o00?o0000o`1V??l0IS`0
0_l0IS`00ol0003o06Xho`1Z>002o`1Z>003o`000?l0L33o070`00;o070`00Go0000o`1f9_l0MRKo
07HVo`000004o`1n5`03o`000?l0Q`Co08L400;o08L400?o0000oa>A0?lCT@000_lCT@000ol0003o
<Y`0oc:L0002oc:L00Go00001?mNZP000ol0003oSKL0ohfg0002ohfg0003o`000?o1a03o`L@000?o
00000oo9^@02o`0000CoeYP000?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`00
;oooool00ol0003oooooooooo`02o`0000ColCT000?o0000one<0?o]C0000oo]C004o`0000;ogWh0
00Go0000omND0?oGU03oei@0o`000005om2X0004o`000?o9^@3obKT0olVi00?o00000_n6]@000ol0
003oL:l0og2_0002og2_0003o`000?mNZP3oGZX000;oGZX000Ko0000oe2V0?l0003o0000ob6G0?l0
0004oaRC0003o`000?lCT@3o4i4000;o4i4000?o0000o`214_l0PA800ol0PA801_l0003o088@o`22
4?l0003o07</o`0000Go07DX0_l00004o`1Z>004o`000?l0L33o070`o`0000?o06=100Co0000o`1Y
>Ol0JCWo00001?l0GTD00ol0003o06Hlo`000005o`1LAP;o00001Ol0GTD01_l0003o05M:o`1GB_l0
003o06=1o`0000Ko05e600Co0000o`1IBOl0FDWo05U90_l00005o`1T?`03o`000?l0Hd3o06=000;o
06=000?o0000o`1T?ol0I3l00_l0I3l00ol0003o06Hlo`1V?002o`1V?003o`000?l0JSSo06Xh013o
000000?o07hGo`000?l0Q`@00ol0Q`@01Ol0003o4i40oa>A0?lCT@3o000000Co<Y`000Co0000oeJX
0?mFZ03oEZP01?l00002oejZ0003o`000?n=]`3oSKL000;oSKL000?o0000ol740?o1a0000_o1a002
o`0000;obKT000?o0000omJH0?oFV0000_oFV0000ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo000`ooooo`;o00000_ooool2o`000003oo4i0?l0003okD`000CokD`000?o0000onMO
0?oWG`000_oWG`04o`000003omND0?l0003od:P000Cod:P000Go0000olVi0?o9^@3obKT0o`000003
okk300?o00000om`[`000ol0003oGZX0oejZ0002oejZ0003o`000?m@YP3oD:H000;oD:H00_l00003
oaRC0003o`000?lCT@3o4i4000?o4i400_l00003o`214P03o`000?l0PQ3o088@00;o088@00?o0000
o`1e:?l0MBP00ol0MBP01?l0003o07PRo`1h8_l00002o`1Z>003o`000?l0L33o070`00;o070`00?o
0000o`1S@Ol000001?l0JCT01?l0003o05i5o`1NAOl00003o`1V?003o`000?l0G4Ko05a600;o0000
00?o06Hlo`000?l0GTD01?l0GTD00ol0003o05M:o`000003o`1S@@03o`000?l0GDKo05e600?o05e6
00Ko0000o`1IBOl0003o0000o`1V??l00005o`1T?`03o`000?l0Hd3o06=000;o06=000Co0000o`1T
?ol0I3oo06@o2Ol00002o`1h8P03o`000?l0OAWo07dI00;o07dI00?o0000o`243?l0Q0`00_l0Q0`0
1?l0003o18/0o`B;0?l4R`05o`000003o`271?l0003o4i4000?o4i4000?o0000oc:L0?lbW0000_lb
W0001Ol0003oEZP0oeJX0?mFZ03o000000;oP;@00ol00004ohfg0003o`000?o1a03o`L@000;o`L@0
00?o0000om2X0?l000000_l00005omJH0003o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1Oooool003;ooooo00Co0000oooooooooooooooo0_l00004one<0003o`000?oWG`3oiel000;oiel0
00?o0000on5c0?oQL`000_oQL`02o`0000Cod:P000Go0000olVi0?o9^@3obKT0o`000004okk30006
o`000?nW_@3oYkd0o`000?m`[`3o00001?mNZP000ol0003oD:H0oe2V0002oe2V0006o`000?m6X`3o
AZ<0o`000?lHT`3o00001OlCT@001_l0003o4I40oa6A0?l0003o084Bo`0000Co088@00?o0000o`24
3?l000000ol0MBP01ol0003o07PRo`1h8_l0N2;o0000o`1Z>?l000001_l0L3000ol0003o06Tio`1Y
>@03o`1Y>@03o`000?l0GTGo000000Co06Hl00?o0000o`1LA_l000001?l0IS`00ol0003o05i5o`1N
A@02o`1NA@;o00001Ol0Hd400ol0003o05e6o`1MAP02o`1MAP;o00001?l0IS`00ol0003o06@oo`1T
?`02o`1T?`03o`000?l0Hd3o06=000;o06=01?l00002o`1c;003o`000?l0MBSo07DX00;o07DX00?o
0000o`1h8_l0N2800_l0N2800ol0003o07dIo`1m6@02o`1m6@03o`000?l0Q0co08@<00;o08@<00Go
0000o`B;0?l4R`3o18/0o`000003oaZD00Oo00001?lbW0000ol0003oEZP0oeJX0002oeJX0003o`00
0?n0]03oP;@000;oP;@01Ol00005ol740004o`000?o@Z03od:P0om2X00Co000000?oeYP0o`000?oo
ool02oooool00ol0003oooooooooo`05ooooo`00<oooool00ol0003oooooooooo`02ooooo`;o0000
00?okD`0o`000?oWG`000ooWG`000ol0003ohG<0on5c0002on5c0003o`000?oKQP3ofhH000;o0000
00?od:P0o`000?o9^@000_o9^@000ol0003o_/<0okk30002okk30003o`000?nW_@3oYkd000;oYkd0
0ol00002oejZ0003o`000?m@YP3oD:H000;oD:H000?o0000odJS0?m6X`000_m6X`000ol0003o4i40
oa>A0003oa>A0003o`000?lAT@3o4I4000;o4I4000?o0000o`224?l0PQ000_l0PQ001ol0003o08@<
o`243?l0Q0co0000o`1e:?l000001Ol0N2800ol0003o070`o`1`<004o`1`<0;o00001Ol0JCT2o`00
00Ko06Hl00?o0000o`1V??l0IS`00ol0IS`00ol0003o05i5o`1NA@02o`000003o`1Y>Ol0003o06=1
00Co06=100?o0000o`1MA_l000000_l000000ol0JSSo0000o`1V?003o`1V?003o`000?l0I3oo06@o
00?o06@o1?l000000ol0LRgo0000o`1c;004o`1c;003o`000?l0MBSo07DX00;o07DX00Go0000o`1h
8_l0N2;o07PRo`000004o`1m6@03o`000?l0Q0co08@<00;o08@<00?o0000o`B;0?l4R`000_l4R`00
0ol0003o6Y@0oaZD0002oaZD0004o`000?leW@3o=Id0ocFM00Ko00001?mFZ0000ol0003oP;@0oh2d
0002oh2d0004o`000?n`_`3o/;l0ok2o00Co00000_o1a0001?l0003od:P0om2X0?o@Z002o`0000;o
fhH00ol0000<ooooo`03o`000?oooooooooo00Cooooo000dooooo`03o`000?oooooooooo00?ooooo
0ol00002onMO0003o`000?oQL`3ohG<000;ohG<000?o0000om^60?oKQP000_oKQP04o`000003olVi
0?l0003o_/<000?o_/<000?o0000ojNm0?nW_@000_nW_@001?l0003oUKT0oiFi0?nE^@03o`0000?o
D:H000?o0000odJS0?m6X`000_m6X`000ol0003o@J40o`000003oa>A0003o`000?lAT@3o4I4000;o
4I400_l00003o`224003o`000?l0Q0co08@<00?o08@<00?o0000o`1h8_l0N2801?l0N2800ol0003o
070`o`1`<003o`1`<004o`000?l0MRKo07HVo`0000?o06Ti00?o0000o`1b;Ol000001Ol0IS`2o`00
00Go06Hl00?o0000o`1NAOl000001?l0JCT00ol0003o06=1o`1S@@02o`1S@@;o00001Ol0JSP00ol0
003o06Hlo`1V?002o`1V?004o`000?l0I3oo06@oo`1T?`;o00001?l0LRd00ol0003o07</o`1c;003
o`1c;003o`000?l0MBSo07DX00;o07DX00?o0000o`1h8_l0N2800_l0N2800ol0003o07dIo`1m6@02
o`1m6@03o`000?l0Q0co08@<00;o08@<00Go0000o`B;0?l4R`3o18/0o`000005oaZD0005o`000?le
W@3o=Id0ocFM0?l000000omFZ006o`0000GoP;@000Go0000ok2o0?n`_`3o/;l0o`000002olbc00?o
00001?o@Z0000ol0003ofhH0om^60002om^60003o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01?ooool003Gooooo0_l00006ooooo`?o00000ooQL`000ol0003ofhH0om^60002om^60003o`00
0?oFV03oeYP000;oeYP00ol00002okk30003o`000?nW_@3oYkd000;oYkd000?o0000oiFi0?nE^@00
0onE^@001Ol0003oQ[D0o`000?m@YP3o000000CoAZ<000Oo0000od6Q0?m1X@3o@J40o`000?lCT@3o
000000Co4I4000Ko0000oa>A0?lCT@3o0000o`224?l00005o`2430;o00001Ol0N2800ol0003o07dI
o`000003o`1`<005o`000?l0MRKo07HVo`1f9_l000000_l0JCT01Ol0003o078]o`1b;Ol0LRgo0000
00?o06Hl00Co0000o`1`;ol0L2oo00001Ol0IS`00ol0003o06Tio`1Y>@03o`1Y>@03o`000?l0Hd7o
06=100;o000000?o070`o`000?l0JSP01?l0JSP00ol0003o06Hlo`1V?002o`1V?006o`000?l0I3oo
0000o`000?l0Lbco00001Ol0LRd00ol0003o07</o`1c;002o`1c;003o`000?l0MBSo07DX00;o07DX
00?o0000o`1h8_l0N2800_l0N2800ol0003o07dIo`1m6@02o`1m6@03o`000?l0Q0co08@<00;o08@<
00?o0000o`B;0?l4R`000_l4R`000ol0003o6Y@0oaZD0002oaZD0003o`000?leW@3o=Id000;o=Id0
00Go0000oeJX0?mFZ03oEZP0o`000003ogbb00Co00000_n0]0000ol0003o/;l0ok2o0002ok2o0003
o`000?o</`3oc;<000;oc;<01?l000000oo@Z03o0000om^60003om^60003o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool003Oooooo00?o0000ooooooooool01_ooool00ol0003ohG<0
o`000004om^60003o`000?oFV03oeYP000;oeYP000Co0000om2W0?o@Y`3od:L00ol00003ojNm0003
o`000?nE^@3oUKT000?oUKT000Co0000ohJe0?n6]@3oQ[D00_l00003odJS0003o`000?m1X@3o@J40
00?o@J400_l00003oa6A0003o`000?lCT@3o4i4000;o4i4000?o0000o`243?l0Q0`00ol0Q0`01?l0
003o08L4o`271?l00003o`1h8P07o`000?l0OAWo07dIo`1m6Ol0003o070`o`000004o`1f9P03o`00
0?l0JCWo000000Go078]00?o0000o`1V??l000000ol0L2l00ol0003o06Hlo`1V?002o`1V?0;o0000
1Ol0JCT00ol0003o06=1o`000004o`1`<003o`000?l0JSSo06Xh00;o06Xh00?o0000o`1V??l0IS`0
0_l0IS`2o`0000Co07</00?o0000o`1b;Ol0LRd00_l0LRd00ol0003o07</o`1c;003o`1c;003o`00
0?l0MBSo07DX00;o07DX00?o0000o`1h8_l0N2804Ol00004oaZD0003o`000?leW@3o=Id000;o=Id0
00?o0000oeJX0?mFZ0000_mFZ0001Ol0003oO;80ogbb0?ml/P3o000000;oZ;h00ol00005ok2o0005
o`000?o</`3oc;<0olbc0?l000000ooGU007o`0000_ooooo00?o0000ooooooooool01?ooool003So
oooo00?o0000ooooooooool01_ooool3o`0000;ofhH000?o0000omJH0?oFV0000_oFV0000ol0003o
d:L0om2W0002om2W0006o`000?o;/`3obk<0o`000?nW_@3o00001OnE^@000ol0003oQ[D0ohJe0002
ohJe0005o`000?ml/P3o0000odJS0?l000001Om1X@001_l0003o?j40ocnQ0?l0003o4I40o`0000Go
4i400_l00003o`243003o`000?l0Q`Co08L400;o08L400?o0000o`1h8_l000001Ol0OAT00ol0003o
07HVo`1f9P04o`1f9P03o`000?l0LRgo078]00Co078]0_l00005o`1`;`04o`000?l0ISco06Hlo`00
00;o078]00?o0000o`1Y>Ol0JCT00_l0JCT2o`0000Go070`00?o0000o`1Z>?l0JSP00ol0JSP4o`00
0003o`1e:?l0003o07</00?o07</00?o0000o`1b;Ol0LRd00_l0LRd00ol0003o07</o`1c;002o`1c
;0Wo00000_l0Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?lETP3o5I8000;o5I8000Co0000obRI
0?lXV@3o:9T01Ol000000olJU03o0000ocFM0002ocFM0003o`000?mFZ03oEZP000;oEZP000?o0000
ogbb0?ml/P000_ml/P000ol0003oZ;h0ojRn0002ojRn00Co000000?o/;l0o`000?o</`000oo</`00
0ol0003oei@0omND0002omND00;o00000_oQL`02o`0000[ooooo00?o0000ooooooooool01?ooool0
03Wooooo00?o0000ooooooooool02?ooool3o`0000?oeYP000?o0000om2W0?o@Y`000_o@Y`000ol0
003obk<0ol^c0002ol^c00;o00001?nE^@000ol0003oQ[D0ohJe0002ohJe0005o`000?ml/P3oO;80
ogbb0?l000001Om1X@000ol0003o?j40ocnQ0002ocnQ0003o`000?lCT@3o4i4000?o4i4000Ko0000
oaRC0?lHT`3o0000o`243?l00006o`271003o`000?l0OAWo07dI00?o07dI0_l00005o`1f9P;o0000
1Ol0LRd00ol0003o07/Mo`000005o`1`;`03o`000?l0ISco000000Co078]00Ko0000o`1Y>Ol0JCWo
0000o`1f9_l00005o`1`<003o`000?l0JSSo06Xh00;o06Xh0_l00005o`1e:003o`000?l0Lbco07</
00;o07</00?o0000o`1b;Ol0LRd00_l0LRd4o`000003o`224?l0003o08@<00?o08@<00?o0000o`27
1?l0Q`@00ol0Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?lETP3o5I8000;o5I8000Go0000obRI
0?lXV@3o:9T0o`000003od6Q00_o00001?ml/P000ol0003oZ;h0ojRn0002ojRn0004o`000?o9^P3o
bKX0olVj00Oo00001OoGU0001Ol0003ohG<0on5c0?oQL`3o000000[ooooo00?o0000ooooooooool0
1?ooool003[ooooo0_l0000;ooooo`03o`000?oFV03o000000Cod:L000?o0000ol^c0?o;/`000_o;
/`000ol0003oakh0olNn0002o`000003oiFi0?l0003oQ[D000?oQ[D000?o0000ogbb0?ml/P000_ml
/P02o`0000?o@J4000?o0000ocnQ0?loX@000oloX@02o`0000?o4i4000?o0000oaRC0?lHT`000_lH
T`000ol0003o08L4o`271004o`2710;o00001?l0OAT01?l0003o08@<o`243?l00003o`1f9P04o`00
0?l0OQOo07hGo`0000?o078]00Go0000o`1k7Ol0Nago07/Mo`000004o`1`;`;o00001Ol0LRd00ol0
003o06Tio`000003o`1f9P03o`000?l0L33o070`00?o070`1?l000000ol0N2;o0000o`1e:004o`1e
:003o`000?l0Lbco07</00;o07</00?o0000o`1b;Ol0LRd00ol00005o`224003o`000?l0Q0co08@<
00;o08@<00?o0000o`271?l0Q`@00_l0Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?lETP3o5I80
00;o5I8000?o0000obRI0?lXV@000_lXV@001Ol0003o@J40od6Q0?m1X@3o000000CoGZX000Co0000
oh2d0?n0]03oP;@01?l00002ogbb0003o`000?nX_P3oZ;h000;oZ;h000?o0000olVj0?o9^P000_o9
^P001?l0003odid0om>M0?oCW@04o`0000;oei@00_l00003on5c0003o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool003cooooo00?o0000ooooooooool02Oooool3o`0000;od:L000?o
0000ol^c0?o;/`000_o;/`000ol0003oakh0olNn0003olNn00;o00000on6]@000ol0003oO;80ogbb
0002ogbb0006o`000?mf/@3oM[40o`000?m1X@3o00001OloX@001_l0003o@J40od6Q0?l0003o4i40
o`0000Go69<000?o0000o`271?l0Q`@00ol0Q`@01?l0003o1X`0o`J<0?l00002o`1m6@03o`000?l0
Q0co08@<00;o08@<00?o0000o`1f9_l000001?l0OQL00ol0003o078]o`000004o`1k7@03o`000?l0
L2oo070_00;o000000?o07/Mo`000?l0LRd01?l0LRd2o`0000Co07HV00?o0000o`1`<?l0L3000_l0
L302o`0000Go07PR00?o0000o`1e:?l0MBP00_l0MBP00ol0003o07</o`1c;002o`1c;0?o00000_l0
PA800ol0003o088@o`224003o`224003o`000?l0Q0co08@<00;o08@<00?o0000o`271?l0Q`@00_l0
Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?lETP3o5I8000;o5I8000?o0000obRI0?lXV@000_lX
V@000ol0003o@J40od6Q0002od6Q0003o`000?mNZP3oGZX000;oGZX000Go0000oh2d0?n0]03oP;@0
o`000002ojRn00?o00001?nX_P000ol0003obKX0olVj0003olVj0005o`000?oCW@3odid0om>M0?l0
00000_oNOP03o`000003on5c0?l0003ohG<000;ohG<000?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`00?Oooool00ol0003oooooooooo`0;ooooo`?o00000oo;/`000ol0003oakh0
olNn0003olNn0006o`000?o3a03o`l@0o`000?n6]@3o00001?ml/P000ol0003oM[40ogJa0002ogJa
0003o`000?loX@3o?j4000?o?j4000?o0000od6Q0?m1X@000_m1X@000ol0003o69<0oaRC0003oaRC
0003o`000?lQU`3o000000?o08L400Oo0000o`J<0?l6S03o1X`0o`000?l0OAWo000000Ko08@<00?o
0000o`1n5ol0OQL01?l0OQL00ol0003o07/Mo`1k7@03o`1k7@03o`000?l0L2oo000000Co07/M00Oo
0000o`1b;Ol0LRgo078]o`000?l0OQOo000000Go07HV00Ko0000o`1`<?l0L33o0000o`1m6Ol00005
o`1h8P03o`000?l0MBSo07DX00?o07DX1?l000000ol0PQ3o0000o`214P03o`214P03o`000?l0PQ3o
088@00?o088@00Go0000o`243?l0Q0co08@<o`000005o`271003o`000?l6S03o1X`000;o1X`000?o
0000oaFB0?lETP000_lETP001Ol0003o:9T0obRI0?lXV@3o000000Co@J4000?o0000oejZ0?mNZP00
0_mNZP000ol0003oP;@0oh2d0002oh2d0003o`000?nX_P3oZ;h000;oZ;h01Ol00005olVj0003o`00
0?oCW@3odid000;odid000?o0000omin0?oNOP000_oNOP07o`0000Sooooo00?o0000ooooooooool0
0oooool003kooooo00?o0000ooooooooool03Oooool00ol0003obk<0o`000005olNn0003o`000?o3
a03o`l@000;o`l@00_l00003ogbb0003o`000?mf/@3oM[4000;oM[4000?o0000ogB`0?l000000olo
X@000ol0003o@J40od6Q0002od6Q0003o`000?m6X`3o000000?o69<000Oo0000ob6G0?lQU`3o8IL0
o`000?l0Q`Co000000Go1X`000?o0000o`243?l0Q0`01?l0Q0`2o`0000Go07hG0_l00006o`1k7@03
o`000?l0Nago07/M00?o07/M00Co0000o`1b;Ol0LRgo00000ol0OQL00ol0003o07HVo`1f9P02o`1f
9P03o`000?l0L33o000000?o07dI00?o0000o`1h8_l0N2800_l0N2800ol0003o07DXo`1e:002o`1e
:0;o00001Ol0PQ001Ol0003o084Bo`214_l0PA;o000000Go088@00?o0000o`243?l0Q0`00_l0Q0`0
0ol0003o08L4o`27100@o`000003obRI0?l0003o@J4000;o@J4000?o0000oejZ0?mNZP000omNZP00
1Ol0003oP;@0oh2d0?n0]03o000000CoZ;h000Co0000olRl0?o8_03ob;`01Ol000000oo9^P3o0000
om>M0003om>M0003o`000?oNOP3ogWh000;ogWh000?o0000onMO0?l000000ooWG`000ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo000oooooo`;o00003_ooool2o`0000Coakh000?o
0000ol?40?o3a0000_o3a0001_l0003o^<80okS20?l0003oO;80o`0000CoM[4000Oo0000ogB`0?md
/03oM;00o`000?loX@3o000000Co@J4000Oo0000odJS0?m6X`3oAZ<0o`000?lHT`3o000000Go8IL0
00?o0000o`J<0?l6S0001?l6S0000ol0003o08@<o`243003o`243004o`000?l4R`3o18/0o`0000?o
07hG00Co0000o`271?l0Q`Co00001?l0Nad2o`0000Go07/M00?o0000o`1b;Ol000001?l0OQL00ol0
003o07HVo`1f9P02o`1f9P;o00001?l0OAT00ol0003o07PRo`1h8P03o`1h8PCo000000?o08@<o`00
0?l0PQ001?l0PQ000ol0003o084Bo`214P02o`214P03o`000?l0PQ3o088@00;o088@00?o0000o`24
3?l0Q0`01Ol00002ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o0000ocnQ0?loX@000_loX@001?l0
003oE:L0oeBW0?mDY`0:o`000003oejZ0?l0003oP;@000?oP;@000?o0000ojRn0?nX_P000_nX_P00
1Ol0003ob;`0olRl0?o8_03o000000?odZ801ol00005omin0003o`000?oWG`3o000000?oiel000?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`00@Oooool00ol0003oooooooooo`0=
ooooo`;o000000?oakh0o`000?o3a0000oo3a0000ol0003o^<80okS20002okS200;o00000omf/@00
0ol0003oM;00ogB`0003ogB`00;o00000om1X@000ol0003oAZ<0odJS0003odJS0003o`000?lQU`3o
8IL000?o8IL00_l00005o`J<0003o`000?lETP3o000000?o08@<00Go0000o`B;0?l4R`3o18/0o`00
0002o`1n5`03o`000?l0Q`Co08L400;o08L400Co0000o`1k7Ol0Nago00000_l0QPL00ol0003o07/M
o`1k7@02o`1k7@;o00001Ol0OQL00ol0003o07HVo`1f9P02o`000003o`243?l0003o07dI00Co07dI
00Co0000o`1h8_l0N2;o07PR0_l00005o`243003o`000?l0PQ3o088@00;o088@00?o0000o`214_l0
PA800_l0PA801?l0003o088@o`224?l0PQ04o`0000;o69<000?o0000ob6G0?lQU`000olQU`000ol0
003o;Y/0objK0002objK0003o`000?loX@3o?j4000;o?j4000Go0000oeBW0?mDY`3oE:L0o`000004
ofj_0004o`000?n=]`3oSKL0ohfg00Oo00001?nX_P000ol0003ob;`0olRl0002olRl0003o`000?oB
XP3odZ8000;odZ8000Co0000omb50?oLQ@3og8D01Ol000001OoNOP3o0000onMO0?oWG`3o000000;o
iel000?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`00@_ooool00ol0003ooooo
ooooo`0>ooooo`;o00000oo3a0000ol0003o^<80okS20002okS20006o`000?nb`03o//00o`000?mf
/@3o00001Omd/0001_l0003oM[40ogJa0?l0003o@J40o`0000KoAZ<000?o0000ob6G0?lQU`000_lQ
U`001?l0003o;Y/0objK0?l00003o`J<0007o`000?lETP3o5I80oaFB0?l0003o08@<o`000004o`B;
0003o`000?l0OQOo000000Go08L400?o0000o`1k7Ol000001?l0QPL01_l0003o07/Mo`1k7Ol0003o
08L4o`0000Ko07hG0_l00004o`243003o`000?l0OAWo07dI00;o07dI00Ko0000o`1h8_l0003o0000
o`271?l00005o`243003o`000?l0PQ3o088@00?o088@00?o0000o`214_l0PA801Ol00002oa>A0003
o`000?lHT`3o69<000;o69<000?o0000ob6G0?lQU`000_lQU`000ol0003o;Y/0objK0002objK0003
o`000?loX@3o?j4000;o?j4000?o0000oeBW0?mDY`000_mDY`000ol0003oKZl0ofj_0002ofj_0003
o`000?n=]`3oSKL000;oSKL000Co0000ok2o0?n`_`3o/;l01_l00005olRl0003o`000?oBXP3odZ80
00;odZ8000Go0000omb50?oLQ@3og8D0o`000003onEX00Ko000000?oiel0o`000?ooool01_ooool0
0ol0003oooooooooo`03ooooo`00@oooool00ol0003oooooooooo`0?ooooo`03o`000?o3a03o0000
00Co^<8000?o0000ok;00?nb`0000_nb`0000ol0003oM;00ogB`0003ogB`0003o`000?mf/@3oM[40
00;oM[4000?o0000odJS0?m6X`001?m6X`000ol0003oD:H0o`000002ob6G0003o`000?l^V`3o;Y/0
00;o;Y/000?o0000o`J<0?l000001OlETP000ol0003o18/0o`B;0004o`B;0003o`000?l0Q`Co08L4
00Go08L400?o0000o`261ol0QPL00ol0QPL00ol0003o07/Mo`000003o`271003o`000?l0OQOo07hG
00;o07hG0_l00005o`243003o`000?l0OAWo07dI00;o07dI0_l00004o`271003o`000?l0Q0co08@<
00?o08@<00Co0000o`224?l0PQ3o088@1?l00002oa6A0003o`000?lCT@3o4i4000?o4i4000Go0000
oaRC0?lHT`3o69<0o`000005ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o0000ocnQ0?loX@000_lo
X@001Ol0003oE:L0oeBW0?mDY`3o000000CoKZl000?o0000ohfg0?n=]`000on=]`001Ol0003o/;l0
ok2o0?n`_`3o000000?obKX01Ol000000oo8_03o0000om:R0003om:R0003o`000?oLQ@3og8D000;o
g8D000?o0000onEX0?oUJ0000_oUJ0000ol0003okD`0one<0004o`0000Kooooo00?o0000oooooooo
ool00oooool004Cooooo0_l0000@ooooo`;o00000onh`P000ol0003o//00ok;00002ok;00003o`00
0?n`_`3o000000?oM;0000?o0000ogJa0?mf/@000omf/@000ol0003oAZ<0odJS0003odJS0006o`00
0?m@YP3oD:H0o`000?lQU`3o00001_l^V`000ol0003o5I80oaFB0003oaFB00;o00001Ol4R`02o`00
00Ko08L40_l00005o`261`;o00001Ol0Q`@01_l0003o07hGo`1n5ol0003o18/0o`0000Go08@<00?o
0000o`1m6Ol0OAT00_l000000ol6S03o0000o`271003o`271003o`000?l0Q0co08@<00?o08@<00Ko
0000o`224?l0003o0000oa>A0?l00005oa6A0003o`000?lCT@3o4i4000;o4i4000?o0000oaRC0?lH
T`000_lHT`000ol0003o8IL0ob6G0002ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o0000ocnQ0?lo
X@000_loX@000ol0003oE:L0oeBW0002oeBW0003o`000?m^[`3oKZl000;oKZl000?o0000ohfg0?n=
]`000_n=]`000ol0003o/;l0ok2o0002ok2o0005o`000?o9^P3obKX0olVj0?l000000ooBXP07o`00
00Gog8D000?o0000onEX0?oUJ0000_oUJ0001_l0003okD`0one<0?l0003okD`0o`0000Oooooo00?o
0000ooooooooool00_ooool004Kooooo00?o0000ooooooooool03oooool00ol0003o^<80o`000004
ok;00007o`000?n`_`3o/;l0ok2o0?l0003oM;00o`000005ogJa0003o`000?ml/P3o000000?oAZ<0
00?o0000oe2V0?m@YP000_m@YP000ol0003o;Y/0objK0004objK00;o00001?lETP001?l0003o:9T0
obRI0?l00003o`B;0004o`000?lJU03o6Y@0o`0000Co08L400Co0000oa>A0?lCT@3o00000ol0QPL0
0ol0003o4i40o`000005o`271003o`000?l0OQOo000000?o18/000?o0000o`243?l0Q0`00ol0Q0`2
o`0000Co1X`000?o0000o`271?l0Q`@00_l0Q`@00ol0003o08@<o`243002o`2430;o00001?lCT@00
0ol0003o4I40oa6A0002oa6A0003o`000?lCT@3o4i4000;o4i4000?o0000oaRC0?lHT`000_lHT`00
0ol0003o8IL0ob6G0002ob6G0004o`000?l^V`3o;Y/0objK00Oo00001?mDY`000ol0003oKZl0ofj_
0002ofj_0003o`000?n=]`3oSKL000;oSKL000?o0000ok2o0?n`_`000_n`_`000ol0003obKX0olVj
0002olVj0003o`000?oBXP3odZ8000;odZ8000Co0000om^70?oKQ`3ofhL01Ol000000ooLQ@3o0000
onEX0003onEX0007o`000?o]C03okD`0one<0?l0003okD`0o`000006ooooo`03o`000?oooooooooo
00;ooooo0017ooooo`03o`000?oooooooooo00oooooo0_l00003ok;00003o`000?n`_`3o/;l000?o
/;l000?o0000ogJa0?mf/@000omf/@001ol0003oO;80ogbb0?ml/P3o0000odJS0?l000001Om@YP00
0ol0003o;Y/0objK0003objK0004o`000?loX@3o?j40o`0000;o5I8000?o0000obRI0?lXV@000_lX
V@000ol0003o18/0o`000004oaZD0004o`000?l0Q`Co08L4o`0000?o4i4000Co0000o`261ol0QPOo
00000olCT@000ol0003o08L4o`271002o`2710;o00001?l4R`000ol0003o08@<o`243002o`2430;o
00001Ol6S0000ol0003o08L4o`271002o`271003o`000?l0Q0co000000;o000000?o69<0o`000?lC
T@000olCT@000ol0003o4I40oa6A0002oa6A0003o`000?lCT@3o4i4000?o4i4000?o0000oaRC0?lH
T`002_l00002oejZ0004o`000?m`[`3oL:l0og2_00oo000000?oSKL0o`000?n`_`000_n`_`000ol0
003obKX0olVj0003olVj0003o`000?oBXP3odZ8000;odZ8000Go0000om^70?oKQ`3ofhL0o`000003
on=/00ko00001Oooool00ol0003oooooooooo`02ooooo`00B?ooool00ol0003oooooooooo`0@oooo
o`03o`000?nb`03o000000Go/;l000?o0000ok;00?l000000omf/@000ol0003oO;80ogbb0003ogbb
0003o`000?m@YP3oD:H000?oD:H000?o0000oejZ0?l000000ol^V`001ol0003o?j40ocnQ0?loX@3o
0000oaFB0?l000001_lXV@000ol0003o6Y@0oaZD0003oaZD0003o`000?l0Q`Co000000Co4i4000?o
0000o`261ol000001?lCT@001ol0003o08L4o`271?l0Q`Co0000oaZD0?l000001Ol4R`001_l0003o
08@<o`243?l0003o5I80o`0000Go1X`000?o0000o`271?l0Q`@00_l0Q`@2o`0000Go69<000?o0000
oa>A0?lCT@000_lCT@000ol0003o4I40oa6A0002oa6A0003o`000?lCT@3o4i4000Go00000_m6X`00
0ol0003oD:H0oe2V0002oe2V0003o`000?mNZP3oGZX000;oGZX000?o0000og2_0?m`[`000_m`[`00
0ol0003oQ[D0ohJe0002ohJe0003o`000?nQ_03oXK`000;oXK`000Co0000ol740?o1a03o`L@01Ol0
00000on`_`3o0000olVj0003olVj0003o`000?oBXP3odZ8000;odZ8000?o0000om^70?oKQ`000_oK
Q`000ol0003ohf`0on=/0002on=/0003o`000?o[D@3oje4000;oje4000Oo0000oo4i0?oa>@3olCT0
o`000?oa>@3o000000Gooooo00?o0000ooooooooool00_ooool004Wooooo0_l0000Aooooo`03o`00
0?n`_`3o/;l000?o/;l000Oo0000ok;00?nb`03o//00o`000?mf/@3o000000GoO;8000?o0000ohJe
0?l000000om@YP001ol0003oGZX0oejZ0?mNZP3o0000objK0?l000001OloX@000ol0003o:9T0obRI
0004obRI00;o00001OlJU002o`0000Go4i400_l00005oa>A0004o`000?l0Q`Co08L4o`0000?o6Y@0
00?o0000o`B;0?l4R`000_l4R`000ol0003o08@<o`000003oaFB0003o`000?l6S03o1X`000?o1X`0
1?l000000olQU`3o0000oaRC0004oaRC0003o`000?lCT@3o4i4000;o4i4000?o0000oa6A0?lAT@00
1Ol00002od6Q0003o`000?m6X`3oAZ<000?oAZ<000?o0000oe2V0?m@YP000_m@YP000ol0003oGZX0
oejZ0002oejZ0003o`000?m`[`3oL:l000;oL:l000?o0000ohJe0?n6]@000_n6]@000ol0003oXK`0
oj6l0002oj6l0005o`000?o1a03o`L@0ol740?l000000oo</`0<o`0000CofhL000?o0000on=/0?oS
K0000ooSK0000ol0003oje40on]A0002on]A0007o`000?oa>@3olCT0oo4i0?l0003olCT0o`000004
ooooo`03o`000?oooooooooo00;ooooo001;ooooo`03o`000?oooooooooo00oooooo00Go0000ok2o
0?n`_`3o/;l0o`000005ok;00003o`000?ml/P3oO;8000?oO;8000Oo0000ohJe0?n6]@3oQ[D0o`00
0?m@YP3o000000CoGZX00_l00005ocnQ00;o00001OlXV@001?l0003o@J40od6Q0?l00003oaZD0003
o`000?leW@3o000000Co4i4000?o0000oc:L0?l000001_lCT@02o`0000Co6Y@000?o0000o`B;0?l4
R`000_l4R`02o`0000Co5I8000?o0000o`J<0?l6S0000_l6S002o`0000Go8IL000?o0000oaRC0?lH
T`000_lHT`000ol0003o4i40oa>A0002oa>A00?o00000_loX@000ol0003o@J40od6Q0003od6Q0003
o`000?m6X`3oAZ<000;oAZ<000?o0000oe2V0?m@YP000_m@YP000ol0003oGZX0oejZ0002oejZ0003
o`000?m`[`3oL:l000;oL:l000?o0000ohJe0?n6]@000_n6]@000ol0003oXK`0oj6l0002oj6l0003
o`000?o1a03o`L@000;o`L@000Go0000olbc0?o</`3oc;<0o`000005om>M0004o`000?oLQ@3og8D0
omb500Ko00001OoSK0000ol0003oje40on]A0002on]A0003o`000?oa>@3olCT000;olCT00_l00004
ooooo`03o`000?oooooooooo00;ooooo001<ooooo`03o`000?oooooooooo00oooooo00?o0000ok2o
0?l000001Onb`0000ol0003o^<80o`000003ogbb0003o`000?n6]@3oQ[D000?oQ[D000?o0000oejZ
0?mNZP000_mNZP001?l0003oL:l0og2_0?l00003ocnQ0004o`000?mDY`3oE:L0o`0000?o:9T000Go
0000od6Q0?m1X@3o@J40o`000002oaZD0005o`000?leW@3o=Id0ocFM0?l000000_lCT@001Ol0003o
<Y`0oc:L0?lbW03o000000Go4i4000?o0000oaZD0?lJU0000olJU0000ol0003o18/0o`B;0002o`00
0003obRI0?l0003o5I8000Co5I8000Ko0000o`J<0?l6S03o0000objK0?l00005ob6G0003o`000?lH
T`3o69<000?o69<01?l000000om1X@3o0000ocnQ0003ocnQ0003o`000?m1X@3o@J4000;o@J4000?o
0000odJS0?m6X`000_m6X`000ol0003oD:H0oe2V0002oe2V0003o`000?mNZP3oGZX000;oGZX000?o
0000og2_0?m`[`000_m`[`000ol0003oQ[D0ohJe0002ohJe0003o`000?nQ_03oXK`000;oXK`000?o
0000ol740?o1a0000_o1a0000ol0003oc;<0olbc0002olbc0003o`000?oCW@3odid000?odid000Go
0000omb50?oLQ@3og8D0o`000003on=/01?o00000oooool00ol0003oooooooooo`02ooooo`00COoo
ool00ol0003oooooooooo`0?ooooo`03o`000?nb`03o//0000?o//0000Oo0000okS20?nh`P3o^<80
o`000?ml/P3o000000GoQ[D00_l00003oejZ0003o`000?m`[`3oL:l000;oL:l000?o0000ocnQ0?l0
00001?mDY`000ol0003o:9T0o`000004od6Q0003o`000?lJU03o000000Co=Id000?o0000oa>A0?l0
00001?lbW0000ol0003o4i40oa>A0002oa>A00;o00001_lJU002o`0000Co:9T000?o0000oaFB0?lE
TP000_lETP000ol0003o1X`0o`000003objK0003o`000?lQU`3o8IL000;o8IL000?o0000oaRC0?lH
T`000_lHT`02o`0000Co@J4000?o0000ocnQ0?loX@000_loX@000ol0003o@J40od6Q0003od6Q0003
o`000?m6X`3oAZ<000;oAZ<000?o0000oe2V0?m@YP000_m@YP000ol0003oGZX0oejZ0002oejZ0003
o`000?m`[`3oL:l000;oL:l000?o0000ohJe0?n6]@000_n6]@000ol0003oXK`0oj6l0002oj6l0005
o`000?o1a03o`L@0ol740?l000001Oo</`000ol0003odid0om>M0002om>M0003o`000?oLQ@3og8D0
00;og8D000Go0000on=/0?oSK03ohf`0o`000005on]C0003o`000?oa?03olC`000;olC`000?o0000
ooHY0?of:@000_of:@02o`0000Cooooo00?o0000ooooooooool00Oooool004kooooo0_l0000@oooo
o`05o`000?nb`03o//00ok;00?l000001Onh`P000ol0003oQ[D0ohJe0003ohJe0006o`000?nE^@3o
UKT0o`000?mNZP3o00001_m`[`000ol0003oE:L0oeBW0004oeBW0003o`000?m1X@3o@J4000Co@J40
00?o0000ocFM0?leW@001?leW@000ol0003o<Y`0oc:L0004oc:L0004o`000?lCT@3o4i40o`0000;o
=Id000?o0000oaZD0?lJU0000_lJU002o`0000Go:9T000?o0000oaFB0?lETP000_lETP02o`0000Co
;Y/000?o0000ob6G0?lQU`000olQU`04o`000003odJS0?l0003o@J4000Co@J4000?o0000ocnQ0?lo
X@000_loX@000ol0003o@J40od6Q0002od6Q0003o`000?m6X`3oAZ<002Co000000?oc;<0o`000?oC
W@000ooCW@000ol0003og8D0omb50002omb50003o`000?oSK03ohf`000;ohf`000?o0000on]C0?o[
D`000oo[D`000ol0003olC`0oo4l0002oo4l0003o`000?of:@3omRT000;omRT00_l00003ooooo`03
o`000?oooooooooo007ooooo001@ooooo`03o`000?oooooooooo00kooooo00?o0000ok;00?l00000
1Onh`P000ol0003o`l@0o`000003ohJe0003o`000?nE^@3oUKT000;oUKT000?o0000og2_0?m`[`00
1?m`[`02o`0000KoE:L000?o0000od6Q0?m1X@000om1X@02o`0000Ko=Id000?o0000oc:L0?lbW000
1?lbW0000ol0003o4i40o`000004ocFM0006o`000?lJU03o6Y@0o`000?m1X@3o00001OlXV@000ol0
003o5I80o`000002o`000003ocnQ0?l0003o;Y/000Co;Y/000Co0000ob6G0?lQU`3o8IL00_l00005
odJS0003o`000?m1X@3o@J4000;o@J4000?o0000ocnQ0?loX@000_loX@001?l0003o@J40od6Q0?m1
X@04o`0000;oO;8000?o0000ohJe0?n6]@000_n6]@000ol0003oUKT0oiFi0002oiFi0003o`000?nW
_@3oYkd000;oYkd000?o0000okk30?nn``000_nn``000ol0003obKT0olVi0002olVi0003o`000?o@
Z03od:P000;od:P000Co0000omND0?oGU03oei@03?l00005on=/0003o`000?o[D`3oje<000;oje<0
00?o0000oo4l0?oa?0000ooa?0000ol0003omRT0ooHY0002ooHY0005o`000?ooooooooooooooool0
00000oooool0057ooooo00?o0000ooooooooool03_ooool00ol0003o^<80okS20003okS20007o`00
0?o3a03o`l@0ol?40?l0003oQ[D0o`000005oiFi0003o`000?m`[`3oL:l000?oL:l000Co0000ohJe
0?n6]@3o00001?mDY`000ol0003oKZl0o`000003od6Q0004o`000?mNZP3oGZX0o`0000Co=Id000?o
0000oeJX0?l000001OlbW002o`0000Go=Id000?o0000oaZD0?l000000om1X@000ol0003o:9T0obRI
0002obRI00;o00001OloX@000ol0003o;Y/0objK0002objK0006o`000?lQU`3o0000o`000?m@YP3o
00001Om6X`000ol0003o@J40od6Q0002od6Q0003o`000?loX@3o?j4000;o?j401?l00002ogJa0003
o`000?ml/P3oO;8000;oO;8000?o0000ohJe0?n6]@000_n6]@000ol0003oUKT0oiFi0002oiFi0003
o`000?nW_@3oYkd000;oYkd000?o0000okk30?nn``000_nn``000ol0003obKT0olVi0002olVi0003
o`000?o@Z03od:P000;od:P000?o0000omND0?oGU0000_oGU0000ol0003ogWh0omin0002omin0004
o`000?oUJ03oiFP0onEX01So00000_ooool00ol0003oooooooooo`01ooooo`00D_ooool00ol0003o
ooooooooo`0>ooooo`05o`000?nh`P3o^<80okS20?l000001Oo3a0000ol0003oUKT0oiFi0003oiFi
0003o`000?nW_@3o000000?oL:l000?o0000ohJe0?n6]@000_n6]@001?l0003oE:L0oeBW0?l00003
ofj_0003o`000?m1X@3o000000CoGZX000Co0000ocFM0?leW@3o00000omFZ0000ol0003o<Y`0oc:L
0002o`000003oeJX0?l0003o=Id000Co=Id00_l00005od6Q0006o`000?lXV@3o:9T0o`000?mDY`3o
00001OloX@000ol0003o;Y/0objK0002objK00;o00001?m@YP000ol0003oAZ<0odJS0002odJS0003
o`000?m1X@3o@J4000?o@J401?l000000omd/03o0000ogJa0004ogJa0005o`000?ml/P3oO;80ogbb
0?l000001?n6]@000ol0003oUKT0oiFi0002oiFi0003o`000?nW_@3oYkd000;oYkd000?o0000okk3
0?nn``000_nn``000ol0003obKT0olVi0002olVi0003o`000?o@Z03od:P000;od:P000?o0000omND
0?oGU0000ooGU0000ol0003ogWh0omin0002omin0005o`000?oUJ03oiFP0onEX0?l000001Oo[D@00
0ol0003olC`0oo4l0002oo4l0003o`000?oe:P3omBX000?omBX000?o0000ooPM0?oh7@000_oh7@02
o`000003ooooool0003ooooo00;ooooo001Cooooo`;o00003oooool00ol0003o^<80o`000005ol?4
0003o`000?o7_P3o000000?oUKT000Oo0000ojNm0?nW_@3oYkd0o`000?m`[`3o000000GoQ[D000?o
0000oeBW0?l000001Om^[`000ol0003oGZX0oejZ0003oejZ0003o`000?leW@3o000000CoEZP000?o
0000oc:L0?l000001?mFZ0001ol0003o=Id0ocFM0?leW@3o0000oejZ0?l000001Om1X@000ol0003o
:9T0o`000003oeBW0003o`000?loX@3o?j4000;o?j4000?o0000objK0?l^V`000_l000000omNZP3o
0000oe2V0003oe2V0003o`000?m6X`3oAZ<000?oAZ<000?o0000od6Q0?m1X@000ol00005ogB`0003
o`000?mf/@3oM[4000;oM[4000?o0000ogbb0?ml/P000_ml/P000ol0003oQ[D0ohJe0002ohJe0005
o`000?nE^@3oUKT0oiFi0?l000001?nW_@000ol0003o_/<0okk30002okk30003o`000?o9^@3obKT0
00?obKT000?o0000om2X0?o@Z0000_o@Z0000ol0003oei@0omND0002omND0003o`000?oNOP3ogWh0
00;ogWh000?o0000onEX0?oUJ0000_oUJ0000ol0003oje40on]A0003on]A0003o`000?oa?03olC`0
00;olC`000?o0000ooDZ0?oe:P000ooe:P000ol0003on1d0ooPM0002ooPM00?o00000oooool005Go
oooo00?o0000ooooooooool03Oooool00ol0003o`l@0ol?40003ol?40007o`000?o7_P3oakh0olNn
0?l0003oUKT0o`000005ojNm0003o`000?n6]@3oQ[D000CoQ[D00_l00005ofj_00;o00001OmNZP02
o`0000GoEZP00_l00005oeJX0004o`000?leW@3o=Id0o`0000?oGZX000?o0000od6Q0?m1X@000_m1
X@02o`0000CoE:L000?o0000ocnQ0?loX@000oloX@02o`0000CoGZX000?o0000oe2V0?m@YP000_m@
YP001?l0003oAZ<0odJS0?m6X`04o`0000;oM[4000?o0000ogB`0?md/0000omd/0000ol0003oM[40
ogJa0002ogJa0003o`000?ml/P3oO;8000;oO;8000?o0000ohJe0?n6]@000_n6]@000ol0003oUKT0
oiFi0002oiFi0003o`000?nW_@3oYkd000_o000000?obKT0o`000?o@Z0000oo@Z0000ol0003oei@0
omND0002omND0003o`000?oNOP3ogWh000;ogWh000?o0000onEX0?oUJ0000_oUJ0000ol0003oje40
on]A0003on]A0003o`000?oa?03olC`000;olC`000?o0000ooDZ0?oe:P000ooe:P000ol0003on1d0
o`000005o`0000?ooooo001Fooooo`03o`000?oooooooooo00gooooo00Go0000ol?40?o3a03o`l@0
o`000005olNn0003o`000?nW_@3oYkd000CoYkd000?o0000ohJe0?n6]@000on6]@000ol0003oXK`0
o`000004ofj_0004o`000?n=]`3oSKL0o`0000?oGZX000?o0000oh2d0?l000001?mFZ0000ol0003o
O;80o`000005oeJX0003o`000?leW@3o000000CoGZX000Oo0000od6Q0?m1X@3o@J40o`000?m^[`3o
000000GoE:L000Co0000ocnQ0?loX@3o?j400_l00005oejZ0003o`000?m@YP3oD:H000;oD:H000Ko
0000odJS0?l0003o0000ogbb0?l00005ogJa0003o`000?md/03oM;0000;oM;0000?o0000ogJa0?mf
/@000omf/@001Ol0003oO;80ogbb0?ml/P3o000000?oQ[D02Ol00002ol^c0003o`000?o@Y`3od:L0
00;od:L000Co0000omJH0?oFV03oeYP0:?l00004ooXI00?o00000_ooool005Oooooo0_l0000>oooo
o`03o`000?o3a03o000000Goakh00_l00005ojNm0003o`000?nn``3o000000?oQ[D000Go0000oj6l
0?nQ_03oXK`0o`000002ofj_0005o`000?n=]`3oSKL0ohfg0?l000000_mNZP001Ol0003oP;@0oh2d
0?n0]03o000000;oEZP000Go0000ogbb0?ml/P3oO;80o`000005oeJX0003o`000?mNZP3oGZX000?o
GZX000Co0000od6Q0?m1X@3o00000om^[`000ol0003oE:L0oeBW0002oeBW0006o`000?loX@3o0000
o`000?m`[`3o00001OmNZP000ol0003oD:H0oe2V0002oe2V00;o00001?ml/P000ol0003oM[40ogJa
0002ogJa0003o`000?md/03oM;0000?oM;0000?o0000ogJa0?mf/@002_l00002ol?40005o`000?o7
_P3oakh0olNn0?l000001Oo;/`000ol0003od:L0om2W0002om2W0003o`000?oFV03oeYP000;oeYP0
00?o0000om^60?oKQP000_oKQP000ol0003ohG<0on5c0002on5c0003o`000?oWG`3oiel000;oiel0
00?o0000one<0?o]C0000_o]C0000ol0003olCT0oo4i0003oo4i0003o`000?of:@3omRT000;omRT0
00?o0000ooPM0?oh7@001?oh7@001?l0003onQT0ooXI0?oj6@03o`0000;ooooo001Iooooo`03o`00
0?oooooooooo00cooooo00?o0000olNn0?o7_P000oo7_P001?l0003obk<0ol^c0?l00003ojNm0007
o`000?nn``3o_/<0okk30?l0003oQ[D0o`000004oj6l0003o`000?m^[`3o000000CoSKL000?o0000
oejZ0?l000001?n0]0000ol0003oEZP0o`000004ogbb0003o`000?mFZ03oEZP000;oEZP00_l00006
oejZ00;o00001?m^[`000ol0003oE:L0oeBW0002oeBW00;o00001?m`[`000ol0003oGZX0oejZ0003
oejZ00Co000000?oQ[D0o`000?ml/P000oml/P000ol0003oM[40ogJa0002ogJa0003o`000?md/03o
M;0000;oM;001?l00002ok;00003o`000?nh`P3o^<8000;o^<8000?o0000ol?40?o3a0000oo3a000
1Ol0003oakh0olNn0?o7_P3o000000Cobk<000?o0000om2W0?o@Y`000_o@Y`000ol0003oeYP0omJH
0003omJH0003o`000?oKQP3ofhH000;ofhH000?o0000on5c0?oQL`000_oQL`000ol0003oiel0onMO
0002onMO0003o`000?o]C03okD`000;okD`000?o0000oo4i0?oa>@000ooa>@000ol0003omRT0ooHY
0002ooHY0003o`000?oh7@3on1d000?on1d01ol00002ooooo`00F_ooool00ol0003oooooooooo`0<
ooooo`05o`000?o7_P3oakh0olNn0?l000001?o;/`000ol0003oYkd0o`000005okk30003o`000?nQ
_03oXK`000CoXK`000?o0000ohfg0?n=]`001?n=]`000ol0003oP;@0oh2d0004oh2d0003o`000?ml
/P3oO;8000CoO;8000Co0000oeJX0?mFZ03o00000_n0]0000ol0003oGZX0oejZ0002oejZ00;o0000
1Om^[`000ol0003oE:L0oeBW0002o`000003ohJe0?l0003oL:l000CoL:l000Co0000oejZ0?mNZP3o
GZX00_l00005ohJe0003o`000?ml/P3oO;8000;oO;8000?o0000ogJa0?mf/@000_mf/@04o`000003
ok2o0?l0003o//0000Co//0000?o0000okS20?nh`P000_nh`P000ol0003o`l@0ol?40002ol?40003
o`000?o7_P3oakh000;oakh000?o0000ol^c0?o;/`000_o;/`000ol0003od:L0om2W0002om2W0003
o`000?oFV03oeYP000;oeYP000?o0000om^60?oKQP000_oKQP000ol0003ohG<0on5c0002on5c0003
o`000?oWG`3oiel000;oiel000?o0000one<0?o]C0000oo]C0000ol0003olCT0oo4i0002oo4i0003
o`000?of:@3omRT000;omRT000?o0000ooPM0?oh7@001ol00005ooooo`00Foooool00ol0003ooooo
ooooo`0<ooooo`03o`000?o7_P3o000000Gobk<00_l00005okk300;o00001OnQ_002o`0000GoSKL0
0_l00006oh2d0003o`000?ml/P3oO;8000CoO;8000?o0000oeJX0?l000001?n0]0001_l0003oGZX0
oejZ0?l0003oSKL0o`0000KoKZl00_l00004ohJe0003o`000?m`[`3oL:l000;oL:l000Ko0000oejZ
0?l0003o0000oiFi0?l00005ohJe0003o`000?ml/P3oO;8000;oO;8000?o0000ogJa0?mf/@000ol0
0005ok2o0003o`000?nb`03o//0000;o//0000?o0000okS20?nh`P000_nh`P000ol0003o`l@0ol?4
0002ol?40003o`000?o7_P3oakh000;oakh000?o0000ol^c0?o;/`000_o;/`000ol0003od:L0om2W
0002om2W0003o`000?oFV03oeYP000;oeYP000?o0000om^60?oKQP000_oKQP000ol0003ohG<0on5c
0002on5c0003o`000?oWG`3oiel000;oiel000?o0000one<0?o]C0000oo]C0001?l0003olCT0oo4i
0?oa>@0<o`0000Wooooo001Looooo`;o00003Oooool00ol0003obk<0ol^c0003ol^c0003o`000?o@
Y`3o000000Co_/<000Co0000olVi0?o9^@3o00000onQ_0001?l0003o`L@0ol740?l00003ohfg0004
o`000?n`_`3o/;l0o`0000CoP;@000?o0000ojRn0?l000001Oml/P02o`0000GoP;@000?o0000oejZ
0?l000000on=]`000ol0003oKZl0ofj_0002ofj_00;o00001On6]@000ol0003oL:l0og2_0002og2_
00;o00001?nE^@000ol0003oQ[D0ohJe0002ohJe0003o`000?ml/P3oO;8000;oO;800ol00002ok;0
0003o`000?n`_`3o/;l000?o/;l000?o0000ok;00?nb`0000_nb`0000ol0003o^<80okS20002okS2
0003o`000?o3a03o`l@000?o`l@000?o0000olNn0?o7_P00:Ol00005ooooo`Co00003?ooool005ko
oooo00?o0000ooooooooool02oooool01Ol0003obk<0ol^c0?o;/`3o000000?od:L000Co0000okk3
0?nn``3o00001?o9^@000ol0003oXK`0o`000004ol740003o`000?n=]`3o000000Co/;l000Co0000
oh2d0?n0]03o00000onX_P000ol0003oO;80ogbb0002o`000003ojRn0?l0003oP;@000CoP;@00_l0
0005ohfg0006o`000?m^[`3oKZl0o`000?nQ_03o00001On6]@000ol0003oL:l0og2_0002o`000003
ojNm0?l0003oUKT000?oUKT000?o0000ohJe0?n6]@000on6]@04o`000003okS20?l0003o//0000?o
//0000?o0000ok2o0?n`_`000on`_`000ol0003o//00ok;00002ok;00003o`000?nh`P3o^<8000;o
^<8000?o0000ol?40?o3a0001Ol0000Zooooo`Co00004?ooool005oooooo00?o0000ooooooooool0
2oooool00ol0003obk<0o`000004om2W0003o`000?nn``3o000000KobKT000?o0000ol740?o1a000
0oo1a002o`0000Go/;l000?o0000oh2d0?l000001?nX_P000ol0003oO;80o`000004ojRn0007o`00
0?n0]03oP;@0oh2d0?l0003o/;l0o`000005ohfg0003o`000?m^[`3o000000?oXK`000?o0000ohJe
0?n6]@000on6]@02o`0000CoYkd000?o0000oiFi0?nE^@000_nE^@001?l0003oQ[D0ohJe0?n6]@02
o`0000Go^<8000Go0000ok;00?nb`03o//00o`000005ok2o0003o`000?nb`03o//0000[o0000:ooo
ool4o`0001Cooooo001Pooooo`03o`000?oooooooooo00_ooooo00?o0000om2W0?o@Y`001?o@Y`00
0ol0003obKT0olVi0004olVi00;o00001?o1a0000ol0003oc;<0o`000005ok2o00;o00001OnX_P02
o`0000GoZ;h000Co0000oh2d0?n0]03o00000on`_`000ol0003oSKL0ohfg0002ohfg00;o00001?nQ
_0000ol0003oQ[D0ohJe0002ohJe00;o00001OnW_@000ol0003oUKT0oiFi0002oiFi0006o`000?n6
]@3o0000o`000?o3a03o00001Onh`P000ol0003o//00ok;00002ok;00003o`000?n`_`3o/;l000;o
/;l00ol0000aooooo`Co00006?ooool0067ooooo0_l0000;ooooo`03o`000?o@Y`3od:L000?od:L0
0_l00005olVi0004o`000?o@Z03od:P0o`0000;o`L@000Go0000olbc0?o</`3oc;<0o`000003ok2o
0003o`000?o9^P3o000000CoZ;h000?o0000olRl0?l000001OnX_P000ol0003oP;@0o`000004ok2o
0003o`000?n=]`3oSKL000;o000000?o`L@0o`000?nQ_0001?nQ_0001_l0003oQ[D0ohJe0?l0003o
_/<0o`0000GoYkd000?o0000oiFi0?nE^@000_nE^@02o`0000Co`l@000?o0000okS20?nh`P000_nh
`P000ol0003o//00ok;00002ok;00003o`000?n`_`3o000000;o0000<Oooool3o`0001cooooo001S
ooooo`03o`000?oooooooooo00Wooooo00Go0000om2W0?o@Y`3od:L0o`000002omJH0005o`000?o9
^@3obKT0olVi0?l000000oo@Z0000ol0003o`L@0o`000004olbc0004o`000?n`_`3o/;l0o`0000?o
bKX000Co0000ojRn0?nX_P3o00000oo8_0000ol0003oZ;h0ojRn0002ojRn00;o00001On`_`000ol0
003oSKL0o`000004ol740003o`000?nQ_03oXK`000;oXK`000?o0000ohJe0?l000000onn``000ol0
003oYkd0ojNm0003ojNm00Co000000?oakh0o`000?o3a0000oo3a0000ol0003o^<80okS20003okS2
0003o`000?nb`03o//0000?o0000<?ooool4o`0001oooooo001Tooooo`03o`000?oooooooooo00Wo
oooo00?o0000om2W0?l000001?oFV0000ol0003obKT0o`000005om2X0003o`000?o</`3oc;<000?o
c;<000?o0000ok2o0?l000001?o9^P000ol0003oZ;h0o`000005olRl0006o`000?nX_P3oZ;h0o`00
0?o9^P3o00001_n`_`000ol0003o`L@0ol740003ol740003o`000?nQ_03oXK`000;oXK`00_l00004
okk30003o`000?nW_@3oYkd000;oYkd00_l00005olNn0003o`000?o3a03o`l@000;o`l@000Co0000
okS20?nh`P3o^<801?l0000_ooooo`Co00008oooool006Gooooo00?o0000ooooooooool02Oooool0
0ol0003oeYP0omJH0003omJH00;o00001Oo@Z002o`0000Goc;<00_l00006olVj0003o`000?o8_03o
b;`000Cob;`000?o0000ojRn0?l000000oo9^P000ol0003o/;l0ok2o0002ok2o00;o00001Oo1a000
0ol0003oXK`0oj6l0002o`000003olVi0?l0003o_/<000?o_/<000?o0000ojNm0?nW_@000_l00000
0oo;/`3o0000olNn0004olNn0003o`000?o3a03o`l@000;o`l@000Co0000okS20?l0003o0000;ooo
ool4o`0002Oooooo001Vooooo`;o00002Oooool00ol0003oeYP0omJH0002omJH0004o`000?oKQP3o
fhH0o`0000?od:P000Co0000omND0?oGU03o00000oo</`000ol0003odid0o`000005olVj00;o0000
1_o8_002o`0000GobKX000Co0000ok2o0?n`_`3o00000_o</`000ol0003o`L@0ol740003ol7400;o
00001?o9^@000ol0003o_/<0okk30002okk300;o00001?o;/`000ol0003oakh0olNn0002olNn0003
o`000?o3a03o`l@000;o`l@00_l0000]ooooo`Co0000:oooool006Sooooo00?o0000ooooooooool0
1oooool01?l0003oeYP0omJH0?l00004om^60003o`000?o@Z03o000000Coei@000?o0000olbc0?l0
00000ooCW@001Ol0003obKX0olVj0?o9^P3o000000;odZ8000?o0000olRl0?o8_0000_o8_0000ol0
003odZ80o`000005olVj0003o`000?n`_`3o000000?oc;<000?o0000ol740?o1a0000_o1a002o`00
00GobKT000Co0000okk30?nn``3o_/<00_l00005ol^c0003o`000?o7_P3oakh000?oakh01?l0000/
ooooo`?o0000;oooool006Wooooo00?o0000ooooooooool01_ooool00ol0003oeYP0o`000005om^6
00;o00001OoGU002o`0000Godid000?o0000olVj0?l000001?oBXP001?l0003ob;`0olRl0?l00003
om:R0003o`000?o9^P3obKX000;obKX00_l00005olbc0006o`000?o1a03o`L@0o`000?o@Z03o0000
1Oo9^@001_l0003o_/<0o`000?l0003od:L0o`0000Gobk<000?o0000olNn0?o7_P000_o7_P02o`00
02_ooooo1?l0000booooo`00J_ooool00ol0003oooooooooo`06ooooo`03o`000?oKQP3ofhH000?o
fhH000?o0000on5c0?l000001?oGU0000ol0003ogWh0o`000005om>M00;o00001OoBXP000ol0003o
b;`0o`000004om:R0003o`000?o9^P3obKX000;o000000?odid0o`000?o</`001?o</`000ol0003o
`L@0o`000003om2X0003o`000?o9^@3obKT000;obKT00_l00004om2W0003o`000?o;/`3obk<000?o
bk<01?l0000Yooooo`Co0000=_ooool006_ooooo0_l00007ooooo`05o`000?oKQP3ofhH0om^60?l0
00000ooQL`001?l0003oei@0omND0?l00003omin0007o`000?oCW@3odid0om>M0?l0003og8D0o`00
0005om:R00;o00001OoBXP000ol0003obKX0o`000004om>M0003o`000?o</`3oc;<000;oc;<00_l0
0004om2X0003o`000?o9^@3obKT000;o000000?oeYP0o`000?o@Y`001?o@Y`001?l0003obk<0ol^c
0?o;/`02o`0002Sooooo1?l0000jooooo`00KOooool00ol0003oooooooooo`05ooooo`03o`000?oK
QP3o000000CohG<000?o0000omND0?l000001?oNOP001?l0003odid0om>M0?l00003omb50007o`00
0?oBXP3odZ80om:R0?l0003ofhL0o`000005om:R00;o00001OoCW@000ol0003oc;<0olbc0002o`00
0003omND0?l0003od:P000?od:P000?o0000olVi0?l000001?oFV0000ol0003od:L0om2W0002om2W
0004o`000?o;/`3o0000o`0002Kooooo1?l0000nooooo`00K_ooool00ol0003oooooooooo`05oooo
o`03o`000?oQL`3ohG<000CohG<000?o0000omin0?oNOP000ooNOP000ol0003odid0o`000005omb5
0003o`000?oBXP3o000000?ofhL000Oo0000om:R0?oBXP3odZ80o`000?oLQ@3o000000Godid000?o
0000olbc0?l000001?oGU0001?l0003od:P0om2X0?o@Z002o`0000GoeYP000?o0000om2W0?o@Y`00
0_o@Y`02o`0002Gooooo0ol00012ooooo`00Koooool00ol0003oooooooooo`04ooooo`03o`000?oQ
L`3ohG<000?ohG<00_l00005omin00;o00001_oLQ@02o`0000GofhL000?o0000om:R0?l000000ooL
Q@000ol0003odid0om>M0002om>M00;o00001OoGU0001_l0003od:P0om2X0?l0003ofhH0o`0000Go
eYP000?o0000om2W0?l000000_l0000Sooooo`Co0000AOooool0073ooooo0_l00005ooooo`05o`00
0?oQL`3ohG<0on5c0?l000000_oWG`001ol0003ogWh0omin0?oNOP3o0000onEX0?l000001OoLQ@00
0ol0003ohf`0o`000005om^700;o00001OoLQ@001_l0003odid0om>M0?l0003ogWh0o`0000Goei@0
00?o0000om2X0?l000000ooKQP000ol0003oeYP0omJH0002omJH00;o00008_ooool4o`0004Wooooo
001booooo`03o`000?oooooooooo00?ooooo00?o0000on5c0?l000001?oWG`000ol0003ogWh0o`00
0003onEX0005o`000?oLQ@3og8D0omb50?l000000ooSK0001ol0003ofhL0om^70?oKQ`3o0000on=/
0?l000001OoLQ@000ol0003odid0o`000003omin0003o`000?oGU03oei@000;oei@00_l00005om^6
0004o`000?oFV03oeYP0o`00023ooooo1?l0001=ooooo`00Loooool00ol0003oooooooooo`03oooo
o`03o`000?oWG`3oiel000?oiel00_l00005onEX0003o`000?oLQ@3o000000Cohf`000Co0000om^7
0?oKQ`3o00000ooSK0000ol0003og8D0omb50002omb500;o00001?oNOP000ol0003oei@0o`000002
o`000003on5c0?l0003ofhH000CofhH000?o0000omJH0?l000007Oooool4o`00057ooooo001doooo
o`03o`000?oooooooooo00;ooooo00Co0000onMO0?oWG`3oiel00_l000000oo]C03o0000onEX0004
onEX00;o00001OoSK0000ol0003ofhL0o`000004on=/0003o`000?oLQ@3og8D000;o000000?oiFP0
o`000?oNOP000ooNOP02o`0000GohG<000?o0000om^60?oKQP000_oKQP02o`0001_ooooo0ol0001E
ooooo`00MOooool2o`0000?ooooo00?o0000onMO0?l000001?o]C0001ol0003oiFP0onEX0?oUJ03o
0000on]A0?l000001OoSK002o`0000Gohf`000?o0000omb50?l000001?oUJ0001_l0003ogWh0omin
0?l0003oiel0o`0000GohG<000?o0000om^60?l000000_l0000Iooooo`Co0000F?ooool007Oooooo
00Go0000ooooooooooooooooo`000006one<0003o`000?oUJ03o000000?oje4000Oo0000on=/0?oS
K03ohf`0o`000?o[D`3o000000Gohf`00_l00005onEX0003o`000?oNOP3o000000?oiel000?o0000
on5c0?oQL`000_oQL`02o`0001Sooooo1?l0001Looooo`00N?ooool01?l0003oooooooooool00006
one<00;o00001Oo[D@000ol0003ohf`0o`000003on]C0007o`000?oSK03ohf`0on=/0?l0003oje40
o`000005onEX00;o00001OoWG`001?l0003ohG<0on5c0?l0000Fooooo`Co0000H?ooool007Wooooo
00Co0000oooooooooooo00000oo]C002o`000003oo4i0?l0003oje4000Coje400_l00005on]C0003
o`000?oSK03o000000?oje4000Oo0000onEX0?oUJ03oiFP0o`000?o]C03o000000Goiel000?o0000
on5c0?l000004oooool4o`0006Cooooo001jooooo`;o000000Coooooo`000?o]C03o00001?oa>@00
0ol0003oje40o`000002o`000003oo4l0?l0003oje<000Coje<00_l00005on]A0003o`000?oUJ03o
000000?okD`000?o0000onMO0?oWG`000_oWG`02o`00017ooooo0ol0001Xooooo`00O?ooool00ol0
003oooooo`000005oo4i00;o00001Ooa?0000ol0003oje<0o`000002o`000003oo4l0?l0003oje40
00Coje400_l00004one<0003o`000?oWG`3o000000;o00003oooool4o`0006_ooooo001mooooo`03
o`000?oooooo000000?olCT000?o0000ooHY0?l000001Ooa?002o`0000GolC`000?o0000on]A0?l0
00000_l000000ooa>@3o0000one<0003one<00;o00003_ooool4o`0006oooooo001nooooo`05o`00
0?oooooo0000oo4i0?l000000oof:@001ol0003olC`0oo4l0?oa?03o0000ooDZ0?l000001Ooa?002
o`0000GolCT000Co0000one<0?o]C03o00003?ooool4o`0007?ooooo001oooooo`?o00001Oof:@00
0ol0003olC`0o`000003ooDZ0007o`000?oa?03olC`0oo4l0?l0003omRT0o`000005oo4i0003o`00
0?o]C03o000000Wooooo1?l0001gooooo`00POooool2o`0000?omRT00ol00005ooDZ0003o`000?oa
?03o000000?omRT000?o0000oo4i0?oa>@000_oa>@02o`0000Oooooo0ol0001kooooo`00P_ooool4
o`0000?on1d000Co0000ooDZ0?oe:P3omBX00ol00005ooHY0004o`000?oa>@3o0000o`0000Gooooo
1?l0001nooooo`00Poooool2o`0000Con1d01?l00003ooPM0004o`000?of:@3omRT0ooHY00?o0000
0oooool4o`0008;ooooo0024ooooo`;o000000?on1d0o`000?l000000_oj6@000ol0003on1d0ooPM
0002ooPM00Co00000_ooool4o`0008Kooooo0026ooooo`;o00001?oj6@001?l0003on1d0o`000?l0
0002ooooo`Co0000R_ooool008Oooooo0_l00002ooXI00?o000000Coooooo`000?l0003o0000S_oo
ool008Sooooo1ol0002Aooooo`00ROooool2o`0009Gooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo000cooooo`?o0000F?ooool3o`0001Oooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`0;ooooo`00=?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0:ooooo`00;_ooool3o`0000?o
oooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l0
00000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_ooool5o`0000;o
oooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool6o`00
00Oooooo00?o0000ooooooooool00oooool4o`000003ooooool0003o000000;o00000_ooool4o`00
00?ooooo0ol00002ooooo`Go00000oooool2o`000004ooooool0003oooooooooo`;o00000oooool3
o`0000Wooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00001?ooool2
o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o0000
0oooool3o`0000Gooooo00?o0000ooooooooool02Oooool002gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0000;ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`09ooooo`00;Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`03ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`?o00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00007ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00?o0000ooooooooool00oooool3o`00
00?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go00001?ooool00ol0003ooooooooo
o`09ooooo`00;Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Ko
0000oooooooooooo0000ooooool00005ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool002gooooo00Ko0000ooooooooooooooooo`00
0?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o
00002Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o
00002Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`0000?ooooo1?l00002ooooo`?o
00001?ooool01?l0003oooooooooooooool2o`000004ooooool0003o0000ooooo`Co00000oooool3
o`0000Wooooo0ol00002ooooo`?o00001?ooool4o`000003ooooool0003o000000;o00000oooool2
o`0000?ooooo1?l00003ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool02Oooool0
02gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`00;_ooool3o`0000Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000
ooooooooool00_ooool2o`0000[ooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000=
ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`?o00002_ooool00ol0003oooooooooo`0@
ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.150433, 0.0170257, \
0.00386341, 0.00386341}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.02269 .27405 -24 -2.74987 ]
[.02269 .27405 0 6.25013 ]
[.01481 .32345 -30 -2.79165 ]
[.01481 .32345 0 6.20835 ]
[.00667 .37445 -18 -2.83493 ]
[.00667 .37445 0 6.16507 ]
[-0.00174 .42714 -30 -2.8798 ]
[-0.00174 .42714 0 6.1202 ]
[-0.01043 .4816 -24 -2.92632 ]
[-0.01043 .4816 0 6.07368 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03492 .26929 m
.04103 .26691 L
s
[(0.05)] .02269 .27405 1 -0.38892 Mshowa
.02707 .31879 m
.03321 .31646 L
s
[(0.075)] .01481 .32345 1 -0.37963 Mshowa
.01897 .3699 m
.02513 .36762 L
s
[(0.1)] .00667 .37445 1 -0.37001 Mshowa
.01061 .4227 m
.01678 .42047 L
s
[(0.125)] -0.00174 .42714 1 -0.36005 Mshowa
.00196 .47727 m
.00815 .47511 L
s
[(0.15)] -0.01043 .4816 1 -0.34971 Mshowa
.125 Mabswid
.03337 .27907 m
.03704 .27765 L
s
.03181 .2889 m
.03548 .28749 L
s
.03024 .2988 m
.03392 .29739 L
s
.02866 .30876 m
.03234 .30736 L
s
.02547 .32888 m
.02916 .32749 L
s
.02386 .33904 m
.02755 .33765 L
s
.02224 .34926 m
.02593 .34788 L
s
.02061 .35954 m
.0243 .35817 L
s
.01732 .38032 m
.02102 .37896 L
s
.01566 .39081 m
.01936 .38946 L
s
.01399 .40137 m
.01769 .40002 L
s
.0123 .412 m
.016 .41066 L
s
.0089 .43347 m
.01261 .43214 L
s
.00718 .44431 m
.01089 .44299 L
s
.00545 .45522 m
.00916 .45391 L
s
.00371 .46621 m
.00742 .4649 L
s
.03646 .25958 m
.04012 .25815 L
s
.00019 .48841 m
.00391 .48711 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .454 .167 r
.39279 .65964 .40417 .63098 .41929 .67752 .40743 .72342 Metetra
.301 .646 0 r
.40743 .72342 .41929 .67752 .43562 .69986 .42381 .7529 Metetra
.6 .729 0 r
.42381 .7529 .43562 .69986 .45269 .70404 .44123 .75704 Metetra
.693 .751 0 r
.44123 .75704 .45269 .70404 .47006 .70227 .45901 .75322 Metetra
.718 .757 0 r
.45901 .75322 .47006 .70227 .48758 .69934 .47692 .74814 Metetra
.731 .76 0 r
.47692 .74814 .48758 .69934 .50524 .69606 .49495 .74291 Metetra
.741 .763 0 r
.49495 .74291 .50524 .69606 .52303 .69253 .5131 .73764 Metetra
.749 .765 0 r
.5131 .73764 .52303 .69253 .54094 .68877 .53137 .73234 Metetra
.756 .766 0 r
.53137 .73234 .54094 .68877 .55899 .68479 .54975 .72703 Metetra
.762 .767 0 r
.54975 .72703 .55899 .68479 .57716 .68061 .56826 .72172 Metetra
.766 .768 0 r
.56826 .72172 .57716 .68061 .59545 .67623 .58688 .71641 Metetra
.769 .769 0 r
.58688 .71641 .59545 .67623 .61388 .67168 .60563 .71111 Metetra
.77 .768 0 r
.60563 .71111 .61388 .67168 .63242 .66697 .62451 .70583 Metetra
.77 .767 0 r
.62451 .70583 .63242 .66697 .65109 .66209 .64351 .70057 Metetra
.77 .767 0 r
.64351 .70057 .65109 .66209 .66988 .65705 .66265 .69533 Metetra
.77 .766 0 r
.66265 .69533 .66988 .65705 .68879 .65186 .68191 .69011 Metetra
.77 .766 0 r
.68191 .69011 .68879 .65186 .70782 .64651 .70131 .68491 Metetra
.77 .767 0 r
.70131 .68491 .70782 .64651 .72697 .641 .72085 .67974 Metetra
.77 .767 0 r
.72085 .67974 .72697 .641 .74625 .63532 .74053 .67458 Metetra
.77 .769 0 r
.74053 .67458 .74625 .63532 .76564 .62947 .76035 .66945 Metetra
.768 .769 0 r
.76035 .66945 .76564 .62947 .78514 .62344 .78031 .66433 Metetra
.764 .768 0 r
.78031 .66433 .78514 .62344 .80476 .61722 .80042 .65921 Metetra
.759 .767 0 r
.80042 .65921 .80476 .61722 .82449 .61078 .82068 .65409 Metetra
.753 .766 0 r
.82068 .65409 .82449 .61078 .84433 .60413 .84108 .64896 Metetra
.746 .764 0 r
.84108 .64896 .84433 .60413 .86427 .59723 .86164 .64382 Metetra
.737 .762 0 r
.86164 .64382 .86427 .59723 .88431 .59006 .88235 .63864 Metetra
.725 .759 0 r
.88235 .63864 .88431 .59006 .90444 .58258 .9032 .63339 Metetra
.709 .755 0 r
.9032 .63339 .90444 .58258 .92463 .57455 .92417 .62774 Metetra
.666 .745 0 r
.92417 .62774 .92463 .57455 .94461 .56387 .94489 .6188 Metetra
.499 .703 0 r
.94489 .6188 .94461 .56387 .9632 .54189 .96372 .5943 Metetra
.089 .574 0 r
.96372 .5943 .9632 .54189 .97837 .49525 .97779 .53506 Metetra
.14 .593 0 r
.38194 .66675 .39279 .65964 .40743 .72342 .39629 .73684 Metetra
.815 .654 0 r
.39629 .73684 .40743 .72342 .42381 .7529 .41269 .76806 Metetra
.903 .379 0 r
.41269 .76806 .42381 .7529 .44123 .75704 .4303 .7712 Metetra
.92 .318 0 r
.4303 .7712 .44123 .75704 .45901 .75322 .4483 .76581 Metetra
.919 .323 0 r
.4483 .76581 .45901 .75322 .47692 .74814 .46642 .75927 Metetra
.915 .337 0 r
.46642 .75927 .47692 .74814 .49495 .74291 .48465 .75277 Metetra
.911 .351 0 r
.48465 .75277 .49495 .74291 .5131 .73764 .50298 .7464 Metetra
.908 .363 0 r
.50298 .7464 .5131 .73764 .53137 .73234 .52142 .74016 Metetra
.905 .374 0 r
.52142 .74016 .53137 .73234 .54975 .72703 .53997 .73405 Metetra
.902 .383 0 r
.53997 .73405 .54975 .72703 .56826 .72172 .55864 .72806 Metetra
.9 .392 0 r
.55864 .72806 .56826 .72172 .58688 .71641 .57742 .72218 Metetra
.898 .398 0 r
.57742 .72218 .58688 .71641 .60563 .71111 .59633 .71644 Metetra
.896 .404 0 r
.59633 .71644 .60563 .71111 .62451 .70583 .61536 .71081 Metetra
.895 .408 0 r
.61536 .71081 .62451 .70583 .64351 .70057 .63453 .70529 Metetra
.894 .41 0 r
.63453 .70529 .64351 .70057 .66265 .69533 .65383 .69989 Metetra
.894 .411 0 r
.65383 .69989 .66265 .69533 .68191 .69011 .67326 .69461 Metetra
.894 .411 0 r
.67326 .69461 .68191 .69011 .70131 .68491 .69284 .68944 Metetra
.894 .409 0 r
.69284 .68944 .70131 .68491 .72085 .67974 .71256 .68439 Metetra
.895 .406 0 r
.71256 .68439 .72085 .67974 .74053 .67458 .73244 .67946 Metetra
.897 .401 0 r
.73244 .67946 .74053 .67458 .76035 .66945 .75246 .67465 Metetra
.898 .395 0 r
.75246 .67465 .76035 .66945 .78031 .66433 .77265 .66996 Metetra
.901 .388 0 r
.77265 .66996 .78031 .66433 .80042 .65921 .793 .6654 Metetra
.903 .379 0 r
.793 .6654 .80042 .65921 .82068 .65409 .81351 .66096 Metetra
.906 .369 0 r
.81351 .66096 .82068 .65409 .84108 .64896 .8342 .65666 Metetra
.909 .358 0 r
.8342 .65666 .84108 .64896 .86164 .64382 .85507 .6525 Metetra
.913 .345 0 r
.85507 .6525 .86164 .64382 .88235 .63864 .87613 .64848 Metetra
.917 .331 0 r
.87613 .64848 .88235 .63864 .9032 .63339 .89737 .64459 Metetra
.92 .318 0 r
.89737 .64459 .9032 .63339 .92417 .62774 .91877 .64049 Metetra
.917 .33 0 r
.91877 .64049 .92417 .62774 .94489 .6188 .93994 .63305 Metetra
.877 .469 0 r
.93994 .63305 .94489 .6188 .96372 .5943 .95911 .60862 Metetra
.618 .733 0 r
.95911 .60862 .96372 .5943 .97779 .53506 .97301 .54526 Metetra
.288 .642 0 r
.3714 .66177 .38194 .66675 .39629 .73684 .38558 .73239 Metetra
.87 .49 0 r
.38558 .73239 .39629 .73684 .41269 .76806 .40199 .76308 Metetra
.957 .178 0 r
.40199 .76308 .41269 .76806 .4303 .7712 .41969 .76553 Metetra
.971 .124 0 r
.41969 .76553 .4303 .7712 .4483 .76581 .43779 .75961 Metetra
.965 .145 0 r
.43779 .75961 .4483 .76581 .46642 .75927 .45601 .75264 Metetra
.958 .174 0 r
.45601 .75264 .46642 .75927 .48465 .75277 .47434 .74577 Metetra
.951 .2 0 r
.47434 .74577 .48465 .75277 .50298 .7464 .49277 .73908 Metetra
.946 .223 0 r
.49277 .73908 .50298 .7464 .52142 .74016 .5113 .73257 Metetra
.941 .242 0 r
.5113 .73257 .52142 .74016 .53997 .73405 .52995 .72622 Metetra
.936 .259 0 r
.52995 .72622 .53997 .73405 .55864 .72806 .54871 .72003 Metetra
.932 .273 0 r
.54871 .72003 .55864 .72806 .57742 .72218 .56759 .71398 Metetra
.929 .285 0 r
.56759 .71398 .57742 .72218 .59633 .71644 .58659 .70808 Metetra
.927 .294 0 r
.58659 .70808 .59633 .71644 .61536 .71081 .60572 .70232 Metetra
.925 .3 0 r
.60572 .70232 .61536 .71081 .63453 .70529 .62497 .6967 Metetra
.924 .304 0 r
.62497 .6967 .63453 .70529 .65383 .69989 .64437 .69121 Metetra
.924 .306 0 r
.64437 .69121 .65383 .69989 .67326 .69461 .6639 .68586 Metetra
.924 .305 0 r
.6639 .68586 .67326 .69461 .69284 .68944 .68358 .68064 Metetra
.924 .303 0 r
.68358 .68064 .69284 .68944 .71256 .68439 .7034 .67556 Metetra
.926 .297 0 r
.7034 .67556 .71256 .68439 .73244 .67946 .72338 .67061 Metetra
.928 .29 0 r
.72338 .67061 .73244 .67946 .75246 .67465 .74352 .66581 Metetra
.931 .28 0 r
.74352 .66581 .75246 .67465 .77265 .66996 .76381 .66115 Metetra
.934 .267 0 r
.76381 .66115 .77265 .66996 .793 .6654 .78428 .65665 Metetra
.938 .252 0 r
.78428 .65665 .793 .6654 .81351 .66096 .80492 .65231 Metetra
.943 .234 0 r
.80492 .65231 .81351 .66096 .8342 .65666 .82574 .64813 Metetra
.948 .213 0 r
.82574 .64813 .8342 .65666 .85507 .6525 .84674 .64414 Metetra
.954 .189 0 r
.84674 .64414 .85507 .6525 .87613 .64848 .86795 .64034 Metetra
.961 .161 0 r
.86795 .64034 .87613 .64848 .89737 .64459 .88935 .63673 Metetra
.968 .133 0 r
.88935 .63673 .89737 .64459 .91877 .64049 .91092 .633 Metetra
.969 .13 0 r
.91092 .633 .91877 .64049 .93994 .63305 .9323 .62606 Metetra
.932 .275 0 r
.9323 .62606 .93994 .63305 .95911 .60862 .95173 .60224 Metetra
.787 .727 0 r
.95173 .60224 .95911 .60862 .97301 .54526 .9659 .53893 Metetra
.322 .652 0 r
.36086 .65359 .3714 .66177 .38558 .73239 .37491 .72346 Metetra
.878 .465 0 r
.37491 .72346 .38558 .73239 .40199 .76308 .39131 .75326 Metetra
.962 .158 0 r
.39131 .75326 .40199 .76308 .41969 .76553 .40907 .7553 Metetra
.974 .11 0 r
.40907 .7553 .41969 .76553 .43779 .75961 .42724 .74923 Metetra
.968 .135 0 r
.42724 .74923 .43779 .75961 .45601 .75264 .44555 .74218 Metetra
.96 .167 0 r
.44555 .74218 .45601 .75264 .47434 .74577 .46395 .73525 Metetra
.953 .195 0 r
.46395 .73525 .47434 .74577 .49277 .73908 .48246 .72849 Metetra
.946 .219 0 r
.48246 .72849 .49277 .73908 .5113 .73257 .50107 .72192 Metetra
.941 .24 0 r
.50107 .72192 .5113 .73257 .52995 .72622 .5198 .71551 Metetra
.936 .258 0 r
.5198 .71551 .52995 .72622 .54871 .72003 .53864 .70925 Metetra
.932 .273 0 r
.53864 .70925 .54871 .72003 .56759 .71398 .5576 .70313 Metetra
.929 .285 0 r
.5576 .70313 .56759 .71398 .58659 .70808 .57668 .69717 Metetra
.927 .295 0 r
.57668 .69717 .58659 .70808 .60572 .70232 .59589 .69134 Metetra
.925 .302 0 r
.59589 .69134 .60572 .70232 .62497 .6967 .61523 .68565 Metetra
.924 .306 0 r
.61523 .68565 .62497 .6967 .64437 .69121 .63471 .68009 Metetra
.923 .308 0 r
.63471 .68009 .64437 .69121 .6639 .68586 .65433 .67467 Metetra
.923 .307 0 r
.65433 .67467 .6639 .68586 .68358 .68064 .67409 .66938 Metetra
.924 .304 0 r
.67409 .66938 .68358 .68064 .7034 .67556 .694 .66422 Metetra
.925 .299 0 r
.694 .66422 .7034 .67556 .72338 .67061 .71407 .6592 Metetra
.928 .291 0 r
.71407 .6592 .72338 .67061 .74352 .66581 .73429 .65432 Metetra
.93 .28 0 r
.73429 .65432 .74352 .66581 .76381 .66115 .75468 .64958 Metetra
.934 .267 0 r
.75468 .64958 .76381 .66115 .78428 .65665 .77524 .645 Metetra
.938 .251 0 r
.77524 .645 .78428 .65665 .80492 .65231 .79597 .64059 Metetra
.943 .231 0 r
.79597 .64059 .80492 .65231 .82574 .64813 .81688 .63633 Metetra
.949 .209 0 r
.81688 .63633 .82574 .64813 .84674 .64414 .83799 .63226 Metetra
.956 .183 0 r
.83799 .63226 .84674 .64414 .86795 .64034 .85928 .62839 Metetra
.963 .153 0 r
.85928 .62839 .86795 .64034 .88935 .63673 .88078 .6247 Metetra
.971 .121 0 r
.88078 .6247 .88935 .63673 .91092 .633 .90246 .62092 Metetra
.973 .114 0 r
.90246 .62092 .91092 .633 .9323 .62606 .92397 .61408 Metetra
.938 .252 0 r
.92397 .61408 .9323 .62606 .95173 .60224 .94361 .59077 Metetra
.796 .704 0 r
.94361 .59077 .95173 .60224 .9659 .53893 .95813 .52833 Metetra
.326 .654 0 r
.35021 .64486 .36086 .65359 .37491 .72346 .36413 .7139 Metetra
.875 .472 0 r
.36413 .7139 .37491 .72346 .39131 .75326 .38052 .74289 Metetra
.957 .177 0 r
.38052 .74289 .39131 .75326 .40907 .7553 .39834 .7446 Metetra
.968 .132 0 r
.39834 .7446 .40907 .7553 .42724 .74923 .41658 .73846 Metetra
.962 .158 0 r
.41658 .73846 .42724 .74923 .44555 .74218 .43496 .73138 Metetra
.954 .189 0 r
.43496 .73138 .44555 .74218 .46395 .73525 .45344 .72441 Metetra
.947 .216 0 r
.45344 .72441 .46395 .73525 .48246 .72849 .47203 .71762 Metetra
.941 .24 0 r
.47203 .71762 .48246 .72849 .50107 .72192 .49072 .711 Metetra
.936 .261 0 r
.49072 .711 .50107 .72192 .5198 .71551 .50952 .70455 Metetra
.931 .278 0 r
.50952 .70455 .5198 .71551 .53864 .70925 .52844 .69824 Metetra
.927 .293 0 r
.52844 .69824 .53864 .70925 .5576 .70313 .54748 .69207 Metetra
.924 .305 0 r
.54748 .69207 .5576 .70313 .57668 .69717 .56665 .68604 Metetra
.921 .314 0 r
.56665 .68604 .57668 .69717 .59589 .69134 .58594 .68016 Metetra
.92 .32 0 r
.58594 .68016 .59589 .69134 .61523 .68565 .60537 .6744 Metetra
.918 .325 0 r
.60537 .6744 .61523 .68565 .63471 .68009 .62493 .66877 Metetra
.918 .326 0 r
.62493 .66877 .63471 .68009 .65433 .67467 .64464 .66327 Metetra
.918 .326 0 r
.64464 .66327 .65433 .67467 .67409 .66938 .66448 .65791 Metetra
.919 .323 0 r
.66448 .65791 .67409 .66938 .694 .66422 .68448 .65267 Metetra
.92 .318 0 r
.68448 .65267 .694 .66422 .71407 .6592 .70464 .64757 Metetra
.922 .31 0 r
.70464 .64757 .71407 .6592 .73429 .65432 .72495 .6426 Metetra
.925 .3 0 r
.72495 .6426 .73429 .65432 .75468 .64958 .74543 .63778 Metetra
.929 .287 0 r
.74543 .63778 .75468 .64958 .77524 .645 .76608 .6331 Metetra
.933 .271 0 r
.76608 .6331 .77524 .645 .79597 .64059 .7869 .62858 Metetra
.938 .252 0 r
.7869 .62858 .79597 .64059 .81688 .63633 .80791 .62423 Metetra
.944 .23 0 r
.80791 .62423 .81688 .63633 .83799 .63226 .8291 .62005 Metetra
.95 .204 0 r
.8291 .62005 .83799 .63226 .85928 .62839 .85049 .61606 Metetra
.958 .175 0 r
.85049 .61606 .85928 .62839 .88078 .6247 .87209 .61226 Metetra
.966 .144 0 r
.87209 .61226 .88078 .6247 .90246 .62092 .89386 .60837 Metetra
.968 .136 0 r
.89386 .60837 .90246 .62092 .92397 .61408 .91549 .60153 Metetra
.934 .268 0 r
.91549 .60153 .92397 .61408 .94361 .59077 .93533 .57865 Metetra
.795 .706 0 r
.93533 .57865 .94361 .59077 .95813 .52833 .95019 .51705 Metetra
.328 .654 0 r
.33943 .63591 .35021 .64486 .36413 .7139 .35322 .70423 Metetra
.872 .483 0 r
.35322 .70423 .36413 .7139 .38052 .74289 .3696 .73251 Metetra
.952 .198 0 r
.3696 .73251 .38052 .74289 .39834 .7446 .38747 .73393 Metetra
.963 .156 0 r
.38747 .73393 .39834 .7446 .41658 .73846 .40579 .72772 Metetra
.956 .181 0 r
.40579 .72772 .41658 .73846 .43496 .73138 .42425 .7206 Metetra
.949 .211 0 r
.42425 .7206 .43496 .73138 .45344 .72441 .44281 .7136 Metetra
.942 .238 0 r
.44281 .7136 .45344 .72441 .47203 .71762 .46147 .70677 Metetra
.936 .261 0 r
.46147 .70677 .47203 .71762 .49072 .711 .48024 .70011 Metetra
.93 .281 0 r
.48024 .70011 .49072 .711 .50952 .70455 .49913 .6936 Metetra
.926 .297 0 r
.49913 .6936 .50952 .70455 .52844 .69824 .51813 .68724 Metetra
.922 .312 0 r
.51813 .68724 .52844 .69824 .54748 .69207 .53725 .68101 Metetra
.919 .323 0 r
.53725 .68101 .54748 .69207 .56665 .68604 .5565 .67493 Metetra
.916 .332 0 r
.5565 .67493 .56665 .68604 .58594 .68016 .57588 .66898 Metetra
.915 .338 0 r
.57588 .66898 .58594 .68016 .60537 .6744 .59539 .66315 Metetra
.913 .343 0 r
.59539 .66315 .60537 .6744 .62493 .66877 .61504 .65746 Metetra
.913 .344 0 r
.61504 .65746 .62493 .66877 .64464 .66327 .63483 .65189 Metetra
.913 .344 0 r
.63483 .65189 .64464 .66327 .66448 .65791 .65477 .64644 Metetra
.914 .341 0 r
.65477 .64644 .66448 .65791 .68448 .65267 .67485 .64113 Metetra
.915 .336 0 r
.67485 .64113 .68448 .65267 .70464 .64757 .6951 .63594 Metetra
.917 .328 0 r
.6951 .63594 .70464 .64757 .72495 .6426 .7155 .63089 Metetra
.92 .318 0 r
.7155 .63089 .72495 .6426 .74543 .63778 .73607 .62598 Metetra
.924 .306 0 r
.73607 .62598 .74543 .63778 .76608 .6331 .75681 .62121 Metetra
.928 .29 0 r
.75681 .62121 .76608 .6331 .7869 .62858 .77773 .61659 Metetra
.933 .272 0 r
.77773 .61659 .7869 .62858 .80791 .62423 .79883 .61213 Metetra
.938 .251 0 r
.79883 .61213 .80791 .62423 .8291 .62005 .82012 .60785 Metetra
.945 .226 0 r
.82012 .60785 .8291 .62005 .85049 .61606 .8416 .60375 Metetra
.952 .198 0 r
.8416 .60375 .85049 .61606 .87209 .61226 .86329 .59983 Metetra
.96 .168 0 r
.86329 .59983 .87209 .61226 .89386 .60837 .88517 .59583 Metetra
.962 .159 0 r
.88517 .59583 .89386 .60837 .91549 .60153 .90691 .58898 Metetra
.929 .285 0 r
.90691 .58898 .91549 .60153 .93533 .57865 .92695 .56644 Metetra
.793 .71 0 r
.92695 .56644 .93533 .57865 .95019 .51705 .94214 .50556 Metetra
.328 .654 0 r
.32852 .62679 .33943 .63591 .35322 .70423 .34217 .69449 Metetra
.869 .492 0 r
.34217 .69449 .35322 .70423 .3696 .73251 .35854 .72214 Metetra
.947 .217 0 r
.35854 .72214 .3696 .73251 .38747 .73393 .37647 .72331 Metetra
.957 .177 0 r
.37647 .72331 .38747 .73393 .40579 .72772 .39487 .71703 Metetra
.951 .201 0 r
.39487 .71703 .40579 .72772 .42425 .7206 .4134 .70987 Metetra
.944 .23 0 r
.4134 .70987 .42425 .7206 .44281 .7136 .43204 .70283 Metetra
.937 .256 0 r
.43204 .70283 .44281 .7136 .46147 .70677 .45078 .69595 Metetra
.931 .279 0 r
.45078 .69595 .46147 .70677 .48024 .70011 .46964 .68924 Metetra
.926 .298 0 r
.46964 .68924 .48024 .70011 .49913 .6936 .4886 .68268 Metetra
.921 .314 0 r
.4886 .68268 .49913 .6936 .51813 .68724 .50769 .67627 Metetra
.917 .328 0 r
.50769 .67627 .51813 .68724 .53725 .68101 .52689 .66998 Metetra
.914 .339 0 r
.52689 .66998 .53725 .68101 .5565 .67493 .54623 .66383 Metetra
.912 .348 0 r
.54623 .66383 .5565 .67493 .57588 .66898 .56569 .65781 Metetra
.91 .354 0 r
.56569 .65781 .57588 .66898 .59539 .66315 .58529 .65192 Metetra
.909 .358 0 r
.58529 .65192 .59539 .66315 .61504 .65746 .60502 .64615 Metetra
.909 .36 0 r
.60502 .64615 .61504 .65746 .63483 .65189 .6249 .64051 Metetra
.909 .359 0 r
.6249 .64051 .63483 .65189 .65477 .64644 .64493 .63499 Metetra
.909 .357 0 r
.64493 .63499 .65477 .64644 .67485 .64113 .66511 .62959 Metetra
.911 .352 0 r
.66511 .62959 .67485 .64113 .6951 .63594 .68544 .62432 Metetra
.913 .344 0 r
.68544 .62432 .6951 .63594 .7155 .63089 .70594 .61918 Metetra
.916 .335 0 r
.70594 .61918 .7155 .63089 .73607 .62598 .7266 .61418 Metetra
.919 .322 0 r
.7266 .61418 .73607 .62598 .75681 .62121 .74744 .60932 Metetra
.923 .308 0 r
.74744 .60932 .75681 .62121 .77773 .61659 .76845 .6046 Metetra
.928 .29 0 r
.76845 .6046 .77773 .61659 .79883 .61213 .78965 .60004 Metetra
.933 .269 0 r
.78965 .60004 .79883 .61213 .82012 .60785 .81103 .59566 Metetra
.94 .245 0 r
.81103 .59566 .82012 .60785 .8416 .60375 .83262 .59145 Metetra
.947 .218 0 r
.83262 .59145 .8416 .60375 .86329 .59983 .85441 .58741 Metetra
.954 .188 0 r
.85441 .58741 .86329 .59983 .88517 .59583 .87638 .58331 Metetra
.957 .179 0 r
.87638 .58331 .88517 .59583 .90691 .58898 .89824 .57643 Metetra
.925 .3 0 r
.89824 .57643 .90691 .58898 .92695 .56644 .91848 .55418 Metetra
.792 .714 0 r
.91848 .55418 .92695 .56644 .94214 .50556 .93397 .4939 Metetra
.329 .654 0 r
.31748 .6175 .32852 .62679 .34217 .69449 .33098 .68467 Metetra
.867 .501 0 r
.33098 .68467 .34217 .69449 .35854 .72214 .34734 .71179 Metetra
.943 .233 0 r
.34734 .71179 .35854 .72214 .37647 .72331 .36533 .71273 Metetra
.953 .195 0 r
.36533 .71273 .37647 .72331 .39487 .71703 .38381 .70638 Metetra
.947 .219 0 r
.38381 .70638 .39487 .71703 .4134 .70987 .40242 .69918 Metetra
.939 .247 0 r
.40242 .69918 .4134 .70987 .43204 .70283 .42114 .69208 Metetra
.933 .272 0 r
.42114 .69208 .43204 .70283 .45078 .69595 .43996 .68516 Metetra
.927 .294 0 r
.43996 .68516 .45078 .69595 .46964 .68924 .4589 .67839 Metetra
.922 .313 0 r
.4589 .67839 .46964 .68924 .4886 .68268 .47795 .67178 Metetra
.917 .329 0 r
.47795 .67178 .4886 .68268 .50769 .67627 .49712 .6653 Metetra
.913 .343 0 r
.49712 .6653 .50769 .67627 .52689 .66998 .51641 .65895 Metetra
.91 .353 0 r
.51641 .65895 .52689 .66998 .54623 .66383 .53583 .65274 Metetra
.908 .362 0 r
.53583 .65274 .54623 .66383 .56569 .65781 .55538 .64665 Metetra
.906 .368 0 r
.55538 .64665 .56569 .65781 .58529 .65192 .57506 .64069 Metetra
.905 .372 0 r
.57506 .64069 .58529 .65192 .60502 .64615 .59489 .63485 Metetra
.905 .374 0 r
.59489 .63485 .60502 .64615 .6249 .64051 .61486 .62913 Metetra
.905 .373 0 r
.61486 .62913 .6249 .64051 .64493 .63499 .63497 .62353 Metetra
.906 .37 0 r
.63497 .62353 .64493 .63499 .66511 .62959 .65525 .61806 Metetra
.907 .365 0 r
.65525 .61806 .66511 .62959 .68544 .62432 .67567 .6127 Metetra
.909 .358 0 r
.67567 .6127 .68544 .62432 .70594 .61918 .69626 .60748 Metetra
.912 .349 0 r
.69626 .60748 .70594 .61918 .7266 .61418 .71702 .60238 Metetra
.915 .337 0 r
.71702 .60238 .7266 .61418 .74744 .60932 .73795 .59743 Metetra
.919 .322 0 r
.73795 .59743 .74744 .60932 .76845 .6046 .75906 .59262 Metetra
.924 .305 0 r
.75906 .59262 .76845 .6046 .78965 .60004 .78036 .58796 Metetra
.929 .285 0 r
.78036 .58796 .78965 .60004 .81103 .59566 .80184 .58347 Metetra
.936 .261 0 r
.80184 .58347 .81103 .59566 .83262 .59145 .82353 .57915 Metetra
.943 .235 0 r
.82353 .57915 .83262 .59145 .85441 .58741 .84542 .57501 Metetra
.95 .206 0 r
.84542 .57501 .85441 .58741 .87638 .58331 .8675 .5708 Metetra
.952 .197 0 r
.8675 .5708 .87638 .58331 .89824 .57643 .88948 .56389 Metetra
.921 .314 0 r
.88948 .56389 .89824 .57643 .91848 .55418 .9099 .54187 Metetra
.79 .718 0 r
.9099 .54187 .91848 .55418 .93397 .4939 .92569 .48207 Metetra
.33 .655 0 r
.30631 .60803 .31748 .6175 .33098 .68467 .31966 .67477 Metetra
.864 .508 0 r
.31966 .67477 .33098 .68467 .34734 .71179 .336 .70144 Metetra
.939 .247 0 r
.336 .70144 .34734 .71179 .36533 .71273 .35405 .70218 Metetra
.949 .21 0 r
.35405 .70218 .36533 .71273 .38381 .70638 .3726 .69575 Metetra
.943 .234 0 r
.3726 .69575 .38381 .70638 .40242 .69918 .3913 .6885 Metetra
.936 .261 0 r
.3913 .6885 .40242 .69918 .42114 .69208 .4101 .68136 Metetra
.929 .286 0 r
.4101 .68136 .42114 .69208 .43996 .68516 .429 .67438 Metetra
.923 .308 0 r
.429 .67438 .43996 .68516 .4589 .67839 .44802 .66755 Metetra
.918 .326 0 r
.44802 .66755 .4589 .67839 .47795 .67178 .46716 .66087 Metetra
.914 .342 0 r
.46716 .66087 .47795 .67178 .49712 .6653 .48641 .65433 Metetra
.91 .355 0 r
.48641 .65433 .49712 .6653 .51641 .65895 .50579 .64792 Metetra
.907 .365 0 r
.50579 .64792 .51641 .65895 .53583 .65274 .52529 .64164 Metetra
.905 .374 0 r
.52529 .64164 .53583 .65274 .55538 .64665 .54493 .63549 Metetra
.903 .38 0 r
.54493 .63549 .55538 .64665 .57506 .64069 .56471 .62946 Metetra
.902 .383 0 r
.56471 .62946 .57506 .64069 .59489 .63485 .58462 .62354 Metetra
.901 .385 0 r
.58462 .62354 .59489 .63485 .61486 .62913 .60469 .61774 Metetra
.902 .385 0 r
.60469 .61774 .61486 .62913 .63497 .62353 .6249 .61207 Metetra
.902 .382 0 r
.6249 .61207 .63497 .62353 .65525 .61806 .64526 .60651 Metetra
.904 .377 0 r
.64526 .60651 .65525 .61806 .67567 .6127 .66578 .60107 Metetra
.906 .37 0 r
.66578 .60107 .67567 .6127 .69626 .60748 .68647 .59576 Metetra
.908 .361 0 r
.68647 .59576 .69626 .60748 .71702 .60238 .70732 .59057 Metetra
.912 .349 0 r
.70732 .59057 .71702 .60238 .73795 .59743 .72835 .58552 Metetra
.916 .335 0 r
.72835 .58552 .73795 .59743 .75906 .59262 .74956 .58062 Metetra
.92 .318 0 r
.74956 .58062 .75906 .59262 .78036 .58796 .77096 .57587 Metetra
.926 .298 0 r
.77096 .57587 .78036 .58796 .80184 .58347 .79255 .57128 Metetra
.932 .275 0 r
.79255 .57128 .80184 .58347 .82353 .57915 .81433 .56686 Metetra
.939 .249 0 r
.81433 .56686 .82353 .57915 .84542 .57501 .83633 .56261 Metetra
.946 .221 0 r
.83633 .56261 .84542 .57501 .8675 .5708 .85851 .55829 Metetra
.948 .212 0 r
.85851 .55829 .8675 .5708 .88948 .56389 .88061 .55134 Metetra
.918 .325 0 r
.88061 .55134 .88948 .56389 .9099 .54187 .90121 .52948 Metetra
.789 .721 0 r
.90121 .52948 .9099 .54187 .92569 .48207 .91729 .47007 Metetra
.33 .655 0 r
.295 .59839 .30631 .60803 .31966 .67477 .30819 .66478 Metetra
.863 .514 0 r
.30819 .66478 .31966 .67477 .336 .70144 .32451 .69109 Metetra
.936 .258 0 r
.32451 .69109 .336 .70144 .35405 .70218 .34262 .69165 Metetra
.946 .223 0 r
.34262 .69165 .35405 .70218 .3726 .69575 .36125 .68515 Metetra
.94 .246 0 r
.36125 .68515 .3726 .69575 .3913 .6885 .38003 .67784 Metetra
.932 .273 0 r
.38003 .67784 .3913 .6885 .4101 .68136 .39891 .67064 Metetra
.926 .298 0 r
.39891 .67064 .4101 .68136 .429 .67438 .4179 .6636 Metetra
.92 .319 0 r
.4179 .6636 .429 .67438 .44802 .66755 .43701 .65671 Metetra
.915 .337 0 r
.43701 .65671 .44802 .66755 .46716 .66087 .45623 .64997 Metetra
.911 .352 0 r
.45623 .64997 .46716 .66087 .48641 .65433 .47557 .64337 Metetra
.907 .365 0 r
.47557 .64337 .48641 .65433 .50579 .64792 .49503 .63688 Metetra
.904 .376 0 r
.49503 .63688 .50579 .64792 .52529 .64164 .51463 .63054 Metetra
.902 .384 0 r
.51463 .63054 .52529 .64164 .54493 .63549 .53436 .62431 Metetra
.9 .389 0 r
.53436 .62431 .54493 .63549 .56471 .62946 .55422 .6182 Metetra
.899 .393 0 r
.55422 .6182 .56471 .62946 .58462 .62354 .57423 .61221 Metetra
.899 .395 0 r
.57423 .61221 .58462 .62354 .60469 .61774 .59438 .60634 Metetra
.899 .394 0 r
.59438 .60634 .60469 .61774 .6249 .61207 .61469 .60058 Metetra
.899 .392 0 r
.61469 .60058 .6249 .61207 .64526 .60651 .63515 .59494 Metetra
.901 .387 0 r
.63515 .59494 .64526 .60651 .66578 .60107 .65577 .58942 Metetra
.903 .38 0 r
.65577 .58942 .66578 .60107 .68647 .59576 .67655 .58402 Metetra
.905 .371 0 r
.67655 .58402 .68647 .59576 .70732 .59057 .69751 .57874 Metetra
.909 .36 0 r
.69751 .57874 .70732 .59057 .72835 .58552 .71864 .5736 Metetra
.913 .346 0 r
.71864 .5736 .72835 .58552 .74956 .58062 .73995 .5686 Metetra
.917 .329 0 r
.73995 .5686 .74956 .58062 .77096 .57587 .76144 .56375 Metetra
.922 .31 0 r
.76144 .56375 .77096 .57587 .79255 .57128 .78313 .55906 Metetra
.929 .287 0 r
.78313 .55906 .79255 .57128 .81433 .56686 .80503 .55455 Metetra
.935 .262 0 r
.80503 .55455 .81433 .56686 .83633 .56261 .82713 .5502 Metetra
.943 .234 0 r
.82713 .5502 .83633 .56261 .85851 .55829 .84942 .54578 Metetra
.945 .225 0 r
.84942 .54578 .85851 .55829 .88061 .55134 .87164 .53877 Metetra
.916 .335 0 r
.87164 .53877 .88061 .55134 .90121 .52948 .89242 .51703 Metetra
.788 .724 0 r
.89242 .51703 .90121 .52948 .91729 .47007 .90878 .45789 Metetra
.33 .655 0 r
.28355 .58857 .295 .59839 .30819 .66478 .29657 .65472 Metetra
.861 .519 0 r
.29657 .65472 .30819 .66478 .32451 .69109 .31287 .68073 Metetra
.934 .268 0 r
.31287 .68073 .32451 .69109 .34262 .69165 .33104 .68114 Metetra
.943 .234 0 r
.33104 .68114 .34262 .69165 .36125 .68515 .34975 .67456 Metetra
.937 .257 0 r
.34975 .67456 .36125 .68515 .38003 .67784 .36861 .66719 Metetra
.93 .283 0 r
.36861 .66719 .38003 .67784 .39891 .67064 .38758 .65993 Metetra
.923 .307 0 r
.38758 .65993 .39891 .67064 .4179 .6636 .40666 .65282 Metetra
.918 .328 0 r
.40666 .65282 .4179 .6636 .43701 .65671 .42585 .64587 Metetra
.913 .346 0 r
.42585 .64587 .43701 .65671 .45623 .64997 .44516 .63906 Metetra
.908 .361 0 r
.44516 .63906 .45623 .64997 .47557 .64337 .46458 .63239 Metetra
.905 .374 0 r
.46458 .63239 .47557 .64337 .49503 .63688 .48414 .62583 Metetra
.902 .384 0 r
.48414 .62583 .49503 .63688 .51463 .63054 .50382 .61941 Metetra
.899 .392 0 r
.50382 .61941 .51463 .63054 .53436 .62431 .52364 .61311 Metetra
.898 .398 0 r
.52364 .61311 .53436 .62431 .55422 .6182 .5436 .60693 Metetra
.897 .401 0 r
.5436 .60693 .55422 .6182 .57423 .61221 .5637 .60086 Metetra
.896 .403 0 r
.5637 .60086 .57423 .61221 .59438 .60634 .58395 .5949 Metetra
.896 .402 0 r
.58395 .5949 .59438 .60634 .61469 .60058 .60435 .58907 Metetra
.897 .4 0 r
.60435 .58907 .61469 .60058 .63515 .59494 .62491 .58334 Metetra
.898 .395 0 r
.62491 .58334 .63515 .59494 .65577 .58942 .64563 .57773 Metetra
.9 .388 0 r
.64563 .57773 .65577 .58942 .67655 .58402 .66651 .57225 Metetra
.903 .38 0 r
.66651 .57225 .67655 .58402 .69751 .57874 .68756 .56689 Metetra
.906 .368 0 r
.68756 .56689 .69751 .57874 .71864 .5736 .70879 .56166 Metetra
.91 .355 0 r
.70879 .56166 .71864 .5736 .73995 .5686 .73021 .55656 Metetra
.915 .338 0 r
.73021 .55656 .73995 .5686 .76144 .56375 .75181 .55162 Metetra
.92 .319 0 r
.75181 .55162 .76144 .56375 .78313 .55906 .77361 .54683 Metetra
.926 .297 0 r
.77361 .54683 .78313 .55906 .80503 .55455 .79561 .54222 Metetra
.933 .272 0 r
.79561 .54222 .80503 .55455 .82713 .5502 .81782 .53776 Metetra
.94 .245 0 r
.81782 .53776 .82713 .5502 .84942 .54578 .84022 .53325 Metetra
.942 .235 0 r
.84022 .53325 .84942 .54578 .87164 .53877 .86257 .52617 Metetra
.913 .343 0 r
.86257 .52617 .87164 .53877 .89242 .51703 .88351 .5045 Metetra
.787 .726 0 r
.88351 .5045 .89242 .51703 .90878 .45789 .90014 .44554 Metetra
.33 .655 0 r
.27196 .57858 .28355 .58857 .29657 .65472 .2848 .64457 Metetra
.86 .523 0 r
.2848 .64457 .29657 .65472 .31287 .68073 .30108 .67035 Metetra
.932 .276 0 r
.30108 .67035 .31287 .68073 .33104 .68114 .31931 .67063 Metetra
.941 .242 0 r
.31931 .67063 .33104 .68114 .34975 .67456 .3381 .66398 Metetra
.935 .265 0 r
.3381 .66398 .34975 .67456 .36861 .66719 .35705 .65655 Metetra
.928 .291 0 r
.35705 .65655 .36861 .66719 .38758 .65993 .3761 .64921 Metetra
.921 .315 0 r
.3761 .64921 .38758 .65993 .40666 .65282 .39527 .64204 Metetra
.915 .335 0 r
.39527 .64204 .40666 .65282 .42585 .64587 .41454 .63502 Metetra
.911 .353 0 r
.41454 .63502 .42585 .64587 .44516 .63906 .43394 .62814 Metetra
.906 .368 0 r
.43394 .62814 .44516 .63906 .46458 .63239 .45346 .62139 Metetra
.903 .38 0 r
.45346 .62139 .46458 .63239 .48414 .62583 .4731 .61476 Metetra
.9 .39 0 r
.4731 .61476 .48414 .62583 .50382 .61941 .49288 .60827 Metetra
.898 .398 0 r
.49288 .60827 .50382 .61941 .52364 .61311 .51279 .60189 Metetra
.896 .404 0 r
.51279 .60189 .52364 .61311 .5436 .60693 .53284 .59563 Metetra
.895 .408 0 r
.53284 .59563 .5436 .60693 .5637 .60086 .55304 .58948 Metetra
.894 .409 0 r
.55304 .58948 .5637 .60086 .58395 .5949 .57338 .58344 Metetra
.895 .409 0 r
.57338 .58344 .58395 .5949 .60435 .58907 .59388 .57752 Metetra
.895 .406 0 r
.59388 .57752 .60435 .58907 .62491 .58334 .61453 .57171 Metetra
.897 .402 0 r
.61453 .57171 .62491 .58334 .64563 .57773 .63535 .56602 Metetra
.899 .395 0 r
.63535 .56602 .64563 .57773 .66651 .57225 .65633 .56045 Metetra
.901 .386 0 r
.65633 .56045 .66651 .57225 .68756 .56689 .67749 .555 Metetra
.904 .375 0 r
.67749 .555 .68756 .56689 .70879 .56166 .69883 .54968 Metetra
.908 .362 0 r
.69883 .54968 .70879 .56166 .73021 .55656 .72034 .54449 Metetra
.913 .345 0 r
.72034 .54449 .73021 .55656 .75181 .55162 .74205 .53945 Metetra
.918 .327 0 r
.74205 .53945 .75181 .55162 .77361 .54683 .76396 .53457 Metetra
.924 .305 0 r
.76396 .53457 .77361 .54683 .79561 .54222 .78607 .52986 Metetra
.931 .28 0 r
.78607 .52986 .79561 .54222 .81782 .53776 .80839 .52531 Metetra
.938 .253 0 r
.80839 .52531 .81782 .53776 .84022 .53325 .8309 .52069 Metetra
.94 .244 0 r
.8309 .52069 .84022 .53325 .86257 .52617 .85338 .51355 Metetra
.912 .349 0 r
.85338 .51355 .86257 .52617 .88351 .5045 .87449 .49189 Metetra
.787 .728 0 r
.87449 .49189 .88351 .5045 .90014 .44554 .89138 .43301 Metetra
.331 .655 0 r
.26023 .56841 .27196 .57858 .2848 .64457 .27288 .63433 Metetra
.859 .526 0 r
.27288 .63433 .2848 .64457 .30108 .67035 .28913 .65996 Metetra
.93 .281 0 r
.28913 .65996 .30108 .67035 .31931 .67063 .30742 .66013 Metetra
.939 .249 0 r
.30742 .66013 .31931 .67063 .3381 .66398 .32629 .6534 Metetra
.933 .271 0 r
.32629 .6534 .3381 .66398 .35705 .65655 .34532 .64589 Metetra
.926 .297 0 r
.34532 .64589 .35705 .65655 .3761 .64921 .36447 .63849 Metetra
.92 .321 0 r
.36447 .63849 .3761 .64921 .39527 .64204 .38372 .63124 Metetra
.914 .341 0 r
.38372 .63124 .39527 .64204 .41454 .63502 .40308 .62415 Metetra
.909 .358 0 r
.40308 .62415 .41454 .63502 .43394 .62814 .42257 .6172 Metetra
.905 .373 0 r
.42257 .6172 .43394 .62814 .45346 .62139 .44218 .61038 Metetra
.901 .385 0 r
.44218 .61038 .45346 .62139 .4731 .61476 .46192 .60367 Metetra
.898 .395 0 r
.46192 .60367 .4731 .61476 .49288 .60827 .48178 .5971 Metetra
.896 .403 0 r
.48178 .5971 .49288 .60827 .51279 .60189 .50179 .59064 Metetra
.895 .409 0 r
.50179 .59064 .51279 .60189 .53284 .59563 .52194 .5843 Metetra
.893 .412 0 r
.52194 .5843 .53284 .59563 .55304 .58948 .54223 .57806 Metetra
.893 .414 0 r
.54223 .57806 .55304 .58948 .57338 .58344 .56267 .57195 Metetra
.893 .414 0 r
.56267 .57195 .57338 .58344 .59388 .57752 .58327 .56594 Metetra
.894 .411 0 r
.58327 .56594 .59388 .57752 .61453 .57171 .60402 .56005 Metetra
.895 .407 0 r
.60402 .56005 .61453 .57171 .63535 .56602 .62494 .55427 Metetra
.897 .4 0 r
.62494 .55427 .63535 .56602 .65633 .56045 .64603 .54861 Metetra
.9 .391 0 r
.64603 .54861 .65633 .56045 .67749 .555 .66729 .54307 Metetra
.903 .38 0 r
.66729 .54307 .67749 .555 .69883 .54968 .68873 .53766 Metetra
.907 .367 0 r
.68873 .53766 .69883 .54968 .72034 .54449 .71035 .53238 Metetra
.911 .351 0 r
.71035 .53238 .72034 .54449 .74205 .53945 .73217 .52725 Metetra
.916 .332 0 r
.73217 .52725 .74205 .53945 .76396 .53457 .75418 .52227 Metetra
.922 .311 0 r
.75418 .52227 .76396 .53457 .78607 .52986 .77641 .51746 Metetra
.929 .286 0 r
.77641 .51746 .78607 .52986 .80839 .52531 .79884 .51282 Metetra
.936 .259 0 r
.79884 .51282 .80839 .52531 .8309 .52069 .82147 .5081 Metetra
.939 .25 0 r
.82147 .5081 .8309 .52069 .85338 .51355 .84407 .50088 Metetra
.91 .354 0 r
.84407 .50088 .85338 .51355 .87449 .49189 .86535 .47919 Metetra
.786 .729 0 r
.86535 .47919 .87449 .49189 .89138 .43301 .8825 .4203 Metetra
.331 .655 0 r
.24835 .55807 .26023 .56841 .27288 .63433 .2608 .624 Metetra
.858 .528 0 r
.2608 .624 .27288 .63433 .28913 .65996 .27701 .64955 Metetra
.929 .285 0 r
.27701 .64955 .28913 .65996 .30742 .66013 .29536 .64963 Metetra
.938 .253 0 r
.29536 .64963 .30742 .66013 .32629 .6534 .31432 .64282 Metetra
.932 .275 0 r
.31432 .64282 .32629 .6534 .34532 .64589 .33344 .63524 Metetra
.925 .301 0 r
.33344 .63524 .34532 .64589 .36447 .63849 .35267 .62776 Metetra
.918 .324 0 r
.35267 .62776 .36447 .63849 .38372 .63124 .37201 .62044 Metetra
.913 .345 0 r
.37201 .62044 .38372 .63124 .40308 .62415 .39147 .61327 Metetra
.908 .362 0 r
.39147 .61327 .40308 .62415 .42257 .6172 .41105 .60623 Metetra
.904 .377 0 r
.41105 .60623 .42257 .6172 .44218 .61038 .43075 .59933 Metetra
.9 .389 0 r
.43075 .59933 .44218 .61038 .46192 .60367 .45058 .59255 Metetra
.897 .399 0 r
.45058 .59255 .46192 .60367 .48178 .5971 .47054 .58589 Metetra
.895 .407 0 r
.47054 .58589 .48178 .5971 .50179 .59064 .49064 .57935 Metetra
.894 .412 0 r
.49064 .57935 .50179 .59064 .52194 .5843 .51089 .57293 Metetra
.892 .416 0 r
.51089 .57293 .52194 .5843 .54223 .57806 .53127 .56661 Metetra
.892 .417 0 r
.53127 .56661 .54223 .57806 .56267 .57195 .55182 .56041 Metetra
.892 .417 0 r
.55182 .56041 .56267 .57195 .58327 .56594 .57251 .55432 Metetra
.893 .414 0 r
.57251 .55432 .58327 .56594 .60402 .56005 .59337 .54834 Metetra
.894 .41 0 r
.59337 .54834 .60402 .56005 .62494 .55427 .61439 .54248 Metetra
.896 .403 0 r
.61439 .54248 .62494 .55427 .64603 .54861 .63558 .53673 Metetra
.899 .395 0 r
.63558 .53673 .64603 .54861 .66729 .54307 .65695 .5311 Metetra
.902 .384 0 r
.65695 .5311 .66729 .54307 .68873 .53766 .67849 .5256 Metetra
.906 .37 0 r
.67849 .5256 .68873 .53766 .71035 .53238 .70023 .52023 Metetra
.91 .355 0 r
.70023 .52023 .71035 .53238 .73217 .52725 .72216 .51501 Metetra
.915 .336 0 r
.72216 .51501 .73217 .52725 .75418 .52227 .74428 .50993 Metetra
.921 .315 0 r
.74428 .50993 .75418 .52227 .77641 .51746 .76662 .50503 Metetra
.928 .29 0 r
.76662 .50503 .77641 .51746 .79884 .51282 .78917 .50029 Metetra
.935 .264 0 r
.78917 .50029 .79884 .51282 .82147 .5081 .81192 .49548 Metetra
.937 .254 0 r
.81192 .49548 .82147 .5081 .84407 .50088 .83464 .48817 Metetra
.909 .357 0 r
.83464 .48817 .84407 .50088 .86535 .47919 .85609 .46641 Metetra
.786 .73 0 r
.85609 .46641 .86535 .47919 .8825 .4203 .87349 .40741 Metetra
.331 .655 0 r
.23632 .54755 .24835 .55807 .2608 .624 .24856 .61358 Metetra
.858 .529 0 r
.24856 .61358 .2608 .624 .27701 .64955 .26473 .63911 Metetra
.929 .287 0 r
.26473 .63911 .27701 .64955 .29536 .64963 .28313 .63913 Metetra
.937 .255 0 r
.28313 .63913 .29536 .64963 .31432 .64282 .30218 .63224 Metetra
.931 .278 0 r
.30218 .63224 .31432 .64282 .33344 .63524 .32139 .62458 Metetra
.924 .304 0 r
.32139 .62458 .33344 .63524 .35267 .62776 .34071 .61701 Metetra
.918 .327 0 r
.34071 .61701 .35267 .62776 .37201 .62044 .36015 .60961 Metetra
.912 .347 0 r
.36015 .60961 .37201 .62044 .39147 .61327 .3797 .60236 Metetra
.907 .364 0 r
.3797 .60236 .39147 .61327 .41105 .60623 .39936 .59524 Metetra
.903 .379 0 r
.39936 .59524 .41105 .60623 .43075 .59933 .41916 .58826 Metetra
.9 .391 0 r
.41916 .58826 .43075 .59933 .45058 .59255 .43908 .58139 Metetra
.897 .401 0 r
.43908 .58139 .45058 .59255 .47054 .58589 .45914 .57465 Metetra
.895 .408 0 r
.45914 .57465 .47054 .58589 .49064 .57935 .47934 .56803 Metetra
.893 .414 0 r
.47934 .56803 .49064 .57935 .51089 .57293 .49968 .56152 Metetra
.892 .418 0 r
.49968 .56152 .51089 .57293 .53127 .56661 .52017 .55512 Metetra
.892 .419 0 r
.52017 .55512 .53127 .56661 .55182 .56041 .54081 .54883 Metetra
.892 .419 0 r
.54081 .54883 .55182 .56041 .57251 .55432 .56161 .54266 Metetra
.892 .416 0 r
.56161 .54266 .57251 .55432 .59337 .54834 .58257 .53659 Metetra
.894 .412 0 r
.58257 .53659 .59337 .54834 .61439 .54248 .60369 .53064 Metetra
.896 .405 0 r
.60369 .53064 .61439 .54248 .63558 .53673 .62499 .5248 Metetra
.898 .397 0 r
.62499 .5248 .63558 .53673 .65695 .5311 .64647 .51908 Metetra
.901 .386 0 r
.64647 .51908 .65695 .5311 .67849 .5256 .66812 .51349 Metetra
.905 .372 0 r
.66812 .51349 .67849 .5256 .70023 .52023 .68997 .50804 Metetra
.91 .357 0 r
.68997 .50804 .70023 .52023 .72216 .51501 .71201 .50272 Metetra
.915 .338 0 r
.71201 .50272 .72216 .51501 .74428 .50993 .73425 .49755 Metetra
.921 .317 0 r
.73425 .49755 .74428 .50993 .76662 .50503 .7567 .49256 Metetra
.927 .292 0 r
.7567 .49256 .76662 .50503 .78917 .50029 .77937 .48772 Metetra
.934 .266 0 r
.77937 .48772 .78917 .50029 .81192 .49548 .80224 .48282 Metetra
.937 .257 0 r
.80224 .48282 .81192 .49548 .83464 .48817 .82509 .47542 Metetra
.909 .359 0 r
.82509 .47542 .83464 .48817 .85609 .46641 .8467 .45353 Metetra
.785 .73 0 r
.8467 .45353 .85609 .46641 .87349 .40741 .86435 .39433 Metetra
.331 .655 0 r
.22415 .53684 .23632 .54755 .24856 .61358 .23616 .60306 Metetra
.858 .529 0 r
.23616 .60306 .24856 .61358 .26473 .63911 .25227 .62865 Metetra
.928 .288 0 r
.25227 .62865 .26473 .63911 .28313 .63913 .27074 .62862 Metetra
.937 .256 0 r
.27074 .62862 .28313 .63913 .30218 .63224 .28987 .62165 Metetra
.931 .278 0 r
.28987 .62165 .30218 .63224 .32139 .62458 .30917 .6139 Metetra
.924 .304 0 r
.30917 .6139 .32139 .62458 .34071 .61701 .32859 .60625 Metetra
.918 .327 0 r
.32859 .60625 .34071 .61701 .36015 .60961 .34811 .59877 Metetra
.912 .347 0 r
.34811 .59877 .36015 .60961 .3797 .60236 .36776 .59143 Metetra
.907 .364 0 r
.36776 .59143 .3797 .60236 .39936 .59524 .38752 .58423 Metetra
.903 .379 0 r
.38752 .58423 .39936 .59524 .41916 .58826 .40741 .57716 Metetra
.9 .391 0 r
.40741 .57716 .41916 .58826 .43908 .58139 .42743 .5702 Metetra
.897 .401 0 r
.42743 .5702 .43908 .58139 .45914 .57465 .44759 .56338 Metetra
.895 .409 0 r
.44759 .56338 .45914 .57465 .47934 .56803 .46788 .55667 Metetra
.893 .414 0 r
.46788 .55667 .47934 .56803 .49968 .56152 .48832 .55007 Metetra
.892 .418 0 r
.48832 .55007 .49968 .56152 .52017 .55512 .50891 .54359 Metetra
.891 .419 0 r
.50891 .54359 .52017 .55512 .54081 .54883 .52965 .53721 Metetra
.892 .419 0 r
.52965 .53721 .54081 .54883 .56161 .54266 .55056 .53095 Metetra
.892 .417 0 r
.55056 .53095 .56161 .54266 .58257 .53659 .57162 .52479 Metetra
.894 .412 0 r
.57162 .52479 .58257 .53659 .60369 .53064 .59285 .51875 Metetra
.895 .406 0 r
.59285 .51875 .60369 .53064 .62499 .5248 .61426 .51282 Metetra
.898 .397 0 r
.61426 .51282 .62499 .5248 .64647 .51908 .63584 .50702 Metetra
.901 .386 0 r
.63584 .50702 .64647 .51908 .66812 .51349 .65761 .50134 Metetra
.905 .373 0 r
.65761 .50134 .66812 .51349 .68997 .50804 .67956 .49579 Metetra
.909 .357 0 r
.67956 .49579 .68997 .50804 .71201 .50272 .70172 .49038 Metetra
.915 .339 0 r
.70172 .49038 .71201 .50272 .73425 .49755 .72408 .48513 Metetra
.92 .317 0 r
.72408 .48513 .73425 .49755 .7567 .49256 .74665 .48004 Metetra
.927 .293 0 r
.74665 .48004 .7567 .49256 .77937 .48772 .76943 .47512 Metetra
.934 .266 0 r
.76943 .47512 .77937 .48772 .80224 .48282 .79243 .47012 Metetra
.937 .257 0 r
.79243 .47012 .80224 .48282 .82509 .47542 .81541 .46261 Metetra
.909 .36 0 r
.81541 .46261 .82509 .47542 .8467 .45353 .83719 .44056 Metetra
.785 .73 0 r
.83719 .44056 .8467 .45353 .86435 .39433 .85508 .38106 Metetra
.331 .655 0 r
.21182 .52595 .22415 .53684 .23616 .60306 .22359 .59245 Metetra
.858 .528 0 r
.22359 .59245 .23616 .60306 .25227 .62865 .23964 .61817 Metetra
.929 .286 0 r
.23964 .61817 .25227 .62865 .27074 .62862 .25816 .6181 Metetra
.937 .254 0 r
.25816 .6181 .27074 .62862 .28987 .62165 .27738 .61105 Metetra
.931 .277 0 r
.27738 .61105 .28987 .62165 .30917 .6139 .29678 .60321 Metetra
.924 .303 0 r
.29678 .60321 .30917 .6139 .32859 .60625 .31629 .59548 Metetra
.918 .326 0 r
.31629 .59548 .32859 .60625 .34811 .59877 .33591 .5879 Metetra
.913 .346 0 r
.33591 .5879 .34811 .59877 .36776 .59143 .35565 .58047 Metetra
.908 .363 0 r
.35565 .58047 .36776 .59143 .38752 .58423 .37551 .57318 Metetra
.904 .378 0 r
.37551 .57318 .38752 .58423 .40741 .57716 .39549 .56603 Metetra
.9 .39 0 r
.39549 .56603 .40741 .57716 .42743 .5702 .41561 .55898 Metetra
.897 .4 0 r
.41561 .55898 .42743 .5702 .44759 .56338 .43587 .55207 Metetra
.895 .408 0 r
.43587 .55207 .44759 .56338 .46788 .55667 .45626 .54527 Metetra
.893 .413 0 r
.45626 .54527 .46788 .55667 .48832 .55007 .4768 .53858 Metetra
.892 .417 0 r
.4768 .53858 .48832 .55007 .50891 .54359 .49749 .53201 Metetra
.892 .418 0 r
.49749 .53201 .50891 .54359 .52965 .53721 .51834 .52554 Metetra
.892 .418 0 r
.51834 .52554 .52965 .53721 .55056 .53095 .53935 .51919 Metetra
.893 .415 0 r
.53935 .51919 .55056 .53095 .57162 .52479 .56052 .51295 Metetra
.894 .411 0 r
.56052 .51295 .57162 .52479 .59285 .51875 .58186 .50681 Metetra
.896 .404 0 r
.58186 .50681 .59285 .51875 .61426 .51282 .60337 .5008 Metetra
.898 .396 0 r
.60337 .5008 .61426 .51282 .63584 .50702 .62506 .4949 Metetra
.902 .385 0 r
.62506 .4949 .63584 .50702 .65761 .50134 .64694 .48913 Metetra
.905 .372 0 r
.64694 .48913 .65761 .50134 .67956 .49579 .66902 .4835 Metetra
.91 .356 0 r
.66902 .4835 .67956 .49579 .70172 .49038 .69129 .478 Metetra
.915 .337 0 r
.69129 .478 .70172 .49038 .72408 .48513 .71376 .47265 Metetra
.921 .316 0 r
.71376 .47265 .72408 .48513 .74665 .48004 .73645 .46748 Metetra
.928 .291 0 r
.73645 .46748 .74665 .48004 .76943 .47512 .75936 .46246 Metetra
.935 .265 0 r
.75936 .46246 .76943 .47512 .79243 .47012 .78248 .45738 Metetra
.937 .255 0 r
.78248 .45738 .79243 .47012 .81541 .46261 .8056 .44975 Metetra
.909 .358 0 r
.8056 .44975 .81541 .46261 .83719 .44056 .82754 .42749 Metetra
.786 .73 0 r
.82754 .42749 .83719 .44056 .85508 .38106 .84567 .36759 Metetra
.331 .655 0 r
.19934 .51488 .21182 .52595 .22359 .59245 .21085 .58175 Metetra
.858 .527 0 r
.21085 .58175 .22359 .59245 .23964 .61817 .22683 .60766 Metetra
.93 .283 0 r
.22683 .60766 .23964 .61817 .25816 .6181 .2454 .60758 Metetra
.938 .251 0 r
.2454 .60758 .25816 .6181 .27738 .61105 .26471 .60045 Metetra
.932 .273 0 r
.26471 .60045 .27738 .61105 .29678 .60321 .28421 .59251 Metetra
.925 .299 0 r
.28421 .59251 .29678 .60321 .31629 .59548 .30381 .58468 Metetra
.919 .323 0 r
.30381 .58468 .31629 .59548 .33591 .5879 .32353 .57701 Metetra
.913 .343 0 r
.32353 .57701 .33591 .5879 .35565 .58047 .34336 .56949 Metetra
.909 .36 0 r
.34336 .56949 .35565 .58047 .37551 .57318 .36332 .56211 Metetra
.904 .375 0 r
.36332 .56211 .37551 .57318 .39549 .56603 .3834 .55486 Metetra
.901 .387 0 r
.3834 .55486 .39549 .56603 .41561 .55898 .40362 .54772 Metetra
.898 .397 0 r
.40362 .54772 .41561 .55898 .43587 .55207 .42398 .54072 Metetra
.896 .405 0 r
.42398 .54072 .43587 .55207 .45626 .54527 .44447 .53383 Metetra
.894 .411 0 r
.44447 .53383 .45626 .54527 .4768 .53858 .46512 .52705 Metetra
.893 .414 0 r
.46512 .52705 .4768 .53858 .49749 .53201 .48591 .52038 Metetra
.893 .416 0 r
.48591 .52038 .49749 .53201 .51834 .52554 .50686 .51383 Metetra
.893 .415 0 r
.50686 .51383 .51834 .52554 .53935 .51919 .52798 .50738 Metetra
.893 .413 0 r
.52798 .50738 .53935 .51919 .56052 .51295 .54925 .50105 Metetra
.895 .408 0 r
.54925 .50105 .56052 .51295 .58186 .50681 .5707 .49483 Metetra
.897 .402 0 r
.5707 .49483 .58186 .50681 .60337 .5008 .59233 .48872 Metetra
.899 .393 0 r
.59233 .48872 .60337 .5008 .62506 .4949 .61414 .48274 Metetra
.902 .382 0 r
.61414 .48274 .62506 .4949 .64694 .48913 .63613 .47688 Metetra
.906 .369 0 r
.63613 .47688 .64694 .48913 .66902 .4835 .65832 .47115 Metetra
.911 .353 0 r
.65832 .47115 .66902 .4835 .69129 .478 .68071 .46556 Metetra
.916 .334 0 r
.68071 .46556 .69129 .478 .71376 .47265 .70331 .46013 Metetra
.922 .313 0 r
.70331 .46013 .71376 .47265 .73645 .46748 .72612 .45486 Metetra
.928 .288 0 r
.72612 .45486 .73645 .46748 .75936 .46246 .74915 .44976 Metetra
.935 .262 0 r
.74915 .44976 .75936 .46246 .78248 .45738 .7724 .44459 Metetra
.938 .252 0 r
.7724 .44459 .78248 .45738 .8056 .44975 .79565 .43684 Metetra
.91 .356 0 r
.79565 .43684 .8056 .44975 .82754 .42749 .81776 .41432 Metetra
.786 .729 0 r
.81776 .41432 .82754 .42749 .84567 .36759 .83612 .35393 Metetra
.33 .655 0 r
.1867 .50361 .19934 .51488 .21085 .58175 .19794 .57094 Metetra
.859 .524 0 r
.19794 .57094 .21085 .58175 .22683 .60766 .21383 .59712 Metetra
.931 .278 0 r
.21383 .59712 .22683 .60766 .2454 .60758 .23246 .59706 Metetra
.94 .245 0 r
.23246 .59706 .2454 .60758 .26471 .60045 .25186 .58984 Metetra
.934 .268 0 r
.25186 .58984 .26471 .60045 .28421 .59251 .27145 .5818 Metetra
.927 .294 0 r
.27145 .5818 .28421 .59251 .30381 .58468 .29115 .57387 Metetra
.92 .318 0 r
.29115 .57387 .30381 .58468 .32353 .57701 .31097 .5661 Metetra
.915 .338 0 r
.31097 .5661 .32353 .57701 .34336 .56949 .3309 .55848 Metetra
.91 .356 0 r
.3309 .55848 .34336 .56949 .36332 .56211 .35095 .55101 Metetra
.906 .37 0 r
.35095 .55101 .36332 .56211 .3834 .55486 .37114 .54366 Metetra
.902 .383 0 r
.37114 .54366 .3834 .55486 .40362 .54772 .39146 .53643 Metetra
.899 .393 0 r
.39146 .53643 .40362 .54772 .42398 .54072 .41192 .52933 Metetra
.897 .401 0 r
.41192 .52933 .42398 .54072 .44447 .53383 .43251 .52234 Metetra
.895 .406 0 r
.43251 .52234 .44447 .53383 .46512 .52705 .45326 .51547 Metetra
.894 .41 0 r
.45326 .51547 .46512 .52705 .48591 .52038 .47416 .50871 Metetra
.894 .412 0 r
.47416 .50871 .48591 .52038 .50686 .51383 .49522 .50206 Metetra
.894 .411 0 r
.49522 .50206 .50686 .51383 .52798 .50738 .51644 .49553 Metetra
.895 .409 0 r
.51644 .49553 .52798 .50738 .54925 .50105 .53783 .4891 Metetra
.896 .404 0 r
.53783 .4891 .54925 .50105 .5707 .49483 .55939 .48279 Metetra
.898 .397 0 r
.55939 .48279 .5707 .49483 .59233 .48872 .58113 .47659 Metetra
.9 .389 0 r
.58113 .47659 .59233 .48872 .61414 .48274 .60305 .47051 Metetra
.904 .378 0 r
.60305 .47051 .61414 .48274 .63613 .47688 .62516 .46456 Metetra
.907 .364 0 r
.62516 .46456 .63613 .47688 .65832 .47115 .64747 .45875 Metetra
.912 .348 0 r
.64747 .45875 .65832 .47115 .68071 .46556 .66998 .45307 Metetra
.917 .329 0 r
.66998 .45307 .68071 .46556 .70331 .46013 .6927 .44755 Metetra
.923 .308 0 r
.6927 .44755 .70331 .46013 .72612 .45486 .71564 .4422 Metetra
.93 .283 0 r
.71564 .4422 .72612 .45486 .74915 .44976 .7388 .43701 Metetra
.937 .256 0 r
.7388 .43701 .74915 .44976 .7724 .44459 .76217 .43175 Metetra
.939 .247 0 r
.76217 .43175 .7724 .44459 .79565 .43684 .78557 .42387 Metetra
.911 .352 0 r
.78557 .42387 .79565 .43684 .81776 .41432 .80783 .40104 Metetra
.786 .728 0 r
.80783 .40104 .81776 .41432 .83612 .35393 .82643 .34006 Metetra
.33 .655 0 r
.1739 .49214 .1867 .50361 .19794 .57094 .18484 .56003 Metetra
.86 .521 0 r
.18484 .56003 .19794 .57094 .21383 .59712 .20064 .58656 Metetra
.933 .272 0 r
.20064 .58656 .21383 .59712 .23246 .59706 .21932 .58653 Metetra
.942 .238 0 r
.21932 .58653 .23246 .59706 .25186 .58984 .23881 .57923 Metetra
.936 .261 0 r
.23881 .57923 .25186 .58984 .27145 .5818 .2585 .57108 Metetra
.929 .287 0 r
.2585 .57108 .27145 .5818 .29115 .57387 .2783 .56305 Metetra
.922 .311 0 r
.2783 .56305 .29115 .57387 .31097 .5661 .29822 .55517 Metetra
.917 .332 0 r
.29822 .55517 .31097 .5661 .3309 .55848 .31825 .54745 Metetra
.912 .349 0 r
.31825 .54745 .3309 .55848 .35095 .55101 .33841 .53987 Metetra
.907 .364 0 r
.33841 .53987 .35095 .55101 .37114 .54366 .35869 .53242 Metetra
.904 .377 0 r
.35869 .53242 .37114 .54366 .39146 .53643 .37911 .52509 Metetra
.901 .387 0 r
.37911 .52509 .39146 .53643 .41192 .52933 .39967 .5179 Metetra
.899 .395 0 r
.39967 .5179 .41192 .52933 .43251 .52234 .42038 .51082 Metetra
.897 .401 0 r
.42038 .51082 .43251 .52234 .45326 .51547 .44123 .50385 Metetra
.896 .404 0 r
.44123 .50385 .45326 .51547 .47416 .50871 .46224 .49699 Metetra
.895 .406 0 r
.46224 .49699 .47416 .50871 .49522 .50206 .48341 .49025 Metetra
.896 .405 0 r
.48341 .49025 .49522 .50206 .51644 .49553 .50474 .48362 Metetra
.896 .403 0 r
.50474 .48362 .51644 .49553 .53783 .4891 .52624 .4771 Metetra
.898 .398 0 r
.52624 .4771 .53783 .4891 .55939 .48279 .54791 .47069 Metetra
.9 .392 0 r
.54791 .47069 .55939 .48279 .58113 .47659 .56976 .46441 Metetra
.902 .383 0 r
.56976 .46441 .58113 .47659 .60305 .47051 .5918 .45824 Metetra
.905 .372 0 r
.5918 .45824 .60305 .47051 .62516 .46456 .61403 .4522 Metetra
.909 .358 0 r
.61403 .4522 .62516 .46456 .64747 .45875 .63646 .44629 Metetra
.914 .342 0 r
.63646 .44629 .64747 .45875 .66998 .45307 .65909 .44053 Metetra
.919 .323 0 r
.65909 .44053 .66998 .45307 .6927 .44755 .68194 .43492 Metetra
.925 .301 0 r
.68194 .43492 .6927 .44755 .71564 .4422 .705 .42949 Metetra
.932 .276 0 r
.705 .42949 .71564 .4422 .7388 .43701 .72829 .42422 Metetra
.939 .249 0 r
.72829 .42422 .7388 .43701 .76217 .43175 .7518 .41886 Metetra
.941 .239 0 r
.7518 .41886 .76217 .43175 .78557 .42387 .77533 .41084 Metetra
.912 .346 0 r
.77533 .41084 .78557 .42387 .80783 .40104 .79776 .38766 Metetra
.787 .727 0 r
.79776 .38766 .80783 .40104 .82643 .34006 .81659 .32598 Metetra
.33 .655 0 r
.16094 .48046 .1739 .49214 .18484 .56003 .17156 .549 Metetra
.862 .516 0 r
.17156 .549 .18484 .56003 .20064 .58656 .18726 .57596 Metetra
.935 .263 0 r
.18726 .57596 .20064 .58656 .21932 .58653 .20598 .576 Metetra
.944 .228 0 r
.20598 .576 .21932 .58653 .23881 .57923 .22557 .56861 Metetra
.938 .251 0 r
.22557 .56861 .23881 .57923 .2585 .57108 .24536 .56036 Metetra
.931 .278 0 r
.24536 .56036 .2585 .57108 .2783 .56305 .26526 .55222 Metetra
.925 .302 0 r
.26526 .55222 .2783 .56305 .29822 .55517 .28527 .54424 Metetra
.919 .323 0 r
.28527 .54424 .29822 .55517 .31825 .54745 .30541 .53641 Metetra
.914 .341 0 r
.30541 .53641 .31825 .54745 .33841 .53987 .32567 .52872 Metetra
.91 .356 0 r
.32567 .52872 .33841 .53987 .35869 .53242 .34606 .52117 Metetra
.906 .369 0 r
.34606 .52117 .35869 .53242 .37911 .52509 .36659 .51374 Metetra
.903 .379 0 r
.36659 .51374 .37911 .52509 .39967 .5179 .38725 .50644 Metetra
.901 .387 0 r
.38725 .50644 .39967 .5179 .42038 .51082 .40806 .49926 Metetra
.899 .393 0 r
.40806 .49926 .42038 .51082 .44123 .50385 .42902 .49219 Metetra
.898 .397 0 r
.42902 .49219 .44123 .50385 .46224 .49699 .45014 .48524 Metetra
.898 .399 0 r
.45014 .48524 .46224 .49699 .48341 .49025 .47141 .4784 Metetra
.898 .398 0 r
.47141 .4784 .48341 .49025 .50474 .48362 .49286 .47167 Metetra
.898 .396 0 r
.49286 .47167 .50474 .48362 .52624 .4771 .51447 .46506 Metetra
.9 .391 0 r
.51447 .46506 .52624 .4771 .54791 .47069 .53626 .45856 Metetra
.902 .384 0 r
.53626 .45856 .54791 .47069 .56976 .46441 .55823 .45218 Metetra
.904 .375 0 r
.55823 .45218 .56976 .46441 .5918 .45824 .58038 .44592 Metetra
.908 .364 0 r
.58038 .44592 .5918 .45824 .61403 .4522 .60273 .4398 Metetra
.911 .35 0 r
.60273 .4398 .61403 .4522 .63646 .44629 .62529 .4338 Metetra
.916 .334 0 r
.62529 .4338 .63646 .44629 .65909 .44053 .64804 .42795 Metetra
.921 .314 0 r
.64804 .42795 .65909 .44053 .68194 .43492 .67101 .42226 Metetra
.927 .292 0 r
.67101 .42226 .68194 .43492 .705 .42949 .69421 .41674 Metetra
.934 .266 0 r
.69421 .41674 .705 .42949 .72829 .42422 .71763 .41137 Metetra
.941 .239 0 r
.71763 .41137 .72829 .42422 .7518 .41886 .74128 .40593 Metetra
.944 .23 0 r
.74128 .40593 .7518 .41886 .77533 .41084 .76495 .39776 Metetra
.915 .339 0 r
.76495 .39776 .77533 .41084 .79776 .38766 .78755 .37415 Metetra
.788 .725 0 r
.78755 .37415 .79776 .38766 .81659 .32598 .80661 .31167 Metetra
.33 .655 0 r
.14782 .46858 .16094 .48046 .17156 .549 .15809 .53787 Metetra
.864 .511 0 r
.15809 .53787 .17156 .549 .18726 .57596 .17366 .56534 Metetra
.938 .252 0 r
.17366 .56534 .18726 .57596 .20598 .576 .19243 .56547 Metetra
.947 .217 0 r
.19243 .56547 .20598 .576 .22557 .56861 .21212 .55799 Metetra
.941 .24 0 r
.21212 .55799 .22557 .56861 .24536 .56036 .23201 .54963 Metetra
.934 .267 0 r
.23201 .54963 .24536 .56036 .26526 .55222 .25201 .54137 Metetra
.927 .292 0 r
.25201 .54137 .26526 .55222 .28527 .54424 .27213 .53328 Metetra
.922 .313 0 r
.27213 .53328 .28527 .54424 .30541 .53641 .29237 .52534 Metetra
.917 .331 0 r
.29237 .52534 .30541 .53641 .32567 .52872 .31274 .51754 Metetra
.912 .347 0 r
.31274 .51754 .32567 .52872 .34606 .52117 .33323 .50988 Metetra
.909 .36 0 r
.33323 .50988 .34606 .52117 .36659 .51374 .35386 .50234 Metetra
.906 .37 0 r
.35386 .50234 .36659 .51374 .38725 .50644 .37464 .49494 Metetra
.903 .378 0 r
.37464 .49494 .38725 .50644 .40806 .49926 .39556 .48766 Metetra
.902 .384 0 r
.39556 .48766 .40806 .49926 .42902 .49219 .41663 .48049 Metetra
.901 .388 0 r
.41663 .48049 .42902 .49219 .45014 .48524 .43785 .47344 Metetra
.9 .39 0 r
.43785 .47344 .45014 .48524 .47141 .4784 .45924 .4665 Metetra
.9 .389 0 r
.45924 .4665 .47141 .4784 .49286 .47167 .4808 .45967 Metetra
.901 .386 0 r
.4808 .45967 .49286 .47167 .51447 .46506 .50252 .45296 Metetra
.902 .382 0 r
.50252 .45296 .51447 .46506 .53626 .45856 .52443 .44637 Metetra
.904 .375 0 r
.52443 .44637 .53626 .45856 .55823 .45218 .54652 .4399 Metetra
.907 .366 0 r
.54652 .4399 .55823 .45218 .58038 .44592 .56879 .43355 Metetra
.91 .354 0 r
.56879 .43355 .58038 .44592 .60273 .4398 .59127 .42733 Metetra
.914 .34 0 r
.59127 .42733 .60273 .4398 .62529 .4338 .61394 .42125 Metetra
.919 .323 0 r
.61394 .42125 .62529 .4338 .64804 .42795 .63683 .41531 Metetra
.924 .304 0 r
.63683 .41531 .64804 .42795 .67101 .42226 .65993 .40954 Metetra
.93 .281 0 r
.65993 .40954 .67101 .42226 .69421 .41674 .68325 .40393 Metetra
.937 .255 0 r
.68325 .40393 .69421 .41674 .71763 .41137 .70681 .39849 Metetra
.944 .228 0 r
.70681 .39849 .71763 .41137 .74128 .40593 .7306 .39296 Metetra
.947 .218 0 r
.7306 .39296 .74128 .40593 .76495 .39776 .75441 .38462 Metetra
.917 .33 0 r
.75441 .38462 .76495 .39776 .78755 .37415 .77718 .36055 Metetra
.789 .722 0 r
.77718 .36055 .78755 .37415 .80661 .31167 .79647 .29715 Metetra
.329 .655 0 r
.13452 .45648 .14782 .46858 .15809 .53787 .14443 .52663 Metetra
.866 .504 0 r
.14443 .52663 .15809 .53787 .17366 .56534 .15986 .55471 Metetra
.941 .24 0 r
.15986 .55471 .17366 .56534 .19243 .56547 .17867 .55496 Metetra
.951 .202 0 r
.17867 .55496 .19243 .56547 .21212 .55799 .19845 .54739 Metetra
.945 .226 0 r
.19845 .54739 .21212 .55799 .23201 .54963 .21845 .5389 Metetra
.938 .254 0 r
.21845 .5389 .23201 .54963 .25201 .54137 .23856 .53052 Metetra
.931 .279 0 r
.23856 .53052 .25201 .54137 .27213 .53328 .25879 .5223 Metetra
.925 .3 0 r
.25879 .5223 .27213 .53328 .29237 .52534 .27913 .51425 Metetra
.92 .319 0 r
.27913 .51425 .29237 .52534 .31274 .51754 .2996 .50634 Metetra
.916 .335 0 r
.2996 .50634 .31274 .51754 .33323 .50988 .32021 .49857 Metetra
.912 .348 0 r
.32021 .49857 .33323 .50988 .35386 .50234 .34095 .49092 Metetra
.909 .359 0 r
.34095 .49092 .35386 .50234 .37464 .49494 .36183 .48341 Metetra
.907 .367 0 r
.36183 .48341 .37464 .49494 .39556 .48766 .38286 .47602 Metetra
.905 .373 0 r
.38286 .47602 .39556 .48766 .41663 .48049 .40404 .46875 Metetra
.904 .377 0 r
.40404 .46875 .41663 .48049 .43785 .47344 .42538 .46159 Metetra
.903 .379 0 r
.42538 .46159 .43785 .47344 .45924 .4665 .44688 .45455 Metetra
.903 .378 0 r
.44688 .45455 .45924 .4665 .4808 .45967 .46855 .44763 Metetra
.904 .376 0 r
.46855 .44763 .4808 .45967 .50252 .45296 .49039 .44082 Metetra
.905 .371 0 r
.49039 .44082 .50252 .45296 .52443 .44637 .51242 .43413 Metetra
.907 .364 0 r
.51242 .43413 .52443 .44637 .54652 .4399 .53463 .42757 Metetra
.91 .354 0 r
.53463 .42757 .54652 .4399 .56879 .43355 .55703 .42113 Metetra
.913 .343 0 r
.55703 .42113 .56879 .43355 .59127 .42733 .57962 .41482 Metetra
.917 .328 0 r
.57962 .41482 .59127 .42733 .61394 .42125 .60243 .40865 Metetra
.922 .311 0 r
.60243 .40865 .61394 .42125 .63683 .41531 .62544 .40263 Metetra
.928 .291 0 r
.62544 .40263 .63683 .41531 .65993 .40954 .64867 .39678 Metetra
.934 .268 0 r
.64867 .39678 .65993 .40954 .68325 .40393 .67213 .39109 Metetra
.941 .242 0 r
.67213 .39109 .68325 .40393 .70681 .39849 .69583 .38557 Metetra
.948 .213 0 r
.69583 .38557 .70681 .39849 .7306 .39296 .71975 .37995 Metetra
.95 .204 0 r
.71975 .37995 .7306 .39296 .75441 .38462 .74372 .37144 Metetra
.92 .319 0 r
.74372 .37144 .75441 .38462 .77718 .36055 .76665 .34684 Metetra
.79 .719 0 r
.76665 .34684 .77718 .36055 .79647 .29715 .78617 .2824 Metetra
.329 .654 0 r
.12107 .44416 .13452 .45648 .14443 .52663 .13057 .51528 Metetra
.868 .496 0 r
.13057 .51528 .14443 .52663 .15986 .55471 .14584 .54407 Metetra
.945 .225 0 r
.14584 .54407 .15986 .55471 .17867 .55496 .16469 .54446 Metetra
.955 .186 0 r
.16469 .54446 .17867 .55496 .19845 .54739 .18457 .5368 Metetra
.949 .209 0 r
.18457 .5368 .19845 .54739 .21845 .5389 .20467 .52818 Metetra
.942 .238 0 r
.20467 .52818 .21845 .5389 .23856 .53052 .22489 .51967 Metetra
.935 .264 0 r
.22489 .51967 .23856 .53052 .25879 .5223 .24523 .51133 Metetra
.929 .286 0 r
.24523 .51133 .25879 .5223 .27913 .51425 .26568 .50315 Metetra
.924 .305 0 r
.26568 .50315 .27913 .51425 .2996 .50634 .28626 .49512 Metetra
.919 .321 0 r
.28626 .49512 .2996 .50634 .32021 .49857 .30697 .48723 Metetra
.916 .335 0 r
.30697 .48723 .32021 .49857 .34095 .49092 .32782 .47947 Metetra
.913 .346 0 r
.32782 .47947 .34095 .49092 .36183 .48341 .34882 .47184 Metetra
.91 .354 0 r
.34882 .47184 .36183 .48341 .38286 .47602 .36996 .46435 Metetra
.908 .361 0 r
.36996 .46435 .38286 .47602 .40404 .46875 .39125 .45697 Metetra
.907 .364 0 r
.39125 .45697 .40404 .46875 .42538 .46159 .41271 .44971 Metetra
.907 .366 0 r
.41271 .44971 .42538 .46159 .44688 .45455 .43432 .44257 Metetra
.907 .366 0 r
.43432 .44257 .44688 .45455 .46855 .44763 .45611 .43554 Metetra
.908 .363 0 r
.45611 .43554 .46855 .44763 .49039 .44082 .47807 .42864 Metetra
.909 .358 0 r
.47807 .42864 .49039 .44082 .51242 .43413 .50022 .42185 Metetra
.911 .351 0 r
.50022 .42185 .51242 .43413 .53463 .42757 .52255 .41519 Metetra
.914 .341 0 r
.52255 .41519 .53463 .42757 .55703 .42113 .54507 .40866 Metetra
.917 .329 0 r
.54507 .40866 .55703 .42113 .57962 .41482 .5678 .40226 Metetra
.921 .314 0 r
.5678 .40226 .57962 .41482 .60243 .40865 .59073 .39601 Metetra
.926 .297 0 r
.59073 .39601 .60243 .40865 .62544 .40263 .61388 .38991 Metetra
.931 .277 0 r
.61388 .38991 .62544 .40263 .64867 .39678 .63724 .38397 Metetra
.938 .253 0 r
.63724 .38397 .64867 .39678 .67213 .39109 .66084 .37821 Metetra
.945 .226 0 r
.66084 .37821 .67213 .39109 .69583 .38557 .68468 .37261 Metetra
.952 .197 0 r
.68468 .37261 .69583 .38557 .71975 .37995 .70875 .36692 Metetra
.955 .188 0 r
.70875 .36692 .71975 .37995 .74372 .37144 .73286 .35822 Metetra
.923 .307 0 r
.73286 .35822 .74372 .37144 .76665 .34684 .75596 .33301 Metetra
.791 .716 0 r
.75596 .33301 .76665 .34684 .78617 .2824 .77572 .26741 Metetra
.328 .654 0 r
.10744 .43161 .12107 .44416 .13057 .51528 .11652 .50381 Metetra
.871 .487 0 r
.11652 .50381 .13057 .51528 .14584 .54407 .1316 .53341 Metetra
.95 .207 0 r
.1316 .53341 .14584 .54407 .16469 .54446 .15047 .53399 Metetra
.96 .166 0 r
.15047 .53399 .16469 .54446 .18457 .5368 .17045 .52623 Metetra
.954 .19 0 r
.17045 .52623 .18457 .5368 .20467 .52818 .19067 .51747 Metetra
.946 .22 0 r
.19067 .51747 .20467 .52818 .22489 .51967 .211 .50882 Metetra
.939 .246 0 r
.211 .50882 .22489 .51967 .24523 .51133 .23145 .50035 Metetra
.933 .269 0 r
.23145 .50035 .24523 .51133 .26568 .50315 .25201 .49204 Metetra
.928 .289 0 r
.25201 .49204 .26568 .50315 .28626 .49512 .27271 .48389 Metetra
.924 .305 0 r
.27271 .48389 .28626 .49512 .30697 .48723 .29353 .47588 Metetra
.92 .319 0 r
.29353 .47588 .30697 .48723 .32782 .47947 .31449 .468 Metetra
.917 .331 0 r
.31449 .468 .32782 .47947 .34882 .47184 .3356 .46026 Metetra
.914 .339 0 r
.3356 .46026 .34882 .47184 .36996 .46435 .35685 .45265 Metetra
.913 .346 0 r
.35685 .45265 .36996 .46435 .39125 .45697 .37826 .44516 Metetra
.911 .35 0 r
.37826 .44516 .39125 .45697 .41271 .44971 .39983 .4378 Metetra
.911 .351 0 r
.39983 .4378 .41271 .44971 .43432 .44257 .42157 .43055 Metetra
.911 .351 0 r
.42157 .43055 .43432 .44257 .45611 .43554 .44347 .42342 Metetra
.912 .348 0 r
.44347 .42342 .45611 .43554 .47807 .42864 .46556 .41642 Metetra
.913 .343 0 r
.46556 .41642 .47807 .42864 .50022 .42185 .48782 .40954 Metetra
.915 .336 0 r
.48782 .40954 .50022 .42185 .52255 .41519 .51028 .40278 Metetra
.918 .326 0 r
.51028 .40278 .52255 .41519 .54507 .40866 .53293 .39616 Metetra
.921 .313 0 r
.53293 .39616 .54507 .40866 .5678 .40226 .55579 .38967 Metetra
.926 .298 0 r
.55579 .38967 .5678 .40226 .59073 .39601 .57885 .38333 Metetra
.93 .28 0 r
.57885 .38333 .59073 .39601 .61388 .38991 .60213 .37715 Metetra
.936 .259 0 r
.60213 .37715 .61388 .38991 .63724 .38397 .62563 .37113 Metetra
.942 .235 0 r
.62563 .37113 .63724 .38397 .66084 .37821 .64937 .36529 Metetra
.95 .207 0 r
.64937 .36529 .66084 .37821 .68468 .37261 .67335 .35963 Metetra
.957 .178 0 r
.67335 .35963 .68468 .37261 .70875 .36692 .69756 .35386 Metetra
.959 .169 0 r
.69756 .35386 .70875 .36692 .73286 .35822 .72183 .34496 Metetra
.927 .292 0 r
.72183 .34496 .73286 .35822 .75596 .33301 .7451 .31908 Metetra
.793 .712 0 r
.7451 .31908 .75596 .33301 .77572 .26741 .7651 .25218 Metetra
.327 .654 0 r
.09363 .41881 .10744 .43161 .11652 .50381 .10225 .49223 Metetra
.874 .477 0 r
.10225 .49223 .11652 .50381 .1316 .53341 .11713 .52275 Metetra
.955 .187 0 r
.11713 .52275 .1316 .53341 .15047 .53399 .13602 .52355 Metetra
.966 .144 0 r
.13602 .52355 .15047 .53399 .17045 .52623 .1561 .5157 Metetra
.959 .169 0 r
.1561 .5157 .17045 .52623 .19067 .51747 .17643 .5068 Metetra
.952 .199 0 r
.17643 .5068 .19067 .51747 .211 .50882 .19688 .498 Metetra
.945 .226 0 r
.19688 .498 .211 .50882 .23145 .50035 .21744 .48939 Metetra
.939 .25 0 r
.21744 .48939 .23145 .50035 .25201 .49204 .23812 .48095 Metetra
.933 .27 0 r
.23812 .48095 .25201 .49204 .27271 .48389 .25893 .47266 Metetra
.929 .287 0 r
.25893 .47266 .27271 .48389 .29353 .47588 .27986 .46453 Metetra
.925 .301 0 r
.27986 .46453 .29353 .47588 .31449 .468 .30094 .45652 Metetra
.922 .313 0 r
.30094 .45652 .31449 .468 .3356 .46026 .32216 .44867 Metetra
.919 .322 0 r
.32216 .44867 .3356 .46026 .35685 .45265 .34353 .44094 Metetra
.917 .329 0 r
.34353 .44094 .35685 .45265 .37826 .44516 .36506 .43334 Metetra
.916 .333 0 r
.36506 .43334 .37826 .44516 .39983 .4378 .38675 .42586 Metetra
.916 .335 0 r
.38675 .42586 .39983 .4378 .42157 .43055 .4086 .41851 Metetra
.916 .334 0 r
.4086 .41851 .42157 .43055 .44347 .42342 .43063 .41128 Metetra
.917 .331 0 r
.43063 .41128 .44347 .42342 .46556 .41642 .45284 .40417 Metetra
.918 .326 0 r
.45284 .40417 .46556 .41642 .48782 .40954 .47523 .39719 Metetra
.92 .318 0 r
.47523 .39719 .48782 .40954 .51028 .40278 .49781 .39034 Metetra
.923 .308 0 r
.49781 .39034 .51028 .40278 .53293 .39616 .52059 .38362 Metetra
.926 .295 0 r
.52059 .38362 .53293 .39616 .55579 .38967 .54358 .37705 Metetra
.931 .28 0 r
.54358 .37705 .55579 .38967 .57885 .38333 .56677 .37063 Metetra
.936 .261 0 r
.56677 .37063 .57885 .38333 .60213 .37715 .59019 .36437 Metetra
.941 .24 0 r
.59019 .36437 .60213 .37715 .62563 .37113 .61383 .35827 Metetra
.948 .215 0 r
.61383 .35827 .62563 .37113 .64937 .36529 .63771 .35236 Metetra
.955 .186 0 r
.63771 .35236 .64937 .36529 .67335 .35963 .66184 .34663 Metetra
.963 .155 0 r
.66184 .34663 .67335 .35963 .69756 .35386 .6862 .34078 Metetra
.965 .147 0 r
.6862 .34078 .69756 .35386 .72183 .34496 .71063 .33167 Metetra
.932 .276 0 r
.71063 .33167 .72183 .34496 .7451 .31908 .73408 .30503 Metetra
.794 .708 0 r
.73408 .30503 .7451 .31908 .7651 .25218 .75432 .23668 Metetra
.325 .653 0 r
.07968 .40564 .09363 .41881 .10225 .49223 .0878 .48032 Metetra
.877 .467 0 r
.0878 .48032 .10225 .49223 .11713 .52275 .10244 .51189 Metetra
.96 .166 0 r
.10244 .51189 .11713 .52275 .13602 .52355 .12134 .51298 Metetra
.972 .119 0 r
.12134 .51298 .13602 .52355 .1561 .5157 .14153 .50506 Metetra
.965 .145 0 r
.14153 .50506 .1561 .5157 .17643 .5068 .16197 .49602 Metetra
.958 .176 0 r
.16197 .49602 .17643 .5068 .19688 .498 .18253 .48709 Metetra
.95 .204 0 r
.18253 .48709 .19688 .498 .21744 .48939 .20321 .47834 Metetra
.944 .228 0 r
.20321 .47834 .21744 .48939 .23812 .48095 .224 .46977 Metetra
.939 .249 0 r
.224 .46977 .23812 .48095 .25893 .47266 .24492 .46135 Metetra
.934 .267 0 r
.24492 .46135 .25893 .47266 .27986 .46453 .26597 .45309 Metetra
.93 .282 0 r
.26597 .45309 .27986 .46453 .30094 .45652 .28717 .44497 Metetra
.927 .294 0 r
.28717 .44497 .30094 .45652 .32216 .44867 .30851 .43699 Metetra
.924 .303 0 r
.30851 .43699 .32216 .44867 .34353 .44094 .33 .42915 Metetra
.923 .31 0 r
.33 .42915 .34353 .44094 .36506 .43334 .35164 .42143 Metetra
.921 .314 0 r
.35164 .42143 .36506 .43334 .38675 .42586 .37345 .41384 Metetra
.921 .316 0 r
.37345 .41384 .38675 .42586 .4086 .41851 .39543 .40638 Metetra
.921 .315 0 r
.39543 .40638 .4086 .41851 .43063 .41128 .41758 .39904 Metetra
.922 .312 0 r
.41758 .39904 .43063 .41128 .45284 .40417 .43991 .39183 Metetra
.923 .307 0 r
.43991 .39183 .45284 .40417 .47523 .39719 .46243 .38475 Metetra
.925 .299 0 r
.46243 .38475 .47523 .39719 .49781 .39034 .48514 .3778 Metetra
.928 .289 0 r
.48514 .3778 .49781 .39034 .52059 .38362 .50805 .37099 Metetra
.932 .275 0 r
.50805 .37099 .52059 .38362 .54358 .37705 .53117 .36432 Metetra
.936 .259 0 r
.53117 .36432 .54358 .37705 .56677 .37063 .5545 .35781 Metetra
.941 .24 0 r
.5545 .35781 .56677 .37063 .59019 .36437 .57806 .35146 Metetra
.947 .218 0 r
.57806 .35146 .59019 .36437 .61383 .35827 .60184 .34528 Metetra
.954 .192 0 r
.60184 .34528 .61383 .35827 .63771 .35236 .62586 .33929 Metetra
.961 .162 0 r
.62586 .33929 .63771 .35236 .66184 .34663 .65014 .33348 Metetra
.969 .131 0 r
.65014 .33348 .66184 .34663 .6862 .34078 .67465 .32753 Metetra
.971 .123 0 r
.67465 .32753 .6862 .34078 .71063 .33167 .69923 .31815 Metetra
.936 .258 0 r
.69923 .31815 .71063 .33167 .73408 .30503 .72286 .29066 Metetra
.796 .704 0 r
.72286 .29066 .73408 .30503 .75432 .23668 .74335 .22075 Metetra
.31 .649 0 r
.06575 .3908 .07968 .40564 .0878 .48032 .07341 .46625 Metetra
.876 .47 0 r
.07341 .46625 .0878 .48032 .10244 .51189 .08779 .4988 Metetra
.962 .158 0 r
.08779 .4988 .10244 .51189 .12134 .51298 .10667 .50036 Metetra
.975 .107 0 r
.10667 .50036 .12134 .51298 .14153 .50506 .12692 .49259 Metetra
.969 .131 0 r
.12692 .49259 .14153 .50506 .16197 .49602 .14745 .48359 Metetra
.961 .162 0 r
.14745 .48359 .16197 .49602 .18253 .48709 .1681 .47466 Metetra
.954 .19 0 r
.1681 .47466 .18253 .48709 .20321 .47834 .18887 .4659 Metetra
.948 .214 0 r
.18887 .4659 .20321 .47834 .224 .46977 .20977 .45729 Metetra
.943 .235 0 r
.20977 .45729 .224 .46977 .24492 .46135 .23079 .44883 Metetra
.938 .252 0 r
.23079 .44883 .24492 .46135 .26597 .45309 .25195 .4405 Metetra
.934 .267 0 r
.25195 .4405 .26597 .45309 .28717 .44497 .27325 .4323 Metetra
.931 .279 0 r
.27325 .4323 .28717 .44497 .30851 .43699 .2947 .42424 Metetra
.928 .289 0 r
.2947 .42424 .30851 .43699 .33 .42915 .3163 .41631 Metetra
.926 .295 0 r
.3163 .41631 .33 .42915 .35164 .42143 .33805 .4085 Metetra
.925 .3 0 r
.33805 .4085 .35164 .42143 .37345 .41384 .35998 .4008 Metetra
.925 .301 0 r
.35998 .4008 .37345 .41384 .39543 .40638 .38207 .39323 Metetra
.925 .301 0 r
.38207 .39323 .39543 .40638 .41758 .39904 .40434 .38578 Metetra
.926 .298 0 r
.40434 .38578 .41758 .39904 .43991 .39183 .4268 .37844 Metetra
.927 .293 0 r
.4268 .37844 .43991 .39183 .46243 .38475 .44944 .37123 Metetra
.929 .285 0 r
.44944 .37123 .46243 .38475 .48514 .3778 .47227 .36414 Metetra
.932 .274 0 r
.47227 .36414 .48514 .3778 .50805 .37099 .49531 .35718 Metetra
.936 .261 0 r
.49531 .35718 .50805 .37099 .53117 .36432 .51855 .35036 Metetra
.94 .245 0 r
.51855 .35036 .53117 .36432 .5545 .35781 .54202 .34367 Metetra
.945 .226 0 r
.54202 .34367 .5545 .35781 .57806 .35146 .5657 .33713 Metetra
.951 .204 0 r
.5657 .33713 .57806 .35146 .60184 .34528 .58962 .33075 Metetra
.957 .178 0 r
.58962 .33075 .60184 .34528 .62586 .33929 .61377 .32453 Metetra
.964 .149 0 r
.61377 .32453 .62586 .33929 .65014 .33348 .63817 .31847 Metetra
.972 .118 0 r
.63817 .31847 .65014 .33348 .67465 .32753 .66282 .31221 Metetra
.973 .112 0 r
.66282 .31221 .67465 .32753 .69923 .31815 .68753 .30234 Metetra
.937 .255 0 r
.68753 .30234 .69923 .31815 .72286 .29066 .71132 .27385 Metetra
.793 .71 0 r
.71132 .27385 .72286 .29066 .74335 .22075 .73208 .20265 Metetra
.228 .623 0 r
.05279 .36803 .06575 .3908 .07341 .46625 .06046 .44057 Metetra
.85 .553 0 r
.06046 .44057 .07341 .46625 .08779 .4988 .07468 .47282 Metetra
.938 .253 0 r
.07468 .47282 .08779 .4988 .10667 .50036 .09339 .47528 Metetra
.953 .194 0 r
.09339 .47528 .10667 .50036 .12692 .49259 .11353 .46848 Metetra
.949 .209 0 r
.11353 .46848 .12692 .49259 .14745 .48359 .13398 .46032 Metetra
.943 .231 0 r
.13398 .46032 .14745 .48359 .1681 .47466 .15458 .45209 Metetra
.938 .252 0 r
.15458 .45209 .1681 .47466 .18887 .4659 .17532 .44389 Metetra
.933 .27 0 r
.17532 .44389 .18887 .4659 .20977 .45729 .19621 .43575 Metetra
.929 .286 0 r
.19621 .43575 .20977 .45729 .23079 .44883 .21724 .42765 Metetra
.925 .3 0 r
.21724 .42765 .23079 .44883 .25195 .4405 .23842 .41961 Metetra
.922 .312 0 r
.23842 .41961 .25195 .4405 .27325 .4323 .25975 .41161 Metetra
.919 .322 0 r
.25975 .41161 .27325 .4323 .2947 .42424 .28124 .40368 Metetra
.917 .329 0 r
.28124 .40368 .2947 .42424 .3163 .41631 .3029 .39581 Metetra
.916 .335 0 r
.3029 .39581 .3163 .41631 .33805 .4085 .32471 .388 Metetra
.915 .338 0 r
.32471 .388 .33805 .4085 .35998 .4008 .3467 .38026 Metetra
.914 .34 0 r
.3467 .38026 .35998 .4008 .38207 .39323 .36886 .37257 Metetra
.914 .339 0 r
.36886 .37257 .38207 .39323 .40434 .38578 .39121 .36494 Metetra
.915 .337 0 r
.39121 .36494 .40434 .38578 .4268 .37844 .41373 .35738 Metetra
.916 .332 0 r
.41373 .35738 .4268 .37844 .44944 .37123 .43645 .34988 Metetra
.918 .326 0 r
.43645 .34988 .44944 .37123 .47227 .36414 .45936 .34244 Metetra
.92 .318 0 r
.45936 .34244 .47227 .36414 .49531 .35718 .48247 .33505 Metetra
.923 .307 0 r
.48247 .33505 .49531 .35718 .51855 .35036 .50579 .32772 Metetra
.927 .294 0 r
.50579 .32772 .51855 .35036 .54202 .34367 .52931 .32045 Metetra
.931 .28 0 r
.52931 .32045 .54202 .34367 .5657 .33713 .55306 .31322 Metetra
.935 .262 0 r
.55306 .31322 .5657 .33713 .58962 .33075 .57703 .30604 Metetra
.94 .243 0 r
.57703 .30604 .58962 .33075 .61377 .32453 .60122 .2989 Metetra
.946 .221 0 r
.60122 .2989 .61377 .32453 .63817 .31847 .62565 .29177 Metetra
.952 .199 0 r
.62565 .29177 .63817 .31847 .66282 .31221 .6503 .28429 Metetra
.951 .203 0 r
.6503 .28429 .66282 .31221 .68753 .30234 .675 .27307 Metetra
.912 .348 0 r
.675 .27307 .68753 .30234 .71132 .27385 .69886 .24374 Metetra
.758 .767 0 r
.69886 .24374 .71132 .27385 .73208 .20265 .71996 .1738 Metetra
0 .53 .02 r
.04284 .32478 .05279 .36803 .06046 .44057 .05194 .38408 Metetra
.643 .739 0 r
.05194 .38408 .06046 .44057 .07468 .47282 .06649 .41135 Metetra
.826 .623 0 r
.06649 .41135 .07468 .47282 .09339 .47528 .08485 .41448 Metetra
.846 .564 0 r
.08485 .41448 .09339 .47528 .11353 .46848 .1045 .40981 Metetra
.848 .557 0 r
.1045 .40981 .11353 .46848 .13398 .46032 .12451 .40373 Metetra
.848 .558 0 r
.12451 .40373 .13398 .46032 .15458 .45209 .14472 .39733 Metetra
.847 .56 0 r
.14472 .39733 .15458 .45209 .17532 .44389 .16512 .39073 Metetra
.847 .563 0 r
.16512 .39073 .17532 .44389 .19621 .43575 .1857 .38393 Metetra
.846 .565 0 r
.1857 .38393 .19621 .43575 .21724 .42765 .20647 .37697 Metetra
.845 .567 0 r
.20647 .37697 .21724 .42765 .23842 .41961 .22742 .36986 Metetra
.844 .569 0 r
.22742 .36986 .23842 .41961 .25975 .41161 .24855 .3626 Metetra
.844 .571 0 r
.24855 .3626 .25975 .41161 .28124 .40368 .26987 .35523 Metetra
.843 .573 0 r
.26987 .35523 .28124 .40368 .3029 .39581 .29136 .34774 Metetra
.843 .574 0 r
.29136 .34774 .3029 .39581 .32471 .388 .31304 .34014 Metetra
.843 .575 0 r
.31304 .34014 .32471 .388 .3467 .38026 .3349 .33243 Metetra
.842 .575 0 r
.3349 .33243 .3467 .38026 .36886 .37257 .35695 .32461 Metetra
.842 .575 0 r
.35695 .32461 .36886 .37257 .39121 .36494 .37918 .31669 Metetra
.843 .575 0 r
.37918 .31669 .39121 .36494 .41373 .35738 .4016 .30866 Metetra
.843 .574 0 r
.4016 .30866 .41373 .35738 .43645 .34988 .42421 .30051 Metetra
.843 .572 0 r
.42421 .30051 .43645 .34988 .45936 .34244 .44701 .29225 Metetra
.844 .571 0 r
.44701 .29225 .45936 .34244 .48247 .33505 .47 .28385 Metetra
.845 .569 0 r
.47 .28385 .48247 .33505 .50579 .32772 .49318 .27532 Metetra
.845 .566 0 r
.49318 .27532 .50579 .32772 .52931 .32045 .51656 .26662 Metetra
.846 .564 0 r
.51656 .26662 .52931 .32045 .55306 .31322 .54013 .25775 Metetra
.847 .562 0 r
.54013 .25775 .55306 .31322 .57703 .30604 .5639 .24869 Metetra
.848 .559 0 r
.5639 .24869 .57703 .30604 .60122 .2989 .58786 .2394 Metetra
.848 .558 0 r
.58786 .2394 .60122 .2989 .62565 .29177 .61201 .22986 Metetra
.848 .558 0 r
.61201 .22986 .62565 .29177 .6503 .28429 .63633 .21972 Metetra
.841 .579 0 r
.63633 .21972 .6503 .28429 .675 .27307 .6607 .20622 Metetra
.799 .696 0 r
.6607 .20622 .675 .27307 .69886 .24374 .68442 .17785 Metetra
.353 .662 0 r
.68442 .17785 .69886 .24374 .71996 .1738 .70603 .11699 Metetra
0 .333 .297 r
.03634 .26033 .04284 .32478 .05194 .38408 .04859 .2952 Metetra
0 .496 .092 r
.04859 .2952 .05194 .38408 .06649 .41135 .06425 .31112 Metetra
.076 .569 0 r
.06425 .31112 .06649 .41135 .08485 .41448 .08236 .31262 Metetra
.142 .594 0 r
.08236 .31262 .08485 .41448 .1045 .40981 .10136 .30927 Metetra
.171 .604 0 r
.10136 .30927 .1045 .40981 .12451 .40373 .1207 .30485 Metetra
.192 .611 0 r
.1207 .30485 .12451 .40373 .14472 .39733 .14027 .3 Metetra
.211 .617 0 r
.14027 .3 .14472 .39733 .16512 .39073 .16007 .29479 Metetra
.227 .622 0 r
.16007 .29479 .16512 .39073 .1857 .38393 .18008 .28924 Metetra
.241 .627 0 r
.18008 .28924 .1857 .38393 .20647 .37697 .20031 .28336 Metetra
.253 .631 0 r
.20031 .28336 .20647 .37697 .22742 .36986 .22075 .27715 Metetra
.262 .634 0 r
.22075 .27715 .22742 .36986 .24855 .3626 .2414 .27062 Metetra
.27 .637 0 r
.2414 .27062 .24855 .3626 .26987 .35523 .26225 .2638 Metetra
.277 .638 0 r
.26225 .2638 .26987 .35523 .29136 .34774 .2833 .25667 Metetra
.281 .64 0 r
.2833 .25667 .29136 .34774 .31304 .34014 .30455 .24925 Metetra
.284 .641 0 r
.30455 .24925 .31304 .34014 .3349 .33243 .32599 .24154 Metetra
.285 .641 0 r
.32599 .24154 .3349 .33243 .35695 .32461 .34762 .23354 Metetra
.285 .641 0 r
.34762 .23354 .35695 .32461 .37918 .31669 .36945 .22524 Metetra
.283 .64 0 r
.36945 .22524 .37918 .31669 .4016 .30866 .39146 .21665 Metetra
.279 .639 0 r
.39146 .21665 .4016 .30866 .42421 .30051 .41365 .20775 Metetra
.274 .638 0 r
.41365 .20775 .42421 .30051 .44701 .29225 .43603 .19855 Metetra
.267 .635 0 r
.43603 .19855 .44701 .29225 .47 .28385 .45859 .18904 Metetra
.258 .633 0 r
.45859 .18904 .47 .28385 .49318 .27532 .48132 .17919 Metetra
.247 .629 0 r
.48132 .17919 .49318 .27532 .51656 .26662 .50423 .169 Metetra
.235 .625 0 r
.50423 .169 .51656 .26662 .54013 .25775 .5273 .15846 Metetra
.22 .62 0 r
.5273 .15846 .54013 .25775 .5639 .24869 .55053 .14755 Metetra
.203 .615 0 r
.55053 .14755 .5639 .24869 .58786 .2394 .57392 .13625 Metetra
.183 .608 0 r
.57392 .13625 .58786 .2394 .61201 .22986 .59747 .12454 Metetra
.16 .6 0 r
.59747 .12454 .61201 .22986 .63633 .21972 .62115 .11221 Metetra
.121 .586 0 r
.62115 .11221 .63633 .21972 .6607 .20622 .64488 .09765 Metetra
.016 .545 0 r
.64488 .09765 .6607 .20622 .68442 .17785 .6683 .07412 Metetra
0 .434 .196 r
.6683 .07412 .68442 .17785 .70603 .11699 .69056 .0314 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00[oooool3
o`0000Cooooo0_l0001Xooooo`00/?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0006Oooooo002`ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000Ioooool0
0;3ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001Wooooo`00/?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Cooooo0_l0001Aooooo`00[oooool2o`00
00Cooooo00Co0000oooooooooooo00004Oooool3o`000003ooooool0003ooooo053ooooo002`oooo
o`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o00001?ooool2o`00053ooooo0035ooooo`?o
00001_ooool00ol0003oooooo`00001?ooooo`00`_ooool3o`0000Wooooo0ol0001?ooooo`00`?oo
ool2o`0000cooooo00Co0000oooooooooooo0000C_ooool00;gooooo0ol0000>ooooo`05o`000?oo
ooooooooooooool00000COooool00;[ooooo0ol0000Aooooo`05o`000?ooooooooooooooool00000
COooool00;Sooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02ooo
ool3o`0000Cooooo0_l0000fooooo`00]_ooool2o`0000?ooooo00?o0000ooooooooool04?ooool2
o`0000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0003Gooooo002cooooo`?o00005oooool3o`0000Cooooo00?o0000ooooooooool00oooool5
o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000eooooo`00/?ooool3
o`0001[ooooo0ol00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000eooooo`00[_ooool2o`0001cooooo00Co0000o`1_<_l0Kc;o00001_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
=Oooool00:_ooooo0ol0000Nooooo`04o`000?l0Kc;o06lbo`0000Kooooo00?o0000ooooooooool0
2?ooool2o`0000Cooooo00Co0000oooooooooooo0000=Oooool00:Wooooo0_l00002ooooo`03o`00
0?oooooooooo01_ooooo00Go0000o`1_<_l0Kc;o06lbo`000005ooooo`?o00002_ooool00ol0003o
ooooooooo`03ooooo`;o0000=_ooool00:Kooooo0ol0000Rooooo`05o`000?l0Kc;o06lbo`1_<_l0
00002?ooool00ol0003oooooooooo`15ooooo`00Y?ooool2o`0002Cooooo00?o0000o`1_<_l0Kc80
0_l0Kc800ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Gooooo002Qooooo`?o00009_oo
ool00ol0003o06lbo`1_<P02o`1_<P;o00002?ooool00ol0003oooooooooo`14ooooo`00W_ooool3
o`0002Sooooo00?o0000o`1_<_l0Kc800ol0Kc82o`0000Wooooo00?o0000ooooooooool0@oooool0
09cooooo0_l000000ooooooo0000ooooo`0Wooooo`;o00001Ol0Kc82o`0000Wooooo00?o0000oooo
ooooool0@oooool009Wooooo0ol0000[ooooo`03o`000?l4R`3o000000Go06lb0_l0000:ooooo`03
o`000?oooooooooo04;ooooo002Gooooo`;o0000;Oooool01?l0003o18/0o`B;0?l00005o`1_<P;o
00002oooool00ol0003oooooooooo`11ooooo`00U?ooool3o`0002kooooo00?o0000o`B;0?l4R`00
0_l4R`000ol0003o06lbo`1_<P02o`1_<P03o`000?l0Kc;o000000[ooooo00?o0000ooooooooool0
@Oooool009;ooooo0_l0000`ooooo`03o`000?l4R`3o18/000?o18/000?o0000o`1_<_l0Kc800_l0
Kc800ol0003o06lbo`00000;ooooo`03o`000?oooooooooo043ooooo001`ooooo`;o00007Oooool3
o`00033ooooo0_l00006o`B;0003o`000?l0Kc;o06lb00?o06lb0_l0000;ooooo`;o0000@Oooool0
06oooooo00Co0000oooooooooooo00006Oooool3o`0003;ooooo00?o0000oajF0?l000001_l4R`00
0ol0003o06lbo`1_<P03o`1_<P;o00003?ooool00ol0003oooooooooo`0oooooo`00Koooool01?l0
003oooooooooool0000Gooooo`;o0000<oooool2o`0000;o7YH000?o0000o`B;0?l4R`001?l4R`00
0ol0003o06lbo`1_<P03o`1_<P;o00003Oooool00ol0003oooooooooo`0nooooo`00Koooool01?l0
003oooooooooool0000Dooooo`?o0000=?ooool00ol0003o7YH0oajF0002oajF0003o`000?l4R`3o
18/000Co18/000?o0000o`1_<_l0Kc800ol0Kc800ol0003o06lbo`00000=ooooo`03o`000?oooooo
oooo03gooooo001_ooooo`04o`000?ooooooooooo`0001;ooooo0_l0000eooooo`;o00001_lNUP00
0ol0003o18/0o`B;0003o`B;0003o`000?l0Kc;o06lb00?o06lb00?o0000o`1_<_l000003Oooool0
0ol0003oooooooooo`0mooooo`00Koooool01?l0003oooooooooool0000?ooooo`?o0000=Oooool2
o`000003obRI0?l0003o7YH000Go7YH000?o0000o`B;0?l4R`001?l4R`000ol0003o06lbo`1_<P02
o`1_<P03o`000?l0Kc;o000000kooooo00?o0000ooooooooool0??ooool0073ooooo0_l0000>oooo
o`;o000000?oooooo`000?ooool0<oooool2o`0000?o:9T000?o0000oajF0?lNUP001?lNUP000ol0
003o18/0o`B;0004o`B;0003o`000?l0Kc;o06lb00;o06lb00?o0000o`1_<_l000003_ooool00ol0
003oooooooooo`0looooo`00OOooool3o`0003Kooooo0_l00005obRI0003o`000?lNUP3o7YH000Co
7YH000?o0000o`B;0?l4R`001?l4R`000ol0003o06lbo`1_<P02o`1_<P03o`000?l0Kc;o000000oo
oooo00?o0000ooooooooool0>oooool007[ooooo0ol0000gooooo`;o000000?o;Y/0o`000?lXV@00
1?lXV@000ol0003o7YH0oajF0004oajF0003o`000?l4R`3o18/000Co18/000?o0000o`1_<_l0Kc80
0_l0Kc82o`000003oeZY0?l0003ooooo00kooooo00?o0000ooooooooool0>_ooool007Sooooo0_l0
000hooooo`;o00000ol^V`000ol0003o:9T0obRI0003obRI0003o`000?lNUP3o7YH000Co7YH000?o
0000o`B;0?l4R`001?l4R`000ol0003o06lbo`1_<P02o`1_<P;o000000?oFZT0o`000?ooool03_oo
ool2o`0003_ooooo001eooooo`?o0000>?ooool2o`0000Go;Y/000?o0000obRI0?lXV@001?lXV@00
0ol0003o7YH0oajF0003oajF0003o`000?l4R`3o18/000Co18/000?o0000o`1_<_l0Kc800_l0Kc82
o`000003oeZY0?l0003ooooo00kooooo0_l0000kooooo`00Loooool2o`0000;ooooo00?o0000oooo
ooooool0=?ooool2o`000003oc>M0?l0003o;Y/000Co;Y/000?o0000obRI0?lXV@001?lXV@000ol0
003o7YH0oajF0004oajF0003o`000?l4R`3o18/000?o18/000?o0000o`1_<_l0Kc800_l0Kc801?l0
003oFZT0oeZY0?l0000Aooooo`03o`000?oooooooooo03Sooooo001`ooooo`?o0000>Oooool2o`00
00?o<id000?o0000objK0?l^V`001?l^V`000ol0003o:9T0obRI0003obRI0003o`000?lNUP3o7YH0
00Co7YH000?o0000o`B;0?l4R`001?l4R`001Ol0003o06lbo`1_<_l0Kc;o000000?oFZT000?o0000
ooooooooool03_ooool00ol0003oooooooooo`0hooooo`00K_ooool2o`0003[ooooo0_l00005oc>M
0003o`000?l^V`3o;Y/000Co;Y/000?o0000obRI0?lXV@000olXV@000ol0003o7YH0oajF0004oajF
0003o`000?l4R`3o18/000Co18/000Go0000o`1_<_l0Kc;o06lbo`000003oeZY0003o`000?oooooo
oooo00oooooo00?o0000ooooooooool0=oooool006_ooooo0ol0000jooooo`;o000000?o>9h0o`00
0?lcW@001?lcW@000ol0003o;Y/0objK0004objK0003o`000?lXV@3o:9T000?o:9T000?o0000oajF
0?lNUP001?lNUP000ol0003o18/0o`B;0004o`B;0003o`000?l0Kc;o06lb00;o00000omJZ@000ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03Kooooo001Yooooo`;o0000>oooool2o`0000?o
>9h000?o0000oc>M0?lcW@001?lcW@000ol0003o;Y/0objK0003objK0003o`000?lXV@3o:9T000?o
:9T000?o0000oajF0?lNUP001?lNUP000ol0003o18/0o`B;0004o`B;0003o`000?l0Kc;o06lb00;o
00001?mJZ@000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Kooooo001Vooooo`Co0000
>_ooool2o`0000Go>9h000?o0000oc>M0?lcW@001?lcW@000ol0003o;Y/0objK0003objK0003o`00
0?lXV@3o:9T000?o:9T000?o0000oajF0?lNUP001?lNUP000ol0003o18/0o`B;0004o`B;0006o`00
0?l0Kc;o06lbo`000?mJZ@3o00000omJZ@000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03Gooooo001Sooooo`?o0000??ooool2o`000003ocbO0?l0003o>9h000Co>9h000?o0000oc>M0?lc
W@001?lcW@000ol0003o;Y/0objK0003objK0003o`000?lXV@3o:9T000?o:9T000?o0000oajF0?lN
UP001?lNUP000ol0003o18/0o`B;0004o`B;0003o`000?l0Kc;o000000;oFZT000Go0000oeZY0?mJ
Z@3oFZT0o`00000Cooooo`03o`000?oooooooooo03Cooooo001Qooooo`;o0000?Oooool2o`0000?o
?9l000?o0000ocRN0?lhWP001?lhWP000ol0003o<id0oc>M0003oc>M0003o`000?l^V`3o;Y/000?o
;Y/000?o0000obRI0?lXV@000olXV@000ol0003o7YH0oajF0005oajF0003o`000?l4R`3o18/000?o
18/000?o0000o`1_<_l000000_mJZ@001Ol0003oFZT0oeZY0?mJZ@3o000001?ooooo00?o0000oooo
ooooool0=?ooool005kooooo0ol0000mooooo`;o00001OllW`000ol0003o>9h0ocRN0004ocRN0003
o`000?lcW@3o<id000?o<id000?o0000objK0?l^V`000ol^V`000ol0003o:9T0obRI0004obRI0003
o`000?lNUP3o7YH000Co7YH000?o0000o`B;0?l4R`001?l4R`02o`0000;oFZT000?o0000oeZY0?mJ
Z@000_mJZ@000ol0003oooooooooo`0@ooooo`;o0000=Oooool005cooooo0_l0000mooooo`?o0000
00?o?j40o`000?llW`001?llW`000ol0003o>9h0ocRN0004ocRN0003o`000?lcW@3o<id000?o<id0
00?o0000objK0?l^V`000ol^V`000ol0003o:9T0obRI0004obRI0003o`000?lNUP3o7YH000Co7YH0
00?o0000o`B;0?l4R`001?l4R`001Ol0003oFZT0oeZY0?mJZ@3o000000CoFZT000?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0booooo`00FOooool3o`000003ooooool0003ooooo03Wooooo
0ol00004ocnQ0003o`000?llW`3o?9l000Co?9l000?o0000ocRN0?lhWP000olhWP000ol0003o<id0
oc>M0003oc>M0003o`000?l^V`3o;Y/000Co;Y/000?o0000obRI0?lXV@000olXV@000ol0003o7YH0
oajF0004oajF0003o`000?l4R`3o18/000Co18/000Go0000oeZY0?mJZ@3oFZT0o`000004oeZY0003
o`000?oooooooooo01;ooooo00?o0000ooooooooool0<_ooool005Oooooo0_l0000mooooo`;o0000
00?o@Z80o`000?loX@001?loX@000ol0003o?9l0ocbO0004ocbO0003o`000?lhWP3o>9h000?o>9h0
00?o0000oc>M0?lcW@000olcW@000ol0003o;Y/0objK0004objK0003o`000?lXV@3o:9T000?o:9T0
00?o0000oajF0?lNUP001?lNUP000ol0003o18/0o`B;0004o`B;0005o`000?mJZ@3oFZT0oeZY0?l0
00000omJZ@000ol0003o`/@0o`00000Dooooo`03o`000?oooooooooo037ooooo001Dooooo`?o0000
?Oooool2o`0000?o@Z8000?o0000ocnQ0?loX@000oloX@000ol0003o?9l0ocbO0004ocbO0003o`00
0?lhWP3o>9h000?o>9h000?o0000oc>M0?lcW@000olcW@000ol0003o;Y/0objK0004objK0003o`00
0?lXV@3o:9T000?o:9T000?o0000oajF0?lNUP001?lNUP000ol0003o18/0o`B;0003o`B;00;o0000
0omJZ@001ol0003oFZT0oeZY0?mJZ@3o0000ol;40?l000005Oooool00ol0003oooooooooo`0`oooo
o`00:_ooool3o`0000Cooooo0_l0000Nooooo`?o0000?_ooool2o`0000Go@Z8000?o0000ocnQ0?lo
X@001?loX@000ol0003o?9l0ocbO0003ocbO0003o`000?lhWP3o>9h000?o>9h000?o0000oc>M0?lc
W@001?lcW@000ol0003o;Y/0objK0003objK0003o`000?lXV@3o:9T000?o:9T000?o0000oajF0?lN
UP001?lNUP000ol0003o18/0o`B;0002o`B;0003o`000?o</P3o000000?oFZT000Go0000oeZY0?mJ
Z@3oFZT0o`000002ol;40003o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool002_o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Kooooo`;o0000?_ooool3o`00
0003odBR0?l0003o@Z8000Co@Z8000?o0000ocnQ0?loX@001?loX@000ol0003o?9l0ocbO0003ocbO
0003o`000?lhWP3o>9h000?o>9h000?o0000oc>M0?lcW@001?lcW@000ol0003o;Y/0objK0003objK
0003o`000?lXV@3o:9T000?o:9T000?o0000oajF0?lNUP001OlNUP001?l0003o18/0o`B;0?l00003
olbb0004o`000?mJZ@3oFZT0o`0000;oFZT000Go0000ol;40?o2a03o`/@0o`00000Eooooo`03o`00
0?oooooooooo02oooooo000Sooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001Sooooo0ol000000ooooooo0000ooooo`0jooooo`?o00001?m4XP000ol0003o@Z80
od:R0004od:R0003o`000?loX@3o?j4000?o?j4000?o0000ocbO0?llW`000ollW`000ol0003o>9h0
ocRN0003ocRN0003o`000?lcW@3o<id000Co<id000?o0000objK0?l^V`000ol^V`000ol0003o:9T0
obRI0003obRI0003o`000?lNUP3o7YH000Go7YH000?o0000o`B;0?l000001?o</P001?l0003oFZT0
oeZY0?l00002oeZY0005o`000?o2a03o`/@0ol;40?l000005_ooool00ol0003oooooooooo`0^oooo
o`00:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Kooooo0_l0000noooo
o`;o000000?oAZ<0o`000?m4XP001?m4XP000ol0003o@Z80od:R0004od:R0003o`000?loX@3o?j40
00?o?j4000?o0000ocbO0?llW`000ollW`000ol0003o>9h0ocRN0004ocRN0003o`000?lcW@3o<id0
00?o<id000?o0000objK0?l^V`000ol^V`000ol0003o:9T0obRI0003obRI0003o`000?lNUP3o7YH0
00Go7YH00_l00005olbb0004o`000?mJZ@3oFZT0o`0000;oFZT000?o0000ol;40?o2a0000_o2a000
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02kooooo000[ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00004oooool3o`0003oooooo00Go0000odJS0?m6X`3oAZ<0o`00
0005odBR0003o`000?m2XP3o@Z8000Co@Z8000?o0000ocnQ0?loX@000oloX@000ol0003o?9l0ocbO
0003ocbO0003o`000?lhWP3o>9h000Co>9h000?o0000oc>M0?lcW@000olcW@000ol0003o;Y/0objK
0003objK0003o`000?lXV@3o:9T000Co:9T000?o0000oajF0?lNUP000olNUP02o`0000Koc;8000Ko
0000oeZY0?mJZ@3o0000oeZY0?l00005ol;40003o`000?oooooooooo01?ooooo0_l0000_ooooo`00
:_ooool2o`0000Cooooo00Co0000oooooooooooo00004Oooool2o`00043ooooo0_l00004odJS0003
o`000?m4XP3oA:8000CoA:8000?o0000od:R0?m2XP000om2XP000ol0003o?j40ocnQ0003ocnQ0003
o`000?llW`3o?9l000Co?9l000?o0000ocRN0?lhWP000olhWP000ol0003o<id0oc>M0003oc>M0003
o`000?l^V`3o;Y/000?o;Y/000?o0000obRI0?lXV@001?lXV@001?l0003o7YH0oajF0?lNUP02o`00
0003omND0?l0003oc;8000Goc;8000Ko0000oeZY0?mJZ@3o0000oeZY0?l00005ol;400;o00005_oo
ool00ol0003oooooooooo`0/ooooo`00:oooool00ol0003oooooooooo`03ooooo`;o00003oooool3
o`0003oooooo0ol000000om7X`3o0000odJS0003odJS0003o`000?m4XP3oA:8000CoA:8000?o0000
od:R0?m2XP000om2XP000ol0003o?j40ocnQ0003ocnQ0003o`000?llW`3o?9l000Co?9l000?o0000
ocRN0?lhWP000olhWP000ol0003o<id0oc>M0003oc>M0003o`000?l^V`3o;Y/000Co;Y/000?o0000
obRI0?lXV@000olXV@001?l0003o7YH0oajF0?l00003omND0003o`000?o</P3oc;8000Goc;8000Go
0000oeZY0?l0003oFZT0o`000004ol;40004o`000?o;]@3obkD0o`0001Gooooo00?o0000oooooooo
ool0;?ooool003oooooo0ol00002ooooo`03o`000?oooooooooo03[ooooo0ol00004odNS0003o`00
0?m6X`3oAZ<000?oAZ<000?o0000odBR0?m4XP000om4XP000ol0003o@Z80od:R0003od:R0003o`00
0?loX@3o?j4000?o?j4000?o0000ocbO0?llW`001?llW`000ol0003o>9h0ocRN0003ocRN0003o`00
0?lcW@3o<id000?o<id000?o0000objK0?l^V`001?l^V`000ol0003o:9T0obRI0003obRI00?o0000
1?oGU0000ol0003oc;80olbb0005olbb0004o`000?mJZ@3oFZT0o`0000Go`/@000Co0000ol^e0?o;
]@3o00005_ooool00ol0003oooooooooo`06ooooo`;o00008oooool003gooooo0_l0000oooooo`?o
000000?oB:<0o`000?m7X`001?m7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4XP3oA:8000?o
A:8000?o0000od:R0?m2XP000om2XP000ol0003o?j40ocnQ0004ocnQ0003o`000?llW`3o?9l000?o
?9l000?o0000ocRN0?lhWP000olhWP000ol0003o<id0oc>M0003oc>M0003o`000?l^V`3o;Y/000Co
;Y/000?o0000obRI0?lXV@000_lXV@02o`0000Ooei@000?o0000olbb0?o</P001?o</P001?l0003o
FZT0oeZY0?l00005ol;40005o`000?o;]@3obkD0ol^e0?l000005_ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`0002;ooooo000jooooo`?o0000?_ooool3o`0000CoB:<000?o0000
odNS0?m7X`000om7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4XP3oA:8000?oA:8000?o0000
od:R0?m2XP000om2XP000ol0003o?j40ocnQ0004ocnQ0003o`000?llW`3o?9l000?o?9l000?o0000
ocRN0?lhWP000olhWP000ol0003o<id0oc>M0004oc>M0003o`000?l^V`3o;Y/000?o;Y/000?o0000
obRI0?l000000_l000000ooISP3o0000omND0006omND0003o`000?o</P3oc;8000Coc;8000Co0000
oeZY0?mJZ@3o00001?o2a0000ol0003obkD0ol^e0002ol^e0003o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000Rooooo`00>?ooool2o`0003kooooo0ol0
00000om8Y03o0000odRS0004odRS0003o`000?m7X`3oAj<000?oAj<000?o0000odJS0?m6X`000om6
X`000ol0003oA:80odBR0003odBR0003o`000?m2XP3o@Z8000Co@Z8000?o0000ocnQ0?loX@000olo
X@000ol0003o?9l0ocbO0003ocbO0003o`000?lhWP3o>9h000?o>9h000?o0000oc>M0?lcW@001?lc
W@000ol0003o;Y/0objK0002objK00?o00001?oISP000ol0003oei@0omND0005omND0003o`000?o<
/P3oc;8000Coc;8000Co0000oeZY0?l0003o00001?o2a0000ol0003obkD0ol^e0002ol^e00;o0000
5_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0002;ooooo000eooooo`?o0000
?_ooool2o`0000CoB:@000?o0000odRS0?m8X`000om8X`000ol0003oAj<0odNS0003odNS0003o`00
0?m6X`3oAZ<000?oAZ<000?o0000odBR0?m4XP000om4XP000ol0003o@Z80od:R0004od:R0003o`00
0?loX@3o?j4000?o?j4000?o0000ocbO0?llW`000ollW`000ol0003o>9h0ocRN0003ocRN0003o`00
0?lcW@3o<id000Co<id000?o0000objK0?l^V`000_l000000ooISP3o0000omV>0005omV>0003o`00
0?oGU03oei@000Coei@000?o0000olbb0?o</P001?o</P001?l0003oFZT0o`000?l00004ol;40005
o`000?o;]@3obkD0ol^e0?l000000_o;]0000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00008_ooool003?ooooo0_l00003ooooo`03o`000?oooooooooo
03Sooooo0ol000000om8Y03o0000odRT0003odRT0003o`000?m8X`3oB:<000CoB:<000?o0000odNS
0?m7X`000om7X`000ol0003oAZ<0odJS0002odJS0003o`000?m4XP3oA:8000?oA:8000?o0000od:R
0?m2XP001?m2XP000ol0003o?j40ocnQ0003ocnQ0003o`000?llW`3o?9l000?o?9l000?o0000ocRN
0?lhWP001?lhWP000ol0003o<id0oc>M0003oc>M00?o00000ooISP000ol0003ofHh0omV>0004omV>
0003o`000?oGU03oei@000Coei@000?o0000olbb0?o</P001Oo</P03o`0000Co`/@000Go0000ol^e
0?o;]@3obkD0o`000003ol^d0003o`000?oooooooooo01?ooooo0_l00003ooooo`04o`000?oooooo
ooooo`0002;ooooo000`ooooo`?o0000?Oooool3o`0000CoB:@000?o0000odRT0?m8Y0000_m8Y000
0ol0003oB:<0odRS0004odRS0003o`000?m7X`3oAj<000?oAj<000?o0000odJS0?m6X`000_m6X`00
0ol0003oA:80odBR0004odBR0003o`000?m2XP3o@Z8000?o@Z8000?o0000ocnQ0?loX@000oloX@00
0ol0003o?9l0ocbO0003ocbO0003o`000?lhWP3o>9h000Co>9h000?o0000oc>M0?lcW@000_lcW@02
o`0000KofHh000?o0000omV>0?oISP000ooISP000ol0003oei@0omND0005omND0003o`000?o</P3o
c;8000Coc;8000?o0000ol;40?l000000oo2a0000ol0003obkD0ol^e0002ol^e0005o`000?o;]03o
bk@0ol^d0?l000005?ooool00ol0003oooooo`000004ooooo`;o00008oooool002gooooo0ol0000m
ooooo`?o000000?oB:@0o`000?m8Y0001?m8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8X`3o
B:<000?oB:<000?o0000odNS0?m7X`000om7X`000ol0003oAZ<0odJS0002odJS0003o`000?m4XP3o
A:8000CoA:8000?o0000od:R0?m2XP000om2XP000ol0003o?j40ocnQ0003ocnQ0003o`000?llW`3o
?9l000Co?9l000?o0000ocRN0?lhWP000olhWP000ol0003o<id0o`000002o`000003omV?0?l0003o
fHh000GofHh000?o0000omV>0?oISP000ooISP000ol0003oei@0omND0005omND0003o`000?o</P3o
c;8000Coc;800ol00003ol;40005o`000?o;]@3obkD0ol^e0?l000000oo;]0000ol0003obkD0o`00
000Fooooo`03o`000?oooooooooo02Kooooo000[ooooo`;o0000?_ooool2o`0000CoB:@000?o0000
odRT0?m8Y0000om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8X`3oB:<000?oB:<000?o0000
odNS0?m7X`000om7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4XP3oA:8000?oA:8000?o0000
od:R0?m2XP000om2XP000ol0003o?j40ocnQ0003ocnQ0003o`000?llW`3o?9l000Co?9l000?o0000
ocRN0?lhWP000_lhWP03o`0000CofHl000?o0000omV>0?oISP001?oISP000ol0003ofHh0omV>0004
omV>0003o`000?oGU03oei@000Coei@000?o0000olbb0?o</P000_o</P03o`000003ol;40?l0003o
`/@000;o`/@000Go0000ol^e0?o;]@3obkD0o`000003ol^d0003o`000?o;]@3o000001Kooooo00?o
0000ooooooooool09_ooool002Sooooo0ol000000ooooooo0000ooooo`0jooooo`?o000000?oAj<0
o`000?m8Y0000om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000?oB:@000?o0000
odRS0?m8X`000om8X`000ol0003oAj<0odNS0003odNS0003o`000?m6X`3oAZ<000?oAZ<000?o0000
odBR0?m4XP000om4XP000ol0003o@Z80od:R0003od:R0003o`000?loX@3o?j4000?o?j4000?o0000
ocbO0?llW`001?llW`000ol0003o>9h0o`000002o`000003omR?0?l0003ofHl000GofHl000?o0000
omV>0?oISP000ooISP000ol0003ofHh0omV>0004omV>0003o`000?oGU03oei@000Coei@000?o0000
olbb0?l000000_l000001_o</P3o0000onUI0?l0003o`/@0o`0000;o`/@000Go0000ol^e0?o;]@3o
bkD0o`000003ol^d0004o`000?o;]@3obkD0o`0001Kooooo00?o0000ooooooooool09Oooool002Oo
oooo0_l0000looooo`?o00001?m7X`000ol0003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?o
B:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0odRS0003odRS0003o`000?m7X`3oAj<000?o
Aj<000?o0000odJS0?m6X`000om6X`000ol0003oA:80odBR0003odBR0003o`000?m2XP3o@Z8000?o
@Z8000?o0000ocnQ0?loX@001?loX@000ol0003o?9l0ocbO0002ocbO00?o00001?oHS`000ol0003o
fHl0omV?0004omV?0003o`000?oISP3ofHh000CofHh000?o0000omV>0?oISP000ooISP000ol0003o
ei@0omND0003omND00?o00000oo</P001?l0003ojET0onUI0?l00002ol;400;o00001?o;]@001?l0
003obk@0ol^d0?l00003ol^e0003o`000?oooooooooo01Gooooo00?o0000ooooooooool09?ooool0
02Oooooo00?o0000ooooool00000>?ooool3o`000003odJS0?l0003oAj<000CoAj<000?o0000odRT
0?m8Y0000_m8Y0000ol0003oB:@0odRT0004odRT0003o`000?m8Y03oB:@000;oB:@000?o0000odRS
0?m8X`000om8X`000ol0003oAj<0odNS0003odNS0003o`000?m6X`3oAZ<000?oAZ<000?o0000odBR
0?m4XP000om4XP000ol0003o@Z80od:R0003od:R0003o`000?loX@3o?j4000Co?j4000?o0000ocbO
0?llW`000_l000000ooHT03o0000omR?0005omR?0003o`000?oIS`3ofHl000?ofHl000?o0000omV>
0?oISP001?oISP000ol0003ofHh0omV>0003omV>0003o`000?oGU03oei@000?o000000?oei@0o`00
0?o</P000_o</P000ol0003ojET0onUI0002onUI0004o`000?o2a03o`/@0o`0000?obkD000Go0000
ol^d0?o;]03obk@0o`000003ol^e00;o00005_ooool00ol0003oooooooooo`0Tooooo`009oooool0
1?l0003oooooooooool0000eooooo`;o00001?m6X`000ol0003oAj<0odNS0003odNS0003o`000?m8
Y03oB:@000;oB:@000?o0000odRT0?m8Y0001?m8Y0000ol0003oB:@0odRT0002odRT0003o`000?m8
X`3oB:<000CoB:<000?o0000odNS0?m7X`000_m7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4
XP3oA:8000?oA:8000?o0000od:R0?m2XP001?m2XP000ol0003o?j40ocnQ0003ocnQ00?o00000ooH
T0000ol0003of8l0omR?0004omR?0003o`000?oIS`3ofHl000?ofHl000?o0000omV>0?oISP001?oI
SP000ol0003ofHh0omV>0003omV>00?o00001OoGU0000ol0003oc;80o`000006onUI0003o`000?o2
a03o000000?obkD000Go0000ol^d0?o;]03obk@0o`000002ol^e0004o`000?o;]P3obkH0o`0001Ko
oooo00?o0000ooooooooool08oooool002Oooooo0_l00002ooooo`03o`000?oooooooooo02oooooo
0ol000000om5X`3o0000odJS0003odJS0003o`000?m7X`3oAj<000?oAj<000?o0000odRT0?m8Y000
0om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000;oB:@000?o0000odRS0?m8X`00
1?m8X`000ol0003oAj<0odNS0002odNS0003o`000?m6X`3oAZ<000?oAZ<000?o0000odBR0?m4XP00
0om4XP000ol0003o@Z80od:R0004od:R0003o`000?loX@3o?j4000;o?j400_l00006omR@0003o`00
0?oHS`3of8l000?of8l000?o0000omV?0?oIS`001?oIS`000ol0003ofHh0omV>0003omV>0003o`00
0?oISP3ofHh000?o000000?ofHh0o`000?oGU0001OoGU002o`0000OojET00_l000001Oo;]@3o0000
ol^e0?o;]@3o000000;obk@000Go0000ol^e0?o;]@3obkD0o`000003ol^f0003o`000?oooooooooo
01Cooooo00?o0000ooooooooool08_ooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`?o00001?ooool3o`0000?ooooo00?o0000ooooooooool0:_ooool4o`0000Co
AJ<000?o0000odJS0?m6X`000_m6X`000ol0003oAj<0odNS0003odNS0003o`000?m8Y03oB:@000?o
B:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8X`3oB:<000?o
B:<000?o0000odNS0?m7X`000_m7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4XP3oA:8000Co
A:8000?o0000od:R0?m2XP000om2XP000ol0003o?j40o`000002o`000003omR@0?l0003of90000Go
f90000?o0000omR?0?oHS`000ooHS`000ol0003ofHl0omV?0004omV?0003o`000?oISP3ofHh000Co
fHh00_l00004omV>0003o`000?oGU03oei@000?oei@00_l00009onUI0006o`000?o;]@3obkD0o`00
0?o;]@3o00000_o;]0001Ol0003obkD0ol^e0?o;]@3o000000?obkH000?o0000ooooooooool04ooo
ool2o`0002Cooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`0Uoooo
o`Co00000om3XP000ol0003oAJ<0odFS0002odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS
0?m7X`001?m7X`000ol0003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT
0?m8Y0000om8Y0000ol0003oB:<0odRS0003odRS0003o`000?m7X`3oAj<000;oAj<000?o0000odJS
0?m6X`000om6X`000ol0003oA:80odBR0004odBR0003o`000?m2XP3o@Z8000;o@Z800ol00004omR@
0003o`000?oHT03of90000Cof90000?o0000omR?0?oHS`000ooHS`000ol0003ofHl0omV?0004omV?
0004o`000?oISP3ofHh0omV>00Co00001OoISP001?l0003oei@0omND0?oGU002o`000003oo<c0?l0
003ojET000SojET000?o0000ol^e0?o;]@000_l00003ol^d0004o`000?o;]@3obkD0o`0000CobkH0
0_l0000Fooooo`03o`000?oooooooooo027ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool01_l0003ooooooooooooooooo0000ooooo`;o00001?ooool0
0ol0003oooooooooo`0Qooooo`?o000000?o@:40o`000?m3XP001?m3XP000ol0003oAJ<0odFS0002
odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`001?m7X`000ol0003oB:@0odRT0002
odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0odRS0003
odRS0003o`000?m7X`3oAj<000?oAj<000?o0000odJS0?m6X`000om6X`000ol0003oA:80odBR0003
odBR0003o`000?m2XP3o000000;o000000?of940o`000?oHT0001OoHT0000ol0003of900omR@0003
omR@0003o`000?oHS`3of8l000Cof8l000?o0000omV?0?oIS`001?oIS`03o`0000?ofHh000?o0000
omV>0?oISP001?oISP03o`0000Colc<000?o0000onUI0?oYF@001OoYF@000ol0003okd40o`000002
ol^e0004o`000?o;]03obk@0o`0000?obkD000Go0000ol^f0?o;]P3obkH0o`000002olZg0003o`00
0?oooooooooo01Cooooo00?o0000ooooooooool08?ooool000gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00005ooooo`06o`000?ooooooooooooooool0003ooooo0_l00005
ooooo`03o`000?oooooooooo01gooooo0ol00004od2Q0003o`000?m3XP3o@j8000?o@j8000?o0000
odFS0?m5X`000_m5X`000ol0003oAZ<0odJS0003odJS0003o`000?m7X`3oAj<000?oAj<000?o0000
odRT0?m8Y0000_m8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000?oB:@000?o0000
odRS0?m8X`000om8X`000ol0003oAj<0odNS0003odNS0003o`000?m6X`3oAZ<000?oAZ<000?o0000
odBR0?m4XP000_m4XP03o`0000Cof94000?o0000omR@0?oHT0001?oHT0000ol0003of900omR@0003
omR@0003o`000?oHS`3of8l000Cof8l000Co0000omV?0?oIS`3ofHl01?l00005omV>0003o`000?oI
SP3ofHh000?ofHh00_l00006oo<c0003o`000?oYF@3ojET000CojET000Ko0000onm10?o_@@3okd40
o`000?o;]@02o`000003ol^d0?l0003obkD000;obkD000Go0000ol^f0?o;]P3obkH0o`000003olZg
0003o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool000gooooo00Co0000oooooooo
oooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00001?ooool4o`0000Kooooo00?o0000
ooooooooool06?ooool4o`0000;o?J0000?o0000od2Q0?m0X@000_m0X@000ol0003o@j80od>R0003
od>R0003o`000?m5X`3oAJ<000;oAJ<000?o0000odJS0?m6X`000om6X`000ol0003oAj<0odNS0003
odNS0003o`000?m8Y03oB:@000;oB:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:@0odRT0003
odRT0003o`000?m8X`3oB:<000?oB:<000?o0000odNS0?m7X`000om7X`000ol0003oAZ<0odJS0003
odJS0003o`000?m4XP3o000000;o000000?of980o`000?oHT@001OoHT@000ol0003of900omR@0003
omR@0003o`000?oHT03of90000Cof90000?o0000omR?0?oHS`000ooHS`04o`0000?ofHl000?o0000
omV>0?oISP001?oISP000ol0003ofHh0o`000002o`000003oo<b0?l0003olc<000Kolc<000?o0000
onUI0?oYF@000_oYF@000ol0003okd40onm10002onm100;o00000_o;]002o`0000;obkD000?o0000
ol^f0?o;]P000_o;]P001Ol0003ob[L0olZg0?o:]`3o000001Kooooo00?o0000ooooooooool07ooo
ool000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Oo
oooo00Go0000ooooool0003o05E<o`000006ooooo`03o`000?oooooooooo01Cooooo0ol000000olj
W`3o0000ocfP0003ocfP0003o`000?m0X@3o@:4000;o@:4000?o0000od>R0?m3XP000om3XP000ol0
003oAJ<0odFS0003odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`000om7X`000ol0
003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT0?m8Y0000om8Y0000ol0
003oB:<0odRS0003odRS0003o`000?m7X`3oAj<000?oAj<000?o0000odJS0?m6X`000_m6X`03o`00
00Cof98000?o0000omRA0?oHT@001?oHT@000ol0003of900omR@0003omR@0003o`000?oHT03of900
00Cof90000Co0000omR?0?oHS`3of8l00ol00006omV?0003o`000?oISP3ofHh000?ofHh00ol00005
oo<b0003o`000?oc<`3olc<000Colc<000?o0000onUI0?oYF@000_oYF@000ol0003okd40onm10003
onm10004o`000?o;]03obk@0o`0000?obkD000Go0000ol^f0?o;]P3obkH0o`000004olZg00;o0000
5_ooool00ol0003oooooooooo`0Nooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go00000ooo
ool01Ol0003oooooo`000?l0EDco000000Oooooo00?o0000ooooooooool04?ooool3o`0000Co>Yl0
00?o0000ocfP0?lmX0000_lmX0000ol0003o@:40od2Q0002od2Q0003o`000?m3XP3o@j8000?o@j80
00?o0000odFS0?m5X`000om5X`000ol0003oAZ<0odJS0002odJS0003o`000?m7X`3oAj<000?oAj<0
00?o0000odRT0?m8Y0000_m8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000?oB:@0
00?o0000odRS0?m8X`001?m8X`000ol0003oAj<0odNS0002odNS0003o`000?m6X`3o000000;o0000
00?oei80o`000?oHTP001OoHTP000ol0003of940omRA0003omRA0003o`000?oHT03of90000Cof900
00?o0000omR@0?oHT0000ooHT004o`0000;of8l000?o0000omV?0?oIS`001OoIS`000ol0003ofHh0
o`000002o`000003oo8h0?l0003olc8000Golc8000?o0000oo<c0?oc<`001Ooc<`001?l0003ojET0
onUI0?l00006onm10003o`000?o;]03obk@000;o00000_o;]@001Ol0003obkH0ol^f0?o;]P3o0000
00?ob[L000Co0000olZh0?o:^03o00005Oooool00ol0003oooooooooo`0Nooooo`009Oooool4o`00
0003o`1EC?l0003o000000Oooooo00?o0000ooooooooool02_ooool5o`0000;o=Yd000?o0000ocZO
0?ljW`000_ljW`000ol0003o?J00ocfP0002ocfP0003o`000?m0X@3o@:4000;o@:4000?o0000od>R
0?m3XP000om3XP000ol0003oAJ<0odFS0003odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS
0?m7X`000om7X`000ol0003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT
0?m8Y0000om8Y0000ol0003oB:<0odRS0004odRS0004o`000?m7X`3oAj<0odNS00?o00001?oGTP00
0ol0003of980omRB0004omRB0003o`000?oHT@3of94000?of94000?o0000omR@0?oHT0001?oHT000
0ol0003of900omR@0002omR@00;o00001_oHS`000ol0003ofHl0omV?0002omV?00Co00001Oob>000
0ol0003olc80oo<b0004oo<b0003o`000?oc<`3olc<000Colc<000?o0000onUI0?l000001_o_@@00
2Ol0003okd80o`000?o;]03o0000ol^e0?l0003obkD0o`000003ol^f0005o`000?o:]`3ob[L0olZg
0?l000000_o:^0000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo000Uooooo`08
o`000?ooooooooooo`000?l0EDco0000o`1n5ol00007ooooo`03o`000?oooooooooo00Gooooo1?l0
0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP
0002ocfP0003o`000?m0X@3o@:4000?o@:4000?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0odFS
0003odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`000om7X`000ol0003oB:@0odRT
0002odRT0003o`000?m8Y03oB:@000CoB:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0odRS
0003odRS00Co000000?oei80o`000?oGTP001OoGTP000ol0003of980omRB0003omRB0003o`000?oH
T@3of94000Cof94000?o0000omR@0?oHT0000ooHT0000ol0003of900o`000002o`000003omR@0?l0
003of8l000Gof8l000?o0000omV?0?l000000_l00002oo0n0003o`000?ob>03olSP000ColSP000?o
0000oo<b0?oc<P001?oc<P000ol0003olc<0oo<c0003oo<c00?o00001_o_@@001Ol0003okd80onm2
0?o_@P3o000000;obkD00_l00003ol^f0003o`000?o:]`3ob[L000;ob[L000?o0000olZh0?o:^000
0_l0000Dooooo`?o00007_ooool002Gooooo0_l000001?oooooo0000o`1EC?l00002o`1n5`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol000000ol[VP3o0000oc6L0003oc6L0003
o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP0002ocfP0003
o`000?m0X@3o@:4000?o@:4000?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0odFS0003odFS0003
o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`000om7X`000ol0003oB:@0odRT0002odRT0003
o`000?m8Y03oB:@000CoB:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0odRS0002odRS00;o
00001?oGTP000ol0003oei80omNB0004omNB0003o`000?oHTP3of98000?of98000?o0000omRA0?oH
T@001?oHT@000ol0003of900omR@0002omR@00?o00001OoHT0000ol0003of8l0omR?0002omR?00?o
00001_o`?P000ol0003olSP0oo8h0004oo8h0003o`000?oc<P3olc8000?olc8000?o0000oo<c0?oc
<`000ol00002ooTL0003o`000?o_@@3okd4000?okd4000?o0000onm20?o_@P000_o_@P001Ol0003o
bkD0ol^e0?o;]@3o000000?obkH000Go0000olZg0?o:]`3ob[L0o`000002olZh0004o`000?o9^03o
bKP0o`0001Gooooo00?o0000ooooooooool07?ooool002Gooooo00Ko0000oooooooooooo0000o`1E
C?l00003o`1n5`_o00001?l[VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd0
00?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP0003ocfP0003o`000?m0X@3o@:4000;o@:40
00?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0odFS0003odFS0003o`000?m6X`3oAZ<000;oAZ<0
00?o0000odNS0?m7X`000om7X`000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000?oB:@0
00?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0o`000002o`000003omNC0?l0003oei8000Coei80
00?o0000omNB0?oGTP000ooGTP000ol0003of980omRB0004omRB0003o`000?oHT@3of94000?of940
00?o0000omR@0?l000000_l000000ooHT03o0000omR@0005omR@0003o`000?oHS`3o000000;o0000
00?okd<0o`000?o`?P001_o`?P000ol0003olSP0oo8h0004oo8h0003o`000?oc<P3olc8000?olc80
0ol00006ooTL0005o`000?o_@@3okd40onm10?l000001?o_@P000ol0003okTH0o`000002ol^e00;o
00000_o;]P001Ol0003ob[L0olZg0?o:]`3o000000;ob[P000Go0000olVh0?o9^03obKP0o`00000E
ooooo`03o`000?oooooooooo01_ooooo000Uooooo`;o00000_ooool2o`0000?o07hG00?o0000oa>A
0?lCT@000_lCT@000ol0003o99P0obBH0002obBH0003o`000?l[VP3o:iX000;o:iX000?o0000oc6L
0?laW0000_laW0000ol0003o=Yd0ocJM0002ocJM0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocfP
0?lmX0000olmX0000ol0003o@:40od2Q0002od2Q0003o`000?m3XP3o@j8000;o@j8000?o0000odFS
0?m5X`000om5X`000ol0003oAZ<0odJS0002odJS0003o`000?m7X`3oAj<000?oAj<000?o0000odRT
0?m8Y0000om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000;oB:@00ol00004omNC
0003o`000?oGTP3oei8000?oei8000?o0000omNB0?oGTP000ooGTP000ol0003of980omRB0004omRB
0003o`000?oHT@3of94000;of9400ol00005omR@0003o`000?oHT03of90000Go00001Oo_@`000ol0
003ol3h0oo0n0005oo0n0003o`000?ob>03olSP000?olSP000?o0000oo<b0?oc<P000ol000000ooh
7P3o0000ooTL0007ooTL0003o`000?o_@@3o000000Cokd8000Co0000oni60?o^AP3okTH00_l00002
ol^f0003o`000?o;]P3o000000?ob[L000Co0000olZh0?o:^03o00000oo9^0000ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01[ooooo000Uooooo`04o`000?ooooooooooooooo`;o00000ol0
OQL00ol0003o4i40oa>A0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[
VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_lj
W`000ol0003o?J00ocfP0003ocfP0003o`000?m0X@3o@:4000;o@:4000?o0000od>R0?m3XP000om3
XP000ol0003oAJ<0odFS0002odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`001?m7
X`000ol0003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT0?l000000_l0
00000ooGT`3o0000omNC0005omNC0003o`000?oGTP3oei8000;oei8000?o0000omNB0?oGTP001?oG
TP000ol0003of980omRB0003omRB0003o`000?oHT@3o000000;o000000?of940o`000?oHT0001?oH
T004o`0000?okTL000?o0000onm30?o_@`001Oo_@`000ol0003ol3h0oo0n0004oo0n0004o`000?ob
>03olSP0oo8h00Go00001Ooh7P000ol0003onA`0ooTL0004ooTL00?o00001?o_@P000ol0003okTH0
oni60003oni60003o`000?o;]P3obkH000;o00000oo:]`001?l0003ob[P0olZh0?l00004olVh00;o
00005Oooool00ol0003oooooooooo`0Jooooo`001_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00Co0000oooooooooooo
oooo0_l00003o`1n5`03o`000?lCT@3o4i4000;o4i4000?o0000obBH0?lTV0000_lTV0000ol0003o
:iX0ob^J0002ob^J0003o`000?laW03o<I`000;o<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o
>Yl0ocZO0002ocZO0003o`000?lmX03o?J0000?o?J0000?o0000od2Q0?m0X@000_m0X@000ol0003o
@j80od>R0003od>R0003o`000?m5X`3oAJ<000;oAJ<000?o0000odJS0?m6X`000_m6X`000ol0003o
Aj<0odNS0004odNS0003o`000?m8Y03oB:@000;oB:@000?o0000odRT0?m8Y0000_m8Y003o`0000Co
ei<000?o0000omNC0?oGT`001?oGT`000ol0003oei80omNB0002omNB0003o`000?oGTP3oei8000Co
ei8000?o0000omRB0?oHTP000_oHTP03o`0000Gof94000?o0000omR@0?l000000_l000000oo]B`3o
0000oni70005oni70003o`000?o_@`3okd<000Cokd<000?o0000oo0n0?o`?P001?o`?P04o`0000?o
mRH000?o0000ooPN0?oh7P001Ooh7P000ol0003onA`0ooTL0003o`0000;on1l000Go0000onm20?o_
@P3okd80o`000006oni60005o`000?o;]P3obkH0ol^f0?l000000oo:]`001?l0003ob[P0olZh0?l0
0003olVh0004o`000?o9^@3obKT0o`0001Gooooo00?o0000ooooooooool06Oooool000Gooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooooooool2o`0000?ooooo0_l00003o`1n5`03o`000?lCT@3o
4i4000;o4i4000?o0000obBH0?lTV0000_lTV0000ol0003o:iX0ob^J0002ob^J0003o`000?laW03o
<I`000;o<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o>Yl0ocZO0002ocZO0003o`000?lmX03o
?J0000?o?J0000?o0000od2Q0?m0X@000_m0X@000ol0003o@j80od>R0003od>R0003o`000?m5X`3o
AJ<000;oAJ<000?o0000odJS0?m6X`000om6X`000ol0003oAj<0odNS0003odNS0003o`000?m8Y03o
B:@000;oB:@000?o0000odRT0?l000000_l000000ooGT`3o0000omNC0005omNC0003o`000?oGT`3o
ei<000?oei<000?o0000omNB0?oGTP000ooGTP000ol0003oei80omNB0003omNB0003o`000?oHTP3o
f98000;o000000?of980o`000?oHT@001?oHT@03o`0000GokD/000?o0000oni70?o^A`000oo^A`00
0ol0003okd<0onm30005onm30003o`000?o`?P3ol3h000?o000000?om2d0o`000?of9P001Oof9P00
0ol0003on1h0ooPN0004ooPN00?o00001_oh7`000ol0003okd80o`000006oni60003o`000?o]BP3o
000000;obkH00_l00002olZg0004o`000?o:^03ob[P0o`0000?obKP000Go0000olVi0?o9^@3obKT0
o`00000Dooooo`03o`000?oooooooooo01Wooooo0005ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001?ooool2o`0000?o07hG00?o0000oa>A0?lCT@000_lCT@000ol0003o99P0obBH0002obBH
0003o`000?l[VP3o:iX000;o:iX000?o0000oc6L0?laW0000_laW0000ol0003o=Yd0ocJM0002ocJM
0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocfP0?lmX0000olmX0000ol0003o@:40od2Q0002od2Q
0003o`000?m3XP3o@j8000?o@j8000?o0000odFS0?m5X`000_m5X`000ol0003oAZ<0odJS0003odJS
0003o`000?m7X`3oAj<000?oAj<000Co0000odRT0?m8Y03oB:@00ol00004omNC0003o`000?oGT`3o
ei<000Coei<000?o0000omNC0?oGT`000ooGT`000ol0003oei80omNB0003omNB0003o`000?oGTP3o
ei8000?oei800ol00004omRB0003o`000?oHT@3o000000;o000000?ok4h0o`000?o]B`001Oo]B`00
0ol0003okTL0oni70004oni70003o`000?o_@`3okd<000?okd<01?l00005oo@]0003o`000?of9P3o
mRH000ComRH000?o0000ooPN0?oh7P000ol000000ooh8@3o0000ooPO0006ooPO00;o00001_o^AP00
1?l0003okDX0one:0?o]BP02o`0000;ob[L00_l00002olZh0003o`000?o9^03obKP000;obKP000Go
0000olVi0?o9^@3obKT0o`00000Eooooo`03o`000?oooooooooo01Sooooo0005ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001?ooool2o`0000?o07hG00?o0000oa>A0?lCT@000_lCT@000ol0
003o99P0obBH0002obBH0003o`000?l[VP3o:iX000;o:iX000?o0000oc6L0?laW0000_laW0000ol0
003o=Yd0ocJM0002ocJM0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocfP0?lmX0000olmX0000ol0
003o@:40od2Q0002od2Q0003o`000?m3XP3o@j8000?o@j8000?o0000odFS0?m5X`000om5X`000ol0
003oAZ<0odJS0002odJS0003o`000?m7X`3oAj<000?oAj<01?l000000ooGT`3o0000omNC0005omNC
0003o`000?oGT`3oei<000?oei<000?o0000omNC0?oGT`001?oGT`000ol0003oei80omNB0002omNB
0003o`000?oGTP3oei8000Co00001OoHTP03o`0000Gok4h000?o0000one;0?o]B`001?o]B`000ol0
003okTL0oni70003oni70003o`000?o_@`3okd<000?o00000_oc=0000ol0003om2d0oo@]0005oo@]
0004o`000?of9P3omRH0ooHV00Go00001Ooh8@000ol0003on1l0ooPO0002ooPO00;o000000?ombD0
o`000?o^AP001?o^AP000ol0003okDX0one:0003one:0003o`000?o:]`3ob[L000;o00000_o:^000
1Ol0003obKP0olVh0?o9^03o000000CobKT00_l0000Dooooo`;o00006Oooool000Gooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o0000
1?ooool2o`0000?ooooo0_l00003o`1n5`03o`000?lCT@3o4i4000;o4i4000?o0000obBH0?lTV000
0_lTV0000ol0003o:iX0ob^J0002ob^J0003o`000?laW03o<I`000;o<I`000?o0000ocJM0?lfW@00
0_lfW@000ol0003o>Yl0ocZO0003ocZO0003o`000?lmX03o?J0000;o?J0000?o0000od2Q0?m0X@00
0_m0X@000ol0003o@j80od>R0003od>R0003o`000?m5X`3oAJ<000?oAJ<000?o0000odJS0?m6X`00
0_m6X`000ol0003oAj<0odNS0002odNS00;o00001?oGT`000ol0003oei<0omNC0004omNC0003o`00
0?oGT`3oei<000?oei<000?o0000omNC0?oGT`001?oGT`000ol0003oei80omNB0002omNB00?o0000
1?oGTP000ol0003of980o`000002o`000003on]A0?l0003ok4h000Gok4h000?o0000one;0?o]B`00
1?o]B`001?l0003okTL0oni70?o^A`05o`0000Kolc@000?o0000oo@]0?od;@001?od;@04o`0000Co
mRT000?o0000ooPQ0?oh8@001?oh8@001?l0003on1l0o`000?l00004ooLU0005o`000?o^AP3okTH0
oni60?l000001Oo]BP000ol0003ok4h0o`000002olZg0004o`000?o:^03ob[P0o`0000?obKP000Go
0000olVi0?o9^@3obKT0o`000002olVj0003o`000?oooooooooo01;ooooo00?o0000ooooooooool0
5oooool000Gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?l0EDco0000
00;o07hG00?o0000oa>A0?lCT@000_lCT@000ol0003o99P0obBH0002obBH0003o`000?l[VP3o:iX0
00;o:iX000?o0000oc6L0?laW0000_laW0000ol0003o=Yd0ocJM0002ocJM0003o`000?ljW`3o>Yl0
00?o>Yl000?o0000ocfP0?lmX0000_lmX0000ol0003o@:40od2Q0002od2Q0003o`000?m3XP3o@j80
00?o@j8000?o0000odFS0?m5X`000om5X`000ol0003oAZ<0odJS0002odJS0003o`000?m7X`3o0000
00;o000000?oei80o`000?oGT`001?oGT`000ol0003oei<0omNC0003omNC0003o`000?oGT`3oei<0
00Coei<000?o0000omNC0?oGT`000ooGT`000ol0003oei80o`000003o`0000Goei800ol00005on]A
0003o`000?o/CP3ok4h000Cok4h000?o0000one;0?o]B`000oo]B`04o`0000GolCT000?o0000oo<d
0?oc=0001?oc=0000ol0003om2d0oo@]0003o`000003oo@a0?l0003omRT000KomRT000Co0000ooPQ
0?oh8@3on2401?l00007ooLU0003o`000?o^AP3o000000GokDX000Co0000ona>0?o/CP3ok4h00_l0
00001?o:^03o0000olZh0?l00003olVh0005o`000?o9^@3obKT0olVi0?l000000_o9^P000ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo0006ooooo`;o00002_ooool2o`0000;ooooo
1Ol000000ooooooo0000o`000003o`0000?ooooo0_l00004ooooo`;o00000_l0OQL00ol0003o4i40
oa>A0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0
oc6L0002oc6L0003o`000?lfW@3o=Yd000?o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00
ocfP0002ocfP0003o`000?m0X@3o@:4000;o@:4000?o0000od>R0?m3XP000om3XP000ol0003oAJ<0
odFS0003odFS0004o`000?m6X`3oAZ<0odJS00?o00001?oGTP000ol0003oei<0omNC0003omNC0003
o`000?oGT`3oei<000?oei<000?o0000omNC0?oGT`001?oGT`000ol0003oei<0omNC0002omNC00?o
00001?oGTP000ol0003oei80o`000002o`000003on]C0?l0003oje4000Goje4000?o0000ona>0?o/
CP001?o/CP000ol0003okD/0one;0003o`0000;ol3h000?o0000oo4i0?oa>@001Ooa>@001?l0003o
lc@0oo<d0?oc=005o`0000Gom34000?o0000ooHY0?of:@001?of:@04o`0000ComRL000?o0000ooLU
0?og9@001?og9@02o`0000GokDX000?o0000ona>0?o/CP000oo/CP001?l0003ob[P0o`000?l00003
olVh0003o`000?o9^@3obKT000;obKT000?o0000olVj0?o9^P000_l0000Eooooo`03o`000?oooooo
oooo01Gooooo000Sooooo`;o00001Oooool2o`0000;o07hG00?o0000oa>A0?lCT@000_lCT@000ol0
003o99P0obBH0002obBH0003o`000?l[VP3o:iX000;o:iX000?o0000oc6L0?laW0000olaW0000ol0
003o=Yd0ocJM0002ocJM0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocfP0?lmX0000_lmX0000ol0
003o@:40od2Q0003od2Q0003o`000?m3XP3o@j8000;o@j8000?o0000odFS0?m5X`000om5X`04o`00
0003omNB0?l0003oei8000Goei8000?o0000omNC0?oGT`000_oGT`000ol0003oei<0omNC0004omNC
0003o`000?oGT`3oei<000?oei<000?o0000omNC0?l000000_l000000ooGT`3o0000omNB0003omNB
00?o00001Oo[D`000ol0003oje40on]A0004on]A0003o`000?o/CP3ok4h000?ok4h00ol00006oo0n
0003o`000?oa>@3olCT000ColCT01?l00004oo8g0003o`000?od<@3om34000Com34000?o0000ooHY
0?of:@000ol00002oo@_0003o`000?of9`3omRL000ComRL000?o0000ooLU0?og9@000ol00002ooD[
0005o`000?o]BP3okDX0one:0?l000001Oo/CP02o`0000;ob[P000Go0000olVh0?o9^03obKP0o`00
0003olVi0004o`000?o9^P3obKX0o`0000;obKX000?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Eooooo`008oooool00ol0003oooooooooo`04ooooo`;o00000_l0OQL00ol0003o4i40oa>A
0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0oc6L
0003oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP
0002ocfP0003o`000?m0X@3o@:4000?o@:4000?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0odFS
0002odFS00;o00001?oGTP000ol0003oei80omNB0004omNB0003o`000?oGT`3oei<000?oei<000?o
0000omNC0?oGT`000ooGT`000ol0003oei<0omNC0003omNC00;o00001OoGT`04o`000003onYD0?l0
003oje<000Koje<000?o0000on]A0?o[D@000oo[D@000ol0003ok4h0ona>0003o`0000;okd8000?o
0000oo0n0?o`?P001Oo`?P000ol0003olCT0oo4i0003o`000003oo0m0?l0003olSL000KolSL000Co
0000oo@a0?od<@3om3401Ol00006oo@_0004o`000?of9`3omRL0ooHW00Go00001_oe:`000ol0003o
kDX0o`000005ona>0005o`000?o[D@3oje40o`000?o:^0000_l00002olVh0005o`000?o9^@3obKT0
olVi0?l000000_o9^P001Ol0003obKX0olVj0?o9^P3o000001Cooooo00?o0000ooooooooool05?oo
ool002?ooooo0_l00005ooooo`;o00000_l0OQL00ol0003o4i40oa>A0002oa>A0003o`000?lTV03o
99P000;o99P000?o0000ob^J0?l[VP000ol[VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o
=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP0003ocfP0003o`000?m0X@3o
@:4000;o@:4000?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0o`000002o`000003omRB0?l0003o
ei8000Coei8000?o0000omNB0?oGTP000ooGTP000ol0003oei<0omNC0003omNC0003o`000?oGT`3o
ei<000?oei<000?o0000omNC0?oGT`001?l00005omNC00;o00001OoZE0000ol0003oje<0on]C0004
on]C0003o`000?o[D@3oje4000?oje400ol00006onm20003o`000?o`?P3ol3h000Col3h00ol00005
oo0m0003o`000?ob=`3olSL000ColSL01?l00004oo8g0003o`000?od;`3om2l000Com2l01?l00004
oo@]0003o`000?oe:`3omB/000ComB/00_l00005ona>0004o`000?o[D@3oje40on]A00;o00000_o9
^002o`0000CobKT000Co0000olVj0?o9^P3o00000oo9^P000ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo00Cooooo0_l00002o`1n5`03o`000?lC
T@3o4i4000;o4i4000?o0000obBH0?lTV0000olTV0000ol0003o:iX0ob^J0002ob^J0003o`000?la
W03o<I`000;o<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o>Yl0ocZO0002ocZO0003o`000?lm
X03o?J0000?o?J0000?o0000od2Q0?m0X@000_m0X@001?l0003o@j80od>R0?m3XP03o`0000Cof980
00?o0000omNB0?oGTP000ooGTP000ol0003oei80omNB0003omNB0003o`000?oGT`3oei<000?oei<0
00?o0000omNC0?oGT`000ooGT`03o`0000Coei<000?o0000omNC0?l000000_l000000ooZEP3o0000
onYD0005onYD0003o`000?o[D`3oje<000Coje<000?o0000on]A0?l000000_l00003oni60003o`00
0?o_@P3okd8000Cokd8000?o0000oo0n0?o`?P000ol00002onm20003o`000?o`?@3ol3d000Col3d0
00?o0000oo8g0?ob=`000ol00002oo0m0003o`000?ob=`3olSL000ColSL000?o0000oo@_0?od;`00
0ol000000ooc=03o0000oo@]0006oo@]0003o`000?oe:`3omB/000?o00000_od<0001Ol0003ok4h0
ona>0?o/CP3o000000Goje4000?o0000olVh0?o9^0000_l00003olVi0004o`000?o9^P3obKX0o`00
00?obKX000?o0000olVj0?l000005?ooool00ol0003oooooooooo`0Cooooo`008oooool2o`0000Go
oooo0_l00003o`1n5`03o`000?lCT@3o4i4000;o4i4000?o0000obBH0?lTV0000_lTV0000ol0003o
:iX0ob^J0002ob^J0003o`000?laW03o<I`000;o<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o
>Yl0ocZO0002ocZO0003o`000?lmX03o?J0000?o?J0000?o0000od2Q0?m0X@000_m0X@04o`000003
omRA0?l0003of98000Gof98000?o0000omNB0?oGTP000_oGTP000ol0003oei80omNB0004omNB0003
o`000?oGT`3oei<000?oei<000?o0000omNC0?l000000ol00005omNC00?o00001OoZEP000ol0003o
jU@0onYD0004onYD0004o`000?o[D`3oje<0on]C00Co00001oo^AP001?l0003okd80onm20?o_@P05
o`0000Kokd8000Co0000oo0m0?o`?@3ol3d01Ol00006oo0m0004o`000?ob=`3olSL0oo8g00Go0000
1Ooc=0000ol0003om2d0oo@]0004oo@]00?o00001_od<0000ol0003ok4h0o`000006on]A00;o0000
0_o9^0001Ol0003obKT0olVi0?o9^@3o000000;obKX000Go0000olVj0?o9^P3obKX0o`000002olVj
0003o`000?oooooooooo017ooooo0_l0000Dooooo`008oooool00ol0003oooooooooo`04ooooo`;o
00000ol0OQL00ol0003o4i40oa>A0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[
VP000_l[VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?lj
W`000_ljW`000ol0003o?J00ocfP0003ocfP0004o`000?m0X@3o@:40od2Q00;o00001?oHT@000ol0
003of980omRB0004omRB0003o`000?oGTP3oei8000;oei8000?o0000omNB0?oGTP001?oGTP000ol0
003oei<0omNC0002omNC00?o00001?oGT`000ol0003oei<0o`000002o`000003onUF0?l0003ojUH0
00KojUH000?o0000onYD0?oZE0000ooZE004o`0000CokDP000?o0000oni60?o^AP001?o^AP04o`00
00CokTH000?o0000onm20?o_@P001?o_@P04o`0000Cokd8000?o0000oo0m0?o`?@001?o`?@04o`00
00ColC`000?o0000oo<d0?oc=0001?oc=0000ol0003om2d0oo@]0003o`000003oo<b0?l0003om300
00Kom3000_l00006on]A0003o`000?oZE03ojU@000;o000000GobKT0o`000?o9^@3obKT0o`000002
olVj0005o`000?o9^P3obKX0olVj0?l000000_o9^P000ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Gooooo0ol00004ooooo`;o00000oooool0013ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00Go0000o`1n5ol0OQOo07hGo`00
0004oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0oc6L
0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP
0003ocfP00Co000000?of940o`000?oHT@001?oHT@000ol0003of980omRB0003omRB0003o`000?oG
TP3oei8000?oei8000?o0000omNB0?oGTP000ooGTP000ol0003oei<0o`000002o`000003omNC0?l0
003oei<000?oei<00ol00005onUF0003o`000?oZEP3ojUH000CojUH000?o0000onYD0?oZE0000ol0
00000oo]B`3o0000one80006one80003o`000?o^AP3okTH000?o000000?okDT0o`000?o^AP001_o^
AP000ol0003okd80onm20003o`0000;okTL000?o0000onm20?o_@P001?o_@P000ol0003ol3d0oo0m
0003o`000003onm20?l0003olC`000KolC`000Co0000oo<d0?oc=03olc@01Ol00005oo<b0003o`00
0?od<03om30000;om3000_l000000ooc=03o0000on]A0004on]A0003o`000?oZE03ojU@000;ojU@0
00Go0000olVi0?l0003obKT0o`000002olVj0005o`000?o9^P3obKX0olVj0?l000000oo9^P02o`00
01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo000?ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool2
o`0000Oooooo00Go0000o`1n5ol0OQOo07hGo`000004oa>A0003o`000?lTV03o99P000;o99P000?o
0000ob^J0?l[VP000_l[VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o
0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP0002ocfP00;o00001?oHT@000ol0003of940omRA
0003omRA0003o`000?oHTP3of98000?of98000?o0000omNB0?oGTP000ooGTP000ol0003oei80omNB
0002omNB00?o00001OoGT`04o`000003onUG0?l0003ojEH000KojEH000?o0000onYF0?oZEP000ooZ
EP03o`0000GokD/000?o0000one80?o]B0001?o]B003o`0000GokDT000?o0000oni60?o^AP001?o^
AP03o`0000KokTL000Co0000onm20?o_@P3okd801Ol00005onm20003o`000?oa?03olC`000ColC`0
1?l00004oo4i0003o`000?oc<P3olc8000Colc8000Co0000oo@`0?l0003o00001?oc=0001Ol0003o
je40on]A0?o[D@3o000000CojU@00_l00002olVi00;o00000_o9^P001Ol0003obKX0olVj0?o9^P3o
000000;obKX000?o0000olVj0?l000005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool000oooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Go0000o`1n5ol0OQOo07hG
o`000004oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0
oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00
o`000002o`000003omR@0?l0003of94000Cof94000?o0000omRA0?oHT@000_oHT@000ol0003of980
omRB0004omRB0003o`000?oGTP3oei8000;oei8000?o0000omNB0?oGTP000_l000000ooGTP3o0000
omNC0004omNC00;o00001OoYE`000ol0003ojEH0onUF0004onUF0003o`000?oZEP3ojUH000?o0000
00?okD`0o`000?o]B`001_o]B`000ol0003okDP0one80003o`0000;ok4`000?o0000one90?o]B@00
1?o]B@000ol0003okTH0oni60003o`0000;okD/000?o0000oni70?o^A`001?o^A`04o`0000CokTL0
00?o0000onm20?o_@P001?o_@P000ol0003olC`0oo4l0003o`0000;ol40000?o0000oo4i0?oa>@00
1?oa>@001?l0003olc80oo<b0?oc<P04o`0000Oolc@000?o0000on]A0?l000001?oZE0001?l0003o
jUH0onYF0?l00002olVi0004o`000?o9^P3obKX0o`0000?obKX000Co0000olVj0?o9^P3o00000_o9
^P000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`003oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01Ol0003o07hGo`1n5ol0OQOo000000Co
4i4000?o0000obBH0?lTV0000_lTV0000ol0003o:iX0ob^J0002ob^J0003o`000?laW03o<I`000;o
<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o>Yl0ocZO0004o`0000Cof90000?o0000omRA0?oH
T@000ooHT@000ol0003of940omRA0002omRA0003o`000?oHTP3of98000Cof98000?o0000omNB0?oG
TP000_oGTP03o`0000Coei8000?o0000omNC0?l000000_l000000ooZEP3o0000onUG0005onUG0003
o`000?oYEP3ojEH000?ojEH00ol00005one<0003o`000?o]B`3okD/000CokD/00ol00006ona<0004
o`000?o]B@3okDT0one900Go00001_o]B`000ol0003okTL0oni70003o`000003one<0?l0003okTL0
00KokTL000Co0000onm20?o_@P3okd801Ol00006oo100004o`000?oa>@3olCT0oo4i00Ko00001?ob
=P000ol0003olc@0oo<d0004oo<d00;o00001?oZE0000ol0003ojUH0onYF0002onYF00;o000000?o
bKX0o`000?l000000oo9^P001Ol0003obKX0olVj0?o9^P3o000000;obKX00_l0000Dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`00
3oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`05
o`000?l0OQOo07hGo`1n5ol000001?lCT@000ol0003o99P0obBH0002obBH0003o`000?l[VP3o:iX0
00;o:iX000?o0000oc6L0?laW0000_laW0001?l0003o=Yd0ocJM0?lfW@04o`0000;of90000?o0000
omR@0?oHT0000ooHT0000ol0003of940omRA0003omRA0003o`000?oHT@3of94000?of94000?o0000
omRB0?oHTP000ooHTP000ol0003oei80o`000003o`0000Goei800ol00005onYF0003o`000?oYE`3o
jEL000CojEL000?o0000onUF0?l000000_l00003ona=0003o`000?o]C03okD`000?okD`000?o0000
one;0?o]B`000ol00002ona>0003o`000?o/C03ok4`000Cok4`01?l00004ona>0003o`000?o]B`3o
kD/000CokD/00ol00005one<0003o`000?o^A`3okTL000CokTL01?l00004oni60003o`000?o`@03o
l40000Col4001?l00003oo0m0003o`000?ob=P3olSH000GolSH000?o0000oo<d0?oc=0000ol00000
0oob=`3o0000onYD0002onYD0003o`000?oZEP3ojUH000?ojUH00_l000000oo9^P3o0000o`000003
olVj0004o`000?o9^P3obKX0o`0000?obKX000?o0000olRj0?l000005?ooool00ol0003ooooooooo
o`02ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`003oooool01?l0003ooooooooo
ool00008ooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`;o00000_l0OQL00ol0003o4i40
oa>A0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0
oc6L0002oc6L00Co000000?of8l0o`000?oHT0000ooHT0000ol0003of900omR@0004omR@0003o`00
0?oHT@3of94000;of94000?o0000omRA0?oHT@000ooHT@000ol0003of980omRB0002omRB00?o0000
1?oGTP000ol0003oei80o`000002o`000003onYE0?l0003ojUH000KojUH000?o0000onUG0?oYE`00
0ooYE`02o`0000Ook4d000Co0000one<0?o]C03okD`01?l00006ona>0003o`000?o/C03ok4`000?o
00000_o[D@000ol0003ok4h0ona>0004ona>0003o`000?o]B`3okD/000?o00000_o[D0000ol0003o
kD`0one<0004one<0003o`000?o^A`3okTL000?o00000_o]C0000ol0003okTH0oni60004oni60003
o`000?o`@03ol40000?o000000?okd@0o`000?o`?@001Oo`?@000ol0003olSH0oo8f0002oo8f00Go
00001Oob=`000ol0003ojU@0o`000005onYF0003o`000?oYF03o000000;obKX000Go0000olVj0?o9
^P3obKX0o`000002olVj0004o`000?o9^P3obKX0o`0000?ob;X000?o0000ooooooooool04?ooool3
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo000@ooooo`;o00002_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo0_l00002o`1n5`03o`000?lCT@3o4i40
00;o4i4000?o0000obBH0?lTV0000_lTV0000ol0003o:iX0ob^J0002ob^J0004o`000?laW03o<I`0
oc6L00;o00001?oHS`000ol0003of900omR@0003omR@0003o`000?oHT03of90000?of90000?o0000
omRA0?oHT@000ooHT@000ol0003of940omRA0002omRA0003o`000?oHTP3o000000;o000000?of980
o`000?oGTP000ooGTP03o`0000GojUD000?o0000onYF0?oZEP001?oZEP000ol0003ojEL0onUG0003
o`0000;ok4d000?o0000ona=0?o/C@001?o/C@04o`0000Cok4l000?o0000ona>0?o/CP000oo/CP03
o`0000Koje4000Co0000ona>0?o/CP3ok4h01Ol00006on]@0004o`000?o]C03okD`0one<00Go0000
1_o]C0001?l0003okTH0oni60?o^AP05o`0000Gokd@000?o0000oo0m0?o`?@000oo`?@05o`0000?o
lCX000?o0000oo8g0?ob=`001?ob=`02o`0000GojUH000Co0000onUH0?oYF03ojEP00_l000001?o9
^P3o0000olVj0?l00003olVj0004o`000?o9^P3obKX0o`0000?ob;X000?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0=ooooo`008_ooool00ol0003oooooooooo`07ooooo`;o000000?o07hG
o`000?lCT@000olCT@000ol0003o99P0obBH0002obBH0003o`000?l[VP3o:iX000;o:iX01?l00000
0ooISP3o0000omR?0004omR?0003o`000?oHT03of90000;of90000?o0000omR@0?oHT0000ooHT000
0ol0003of940omRA0003omRA0004o`000?oHT@3of940omRA00?o00001OoHTP04o`000003onYD0?l0
003ojUD000KojUD000?o0000onYF0?oZEP000ooZEP03o`0000Kok4d000?o0000ona=0?o/C@000ol0
00000oo[D03o0000ona?0006ona?0003o`000?o/CP3o000000;o00000oo[D`000ol0003oje40on]A
0003on]A00Co00001?o[D`000ol0003oje00on]@0004on]@00Co00001?o[D0000ol0003okD`0one<
0004one<00Co00001?o]BP000ol0003okd@0onm40003onm40003o`000?o`?@3ol3d000?o000000?o
kd40o`000?oa>P001_oa>P000ol0003olSL0oo8g0003o`0000;olCX000Go0000onYF0?oZEP3ojUH0
o`000005onUH0005o`000?o9^P3o0000olVj0?l000000_o9^P001Ol0003obKX0olVj0?o9^P3o0000
00;ob;X000?o0000olRj0?l000005?ooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`04o`000?nT_@3o0000o`0000Co4i4000?o0000obBH0?lTV0000_lTV0000ol0
003o:iX0ob^J0003o`0000CofHh000?o0000omR?0?oHS`000ooHS`000ol0003of900omR@0002omR@
0003o`000?oHT03of90000?of90000?o0000omRA0?oHT@000ooHT@04o`000003omRA0?l0003of980
00Cof9800_l00005onYD0003o`000?oZE@3ojUD000CojUD000?o0000onYF0?oZEP000ol00002ona<
0003o`000?o/C@3ok4d000Cok4d00ol00005on]@0003o`000?o/C`3ok4l000Cok4l00_l00007on]C
0003o`000?o[D@3o000000;o000000?ojUH0o`000?o[D`001_o[D`000ol0003oje00on]@0003o`00
0003onYD0?l0003oje0000Koje0000?o0000one<0?o]C0000ol000000oo/C`3o0000one:0006one:
0004o`000?o_A03okd@0onm400Co00001Oo_@@000ol0003olCX0oo4j0004oo4j00?o00001_oa>P00
0ol0003ojUH0o`000006onUH00;o000000?obKX0o`000?l000000_o9^P001Ol0003obKX0olVj0?o9
^P3o000000;ob;X000?o0000olRj0?l000005Oooool00ol0003oooooooooo`0;ooooo`008Oooool2
o`0000Wooooo00Co0000ojBm0?l0003o00001?lCT@000ol0003o99P0obBH0005o`0000;ofHh000?o
0000omV>0?oISP000_oISP000ol0003of8l0omR?0003omR?0003o`000?oHT03of90000;of90000?o
0000omR@0?oHT0000ooHT0000ol0003of940omRA0002omRA00;o00001OoHT@000ol0003of980o`00
0002o`000003on]B0?l0003ojU@000GojU@000?o0000onYE0?oZE@000ooZE@03o`0000Kok4`000?o
0000ona=0?o/C@000ol00002on]@0003o`000?o[D03oje0000Coje0000?o0000ona?0?o/C`000ol0
0002onYD0003o`000?o[D`3oje<000Coje<00_l00005onYF0003o`000?o[D`3oje<000Coje<00ol0
0005onYD0003o`000?o[D03oje0000Coje000ol00005ona?0003o`000?o]BP3okDX000CokDX01?l0
0003oni70003o`000?o_@@3okd4000Cokd4000?o0000oo4j0?oa>P000ol000000oo`?@3o0000oo4j
0006oo4j00;o00001_oYF0000ol0003ojEX0onUJ0003o`0000;obKX000Co0000olVj0?o9^P3o0000
0oo8^P001?l0003ob;X0olRj0?l0000Dooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ojBm0?nT_@002?l00002omR@0003o`000?oISP3ofHh000;ofHh0
00?o0000omV>0?oISP000ooISP000ol0003of8l0omR?0002omR?0003o`000?oHT03of90000?of900
00?o0000omR@0?oHT0000_oHT0000ol0003of940o`000002o`000003omRA0?l0003of94000?of940
0ol00005on]B0003o`000?oZE03ojU@000CojU@000?o0000onYE0?l000000_l00003one;0003o`00
0?o/C03ok4`000?ok4`00ol00006on]@0004o`000?o[D03oje00on]@00Go00001_oZE0000ol0003o
je<0on]C0003o`0000;ojEL000?o0000onYF0?oZEP000ooZEP000ol0003oje<0on]C0003o`0000;o
jEL000?o0000onYD0?oZE0001?oZE0000ol0003oje00on]@0003o`0000;ojU<000?o0000ona?0?o/
C`001?o/C`000ol0003okDX0one:0003o`000003ona=0?l0003okTL000GokTL000Co0000onm10?o_
@@3okd401Ol00005oo0m0003o`000?oa>P3olCX000;olCX00_l000000oo`?@3o0000onUH0004onUH
0003o`000?oYFP3ojEX000;ojEX000Co0000olVj0?l0003o00000oo9^P001?l0003ob;X0olRj0?l0
0003olRj0003o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool0027ooooo00?o0000
ooooooooool02?ooool01?l0003oY;d0ojBm0?l00004om>O0003o`000?oHT03of90000;of90000?o
0000omV>0?oISP000_oISP000ol0003ofHh0omV>0003omV>0003o`000?oHS`3of8l000;of8l000?o
0000omR@0?oHT0000ooHT0001?l0003of900omR@0?oHT003o`0000Gof9401?l000000oo/C`3o0000
on]B0006on]B0003o`000?oZE03ojU@000?ojU@00_l00007one;0003o`000?o/C03o000000;o0000
0oo[D0000ol0003oje00on]@0003on]@00Co00001?oZE@000ol0003ojU@0onYD0004onYD00?o0000
1_oYE`001?l0003ojUH0onYF0?oZEP04o`0000KojEL000Co0000onYD0?oZE03ojU@01Ol00006onYC
0004o`000?o/C`3ok4l0ona?00Go00001Oo/C@001?l0003okTL0oni70?o^A`06o`0000Cokd@000?o
0000oo0m0?o`?@001?o`?@001?l0003olCX0o`000?l00004oo0m0005o`000?oYF03ojEP0onUH0?l0
00001?oYFP02o`000003olVj0?l0003o000000?obKX000Co0000olRj0?o8^P3o00000oo8^P02o`00
01Gooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`04o`000?nT_@3oY;d0o`00
00Codil000?o0000omR@0?oHT0000_oHT0000ol0003ofHh0omV>0003omV>0003o`000?oISP3ofHh0
00;ofHh000?o0000omR?0?oHS`000ooHS`000ol0003of900omR@0002omR@00Co00000_oHT0000ol0
003of940omRA0002omRA00;o00001Oo/C`000ol0003oje80on]B0004on]B0003o`000?oZE03ojU@0
00?o00000_o]B@000ol0003okD/0one;0004one;00;o00001oo[D0000ol0003oje00o`000002o`00
00;ojUD000?o0000onYE0?oZE@001?oZE@000ol0003ojU@0onYD0003o`0000;ojET000?o0000onUG
0?oYE`001?oYE`04o`0000CojET000?o0000onUG0?oYE`000ooYE`04o`0000CojEL000?o0000onYC
0?oZD`001?oZD`04o`0000?oje8000?o0000ona=0?o/C@001?o/C@04o`0000CokDX000?o0000onm4
0?o_A0001?o_A0001?l0003ol3d0oo0m0?o`?@04o`0000Ool3d000?o0000onUH0?l000001?oYFP00
1_l0003oj5/0onQK0?l0003obKX0o`0000;obKX000Go0000olRj0?o8^P3ob;X0o`000002olRj0004
o`000?o9^P3obKX0o`0001?ooooo0_l0000;ooooo`000_ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`04
o`000?nT_@3oY;d0o`0000Codil000?o0000omR@0?oHT0000_oHT0000ol0003ofHh0omV>0003omV>
0003o`000?oISP3ofHh000;ofHh000?o0000omR?0?oHS`000ooHS`000ol0003of900omR@0003o`00
00Gof90000?o0000omRA0?l000000_l000000oo/C03o0000ona?0005ona?0003o`000?o[DP3oje80
00?oje800ol00006one90003o`000?o]B`3okD/000?o00000_o/C`000ol0003oje00on]@0004on]@
00;o00001_oZE@000ol0003ojUD0onYE0003onYE00?o00001_oYF@000ol0003ojEL0onUG0003o`00
00;oj5/000?o0000onUI0?oYF@001?oYF@000ol0003ojEL0o`000002o`0000;oj5X000?o0000onUG
0?oYE`001?oYE`000ol0003ojU<0onYC0003o`0000;ojEL000?o0000on]B0?o[DP000oo[DP000ol0
003ok4d0ona=0003o`000003on]@0?l0003okDX000KokDX000Co0000onm40?o_A03okd@01_l00004
oo0o0003o`000?o`?@3ol3d000Col3d00_l00004onUJ0004o`000?oXF`3oj5/0onQK00;o000000Co
bKX0o`000?o9^P3o00000_o8^P001Ol0003ob;X0olRj0?o8^P3o000000;obKX00_l0000Dooooo`03
o`000?oooooooooo00Sooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000oooooooo
ool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000ooooooooooooooooo`00
000<ooooo`03o`000?nT_@3o000000Codil000?o0000omR@0?oHT0000ooHT0000ol0003ofHh0omV>
0002omV>0003o`000?oISP3ofHh000;ofHh000?o0000omR?0?oHS`000ooHS`03o`0000;of90000?o
0000omR@0?oHT0000_oHT003o`0000Gok4`000?o0000ona?0?o/C`001?o/C`000ol0003oje80o`00
0002o`0000?okTL000?o0000one90?o]B@000oo]B@03o`0000Kok4l000?o0000on]@0?o[D0000ol0
0002onYE0003o`000?oZE@3ojUD000CojUD000?o0000onYE0?l000000_l00002onUI0003o`000?oY
F@3ojET000CojET00ol00006onQK0004o`000?oYF@3ojET0onUI00Co00001_oXFP001?l0003ojEL0
onUG0?oYE`05o`0000KojEL000Co0000on]B0?o[DP3oje801?l00005on]@0003o`000?o]BP3okDX0
00CokDX01?l00004oni60003o`000?o`?`3ol3l000Col3l000?o0000oo0m0?o`?@000ol000000oo`
?`3o0000onUJ0002onUJ0003o`000?oXF`3oj5/000?oj5/000?o0000olVj0?o9^P000_l00002olRj
0005o`000?o8^P3ob;X0olRj0?l000000_o9^P000ol0003obKX0o`00000Booooo`?o00002Oooool0
0005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooooooo0_l0000;ooooo`04o`000?nT_@3oY;d0o`0000Codil0
00?o0000omR@0?oHT0000_oHT0000ol0003ofHh0omV>0002omV>0003o`000?oISP3ofHh000;ofHh0
00?o0000omR?0?oHS`001?l00005omR@00Co000000?okDT0o`000?o/C0001_o/C0000ol0003ok4l0
ona?0003ona?00;o00001oo^A`000ol0003okDT0o`000002o`0000?ok4d000?o0000ona?0?o/C`00
0oo/C`03o`0000KojUD000Co0000onYE0?oZE@3ojUD01?l00006onUI0003o`000?oYF@3ojET000?o
00000_oXG0000ol0003oj5/0onQK0004onQK00Co00001?oXG@000ol0003oj5X0onQJ0003onQJ00Co
00001?oXFP000ol0003ojEL0onUG0004onUG00Co00000ooZE@000ol0003oje00on]@0004on]@0003
o`000?o]BP3okDX000?o000000?ok4d0o`000?o^AP001_o^AP001?l0003ol3l0oo0o0?o`?`05o`00
00Gol3l000?o0000onUJ0?l000001OoXF`001?l0003oj5/0o`000?o9^P02o`0000;ob;X000Oo0000
olRj0?o8^P3ob;X0o`000?o9^P3o000000?obKX000?o0000ooooooooool03?ooool3o`0000;ooooo
00?o0000ooooooooool01oooool00005ooooool0003oooooooooool000002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<ooooo`04
o`000?nT_@3oY;d0o`0000Codil000?o0000omR@0?oHT0000_oHT0000ol0003ofHh0omV>0002omV>
0003o`000?oISP3ofHh000;ofHh00ol00003omR?0003o`000?oHT03of90000;of9000_l00005one9
0003o`000?o/C03ok4`000Cok4`000?o0000ona?0?o/C`000ol00002onm40003o`000?o^A`3okTL0
00CokTL00_l00007ona=0003o`000?o/C`3o000000;o00000ooZE0000ol0003ojUD0onYE0003onYE
00Co00001?oYF@000ol0003ojET0onUI0003onUI00?o00001_oXG0000ol0003oj5/0onQK0003o`00
0003onMN0?l0003oj5d000Koj5d000?o0000onQJ0?l000000_l00002onQM0003o`000?oXFP3oj5X0
00Coj5X000?o0000onUG0?oYE`000ol000000ooYF@3o0000onYE0005onYE0004o`000?o[D03oje00
on]@00Go00001Oo/C@000ol0003okTH0oni60004oni600Co00000oo_@@000ol0003ol3l0oo0o0004
oo0o00;o00001OoXF`001?l0003oj5/0onQK0?oXF`03o`000003olRj0?l0003ob;X000;ob;X000Co
0000olVj0?o9^P3o00000oo9^P000ol0003oooooooooo`09ooooo`?o00001Oooool00ol0003ooooo
ooooo`07ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000003o`0000Cooooo00?o0000ooooooooool02_ooool01?l0003o
Y;d0ojBm0?l00004om>O0003o`000?oHT03of90000;of90000?o0000omV>0?oISP000_oISP000ol0
003ofHh0omV>0004o`0000Gof8l01?l000000oo^A@3o0000one90005one90003o`000?o/C03ok4`0
00?ok4`00ol00006onm40003o`000?o^A`3okTL000?o00000_o]B`000ol0003ok4d0ona=0004ona=
00;o00001ooZE0000ol0003ojUD0o`000002o`0000;ojET000?o0000onUI0?oYF@001?oYF@000ol0
003ojET0o`000002o`0000?oj5d000?o0000onQL0?oXG0000ooXG003o`0000Goieh000?o0000onQM
0?oXG@001?oXG@02o`0000Koj5d000Co0000onQJ0?oXFP3oj5X01Ol00005onUI0003o`000?oZE@3o
jUD000?ojUD01?l00004on]B0003o`000?o/C@3ok4d000Cok4d000?o0000oni60?o^AP000ol00000
0oo^B03o0000onm10005onm10003o`000?o`?`3ol3l000?o00000_o`@0001Ol0003oj5/0onQK0?oX
F`3o000000Goj5/000Co0000olRj0?l0003o00000oo8^P001?l0003obKX0olVj0?l00002olVj0003
o`000?o9^P3o000000Kooooo1?l00008ooooo`03o`000?oooooooooo00Oooooo00001Ooooooo0000
oooooooooooo000000Sooooo0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000007
ooooo`;o00002oooool01?l0003oY;d0ojBm0?l00004om>O0003o`000?oHT03of90000;of90000?o
0000omV>0?oISP000_oISP03o`0000?ofHh000?o0000omR?0?oHS`000_oHS`02o`0000GokTD000?o
0000one90?o]B@001?o]B@000ol0003ok4`0o`000002o`0000?ol40000?o0000onm40?o_A0000oo_
A003o`0000KokD/000?o0000ona=0?o/C@000ol00002on]B0003o`000?oZE03ojU@000CojU@00_l0
0006onUI0004o`000?oYF@3ojET0onUI00Co00001ooXG@000ol0003oj5`0o`000002o`0000;oif00
00?o0000onMN0?oWGP001?oWGP000ol0003oj5d0onQM0003o`0000;oiel000?o0000onQM0?oXG@00
0ooXG@04o`0000Coj5d000?o0000onUI0?oYF@001?oYF@000ol0003ojUD0o`000002o`0000;ojEL0
00?o0000on]B0?o[DP001?o[DP001?l0003ok4d0ona=0?o/C@05o`0000GokTP000Co0000onm10?o_
@@3okd401Ol00006oo100003o`000?oXF`3o000000Goj5/00_l000000oo8^P3o0000o`000003olRj
0004o`000?o9^P3obKX0o`0000;obKX000Co0000olVj0?o9^P3o00000_ooool3o`0000cooooo00?o
0000ooooooooool01oooool000;ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo0ol00002
ooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?nT_@3o000000Codil000?o0000
omR@0?oHT0000_oHT0000ol0003ofHh0o`000002o`000003omV>0?l0003ofHh000?ofHh000?o0000
omR?0?l000000_l000000oo`@03o0000oni50005oni50003o`000?o]B@3okDT000?okDT00ol00006
oo100003o`000?o_A03o000000;o00000oo^B0000ol0003okD/0one;0003one;00?o00001_o[DP00
0ol0003ojU@0onYD0003o`0000;ojEP000?o0000onUI0?oYF@000ooYF@04o`0000Coj5d000?o0000
onQM0?oXG@001?oXG@02o`0000Koif0000Co0000onMN0?oWGP3oieh01Ol00006onMO0003o`000?oX
G@3o000000;o000000?oiel0o`000?oXG@001_oXG@001?l0003ojET0onUI0?oYF@04o`0000KojEL0
00Co0000on]B0?o[DP3oje801_l00003ona>0003o`000?o^B03okTP000CokTP01?l00004onm30003
o`000?o`@03ol40000Col4000_l00005onQK0003o`000?oXG03oj5`000?o00000_o8^P001?l0003o
bKX0olVj0?l00003olVj0003o`000?o9^P3obKX000?o00004?ooool00ol0003oooooooooo`06oooo
o`008?ooool00ol0003oooooooooo`0;ooooo`03o`000?nT_@3o000000Codil000Co0000omR@0?oH
T03of9000ol00004omV>0004o`000?oISP3ofHh0omV>00?o00001Oo`@0000ol0003okTD0oni50004
oni50003o`000?o]B@3o000000;o00000ooa?0000ol0003ol400oo100003oo1000;o00001oo^B000
0ol0003okD/0o`000002o`0000?ok50000?o0000on]B0?o[DP000oo[DP03o`0000KojEP000?o0000
onUI0?l000000_l00003onQM0003o`000?oXG@3oj5d000?oj5d000?o0000onQM0?oXG@000ol00002
onMP0003o`000?oWH03oif0000?oif001?l00004onIQ0003o`000?oWG`3oiel000Coiel00_l00005
onMO0003o`000?oXG@3oj5d000Coj5d01?l00003onQK0003o`000?oYE`3ojEL000CojEL01?l00004
onYD0003o`000?o/CP3ok4h000?ok4h000?o0000oni80?o^B0000ol000000oo]B@3o0000onm30006
onm30003o`000?o`@03ol40000?o000000?okd40o`000?oXF`000ooXF`000ol0003oj5`0onQL0002
onQL0005o`000?o8^P3o0000olRj0?l000000_o9^P001?l0003obKX0olVj0?l00003olVj00;o0000
4Oooool00ol0003oooooooooo`06ooooo`007oooool00ol0003oooooooooo`0=ooooo`;o00001?oC
W`04o`0000;of90000?o0000omV>0?oISP000_oISP04o`000003oo4k0?l0003ol40000Gol40000?o
0000oni50?o^A@001?o^A@02o`0000OolC`000?o0000oo100?l000000_l00002onm40003o`000?o^
B03okTP000CokTP00_l00007ona@0003o`000?o[DP3o000000;o00000_oYEP000ol0003ojEP0onUH
0004onUH00;o00001ooXG@001?l0003oj5d0onQM0?oXG@04o`0000Koif0000?o0000onMP0?l00000
0_l00002onIR0003o`000?oVH@3oiV4000CoiV4000?o0000onMO0?oWG`000ol000000ooVHP3o0000
onMO0005onMO0003o`000?oXG@3oj5d000?o00000_oWG`000ol0003oj5/0onQK0003onQK0003o`00
0?oYE`3ojEL000?o00000_oYF@000ol0003ojU@0onYD0004onYD0004o`000?o/CP3ok4h0ona>00Co
00001Oo]B@000ol0003okd<0onm30004onm300?o00001Oo_@@001?l0003oj5/0onQK0?l00005onQL
0003o`000?o8^P3ob;X000;o00000_o9^P001?l0003obKX0olVj0?l00002olVj0003o`000?o9^@3o
0000017ooooo00?o0000ooooooooool01_ooool001oooooo00?o0000ooooooooool03Oooool01?l0
003oY;d0o`000?oCW`03o`0000Gof90000Co0000omV>0?oISP3ofHh00_l00005oo4k0003o`000?o`
@03ol40000Col40000Co0000oni50?o^A@3okTD00_l000000oob=P3o0000oo4l0006oo4l00;o0000
1_o_A0000ol0003okTP0oni80003o`0000;ok4d000?o0000ona@0?o/D0001?o/D002o`0000KojEH0
00?o0000onUH0?oYF0000ol00002onQL0003o`000?oXG@3oj5d000Coj5d01?l00003onMQ0003o`00
0?oWH03oif0000Coif000_l00006onIR0004o`000?oVH@3oiV40onIQ00Go00001OoVHP001?l0003o
iel0onMO0?oWG`05o`0000Koiel000Co0000onQK0?oXF`3oj5/01?l00006onUI0004o`000?oZE03o
jU@0onYD00Ko00000oo/D0000ol0003okDT0one90004one90003o`000?o_@`3okd<000?o000000?o
kd<0o`000?o_@@001Oo_@@000ol0003oj5/0o`000005onQL0004o`000?oXF`3o0000olRj00;o0000
00?obKX0o`000?o9^P000_o9^P001?l0003obKX0olVj0?l00002olVi0003o`000?oooooooooo00ko
oooo00?o0000ooooooooool01_ooool001oooooo0_l0000?ooooo`?o00000ooCW`000ol0003of900
omR@0002omR@00Co000000?olSD0o`000?oa>`001Ooa>`000ol0003ol400oo100003oo100004o`00
0?o^A@3o0000o`0000ColSH000?o0000oo4l0?oa?0000_oa?002o`0000;ol3l000?o0000onm40?o_
A0000oo_A003o`0000Kok4d000?o0000ona@0?o/D0000ol00002onYD0003o`000?oYEP3ojEH000?o
jEH00ol00006onQL0003o`000?oXG@3oj5d000?o00000_oWH0000ol0003oif40onMQ0003onMQ0003
o`000?oWH03oif0000?o00000_oVH`000ol0003oiV80onIR0003onIR00Co00001?oVI0000ol0003o
iV80onIR0003onIR00Co00001?oVHP000ol0003oiel0onMO0004onMO00Co00000ooXG@000ol0003o
jET0onUI0004onUI00Co00000ooZE@000ol0003ok500ona@0004ona@0004o`000?o]B@3okDT0one9
00Go00001Oo_@`000ol0003okd40onm10003onm100;o00001OoXG0001?l0003oj5/0onQK0?oXF`03
o`000005olVj0?l0003obKX0olVj0?l000000oo9^P001?l0003obKT0olVi0?l0000@ooooo`03o`00
0?oooooooooo00Kooooo000Oooooo`03o`000?oooooooooo00cooooo1?l00004om>O0004o`000?oH
T03of900omR@00;o00001Oob=@000ol0003olC/0oo4k0003oo4k0003o`000?o`@03ol40000?ol400
0ol00006oo8f0004o`000?oa?03o0000o`0000Gol3l000?o0000onm40?l000000_l00003one90003
o`000?o/C@3ok4d000?ok4d00ol00006onYD0003o`000?oYEP3o000000;o00000ooXFP000ol0003o
j5`0onQL0003onQL00?o00001_oWH0001?l0003oif40onMQ0?oWH@04o`0000KoiV<000?o0000onIR
0?l000000_l00002onEU0003o`000?oVI03oiV@000CoiV@000?o0000onIR0?l000000_l00002onIT
0003o`000?oVHP3oiV8000CoiV8000?o0000onMO0?oWG`000ol000000ooWH03o0000onQM0005onQM
0003o`000?oYF@3ojET000?o000000?ojEX0o`000?oZE@001OoZE@001?l0003ok500ona@0?o/D006
o`0000?okDX000?o0000onm30?o_@`001?o_@`000ol0003okd40onm10003o`0000;okd4000Go0000
onQL0?oXG03oj5`0o`000004onQK00;o000000?obKX0o`000?l000000_o9^P001Ol0003obKX0olVj
0?o9^P3o000000;obKT00_l0000?ooooo`03o`000?oooooooooo00Kooooo000Oooooo`03o`000?oo
oooooooo00Wooooo0ol00003ooooo`Co000000?odil0o`000?l000000_l000000ooc<@3o0000oo8e
0005oo8e0003o`000?oa>`3olC/000?olC/000?o0000oo100?l000000_l00003oo@`0003o`000?ob
=P3olSH000?olSH00ol00006oo0o00?o00001_o]B@000ol0003ok4d0o`000002o`0000?oje4000?o
0000onYD0?oZE0000ooZE002o`0000Ooj5X000?o0000onQL0?l000000_l00002onMO0003o`000?oW
H03oif0000Coif001?l00003onIS0003o`000?oVH`3oiV<000CoiV<00_l00006onEU0004o`000?oV
I03oiV@0onIT00Co00001_oVI0001?l0003oiV80onIR0?oVHP05o`0000Goif0000Co0000onQM0?oX
G@3oj5d01Ol00005onUJ0003o`000?oZE@3ojUD000?ojUD01?l00004on]@0003o`000?o]BP3okDX0
00?okDX000Co0000onm30?o_@`3okd<01Ol00006onm10003o`000?oXG03o000000Coj5/000Co0000
onQK0?l0003obKX00_l00002olVj0004o`000?o9^P3obKX0o`0000;obKT000Co0000olVi0?o9^@3o
00003_ooool00ol0003oooooooooo`06ooooo`007_ooool3o`0000Oooooo0ol00006ooooo`04o`00
0?o`@03ol400oo1000;o00001Ooc<@000ol0003olSD0oo8e0003oo8e0003o`000?oa>`3olC/000?o
lC/00ol00006oo@`0003o`000?ob=P3o000000;o00000ooa>P02o`000004oo0o0?l0003o0000o`00
00?okTD000?o0000one90?o]B@000oo]B@02o`0000Ooje4000?o0000onYD0?l000000_l00002onUH
0003o`000?oXFP3oj5X000Coj5X00_l00006onMO0003o`000?oWH03oif0000?o00000_oVH`000ol0
003oiV<0onIS0003onIS0003o`000?oVH`3oiV<000?o00000_oUI@000ol0003oiFD0onEU0003onEU
00Co00001?oUI@000ol0003oiV@0onIT0003onIT00Co00001?oVH`000ol0003oif00onMP0003onMP
00Co00001?oWGP000ol0003ojEX0onUJ0004onUJ0003o`000?oZE@3o000000;o00000_oZEP000ol0
003oje00on]@0004on]@0004o`000?o]BP3okDX0one:00Go00001?o_A0000ol0003okd40onm10004
onm100;o00001?oXF`001?l0003oj5/0onQK0?oXF`03o`000003olVj0?l0003obKX000;obKX000Co
0000olVi0?o9^@3o00000_o9^@000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo
0005ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Kooooo00?o
0000ooooooooool00oooool3o`0000[ooooo00Go0000oo100?o`@03ol400o`000005oo<a0003o`00
0?ob=@3olSD000ColSD000?o0000oo4k0?l000000_l00003ooHY0003o`000?od<03om30000?om300
0_l00007oo4j00;o00001oo^A@000ol0003okDT0o`000002o`0000;ok4h000?o0000on]A0?o[D@00
1?o[D@02o`0000KojEP000?o0000onQJ0?oXFP000ol00002onQM0003o`000?oWG`3oiel000?oiel0
0ol00006onIS0004o`000?oVH`3oiV<0onIS00Co00001_oUI@000ol0003oiFD0o`000002o`0000;o
iFL000?o0000onEU0?oUI@001?oUI@000ol0003oiV@0o`000002o`0000;oiFD000?o0000onIS0?oV
H`001?oVH`000ol0003oif00o`000002o`0000;oiV4000?o0000onMN0?oWGP001?oWGP001?l0003o
jEX0onUJ0?oYFP04o`0000KojUH000Co0000on]@0?o[D03oje001_l00003one;0003o`000?o_A03o
kd@000Cokd@000?o0000onm10?o_@@000ol000000oo_@@3o0000onQK0002onQK0003o`000?oXF`3o
j5/000?oj5/000Co0000olVj0?l0003o00000oo9^P001?l0003obKT0olVi0?l00002olVi00;o0000
3_ooool00ol0003oooooooooo`05ooooo`001?ooool01?l0003oooooooooool00009ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`?o00003Oooool00ol0003ol400oo100002oo100003o`000?oc<@3olc4000?olc4000?o0000oo8e
0?ob=@000oob=@02o`0000OomRT000?o0000oo@`0?l000000_l00002oo<d0003o`000?oa>P3olCX0
00;olCX00_l00002oo0o0003o`000?o^A@3okTD000CokTD00_l00006ona>0003o`000?o[D@3oje40
00?o00000_oZE@000ol0003ojEP0onUH0003onUH00?o00001_oXG@000ol0003oiel0o`000002o`00
00?oiV8000?o0000onIS0?oVH`000ooVH`04o`0000?oiFH000?o0000onEU0?oUI@001?oUI@02o`00
00KoiFL000Co0000onEU0?oUI@3oiFD01?l00006onEU0004o`000?oVH`3oiV<0onIS00Co00001_oV
H@001?l0003oieh0onMN0?oWGP06o`0000?oj5/000?o0000onYF0?oZEP001?oZEP04o`0000?oje40
00?o0000one;0?o]B`001?o]B`001?l0003okd@0onm40?o_A005o`0000Gokd4000?o0000onQK0?l0
00001OoXF`02o`0000;obKX000Co0000olVj0?o9^P3o00000oo9^@000ol0003obKT0o`000002olVh
0003o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool000Cooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1?l0000Aoooo
o`05o`000?o`@03ol400oo100?l000001Ooc<@000ol0003olSD0oo8e0003o`0000;on24000?o0000
ooHY0?of:@001?of:@02o`0000Kolc@000Co0000oo4j0?l0003o00001Oo`?`000ol0003okTD0oni5
0003o`0000;okDT000?o0000ona>0?o/CP000oo/CP03o`0000KojUD000?o0000onUH0?l000000_l0
0003onQK0003o`000?oXG@3oj5d000?oj5d00_l00007onIR0003o`000?oVH`3o000000;o00000_oU
I@000ol0003oiFH0onEV0003onEV0003o`000?oUI@3oiFD000?o00000_oUI`000ol0003oiFL0onEW
0003onEW00Co00001?oUI`000ol0003oiFD0onEU0003onEU00Co00001?oVI0000ol0003oiV40onIQ
0003onIQ00Co00001?oWG`000ol0003oj5/0onQK0003onQK0003o`000?oZEP3ojUH000?o000000?o
jUH0o`000?o[D@001Oo[D@001?l0003okD/0one;0?o]B`06o`0000?okd@000?o0000onm10?o_@@00
1?o_@@02o`0000Goj5/000?o0000onQJ0?oXFP000ol00002olVj0004o`000?o9^@3obKT0o`0000;o
bKT000?o0000olVh0?o9^0000_l0000<ooooo`03o`000?oooooooooo00Gooooo0004ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o
00004oooool00ol0003ol400oo100002oo100003o`000?oc<@3olc4000;olc400ol00006ooPQ0003
o`000?of:@3omRT000?o00000_oe;@000ol0003olc@0oo<d0003oo<d00?o00001_o`?`03o`0000Ko
kDT000?o0000ona>0?l000000_l00003on]B0003o`000?oZE@3ojUD000?ojUD00_l00007onQK0003
o`000?oXG@3o000000;o00000_oWH0000ol0003oiV80onIR0004onIR00;o00001_oUI@001?l0003o
iFH0onEV0?oUIP04o`0000KoiFL000?o0000onEW0?l000000_l000000ooUJ03o0000onEW0006onEW
0003o`000?oUI@3o000000;o00000_oUIP000ol0003oiV@0onIT0004onIT0003o`000?oVH@3o0000
00;o000000?oiV80o`000?oWG`001_oWG`001?l0003oj5/0onQK0?oXF`04o`0000GojUH000?o0000
on]A0?o[D@000oo[D@04o`0000CokDX000?o0000onm40?o_A0000oo_A0000ol0003okd40onm10003
o`0000;okd4000Go0000onQK0?oXF`3oj5/0o`000004onQJ0005o`000?o9^P3o0000olVj0?l00000
0_o9^@001?l0003obKT0olVi0?l00002olVh0003o`000?o:]`3o000000_ooooo00?o0000oooooooo
ool01Oooool000Cooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooooooool4o`00
00Oooooo00?o0000ooooooooool04?ooool00ol0003ol400oo100002oo100003o`000?oc<@3o0000
00;o00000_oi6`000ol0003on240ooPQ0004ooPQ00?o00001_oe;@000ol0003olc@0o`000002o`00
00?olCT00_l000001?o`?`3o0000o`000?l00003oni40003o`000?o]B@3okDT000?okDT00_l00007
on]B0003o`000?oZE@3o000000;o00000_oYF@000ol0003oj5/0onQK0004onQK00;o00001_oWH000
0ol0003oiV80onIR0003o`0000;oiV@000?o0000onEU0?oUI@000ooUI@04o`0000?oiFL000?o0000
onEW0?oUI`001?oUI`02o`0000GoiFP000?o0000onEW0?oUI`001?oUI`02o`0000KoiFH000Co0000
onIT0?oVI03oiV@01?l00005onIR0003o`000?oWG`3oiel000Coiel01?l00003onQK0003o`000?oZ
EP3ojUH000CojUH000?o0000on]A0?l000000_l000000oo[D@3o0000one:0006one:0004o`000?o_
A03okd@0onm400Co00001_o_@@000ol0003oj5/0o`000005onQJ00;o000000?obKX0o`000?l00000
0_o9^@001_l0003obKT0olVi0?l0003obKP0o`0000?ob[L000?o0000ooooooooool02?ooool00ol0
003oooooooooo`05ooooo`001?ooool01?l0003oooooooooool00008ooooo`;o00000oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo1_l00006ooTK0004o`000?oh8@3on240
ooPQ00;o00000oog9@000ol0003omBd0ooD]0003ooD]00?o00001_oa>@03o`0000KokT@000?o0000
one90?l000000_l00002ona>0003o`000?o[DP3oje8000Coje800_l00006onUI0003o`000?oXF`3o
j5/000?o00000_oWGP000ol0003oif00onMP0003onMP00?o00001_oVI0000ol0003oiFD0o`000002
o`0000;oiFL000?o0000onEW0?oUI`000ooUI`000ol0003oiFL0onEW0003o`0000;oi6T000?o0000
onEX0?oUJ0000ooUJ0000ol0003oiFL0onEW0003o`0000;oiFP000?o0000onEV0?oUIP000ooUIP04
o`0000?oiFD000?o0000onIR0?oVHP001?oVHP000ol0003oiel0onMO0003o`000003onMO0?l0003o
j5/000Goj5/000Co0000onYF0?oZEP3ojUH01?l00005on]A0003o`000?o]BP3okDX000CokDX01?l0
0003onm30003o`000?o_@@3okd4000Cokd400_l00005onQJ0003o`000?oYF@3ojET000?o000000Go
bKT0o`000?o9^@3obKT0o`000002olVh0005o`000?o:]`3ob[L0olZg0?l000002_ooool00ol0003o
ooooooooo`05ooooo`001Oooool2o`0000[ooooo00Co0000oooooooooooooooo1Ol00008ooooo`03
o`000?oooooooooo017ooooo00Go0000ooHX0?of:03omRP0o`000006ooTK0003o`000?oh8@3o0000
00KombD000?o0000ooD]0?l000000_l00003oo<b0004o`000?oa>@3olCT0oo4i00;o00000oo`?P00
0ol0003okT@0oni40003oni400;o00001_o/CP000ol0003oje80on]B0003o`0000;ojUD000?o0000
onUI0?oYF@000ooYF@03o`0000Koieh000?o0000onMP0?l000000_l00002onIS0003o`000?oVI03o
iV@000CoiV@00_l00006onEW0004o`000?oUI`3oiFL0onEW00Co00001_oTJ@001?l0003oiFP0onEX
0?oUJ004o`0000KoiFP000?o0000onEV0?l000000_l000000ooUI`3o0000onEU0005onEU0004o`00
0?oVHP3oiV80onIR00Go00001OoWG`001?l0003oj5/0onQK0?oXF`06o`0000?ojUH000?o0000on]A
0?o[D@001?o[D@000ol0003okDX0one:0003o`000003one:0?l0003okd<000Gokd<000?o0000onm1
0?o_@@000ol000000oo`?`3o0000onQJ0003onQJ0003o`000?oYF@3ojET000;ojET00_l000001Oo9
^@3o0000olVi0?o9^@3o000000;obKP000Co0000olZg0?o:]`3ob[L00_l00008ooooo`;o00001ooo
ool002?ooooo0_l0000Booooo`05o`000?of:03omRP0ooHX0?l000001Ooi6`03o`0000KombD00ol0
0006oo<b0003o`000?oa>@3o000000Kol3h000?o0000oni40?l000000_l00002one90003o`000?o/
CP3ok4h000?ok4h00ol00006onYE0003o`000?oYF@3o000000;o00000ooXG0000ol0003oieh0onMN
0003onMN00;o00001_oVH`000ol0003oiV@0onIT0003o`0000;oiFH000?o0000onEW0?oUI`000ooU
I`04o`0000?oi6T000?o0000onAY0?oTJ@001?oTJ@04o`0000?oi6T000?o0000onEX0?oUJ0001?oU
J002o`0000GoiFL000?o0000onEU0?oUI@000ooUI@04o`0000CoiV8000?o0000onMO0?oWG`000ooW
G`04o`0000?oj5/000?o0000onYF0?oZEP001?oZEP001?l0003oje40on]A0?o[D@05o`0000GokDX0
00?o0000onm30?o_@`000oo_@`03o`0000Gol3l000Co0000onQJ0?oXFP3o00001?oYF@02o`000003
olVi0?l0003o000000;obKT000Co0000olVh0?o9^03o00000_o:]`001?l0003ob[H0olZf0?l00007
ooooo`;o00001oooool002Gooooo00?o0000ooooooooool04?ooool5o`000004ooTK0?l0003o0000
o`0000?on1h00_l000001?og9@3o0000o`000?l00003ooD[0003o`000?oc<P3olc8000?olc800ol0
0006oo0n00;o00001_o]B@000ol0003ok4h0o`000002o`0000?oje4000?o0000onYE0?oZE@000ooZ
E@02o`0000Ooj5`000?o0000onMN0?l000000_l00002onMQ0003o`000?oVH`3oiV<000?oiV<00ol0
0006onEV0003o`000?oUI`3o000000;o00000_oTJ0000ol0003oi6T0onAY0003onAY0003o`000?oT
J@3oi6T000?o00000_oTJP000ol0003oi6T0onAY0003onAY0003o`000?oUJ03oiFP000?o000000?o
i6T0o`000?oUI`001OoUI`000ol0003oiFD0o`000002o`0000;oiFD000?o0000onIR0?oVHP001?oV
HP000ol0003oiel0o`000002o`0000;oiel000?o0000onQK0?oXF`000ooXF`001?l0003ojUH0onYF
0?oZEP06o`0000?oje0000?o0000one:0?o]BP001?o]BP000ol0003okd<0onm30003o`000003onm2
0?l0003ol3l000Gol3l000?o0000onQJ0?l000001?oYF@002?l0003ojEL0onUG0?l0003obKT0o`00
0?o9^@3o00000_o9^0001Ol0003ob[L0olZg0?o:]`3o000000;ob[H000?o0000ooooooooool01Ooo
ool3o`0000Kooooo000Vooooo`03o`000?oooooooooo017ooooo00?o0000ooDZ0?l000000_l00006
ooPN00;o00001ooe:`000ol0003olc80o`000002o`0000?olSP000?o0000oo0n0?o`?P000ol00002
onm30003o`000?o]B@3okDT000?okDT00ol00006on]A0003o`000?oZE@3o000000;o00000_oYF000
0ol0003oj5`0onQL0004onQL00;o00001_oWH@000ol0003oiV<0o`000002o`0000;oiVD000?o0000
onEV0?oUIP001?oUIP02o`0000Koi6P000Co0000onAY0?oTJ@3oi6T01?l00006onAZ0004o`000?oT
J@3oi6T0onAY00Co00001OoTJ@001?l0003oiFL0onEW0?oUI`04o`0000KoiFD000Co0000onIR0?oV
HP3oiV801?l00006onMO0004o`000?oXF`3oj5/0onQK00Go00001?oZEP000ol0003oje00on]@0003
on]@0004o`000?o]BP3okDX0one:00Go00001Oo_@P000ol0003ol3l0oo0o0003oo0o00;o00001?oY
F@001?l0003ojEL0onUG0?oYE`03o`000005olVi0?l0003obKP0olVh0?l000000oo:]`000ol0003o
b[H0olZf0002o`0000Gooooo00Co0000oaJB0?l0003o00001_ooool002Oooooo00?o0000oooooooo
ool04Oooool01?l0003omBX0ooDZ0?oe:P02o`000004ooPN0?l0003o0000o`0000;omb@000?o0000
ooD[0?oe:`001?oe:`03o`0000GolSP00ol00006onm30003o`000?o]B@3o000000;o00000oo/C000
0ol0003oje40on]A0003on]A00;o00001_oYF0000ol0003oj5`0onQL0003o`0000;oieh000?o0000
onMQ0?oWH@000ooWH@02o`0000KoiVD000?o0000onEV0?oUIP000ol00002onEW0003o`000?oTJ03o
i6P000?oi6P01?l00003onAZ0003o`000?oTJP3oi6X000Coi6X01?l00003onAZ0003o`000?oTJ@3o
i6T000?oi6T01?l00004onEW0003o`000?oUI@3oiFD000?oiFD01?l00003onIR0003o`000?oWG`3o
iel000Coiel01?l00003onQJ0003o`000?oZEP3ojUH000CojUH000Co0000on]@0?o[D03oje001Ol0
0003one90003o`000?o_@P3okd8000Cokd8000?o0000oo0o0?o`?`000ol000000oo`?P3o0000onUI
0002onUI0003o`000?oYE`3ojEL000?ojEL000Co0000olVi0?l0003o00000_o9^0001ol0003ob[L0
olZg0?o:]`3o0000olZf0?l000000_o;]@000ol0003oooooooooo`02ooooo`04o`000?lFTP3o0000
o`0000Kooooo000Xooooo`;o00004_ooool6o`0000Komb@000?o0000ooD[0?oe:`000ol00003oo@`
0003o`000?ob>03o000000;o00000ooa?0000ol0003okd<0onm30003onm300;o00001oo/C0000ol0
003oje40o`000002o`0000;ojU@000?o0000onUH0?oYF0000ooYF003o`0000Koieh000?o0000onMQ
0?l000000_l00002onIS0003o`000?oVI@3oiVD000?oiVD00ol00006onEW0003o`000?oTJ03o0000
00;o00000_oTJ@000ol0003oi6X0onAZ0003onAZ0003o`000?oTJP3oi6X000?o00000_oTJ`000ol0
003oi6X0onAZ0003onAZ0003o`000?oTJ@3o000000;o00000_oTJ@000ol0003oiFL0onEW0004onEW
0003o`000?oUI@3o000000;o00000_oUI@000ol0003oiV80onIR0003onIR0003o`000?oWG`3oiel0
00?o000000?oieh0o`000?oXFP001OoXFP001?l0003ojUH0onYF0?oZEP06o`0000?ok4l000?o0000
one90?o]B@000oo]B@001?l0003okd80onm20?o_@P05o`0000Gol3h000?o0000onUI0?l000001OoY
E`02o`0000;obKT000?o0000olVh0?l000000oo:]`001?l0003ob[H0olZf0?l00002ol^e0003o`00
0?oooooooooo00;ooooo00Co0000oaJB0?l0003o00001_ooool002[ooooo00?o0000ooooooooool0
4Oooool01Ol0003om2l0oo@_0?od;`3o000000Gomb@00ol00006oo@`00?o00001_oa?0000ol0003o
kd<0o`000002o`0000;okTL000?o0000ona<0?o/C0001?o/C002o`0000KojU@000?o0000onUH0?l0
00000_l00003onQK0003o`000?oWGP3oieh000?oieh00_l00006onIS0003o`000?oVI@3o000000;o
00000_oUIP000ol0003oiFL0onEW0004onEW00;o00001_oTJ@001?l0003oi6X0onAZ0?oTJP04o`00
00Koi6/000Co0000onAZ0?oTJP3oi6X00ol00006onAY0004o`000?oUI`3oiFL0onEW00Co00001_oU
I@001?l0003oiV80onIR0?oVHP04o`0000Goieh000?o0000onQJ0?oXFP000ooXFP04o`0000?ojU@0
00?o0000ona?0?o/C`001?o/C`001?l0003okDT0one90?o]B@05o`0000Col40000?o0000oo0n0?o`
?P000oo`?P02o`0000GojEL000?o0000onYE0?oZE@000_l000000oo9^03o0000o`000003olZg0004
o`000?o:]P3ob[H0o`0000;obkD00_l00002ooooo`03o`000?lFTP3o5Y8000;o00001_ooool002_o
oooo00?o0000ooooooooool04Oooool01_l0003om2l0oo@_0?od;`3o0000ooLT00?o00000ooe:P00
1?l0003om300oo@`0?od<002o`0000?olSD000?o0000oo4l0?oa?0000ooa?002o`0000KokTL000?o
0000ona<0?o/C0000ol00002ona@0003o`000?oZE03ojU@000?ojU@00ol00006onQK0003o`000?oW
GP3o000000;o00000_oWH0000ol0003oiV<0onIS0003onIS00;o00001_oUIP000ol0003oiFL0onEW
0003o`0000;oi6T000?o0000onAY0?oTJ@000ooTJ@04o`0000?oi6/000?o0000onA[0?oTJ`001?oT
J`04o`0000?oi6X000?o0000onAY0?oTJ@000ooTJ@04o`0000?oiFL000?o0000onEU0?oUI@001?oU
I@04o`0000?oiV8000?o0000onMN0?oWGP000ooWGP000ol0003oj5X0onQJ0003o`000003onUI0?l0
003ojU@000GojU@000Co0000ona?0?o/C`3ok4l01_l00003oni70003o`000?o`@03ol40000Col400
00?o0000oo0n0?l000000_l00002oo4l0005o`000?oYE`3ojEL0onUG0?l000001?oZE@001?l0003o
bKP0o`000?l00003olZg0006o`000?o:]P3ob[H0o`000?o;]@3o00000_o;]0000ol0003oooooo`00
0002oaJB00;o00001_ooool002cooooo00?o0000ooooooooool04Oooool6o`0000KomBX000?o0000
oo@`0?l000001_ob=@000ol0003olC`0o`000002o`0000;ol44000?o0000oni70?o^A`000oo^A`03
o`0000Kok50000?o0000onYD0?l000000_l00003onUG0004o`000?oXF`3oj5/0onQK00Go00001OoW
H0000ol0003oiV<0o`000002o`0000;oiV@000?o0000onEV0?oUIP000ooUIP03o`0000Koi6T000?o
0000onAY0?l000000_l00002onAZ0003o`000?oTJ`3oi6/000?oi6/000?o0000onA[0?oTJ`000ol0
00000ooTJ`3o0000onAZ0005onAZ0003o`000?oTJ@3o000000;o00000_oTJ@000ol0003oiFL0onEW
0003onEW0003o`000?oUI@3oiFD000?o000000?oiVD0o`000?oVHP001OoVHP001?l0003oieh0onMN
0?oWGP04o`0000GojET000Co0000onYD0?oZE03ojU@01_l00003ona>0003o`000?o^A`3okTL000Co
kTL000Co0000oo100?o`@03ol4001?l00006oo4l0003o`000?oYE`3o000000CojUD00_l00002olVh
0004o`000?o:]`3ob[L0o`0000;ob[H000Co0000ol^e0?o;]@3o00000_o;]003o`0000;o5Y800_l0
0006ooooo`00;Oooool2o`0001;ooooo00?o0000oo<d0?oc=0000_oc=0000ol0003omBX0ooDZ0003
ooDZ00?o00001_ob=@02o`0000Kol44000?o0000oni70?l000000_l00003one:0003o`000?o/D03o
k50000?ok5000ol00005onUG00Co00001OoXG@001?l0003oif00onMP0?oWH004o`0000GoiV@000?o
0000onEV0?l000000_l00002onEW0003o`000?oTJ@3oi6T000Coi6T00_l00006onAZ0004o`000?oT
J`3oi6/0onA[00Co00001OoTJ`001?l0003oi6X0onAZ0?oTJP04o`0000Koi6T000Co0000onEW0?oU
I`3oiFL01?l00005onIU0004o`000?oVHP3oiV80onIR00Ko00000ooXG@000ol0003ojET0onUI0003
onUI00Co00001?o[D`000ol0003ok4h0ona>0003ona>0004o`000?o^A`3okTL0oni700Ko00000oo`
?P000ol0003olC`0oo4l0004oo4l00;o00001?oZE@000ol0003oje<0on]C0002o`000004olZg0?l0
003ob[L0o`0000;ob[H000Co0000ol^e0?o;]@3o00000_o;]0000ol0003obk@0o`000002oaJB00;o
00001_ooool002oooooo00?o0000ooooooooool04?ooool00ol0003olc@0oo<d0002oo<d0003o`00
0?oe:P3o000000;o00000ood;`02o`000004oo8e0?l0003o0000o`0000;olCT000?o0000oo110?o`
@@000oo`@@03o`0000KokDX000?o0000ona@0?l000000_l00003on]B0003o`000?oYE`3o000000;o
00000ooYF@000ol0003oj5d0onQM0003onQM00Co00001?oVHP001?l0003oiV@0onIT0?oVI003o`00
00KoiFL000?o0000onAY0?oTJ@000ol00002onAY0003o`000?oTJP3oi6X000?oi6X01?l00003onA[
0003o`000?oTJ`3oi6/000?oi6/01?l00004onAZ0003o`000?oTJ@3oi6T000?oi6T01?l00003onEW
0003o`000?oVI@3oiVD000?oiVD01?l00003onMQ0003o`000?oXG@3oj5d000Coj5d000?o0000onUI
0?l000000_l00002onUH0003o`000?o[D`3oje<000Coje<000Co0000ona>0?o/CP3ok4h01Ol00003
oni50003o`000?o`?P3ol3h000Col3h000?o0000oo4l0?oa?0000ol000000ooa>@3o0000onYE0002
onYE0003o`000?o[D`3oje<000;oje<000Go0000olZg0?l0003ob[L0o`000002olZf0006o`000?o;
]@3obkD0o`000?o;]03o00000_o;]0001_l0003o5Y80o`000?l0003oooooo`0000Gooooo000`oooo
o`03o`000?oooooooooo013ooooo1ol00006oo@_00;o00001_oa>@000ol0003ol440o`000002o`00
00?okd@000?o0000one:0?o]BP000oo]BP03o`0000Goje800_l00007onUI0003o`000?oXG@3o0000
00;o00000_oWGP000ol0003oiV80onIR0003onIR00Co00000ooUI@000ol0003oiFL0onEW0003onEW
00?o00001_oTJ@000ol0003oi6X0o`000002o`0000;oi6/000?o0000onA[0?oTJ`000ooTJ`000ol0
003oi6/0o`000002o`0000;oi6/000?o0000onAZ0?oTJP001?oTJP000ol0003oi6T0o`000002o`00
00;oi6P000?o0000onEW0?oUI`000ooUI`000ol0003oiVD0o`000002o`0000;oiV@000?o0000onMQ
0?oWH@000ooWH@001?l0003oj5d0onQM0?oXG@04o`0000KojEP000Co0000on]C0?o[D`3oje<01_l0
0003one<0003o`000?o^A@3okTD000?okTD000Co0000oo0n0?o`?P3ol3h01Ol00005oo4i0003o`00
0?oZE@3o000000Goje<00_l000001Oo:]`3o0000o`000?o:]P3o000000;obkD000Co0000ol^d0?o;
]03o00000_o;]003o`0000;ooooo00?o0000ooooooooool00oooool0037ooooo00?o0000oooooooo
ool04Oooool2o`0000?olCT00_l000001?od;`3o0000o`000?l00002oo<c0003o`000?oa>@3olCT0
00?olCT00ol00006onm40003o`000?o]BP3o000000;o00000oo/C@000ol0003oje80o`000002o`00
00;ojU@000?o0000onUI0?oYF@001?oYF@02o`0000Koieh000?o0000onIR0?l000000_l00002onIS
0003o`000?oUI@3oiFD000?oiFD000?o0000onEW0?l000000_l00002onEX0003o`000?oTJ@3oi6T0
00Coi6T00_l00006onA[0004o`000?oTJ`3oi6/0onA[00?o00001_oTJ`001?l0003oi6X0onAZ0?oT
JP04o`0000Koi6P000Co0000onEW0?oUI`3oiFL00ol00006onIT0004o`000?oWH@3oif40onMQ00Go
00000ooXG0000ol0003ojEP0onUH0004onUH00Co00000oo[D@000ol0003okD`0one<0004one<0004
o`000?o^A@3okTD0oni500Go00000ooa>`000ol0003olCT0oo4i0004oo4i00;o00001Oo[D`000ol0
003oje00on]@0003o`000005olZf0?l0003obkD0ol^e0?l000000_o;]0001?l0003obk@0o`000?o9
^P02o`0000;ooooo00?o0000ooooooooool00oooool003;ooooo0_l0000Cooooo`Ko00001_oc<`00
0ol0003olCT0o`000002o`0000?ol3d000?o0000onm40?o_A0000oo_A003o`0000Gok4d00_l00006
onYD0003o`000?oYF@3ojET000?o00000_oXF`000ol0003oieh0onMN0003onMN00;o00001_oVH`00
1?l0003oiFD0onEU0?oUI@04o`0000GoiFP000?o0000onAY0?oTJ@000ol00002onAY0003o`000?oT
J`3oi6/000?oi6/01?l00003onA[0003o`000?oTJ`3oi6/000?oi6/01?l00003onAY0003o`000?oT
J03oi6P000Coi6P01?l00003onEV0003o`000?oVI03oiV@000?oiV@01?l00003onMO0003o`000?oX
G03oj5`000?oj5`000?o0000onUH0?oYF0000ol000000ooZEP3o0000on]A0005on]A0004o`000?o]
C03okD`0one<00Ko00000oo_@`000ol0003olC/0oo4k0003oo4k0003o`000?oa>@3olCT000?o0000
00?olSH0o`000?o[D`000oo[D`000ol0003oje00on]@0002on]@0004o`000?o:]P3o0000o`0000;o
bkD000Oo0000ol^d0?o;]03o0000ol^d0?l0003obKX000;o00000_ooool00ol0003oooooooooo`03
ooooo`00=?ooool00ol0003oooooooooo`0Aooooo`03o`000?o`?@3ol3d000;ol3d000?o0000oo<c
0?oc<`000ooc<`03o`0000Kol3d000?o0000onm40?l000000_l00003oni70003o`000?o/C@3o0000
00;o00000_o/C`000ol0003ojU@0onYD0003onYD00?o00001_oXF`000ol0003oieh0o`000002o`00
00;oiel000?o0000onIS0?oVH`000ooVH`04o`0000CoiFH000Co0000onEX0?oUJ03oiFP01?l00006
onAY0003o`000?oTJ`3o000000;o00000_oTJ`000ol0003oi6/0onA[0003onA[0003o`000?oTJ`3o
000000;o00000_oTJP000ol0003oi6T0onAY0003onAY0003o`000?oTJ03oi6P000?o000000?oiFP0
o`000?oUIP001OoUIP000ol0003oiV@0o`000002o`0000;oiV8000?o0000onMO0?oWG`000ooWG`00
1?l0003oj5`0onQL0?oXG004o`0000GojUH000?o0000on]A0?o[D@000oo[D@04o`0000?okDT000?o
0000onm30?o_@`001?o_@`001?l0003olC/0oo4k0?oa>`04o`0000GolSH000Co0000on]C0?o[D`3o
00001?o[D002o`000005olZf0?l0003o0000ol^e0?l000000_o;]0001Ol0003obk@0ol^d0?l0003o
bKX000;o00000_ooool00ol0003oooooooooo`03ooooo`00=Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?o`?@3ol3d000;ol3d000?o0000oo<c0?l000000_l00003oo8g0003o`000?o`?@3ol3d0
00?ol3d00ol00005oni700;o00001_o/C`000ol0003ojU@0o`000002o`0000?ojUH000?o0000onQK
0?oXF`000ooXF`02o`0000Koiel000?o0000onIS0?l000000_l00002onIS0003o`000?oUIP3oiFH0
00?oiFH01?l00003onEX0003o`000?oTJ@3oi6T000Coi6T00_l00006onA[0004o`000?oTJ`3oi6/0
onA[00?o00001_oTJP001?l0003oi6T0onAY0?oTJ@04o`0000GoiFP000Co0000onEV0?oUIP3oiFH0
1?l00006onIR0004o`000?oWG`3oiel0onMO00Go00000ooXFP000ol0003ojUH0onYF0003onYF0003
o`000?o[D@3oje4000?o000000?ok4l0o`000?o]B@001Oo]B@001?l0003okd<0onm30?o_@`06o`00
00?olSP000?o0000oo8f0?ob=P000oob=P000ol0003oje<0o`000004on]@0003o`000?o/C03ok4`0
00?o000000GobkD0o`000?o;]03obk@0o`000002ol^d00?o00000oooool00ol0003oooooooooo`03
ooooo`00=_ooool00ol0003oooooooooo`0Aooooo`Oo00001_ob=`000ol0003ol3d0o`000002o`00
00?ol40000?o0000oni70?l000000_l00002one90003o`000?o/C`3ok4l000?ok4l00ol00006onYF
0003o`000?oXF`3o000000;o00000_oXG0000ol0003oiel0onMO0003onMO00;o00001_oVH`000ol0
003oiFH0o`000002o`0000;oiFH000?o0000onEX0?oUJ0000ooUJ0000ol0003oi6T0onAY0003o`00
0003onAY0?l0003oi6/000Goi6/01?l00003onAZ0003o`000?oTJP3oi6X000?oi6X01?l00003onAY
0003o`000?oUJ03oiFP000?oiFP01?l00003onIU0003o`000?oVHP3oiV8000CoiV801?l00003onMN
0003o`000?oXFP3oj5X000?oj5X000Co0000onYF0?oZEP3ojUH01?l00005ona?0004o`000?o]B@3o
kDT0one900Ko00000oo`?`000ol0003olSP0oo8h0004oo8h0004o`000?ob=P3olSH0oo8f00?o0000
1?o[D0000ol0003ok4`0ona<0002ona<0004o`000?o;]@3o0000o`0000;obk@000Co0000ol^d0?l0
003obKX00_l00003ooooo`03o`000?oooooooooo00?ooooo000gooooo`;o00004oooool00ol0003o
l400oo100002oo100003o`000?ob=`3olSL000?olSL00_l00006oo1000;o00001_o]B@000ol0003o
k4l0o`000002o`0000?oje4000?o0000onYF0?oZEP000ooZEP02o`0000Koj5`000?o0000onMO0?l0
00000_l00002onMP0003o`000?oVH`3oiV<000?oiV<00_l00006onEV0004o`000?oUJ03oiFP0onEX
00Co00001OoTJ@000ol0003oi6/0onA[0003o`000003onAZ0?l0003oi6X000Goi6X000?o0000onAZ
0?l000000_l00002onAY0003o`000?oTJ@3oi6T000?oi6T000?o0000onEX0?l000000_l00002onEV
0003o`000?oVI@3oiVD000?oiVD000?o0000onIR0?oVHP000ol000000ooWH@3o0000onMN0005onMN
0004o`000?oXFP3oj5X0onQJ00Go00000ooZE0000ol0003ok4l0ona?0003ona?00Co00000oo^AP00
0ol0003ol3l0oo0o0004oo0o0004o`000?ob>03olSP0oo8h00Ko00000_oc<P001Ol0003oje00on]@
0?o[D03o000000Gok4`000Ko0000ol^e0?l0003o0000ol^d0?l00002ol^d0004o`000?o9^P3o0000
o`0000?ooooo00?o0000ooooooooool00oooool003Wooooo00?o0000ooooooooool04Oooool00ol0
003ol400oo100002oo100003o`000?ob=`3o000000;o00000_oa>P001?l0003ol400oo100?o`@002
o`0000;okd8000?o0000one90?o]B@000oo]B@03o`0000Koje4000?o0000onYF0?l000000_l00002
onUG0003o`000?oXG03oj5`000?oj5`00_l00006onMP0003o`000?oVH`3o000000;o00000_oVI000
0ol0003oiFH0onEV0003onEV00Co00000ooUJ0000ol0003oi6T0onAY0003onAY00?o00001OoTJP00
1?l0003oi6X0onAZ0?oTJP04o`0000Koi6T000Co0000onAY0?oTJ@3oi6T00ol00006onEV0004o`00
0?oVI@3oiVD0onIU00Co00001OoWH@001?l0003oieh0onMN0?oWGP06o`0000;ojEP000?o0000onYD
0?oZE0001?oZE0000ol0003ok4l0o`000002o`000003one<0?l0003okTH000GokTH000Co0000oo0o
0?o`?`3ol3l01_l00003oo<d0003o`000?oc<P3olc8000?olc8000?o0000on]@0?l000001Oo/C000
0ol0003okDP0o`000002o`000007ol^d0?l0003obk@0ol^d0?l0003obKX0o`000004ooooo`03o`00
0?oooooooooo00?ooooo000jooooo`03o`000?oooooooooo017ooooo1ol00005oo4j0003o`000?o`
@03o000000Gokd8000?o0000one90?l000000_l00003one;0003o`000?o[D@3oje4000?oje400_l0
0006onUG0003o`000?oXG03o000000;o00000_oXG0000ol0003oif00onMP0003onMP00;o00001_oV
I0000ol0003oiFH0o`000002o`0000;oiFH000?o0000onEX0?oUJ0000ooUJ0000ol0003oi6T0o`00
0002o`0000;oi6T000?o0000onAZ0?oTJP000ooTJP04o`0000?oi6T000?o0000onAY0?oTJ@001?oT
J@04o`0000?oiFL000?o0000onEV0?oUIP000ooUIP04o`0000?oiV<000?o0000onMQ0?oWH@000ooW
H@04o`0000?oj5`000?o0000onUH0?oYF0000ooYF0001?l0003ojU@0onYD0?oZE004o`0000GokD`0
00?o0000oni60?o^AP000oo^AP04o`0000?olC`000?o0000oo<d0?oc=0001?oc=0000ol0003olc80
oo<b0002oo<b00;o00001Oo/C0001_l0003okDP0one80?o]B03o0000ol^d00;o00000_o;]0000ol0
003obKX0o`000005ooooo`03o`000?oooooooooo00;ooooo000kooooo`03o`000?oooooooooo01;o
oooo00?o0000onm30?o_@`000_o_@`001?l0003olCX0oo4j0?oa>P04o`0000Gokd800ol00006one;
0003o`000?o[D@3o000000;o00000_o[DP000ol0003ojEL0onUG0003onUG00;o00001_oXG0000ol0
003oif00o`000002o`0000;oif4000?o0000onIT0?oVI0000ooVI002o`0000KoiFH000Co0000onEX
0?oUJ03oiFP01?l00005onAY0003o`000?oTJP3o000000;o00000_oTJ@000ol0003oi6T0onAY0003
onAY0003o`000?oTJ@3oi6T000?o000000?oiFP0o`000?oUI`001OoUI`000ol0003oiFH0o`000002
o`000003onEU0?l0003oiV<000GoiV<000?o0000onMQ0?l000000_l00002onMN0003o`000?oXG03o
j5`000?oj5`000Co0000onUH0?oYF03ojEP01Ol00003on]A0003o`000?o]C03okD`000CokD`000?o
0000oni60?l000000_l000000oo_@P3o0000oo4l0005oo4l0003o`000?oc=03olc@000?olc@000?o
0000oo<b0?l000000_l00002oo@]0005o`000?o/C03ok4`0ona<0?l000001?o]B0001ol0003obk@0
ol^d0?l0003obk@0o`000?o9^P000_l00005ooooo`03o`000?oooooooooo00;ooooo000looooo`03
o`000?oooooooooo01;ooooo2?l00004oo4l0003o`000?o_@P3o000000;o00000oo_A0000ol0003o
kD/0one;0003one;00;o00001_o[DP000ol0003ojEL0o`000002o`0000;ojEP000?o0000onQL0?oX
G0000ooXG002o`0000Koif4000?o0000onIT0?l000000_l00002onIT0003o`000?oUIP3oiFH000?o
iFH01?l00004onEX0004o`000?oTJ@3oi6T0onAY00?o00001_oTJ@001?l0003oi6T0onAY0?oTJ@04
o`0000GoiFP000Co0000onEW0?oUI`3oiFL01?l00005onEU0004o`000?oVH`3oiV<0onIS00Co0000
1_oWGP001?l0003oj5`0onQL0?oXG005o`0000?ojUD000?o0000on]A0?o[D@000oo[D@001?l0003o
kD`0one<0?o]C004o`0000Gokd8000?o0000oo4l0?oa?0000ooa?0001?l0003olc@0oo<d0?oc=004
o`0000Kom2d000?o0000ona<0?l000001?o]B0000ol0003okd@0o`000002o`000003ol^d0?l0003o
bKX000;o00001Oooool00ol0003oooooooooo`02ooooo`00?Oooool2o`0001Cooooo00Go0000oni5
0?o^A@3okTD0o`000005oo4l00?o00001_o_A0000ol0003okD/0o`000002o`0000;ok4`000?o0000
on]B0?o[DP000oo[DP03o`0000GojEP000?o0000onQL0?l000000_l00002onQM0003o`000?oWH@3o
if4000?oif400_l00006onIT0003o`000?oUIP3o000000;o00000_oUIP000ol0003oiFP0onEX0003
onEX00Co00000ooUJ0000ol0003oi6T0onAY0003onAY00Co00000ooTJ0000ol0003oiFP0onEX0003
onEX00Co00000ooUIP000ol0003oiFD0onEU0003onEU00Co00000ooWH@000ol0003oieh0onMN0004
onMN00Co00000_oYF@000ol0003ojUD0onYE0004onYE0004o`000?o[D@3oje40on]A00Go00000oo]
B0000ol0003okd80onm20004onm20004o`000?oa?03olC`0oo4l00Go00000ood<0000ol0003om2d0
oo@]0004oo@]00;o00001?o]B0001_l0003okd@0onm40?o_A03o0000ol^d00;o000000?obKX0o`00
0?ooool01Oooool00ol0003oooooooooo`02ooooo`00?oooool00ol0003oooooooooo`0Booooo`06
o`000?o^A@3okTD0oni50?l0003olC`00ol00003oo0n0003o`000?o_A03okd@000?okd@00_l00006
ona<0003o`000?o[DP3o000000;o00000oo[D`001?l0003ojEP0onUH0?oYF004o`0000Goj5d000?o
0000onMQ0?l000000_l00002onMQ0003o`000?oVI03oiV@000?oiV@00_l00006onEV0003o`000?oU
J03o000000;o00000_oUI`000ol0003oiFP0onEX0003onEX0003o`000?oTJ@3o000000;o00000_oU
J0000ol0003oi6P0onAX0003onAX0003o`000?oUJ03o000000;o00000_oUIP000ol0003oiFH0onEV
0003onEV0003o`000?oUI@3o000000;o00000_oVH`000ol0003oif40onMQ0003onMQ0003o`000?oW
GP3oieh000?o000000?oj5`0o`000?oYF@001?oYF@001?l0003ojUD0onYE0?oZE@06o`0000?ok4h0
00?o0000one80?o]B0000oo]B0001?l0003okd80onm20?o_@P06o`0000;olSL000?o0000oo@`0?od
<0001?od<0000ol0003om2d0oo@]0003o`000003ooHX0?l0003okDP000;okDP000?o0000onm40?o_
A0000_o_A0001_l0003obk@0ol^d0?l0003obKX0o`0000Kooooo00?o0000ooooooooool00_ooool0
043ooooo00?o0000ooooooooool04_ooool6o`0000Kol3h000?o0000onm40?l000000_l00002oni5
0003o`000?o/C03ok4`000?ok4`00ol00005on]C00Co00001?oYF0001?l0003oj5d0onQM0?oXG@04
o`0000Goif4000?o0000onIT0?l000000_l00002onIS0003o`000?oUIP3oiFH000?oiFH00_l00006
onEW0004o`000?oUJ03oiFP0onEX00?o00001_oUJ0001?l0003oi6P0onAX0?oTJ004o`0000GoiFH0
00Co0000onEV0?oUIP3oiFH01?l00005onIS0004o`000?oWH@3oif40onMQ00Co00001OoXG0001?l0
003ojET0onUI0?oYF@05o`0000?oje8000?o0000ona>0?o/CP001?o/CP001?l0003okDP0one80?o]
B005o`0000?ol3h000?o0000oo8g0?ob=`000oob=`001?l0003om300oo@`0?od<005o`0000GomRP0
00?o0000one80?l000001?o_A0001Ol0003ol400o`000?l0003obKX000;o00001_ooool00ol0003o
ooooooooo`02ooooo`00@Oooool00ol0003oooooooooo`0Booooo`03o`000?o^A`3okTL000;okTL0
00?o0000oo0n0?o`?P000oo`?P02o`0000KokTD000?o0000ona<0?l000000_l00003ona=0003o`00
0?o[D`3o000000;o00000_o[D`000ol0003ojEP0onUH0003onUH00Co00001?oXG@001?l0003oif40
onMQ0?oWH@04o`0000GoiV<000?o0000onEV0?l000000_l00002onEU0003o`000?oUI`3oiFL000?o
iFL01?l00003onEW0003o`000?oUJ03oiFP000?oiFP01?l00004onEW0004o`000?oUIP3oiFH0onEV
00Go00001?oVI0001?l0003oiV<0onIS0?oVH`05o`0000?oieh000?o0000onQL0?oXG0000ooXG004
o`0000?ojUH000?o0000on]B0?o[DP000oo[DP001?l0003ok4h0ona>0?o/CP06o`0000;okT@000?o
0000oo0n0?o`?P001?o`?P001?l0003olSL0oo8g0?ob=`05o`0000?omB/000?o0000ooHX0?of:000
1?of:002o`0000Cokd@000Ko0000oo100?o`@03ol400o`000?o9^P02o`0000Kooooo00?o0000oooo
ooooool00_ooool004;ooooo0_l0000Cooooo`03o`000?o^A`3okTL000;okTL000?o0000oo0n0?l0
00000_l00002oo100003o`000?o^A@3okTD000?okTD00ol00005ona=00;o00001_o[D`000ol0003o
jEP0o`000002o`0000;ojEP000?o0000onQM0?oXG@000ooXG@04o`0000Coif0000Co0000onIS0?oV
H`3oiV<00ol00006onEU0003o`000?oUI`3o000000;o00000_oUI@000ol0003oiFL0onEW0003onEW
0003o`000?oUJ03o000000;o00000_oUIP000ol0003oiFL0onEW0003onEW00Co00000ooVI0000ol0
003oiV@0onIT0003onIT00Co00000ooWH0000ol0003oieh0onMN0003onMN0003o`000?oXG03o0000
00;o00000_oYF@000ol0003ojUH0onYF0003onYF0004o`000?o[DP3oje80on]B00Go00000oo]BP00
0ol0003okT@0oni40003oni40004o`000?o`?P3ol3h0oo0n00Ko00000ooc<P000ol0003omB/0ooD[
0003ooD[0003o`000?of:03omRP000?o000000?omb80o`000?o_A0000_o_A0000ol0003ol400oo10
0002oo1000Co00001_ooool00ol0003oooooooooo`02ooooo`00A?ooool00ol0003oooooooooo`0A
ooooo`Oo00001Oo`@0000ol0003okTD0o`000002o`0000?okTH000?o0000ona=0?l000000_l00002
ona=0003o`000?o[D`3oje<000?oje<00_l00006onUH0003o`000?oXG@3o000000;o00000_oXG000
0ol0003oif00onMP0003onMP00Co00000ooVHP000ol0003oiFD0onEU0003onEU00;o00001_oUI@00
1?l0003oiFL0onEW0?oUI`04o`0000GoiFH000?o0000onEW0?l000000_l000000ooVI@3o0000onIT
0005onIT0003o`000?oVI03o000000;o000000?oiV40o`000?oWH0001OoWH0001?l0003oieh0onMN
0?oWGP03o`0000KojET000Co0000onYF0?oZEP3ojUH01Ol00003ona>0003o`000?o]BP3okDX000?o
kDX000Co0000oni40?o^A03okT@01Ol00003oo4i0003o`000?oc<P3olc8000Colc8000Co0000ooD[
0?oe:`3omB/01?l00005ooLR0003o`000?o_A03o000000Col40000Ko0000oni60?o^AP3o0000oooo
ool00006ooooo`03o`000?oooooooooo007ooooo0015ooooo`03o`000?oooooooooo01;ooooo00?o
0000oni80?o^B0000_o^B0001?l0003ol400oo100?o`@004o`0000GokTH00_l00006ona=0003o`00
0?o[D`3o000000;o00000_o[D`000ol0003ojEP0onUH0003onUH00;o00001_oXG0000ol0003oif00
o`000002o`0000;oiel000?o0000onIR0?oVHP000ooVHP000ol0003oiFD0o`000002o`0000;oiV<0
00?o0000onEU0?oUI@000ooUI@04o`0000CoiFD000Co0000onEV0?oUIP3oiFH00ol00005onIU0004
o`000?oVI03oiV@0onIT00Co00001OoVH@001?l0003oif00onMP0?oWH006o`0000;oj5/000?o0000
onUI0?oYF@001?oYF@04o`0000;oje8000?o0000ona>0?o/CP001?o/CP001?l0003okDX0one:0?o]
BP05o`0000?ol40000?o0000oo4i0?oa>@000ooa>@001?l0003olc80oo<b0?oc<P06o`0000;omb@0
00?o0000ooLR0?og8P001?og8P02o`0000Col40000Oo0000oni60?o^AP3okTH0o`000?oooooo0000
00Kooooo00?o0000ooooooooool00Oooool004Kooooo00?o0000ooooooooool04_ooool8o`0000Co
kd4000?o0000oni60?l000000_l00002oni70003o`000?o/C@3ok4d000?ok4d00_l00006on]C0003
o`000?oYF03o000000;o00000_oYF0000ol0003oj5`0onQL0003onQL00;o00001_oWG`001?l0003o
iV80onIR0?oVHP04o`0000GoiV<000?o0000onEU0?l000000_l000000ooVI03o0000onEU0005onEU
00Co00000_oVI0000ol0003oiVD0onIU0003onIU00Co00000ooVHP000ol0003oiV40onIQ0003onIQ
00Co00000ooXG@000ol0003oj5/0onQK0003onQK0003o`000?oYF@3ojET000?o000000?ojUD0o`00
0?o[DP001?o[DP001?l0003ok4h0ona>0?o/CP06o`0000;okTD000?o0000oo100?o`@0001?o`@000
1?l0003olCT0oo4i0?oa>@05o`0000?omB`000?o0000ooLT0?og90000oog90000ol0003omb80ooLR
0003o`000003ooTM0?l0003ol40000;ol40000Go0000oni60?o^AP3okTH0o`000003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00Oooool004Oooooo0_l0000Cooooo`03o`000?o]
B@3okDT000;okDT000?o0000onm10?o_@@000oo_@@02o`0000KokTL000?o0000ona=0?l000000_l0
0002ona=0003o`000?o[D`3oje<000?oje<00_l00006onUH0003o`000?oXG03o000000;o00000_oX
F`000ol0003oiel0onMO0003onMO00Co00001?oWH@001?l0003oiV<0onIS0?oVH`03o`0000GoiV@0
00?o0000onEU0?oUI@000ol000000ooVH`3o0000onIT0004onIT0003o`000?oVI@3o000000;o0000
0_oVHP000ol0003oiV80onIR0003onIR0003o`000?oVH@3o000000;o00000_oWGP000ol0003oj5d0
onQM0003onQM0004o`000?oXF`3oj5/0onQK00Co00001OoZE@001?l0003oje80on]B0?o[DP05o`00
00?okDX000?o0000oni50?o^A@000oo^A@001?l0003ol400oo100?o`@006o`0000;olc@000?o0000
ooD/0?oe;0001?oe;0001?l0003omb@0ooLT0?og9004o`0000GonAd000?o0000oo100?l000000oo^
AP000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00Ooo
ool004Wooooo00?o0000ooooooooool04Oooool00ol0003okDT0one90002one90003o`000?o_@@3o
000000;o00000_o_@@000ol0003okTL0oni70003oni700;o00001_o/C@000ol0003oje<0o`000002
o`0000;oje8000?o0000onUH0?oYF0000ooYF002o`0000Koj5/000?o0000onMO0?l000000_l00002
onMN0003o`000?oWH@3oif4000?oif401?l00002onIR0003o`000?oVI03oiV@000?oiV@00ol00005
onIS0004o`000?oVI03oiV@0onIT00?o00001_oVHP001?l0003oiV80onIR0?oVHP03o`0000Koieh0
00Co0000onQM0?oXG@3oj5d01Ol00003onUH0003o`000?oZE@3ojUD000?ojUD01?l00003ona>0003
o`000?o]BP3okDX000?okDX000Co0000oni50?o^A@3okTD01Ol00003oo4j0003o`000?oc=03olc@0
00?olc@000Co0000ooD/0?oe;03omB`01_l00003ooPN0003o`000?oi7@3onAd000?onAd00_l00003
oni60003o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`00B_ooool0
0ol0003oooooooooo`0Aooooo`Ko00001_o_@@000ol0003okTL0o`000002o`0000;okTL000?o0000
ona=0?o/C@000oo/C@02o`0000Koje8000?o0000onUH0?l000000_l00002onUG0003o`000?oXF`3o
j5/000?oj5/00_l00006onMN0003o`000?oWH@3o000000;o000000?oiel0o`000?oVHP001?oVHP00
0ol0003oiV@0o`000002o`0000;oiV8000?o0000onIS0?oVH`000ooVH`04o`0000?oiV8000?o0000
onIR0?oVHP000ooVHP04o`0000?oiel000?o0000onMN0?oWGP000ooWGP04o`0000?ojEX000?o0000
onUH0?oYF0000ooYF0000ol0003ojUD0o`000002o`000003on]A0?l0003ok4h000Gok4h000Co0000
one:0?o]BP3okDX01Ol00003oo100003o`000?oa>P3olCX000?olCX000Co0000oo<d0?oc=03olc@0
1Ol00003ooHW0003o`000?oh7P3on1h000Con1h000?o0000ooTM0?l000000_l00002ooPQ0003o`00
0?o^AP3o000000Sooooo00Go0000ooooooooooooooooo`000003ooooo`00Boooool00ol0003ooooo
ooooo`0Booooo`05o`000?o]B@3okDT0one90?l000001Oo_@@02o`0000KokTL000?o0000ona=0?l0
00000_l00002ona=0003o`000?o[DP3oje8000?oje800_l00006onUG0003o`000?oXF`3o000000;o
00000_oYFP000ol0003oieh0onMN0003onMN00;o00001OoWG`001?l0003oiV80onIR0?oVHP04o`00
00GoiV8000?o0000onIS0?l000000_l00002onMQ0003o`000?oVHP3oiV8000?oiV8000?o0000onIR
0?l000000_l00002onMO0003o`000?oWG`3oiel000?oiel000?o0000onMN0?l000000_l000000ooX
F`3o0000onUJ0005onUJ0004o`000?oYF03ojEP0onUH00?o00001Oo[D@001?l0003ok4h0ona>0?o/
CP06o`0000;okTD000?o0000oo100?o`@0001?o`@0001?l0003olCX0oo4j0?oa>P05o`0000?om2h0
00?o0000ooHW0?of9`000oof9`001?l0003on1h0ooPN0?oh7P04o`0000Gon2400_l0000:ooooo`04
o`000?ooooooooooo`0000?ooooo001<ooooo`;o00004oooool01_l0003okDT0one90?o]B@3o0000
onm100?o00000_o_@@000ol0003okTL0oni70003oni700;o00001_o/C@000ol0003oje80o`000002
o`0000;oje8000?o0000onUG0?oYE`000ooYE`02o`0000KojEX000?o0000onMN0?l000000_l00000
0ooXG03o0000onMO0004onMO00Co00001?oWH0001?l0003oiV80onIR0?oVHP03o`0000Koif4000Co
0000onIR0?oVHP3oiV800ol00006onMO0004o`000?oWG`3oiel0onMO00?o00001OoXF`001?l0003o
jEX0onUJ0?oYFP06o`0000;ojU<000?o0000on]A0?o[D@000oo[D@04o`0000?okDT000?o0000oni5
0?o^A@000oo^A@001?l0003ol400oo100?o`@006o`0000;olSD000?o0000oo@^0?od;P001?od;P00
1?l0003omRL0ooHW0?of9`05o`0000Comb8000?o0000ooPQ0?l000000_l0000=ooooo`03o`000?oo
oooo000000?ooooo001>ooooo`03o`000?oooooooooo017ooooo1_l00005onm10003o`000?o^A`3o
000000;o00000_o^AP000ol0003ok4d0ona=0003ona=00?o00001Oo[DP000ol0003ojEL0o`000002
o`0000;ojUD000?o0000onUJ0?oYFP000ooYFP02o`0000Goj5`000?o0000onMO0?l000000_l00002
onQM0003o`000?oWH03oif0000?oif001?l00003onMO0003o`000?oWH@3oif4000?oif401?l00002
onMO0003o`000?oWG`3oiel000Coiel01?l00002onQK0003o`000?oXF`3oj5/000?oj5/01?l00003
onYF0003o`000?oZD`3ojU<000?ojU<000?o0000on]A0?l000000_l00002ona<0003o`000?o]B@3o
kDT000?okDT000Co0000oni50?o^A@3okTD01Ol00003oo4k0003o`000?ob=@3olSD000?olSD000Co
0000oo@^0?od;P3om2h01_l00003ooHY0004o`000?og8P3omb80ooLR00Co00004?ooool01?l0003o
ooooooooool00002ooooo`00Coooool00ol0003oooooooooo`0Booooo`05o`000?o]B@3okDT0one9
0?l000000oo_@@04o`0000GokTH000?o0000ona=0?l000000_l00003one<0004o`000?o[DP3oje80
on]B00Co00001OoZE@000ol0003ojEX0o`000002o`000003onUH0?l0003oj5`000Coj5`00_l00006
onQM0003o`000?oWH03o000000;o00000_oXG@000ol0003oiel0onMO0003onMO0003o`000?oWH@3o
000000;o000000?oieh0o`000?oWG`001?oWG`000ol0003oiel0onMO0003o`000003onQL0?l0003o
j5/000Coj5/000?o0000onQK0?l000000_l00002onUG0003o`000?oZEP3ojUH000?ojUH000Co0000
onYC0?oZD`3ojU<00ol00006ona<0004o`000?o]B@3okDT0one900Go00000oo`@0000ol0003olC/0
oo4k0003oo4k0004o`000?ob=@3olSD0oo8e00Go00001?od<0001?l0003omRT0ooHY0?of:@05o`00
01Gooooo00?o0000ooooool000000_ooool0053ooooo00?o0000ooooooooool04_ooool7o`0000Co
l40000Co0000oni60?o^AP3okTH01?l00005one<00Co00001?o[D0001?l0003ojUD0onYE0?oZE@04
o`0000CojEP000?o0000onQL0?l000000_l00002onUJ0003o`000?oXG@3oj5d000?oj5d00_l00006
onQM0004o`000?oWG`3oiel0onMO00?o00001OoWGP001?l0003oiel0onMO0?oWG`04o`0000Goj5`0
00Co0000onQK0?oXF`3oj5/00ol00006onUG0004o`000?oZEP3ojUH0onYF00Go00000oo/C`000ol0
003ok4`0ona<0003ona<00Co00000_o_A0000ol0003ol400oo100004oo100004o`000?oa>`3olC/0
oo4k00Go00000oob=P001?l0003om300oo@`0?od<006o`0001_ooooo0_l00002ooooo`00DOooool2
o`0001?ooooo00Go0000one80?o]B03okDP0o`000005oo1000Co00001?o^A@000ol0003okD`0o`00
0002o`0000;okDX000?o0000on]@0?o[D0000oo[D004o`0000Coje<000?o0000onUH0?oYF0001?l0
0005onUJ0003o`000?oXG@3o000000;o00000_oXFP000ol0003oj5d0onQM0003onQM00Co00000_oX
G0000ol0003oieh0onMN0003onMN00Co00001?oXF`001?l0003oj5`0onQL0?oXG005o`0000?ojEP0
00?o0000onUG0?oYE`000ooYE`04o`0000;oje4000?o0000ona?0?o/C`001?o/C`000ol0003ok4`0
o`000002o`000003oni70?l0003okd@000Cokd@000Co0000oo100?o`@03ol4001_l00003oo4k0004
o`000?ob=P3olSH0oo8f00Go00008?ooool3o`0000;ooooo001Cooooo`03o`000?oooooooooo017o
oooo00Ko0000one80?o]B03okDP0o`000?o`@003o`0000;ol3l000?o0000oni50?o^A@000oo^A@02
o`0000KokDX000?o0000on]@0?l000000_l00002ona>0003o`000?o[D`3oje<000?oje<00ol00004
onYF0004o`000?oYFP3ojEX0onUJ00Co00001OoXFP000ol0003oj5d0o`000002o`000003onQJ0?l0
003oj5`000Coj5`000?o0000onMN0?l000000_l00002onQJ0003o`000?oXF`3oj5/000?oj5/01?l0
0003onUH0003o`000?oYF03ojEP000?ojEP000?o0000onUG0?l000000_l000000oo[DP3o0000on]A
0004on]A0004o`000?o/C`3ok4l0ona?00Co00001Oo^A`001?l0003okd@0onm40?o_A005o`0000Co
l40000Co0000oo4k0?oa>`3olC/01Ol0000Qooooo`Co00001Oooool005Cooooo00?o0000oooooooo
ool04Oooool6o`0000Gol3l000?o0000oni50?l000000_l00002onm30003o`000?o]BP3okDX000?o
kDX00_l00006ona>0003o`000?o[D`3o000000;o000000?oje40o`000?oZEP001?oZEP04o`0000Co
jEL000Co0000onQJ0?oXFP3oj5X00ol00005onQJ0004o`000?oXG03oj5`0onQL00Co00001OoXFP00
0ol0003oj5/0o`000002o`0000;ojEL000?o0000onUH0?oYF0000ooYF0001?l0003ojEP0onUH0?oY
F003o`0000Goje8000Co0000on]A0?o[D@3oje401Ol00003one:0003o`000?o^A`3okTL000?okTL0
1?l00003onm40003o`000?o`@03ol40000?ol4001?l0000Sooooo`?o00002Oooool005Gooooo00?o
0000ooooooooool04Oooool00ol0003okTL0oni70002oni70003o`000?o`?`3ol3l000;ol3l00_l0
0006onm30003o`000?o]BP3o000000;o00000_o^B0000ol0003ok4h0ona>0003ona>00;o00001Oo[
D@000ol0003ojUH0o`000002o`0000;oje<000?o0000onUG0?oYE`000ooYE`04o`0000?ojEL000?o
0000onQJ0?oXFP000_oXFP04o`0000CojET000Co0000onQJ0?oXFP3oj5X00ol00006onUG0004o`00
0?oYF03ojEP0onUH00Go00000_o[D`000ol0003oje80on]B0003on]B00Co00000oo/C0000ol0003o
kDX0one:0003one:0003o`000?o^A`3o000000;o000000?okTL0o`000?o_A0001Oo_A0000ol0003o
l400o`000002o`0002?ooooo1?l0000<ooooo`00E_ooool2o`0001;ooooo00?o0000oni70?o^A`00
0_o^A`001?l0003ol3l0o`000?l00002oo0m0003o`000?o_@`3okd<000?okd<00_l00006oni80003
o`000?o/CP3o000000;o00000_o]C0000ol0003oje40on]A0002on]A00;o00001_o[D`000ol0003o
jEL0o`000002o`0000;ojU@000?o0000onUG0?oYE`000ooYE`001?l0003oj5X0o`000?l00002onUF
0003o`000?oYF@3ojET000?ojET01?l00003onYF0003o`000?oYE`3ojEL000?ojEL01?l00002on]C
0003o`000?o[D`3oje<000?oje<000?o0000on]B0?l000000_l00002ona=0003o`000?o/C03ok4`0
00?ok4`000Co0000one:0?o]BP3okDX00ol00005oni70004o`000?o_A03okd@0onm400Co00008_oo
ool4o`00013ooooo001Hooooo`03o`000?oooooooooo013ooooo1_l00005oo0m0003o`000?o_@`3o
000000;o00000_o_@@000ol0003okTP0oni80003oni800;o00001_o]C0001?l0003oje40o`000?l0
0002ona>0003o`000?o[D`3oje<000?oje<00_l00006onYD0004o`000?oYE`3ojEL0onUG00?o0000
1OoYEP000ol0003ojET0o`000002o`0000;ojU@000?o0000onYF0?oZEP000ooZEP000ol0003ojEL0
o`000002o`000003on]C0?l0003oje<000Coje<000Co0000on]C0?o[D`3oje<01?l00005ona=0004
o`000?o/C03ok4`0ona<00Go00000oo]BP001?l0003okTL0oni70?o^A`05o`0002;ooooo1?l0000D
ooooo`00FOooool00ol0003oooooooooo`0Aooooo`05o`000?o^AP3okTH0oni60?l000001?o`?@02
o`0000Kokd4000?o0000oni80?l000000_l00002oni50003o`000?o]C03okD`000?okD`00_l00005
ona>0003o`000?o[D`3o000000;o00000_o/D0000ol0003ojU@0onYD0003onYD00Co00000_oZD`00
0ol0003ojEH0onUF0003onUF00;o00001_oZE0001?l0003ojUH0onYF0?oZEP03o`0000Goje<000Co
0000on]C0?o[D`3oje<01Ol00004ona>0004o`000?o/C@3ok4d0ona=00Go00000oo]C0001?l0003o
kDX0one:0?o]BP05o`0002Cooooo0ol0000Hooooo`00F_ooool00ol0003oooooooooo`0Aooooo`Go
000000?ol3d0o`000?l000000_oa>`000ol0003okd40onm10003onm100?o00001Oo^A@000ol0003o
kD`0o`000002o`000003one90?l0003ok4h000Cok4h00_l00006ona@0003o`000?oZE03o000000;o
000000?oje00o`000?oZD`001?oZD`000ol0003ojEH0o`000002o`0000;oje8000?o0000onYD0?oZ
E0000ooZE004o`0000;oje4000?o0000on]C0?o[D`000oo[D`04o`0000?ok4h000?o0000ona>0?o/
CP000oo/CP04o`0000?ok4d000Co0000one<0?o]C03okD`01Ol0000Uooooo`Co00006oooool005_o
oooo0_l0000Booooo`03o`000?o_A03okd@000;o00001Ooa>`000ol0003okd40o`000002o`0000?o
l3h000Co0000oni50?o^A@3okTD01?l00004one90003o`000?o/CP3o000000;o00000_o]B`000ol0
003ok500ona@0003ona@00;o00001Oo[D0001?l0003ojU<0onYC0?oZD`04o`0000Goje8000?o0000
onYD0?l000000_l000000oo[D03o0000on]A0004on]A0003o`000?o[D`3o000000;o00000_o/CP00
0ol0003ok4h0ona>0003ona>0003o`000?o/CP3o000000;o000000?ok4h0o`000?o/C@001?o/C@04
o`0002Kooooo1?l0000Oooooo`00GOooool00ol0003oooooooooo`0@ooooo`05o`000?o_A03okd@0
onm40?l000000ooa>`04o`0000Gol3h01?l00004onm20003o`000?o]B@3okDT000Co00001Oo]B`00
0ol0003ok500o`000002o`000003one<0?l0003oje0000Coje001?l00004ona?0004o`000?o[DP3o
je80on]B00?o00001Oo[D0001?l0003oje40on]A0?o[D@03o`0000Kok4h000Co0000ona>0?o/CP3o
k4h00ol00005ona>0003o`000?o/C@3o000000;o00009oooool3o`0002?ooooo001Nooooo`03o`00
0?oooooooooo013ooooo1ol00004oo8i0003o`000?o`?P3o000000;o00000_oa>`000ol0003okd80
onm20003onm200?o00001?o^A@001?l0003okD/0one;0?o]B`04o`0000CokD`000?o0000on]@0?l0
00000_l00002one<0003o`000?o/C`3ok4l000?ok4l01?l00002ona>0003o`000?o[D03oje0000?o
je001?l00003ona=0003o`000?o/CP3ok4h000?ok4h01?l00003ona>0004o`000?o/CP3ok4h0ona>
00?o00009_ooool4o`0002Kooooo001Oooooo`03o`000?oooooooooo013ooooo00Go0000onm20?o_
@P3okd80o`000005oo8i00;o00001_oa>`000ol0003okd80o`000002o`000003oo0o0?l0003okTD0
00CokTD01?l00004oni70003o`000?o]C03okD`000?o00001_o]C0000ol0003ok4l0o`000002o`00
0003one;0?l0003ok4h000Cok4h000?o0000on]@0?l000000_l00002one;0003o`000?o/C@3ok4d0
00?ok4d000?o0000ona>0?l000000_l00002ona=0004o`000?o/CP3ok4h0ona>00Go00009Oooool4
o`0002[ooooo001Pooooo`;o00004Oooool01_l0003okd80onm20?o_@P3o0000oo8i00?o00000_ob
=@000ol0003olC/0oo4k0003oo4k00;o00001Oo`?`000ol0003okTD0o`000002o`0000;okd4000?o
0000oni70?o^A`000oo^A`03o`0000?okTL000?o0000one<0?o]C0000oo]C002o`0000GokD/000Co
0000ona>0?o/CP3ok4h01?l00005one;0004o`000?o/C@3ok4d0ona=00?o00001Oo/C@04o`0002Ko
oooo1?l0000^ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`Go00001_ob=@000ol0003olC/0
o`000002o`0000;olSP000?o0000oo0o0?o`?`000_o`?`02o`0000Kokd4000?o0000oni70?l00000
0_l000000oo_@P3o0000oni70004oni70003o`000?o]C03o000000;o00000_o^A`000ol0003okD/0
one;0002one;00Co00001?o]B0001?l0003okD/0one;0?o]B`05o`0000?ok4`000?o0000ona=0?l0
00000_l0000Wooooo`?o0000<_ooool006?ooooo00?o0000ooooooooool04?ooool01?l0003ol3l0
oo0o0?l00005oo8e00;o00001_ob>0001?l0003ol3l0o`000?l00002oo4j0003o`000?o_@@3okd40
00?okd400_l00005onm20004o`000?o^A`3okTL0oni700Co00001Oo^A`001?l0003okD/0o`000?l0
0002oni50003o`000?o]B03okDP000?okDP01?l00003one;0004o`000?o/C03ok4`0ona<00?o0000
9_ooool4o`0003Gooooo001Tooooo`03o`000?oooooooooo013ooooo1?l000001?ob=@3o0000o`00
0?l00002oo<a0003o`000?ob>03olSP000?olSP00_l00005oo4j0003o`000?o_@@3o000000;o0000
0_oa?0000ol0003okd80onm20002onm200Co00001?o_@P001?l0003okTL0oni70?o^A`03o`0000Go
kTD000?o0000one80?l000000_l000000oo]B03o0000one;0004one;00Co00009Oooool4o`0003Wo
oooo001Uooooo`;o00004Oooool00ol0003olC/0o`000002o`0000Golc4000?o0000oo8h0?l00000
0_l000000ooc<`3o0000oo4j0004oo4j00;o00001_oa?0001?l0003okd80o`000?l00002oo0m0003
o`000?o_@P3okd8000?okd801?l00003onm20004o`000?o^A@3okTD0oni500?o00001Oo]B0000ol0
003okD/0o`000002o`0002Gooooo1?l0000mooooo`00Ioooool00ol0003oooooooooo`0?ooooo`05
o`000?oa>`3olC/0oo4k0?l000000ooc<@04o`0000Colc<000?o0000oo4j0?l000000_l00002oo8f
0003o`000?oa?03olC`000?olC`00_l00005oo0m0003o`000?o_@P3o000000;o000000?ol3d0o`00
0?o_@P001?o_@P04o`0000?okTD000Co0000one80?o]B03okDP00ol0000Uooooo`?o0000@Oooool0
06Sooooo00?o0000ooooooooool03oooool7o`0000Com2d000?o0000oo<c0?oc<`001?l00005oo8f
0003o`000?oa?03o000000;o000000?olSL0o`000?o`?@001?o`?@02o`0000Gol3d000?o0000onm2
0?l000000_l00002onm20003o`000?o^A@3okTD000;okTD01?l0000Tooooo`Co0000A?ooool006Wo
oooo00?o0000ooooooooool03_ooool00ol0003olSL0oo8g0002oo8g0003o`000?od;@3om2d000?o
m2d00ol00004oo@^0004o`000?ob=P3olSH0oo8f00?o00001Oob=`000ol0003ol3d0o`000002o`00
00;olSP000?o0000oo0m0?o`?@000_o`?@03o`0000Gokd8000Co0000oni50?l0003o00009?ooool4
o`0004Sooooo001Zooooo`;o00003oooool00ol0003olSL0oo8g0002oo8g0003o`000?od;@3o0000
00;o000000?omRL0o`000?od;P001?od;P04o`0000?om30000Co0000oo8g0?ob=`3olSL01?l00005
oo8h0004o`000?o`?@3o0000o`0000?ol3d000Co0000onm20?o_@P3okd800ol0000Rooooo`Co0000
C?ooool006cooooo00?o0000ooooooooool03Oooool6o`0000GomRL000?o0000oo@^0?l000000_l0
0002ooHX0003o`000?od<03om30000;om3001?l00004oo<a0004o`000?ob>03olSP0oo8h00?o0000
1Oo`?@04o`0002;ooooo0ol0001@ooooo`00KOooool00ol0003oooooooooo`0>ooooo`05o`000?oc
<P3olc80oo<b0?l000001?of9`02o`0000KomRP000Co0000oo@`0?l0003o00000_oe:P000ol0003o
lc40oo<a0003oo<a00Co00000oob>@000ol0003ol3d0o`000002o`0002;ooooo1?l0001Cooooo`00
K_ooool00ol0003oooooooooo`0>ooooo`Go000000?omRL0o`000?l000000_og8@000ol0003omRP0
ooHX0003ooHX00;o00001Ooe:P000ol0003olc40o`000002o`0000;olc<000Co0000oo8i0?ob>@3o
lST00ol0000Qooooo`Co0000Eoooool006oooooo00?o0000ooooooooool03_ooool00ol0003om2d0
oo@]0002o`0000Gomb4000?o0000ooHX0?l000000_l000000oog8P3o0000ooDZ0004ooDZ00?o0000
1?oc<`04o`00027ooooo0ol0001Kooooo`00L?ooool2o`0000oooooo00Go0000oo@]0?od;@3om2d0
o`000003ooLQ00?o00001Oog8P000ol0003omBX0o`000002o`0000?omB`000Co0000oo<c0?l0003o
00008Oooool4o`0005kooooo001booooo`03o`000?oooooooooo00gooooo1ol00003ooTL0003o`00
0?og8P3omb8000;omb801?l00003ooD/00?o00007oooool4o`0006;ooooo001cooooo`03o`000?oo
oooooooo00kooooo00Co0000ooHX0?of:03o00001Ooi70001?l0003omb80o`000?l00003ooLU00Co
00007_ooool4o`0006Kooooo001dooooo`03o`000?oooooooooo00gooooo1Ol00003ooTL00Co0000
00CombD0o`000?l0003o00007oooool3o`0006[ooooo001eooooo`;o00003Oooool01?l0003ooooo
o`000?od;@04o`0000?on1l00_l0000Nooooo`Co0000KOooool007Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`05o`000003ooPO0?l0003o000001cooooo1?l0001aooooo`00N?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0_l0000Jooooo`Co0000MOoo
ool007Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`?o0000NOooool0
07[ooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0001looooo`00O?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l00020ooooo`00OOooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol00024ooooo`00O_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo1?l00027ooooo`00Ooooool2o`0000?ooooo00?o0000
ooooooooool02_ooool4o`0008_ooooo0021ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002?
ooooo`00P_ooool00ol0003oooooo`000005ooooo`?o0000Toooool008?ooooo0_l000000ooooooo
0000o`000002o`0009Kooooo0024ooooo`;o0000V_ooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00=Cooooo0ol00019ooooo`00eOooool00ol0003oooooooooo`18ooooo`00Hooo
ool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00002?oo
ool3o`0000?ooooo0ol00004ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
0008ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o0000
0_ooool3o`000003ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`00
0?oooooooooo04Oooooo001Sooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005
ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo04Oooooo001Sooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oo
oooo000000;ooooo1Ol00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000B?ooool0
06;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000008ooooo`?o00000oooool2o`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000018ooooo`00H_ooool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Wooooo00?o0000ooooooooool00_ooool2
o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo00Co0000
oooooooooooooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Co
ooooo`000?l0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000017ooooo`00H_oo
ool01Ol0003oooooo`000?oooooo000001[ooooo00Co0000oooooooooooo00005?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1>ooooo`00H_ooool6o`0001Sooooo1Ol0000Dooooo`03o`000?oooooooooo00Sooooo
1Ol00008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1>ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.11354, 0.0326256, \
0.00372925, 0.00372925}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.02412 .26509 -6 -2.7423 ]
[.02412 .26509 0 6.2577 ]
[.01077 .34875 -12 -2.8131 ]
[.01077 .34875 0 6.1869 ]
[-0.00332 .43708 -12 -2.88827 ]
[-0.00332 .43708 0 6.11173 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26032 m
.04245 .25793 L
s
[(0)] .02412 .26509 1 -0.3906 Mshowa
.02306 .34414 m
.0292 .34184 L
s
[(20)] .01077 .34875 1 -0.37487 Mshowa
.00903 .43265 m
.01521 .43044 L
s
[(40)] -0.00332 .43708 1 -0.35816 Mshowa
.125 Mabswid
.03308 .28085 m
.03676 .27943 L
s
.02979 .30167 m
.03346 .30026 L
s
.02644 .32276 m
.03013 .32137 L
s
.01962 .36581 m
.02331 .36445 L
s
.01614 .38779 m
.01984 .38643 L
s
.01261 .41006 m
.01631 .40872 L
s
.0054 .45556 m
.00911 .45425 L
s
.00172 .47879 m
.00543 .47749 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.976 .099 0 r
.38757 .79726 .39809 .8049 .41556 .80118 .40517 .79142 Metetra
.972 .117 0 r
.40517 .79142 .41556 .80118 .4332 .7955 .42294 .78377 Metetra
.961 .161 0 r
.42294 .78377 .4332 .7955 .45097 .78828 .44082 .77474 Metetra
.946 .223 0 r
.44082 .77474 .45097 .78828 .46885 .77987 .45879 .76468 Metetra
.926 .296 0 r
.45879 .76468 .46885 .77987 .48683 .77063 .47684 .75394 Metetra
.904 .374 0 r
.47684 .75394 .48683 .77063 .50488 .76084 .49496 .74281 Metetra
.882 .452 0 r
.49496 .74281 .50488 .76084 .523 .75079 .51312 .73155 Metetra
.859 .526 0 r
.51312 .73155 .523 .75079 .54118 .7407 .53135 .72041 Metetra
.836 .593 0 r
.53135 .72041 .54118 .7407 .55944 .7308 .54963 .70957 Metetra
.815 .652 0 r
.54963 .70957 .55944 .7308 .57776 .72124 .56798 .69922 Metetra
.797 .702 0 r
.56798 .69922 .57776 .72124 .59618 .71219 .58641 .68949 Metetra
.781 .742 0 r
.58641 .68949 .59618 .71219 .61469 .70376 .60493 .68051 Metetra
.763 .768 0 r
.60493 .68051 .61469 .70376 .63332 .69606 .62356 .67238 Metetra
.722 .758 0 r
.62356 .67238 .63332 .69606 .65207 .68916 .64232 .66515 Metetra
.698 .752 0 r
.64232 .66515 .65207 .68916 .67096 .6831 .66122 .65889 Metetra
.69 .75 0 r
.66122 .65889 .67096 .6831 .69002 .67792 .68028 .65362 Metetra
.698 .752 0 r
.68028 .65362 .69002 .67792 .70925 .67362 .69952 .64934 Metetra
.722 .758 0 r
.69952 .64934 .70925 .67362 .72868 .67019 .71897 .64604 Metetra
.763 .768 0 r
.71897 .64604 .72868 .67019 .74831 .66757 .73862 .64368 Metetra
.781 .742 0 r
.73862 .64368 .74831 .66757 .76816 .66571 .75851 .6422 Metetra
.797 .702 0 r
.75851 .6422 .76816 .66571 .78824 .66451 .77864 .64151 Metetra
.815 .652 0 r
.77864 .64151 .78824 .66451 .80856 .66386 .79902 .64149 Metetra
.836 .593 0 r
.79902 .64149 .80856 .66386 .8291 .66361 .81965 .64201 Metetra
.859 .526 0 r
.81965 .64201 .8291 .66361 .84987 .66357 .84053 .64289 Metetra
.882 .452 0 r
.84053 .64289 .84987 .66357 .87085 .66354 .86165 .64393 Metetra
.904 .374 0 r
.86165 .64393 .87085 .66354 .89202 .66327 .88299 .64489 Metetra
.926 .296 0 r
.88299 .64489 .89202 .66327 .91335 .66247 .90453 .64549 Metetra
.946 .223 0 r
.90453 .64549 .91335 .66247 .93478 .66082 .92621 .64541 Metetra
.961 .161 0 r
.92621 .64541 .93478 .66082 .95627 .65795 .948 .64429 Metetra
.972 .117 0 r
.948 .64429 .95627 .65795 .97774 .65345 .96982 .64173 Metetra
.976 .099 0 r
.96982 .64173 .97774 .65345 .99909 .64687 .99158 .63727 Metetra
.972 .117 0 r
.37699 .7876 .38757 .79726 .40517 .79142 .39474 .77978 Metetra
.96 .165 0 r
.39474 .77978 .40517 .79142 .42294 .78377 .41262 .77031 Metetra
.942 .235 0 r
.41262 .77031 .42294 .78377 .44082 .77474 .43061 .75961 Metetra
.92 .318 0 r
.43061 .75961 .44082 .77474 .45879 .76468 .44868 .74804 Metetra
.895 .406 0 r
.44868 .74804 .45879 .76468 .47684 .75394 .4668 .73593 Metetra
.868 .495 0 r
.4668 .73593 .47684 .75394 .49496 .74281 .48497 .72356 Metetra
.841 .58 0 r
.48497 .72356 .49496 .74281 .51312 .73155 .50319 .7112 Metetra
.814 .657 0 r
.50319 .7112 .51312 .73155 .53135 .72041 .52146 .69909 Metetra
.788 .724 0 r
.52146 .69909 .53135 .72041 .54963 .70957 .53977 .6874 Metetra
.746 .764 0 r
.53977 .6874 .54963 .70957 .56798 .69922 .55814 .67632 Metetra
.657 .743 0 r
.55814 .67632 .56798 .69922 .58641 .68949 .57659 .66597 Metetra
.584 .725 0 r
.57659 .66597 .58641 .68949 .60493 .68051 .59512 .65649 Metetra
.528 .71 0 r
.59512 .65649 .60493 .68051 .62356 .67238 .61375 .64795 Metetra
.488 .699 0 r
.61375 .64795 .62356 .67238 .64232 .66515 .63251 .64042 Metetra
.464 .693 0 r
.63251 .64042 .64232 .66515 .66122 .65889 .65141 .63397 Metetra
.456 .691 0 r
.65141 .63397 .66122 .65889 .68028 .65362 .67048 .6286 Metetra
.464 .693 0 r
.67048 .6286 .68028 .65362 .69952 .64934 .68973 .62433 Metetra
.488 .699 0 r
.68973 .62433 .69952 .64934 .71897 .64604 .70918 .62114 Metetra
.528 .71 0 r
.70918 .62114 .71897 .64604 .73862 .64368 .72885 .619 Metetra
.584 .725 0 r
.72885 .619 .73862 .64368 .75851 .6422 .74877 .61785 Metetra
.657 .743 0 r
.74877 .61785 .75851 .6422 .77864 .64151 .76893 .6176 Metetra
.746 .764 0 r
.76893 .6176 .77864 .64151 .79902 .64149 .78936 .61814 Metetra
.788 .724 0 r
.78936 .61814 .79902 .64149 .81965 .64201 .81007 .61935 Metetra
.814 .657 0 r
.81007 .61935 .81965 .64201 .84053 .64289 .83104 .62105 Metetra
.841 .58 0 r
.83104 .62105 .84053 .64289 .86165 .64393 .85228 .62304 Metetra
.868 .495 0 r
.85228 .62304 .86165 .64393 .88299 .64489 .87376 .62511 Metetra
.895 .406 0 r
.87376 .62511 .88299 .64489 .90453 .64549 .89548 .62697 Metetra
.92 .318 0 r
.89548 .62697 .90453 .64549 .92621 .64541 .91738 .62831 Metetra
.942 .235 0 r
.91738 .62831 .92621 .64541 .948 .64429 .93943 .62878 Metetra
.96 .165 0 r
.93943 .62878 .948 .64429 .96982 .64173 .96156 .62799 Metetra
.972 .117 0 r
.96156 .62799 .96982 .64173 .99158 .63727 .98368 .62548 Metetra
.961 .161 0 r
.36636 .77629 .37699 .7876 .39474 .77978 .38424 .76666 Metetra
.942 .235 0 r
.38424 .76666 .39474 .77978 .41262 .77031 .40225 .75553 Metetra
.918 .325 0 r
.40225 .75553 .41262 .77031 .43061 .75961 .42034 .7433 Metetra
.89 .423 0 r
.42034 .7433 .43061 .75961 .44868 .74804 .4385 .73034 Metetra
.86 .522 0 r
.4385 .73034 .44868 .74804 .4668 .73593 .4567 .71697 Metetra
.828 .616 0 r
.4567 .71697 .4668 .73593 .48497 .72356 .47494 .70347 Metetra
.797 .702 0 r
.47494 .70347 .48497 .72356 .50319 .7112 .49321 .69012 Metetra
.755 .766 0 r
.49321 .69012 .50319 .7112 .52146 .69909 .51151 .67711 Metetra
.633 .737 0 r
.51151 .67711 .52146 .69909 .53977 .6874 .52986 .66466 Metetra
.528 .71 0 r
.52986 .66466 .53977 .6874 .55814 .67632 .54826 .6529 Metetra
.44 .686 0 r
.54826 .6529 .55814 .67632 .57659 .66597 .56672 .642 Metetra
.369 .666 0 r
.56672 .642 .57659 .66597 .59512 .65649 .58526 .63204 Metetra
.315 .65 0 r
.58526 .63204 .59512 .65649 .61375 .64795 .6039 .62313 Metetra
.277 .639 0 r
.6039 .62313 .61375 .64795 .63251 .64042 .62266 .61533 Metetra
.255 .632 0 r
.62266 .61533 .63251 .64042 .65141 .63397 .64156 .60869 Metetra
.247 .629 0 r
.64156 .60869 .65141 .63397 .67048 .6286 .66063 .60323 Metetra
.255 .632 0 r
.66063 .60323 .67048 .6286 .68973 .62433 .67988 .59895 Metetra
.277 .639 0 r
.67988 .59895 .68973 .62433 .70918 .62114 .69934 .59585 Metetra
.315 .65 0 r
.69934 .59585 .70918 .62114 .72885 .619 .71902 .5939 Metetra
.369 .666 0 r
.71902 .5939 .72885 .619 .74877 .61785 .73895 .59302 Metetra
.44 .686 0 r
.73895 .59302 .74877 .61785 .76893 .6176 .75915 .59315 Metetra
.528 .71 0 r
.75915 .59315 .76893 .6176 .78936 .61814 .77962 .59419 Metetra
.633 .737 0 r
.77962 .59419 .78936 .61814 .81007 .61935 .80038 .596 Metetra
.755 .766 0 r
.80038 .596 .81007 .61935 .83104 .62105 .82143 .59842 Metetra
.797 .702 0 r
.82143 .59842 .83104 .62105 .85228 .62304 .84276 .60127 Metetra
.828 .616 0 r
.84276 .60127 .85228 .62304 .87376 .62511 .86438 .60432 Metetra
.86 .522 0 r
.86438 .60432 .87376 .62511 .89548 .62697 .88625 .60731 Metetra
.89 .423 0 r
.88625 .60731 .89548 .62697 .91738 .62831 .90834 .60994 Metetra
.918 .325 0 r
.90834 .60994 .91738 .62831 .93943 .62878 .93062 .61185 Metetra
.942 .235 0 r
.93062 .61185 .93943 .62878 .96156 .62799 .95302 .61265 Metetra
.961 .161 0 r
.95302 .61265 .96156 .62799 .98368 .62548 .97547 .61191 Metetra
.946 .223 0 r
.35566 .76372 .36636 .77629 .38424 .76666 .37369 .75242 Metetra
.92 .318 0 r
.37369 .75242 .38424 .76666 .40225 .75553 .39181 .73976 Metetra
.89 .423 0 r
.39181 .73976 .40225 .75553 .42034 .7433 .41001 .72614 Metetra
.857 .531 0 r
.41001 .72614 .42034 .7433 .4385 .73034 .42826 .71192 Metetra
.822 .634 0 r
.42826 .71192 .4385 .73034 .4567 .71697 .44654 .69741 Metetra
.786 .729 0 r
.44654 .69741 .4567 .71697 .47494 .70347 .46485 .6829 Metetra
.69 .751 0 r
.46485 .6829 .47494 .70347 .49321 .69012 .48317 .66863 Metetra
.552 .716 0 r
.48317 .66863 .49321 .69012 .51151 .67711 .50152 .65482 Metetra
.432 .684 0 r
.50152 .65482 .51151 .67711 .52986 .66466 .5199 .64166 Metetra
.331 .655 0 r
.5199 .64166 .52986 .66466 .54826 .6529 .53832 .62931 Metetra
.247 .629 0 r
.53832 .62931 .54826 .6529 .56672 .642 .5568 .61788 Metetra
.182 .607 0 r
.5568 .61788 .56672 .642 .58526 .63204 .57536 .6075 Metetra
.132 .59 0 r
.57536 .6075 .58526 .63204 .6039 .62313 .59401 .59825 Metetra
.098 .577 0 r
.59401 .59825 .6039 .62313 .62266 .61533 .61277 .5902 Metetra
.077 .57 0 r
.61277 .5902 .62266 .61533 .64156 .60869 .63168 .58337 Metetra
.071 .567 0 r
.63168 .58337 .64156 .60869 .66063 .60323 .65074 .57782 Metetra
.077 .57 0 r
.65074 .57782 .66063 .60323 .67988 .59895 .67 .57353 Metetra
.098 .577 0 r
.67 .57353 .67988 .59895 .69934 .59585 .68946 .5705 Metetra
.132 .59 0 r
.68946 .5705 .69934 .59585 .71902 .5939 .70915 .56869 Metetra
.182 .607 0 r
.70915 .56869 .71902 .5939 .73895 .59302 .7291 .56806 Metetra
.247 .629 0 r
.7291 .56806 .73895 .59302 .75915 .59315 .74932 .56852 Metetra
.331 .655 0 r
.74932 .56852 .75915 .59315 .77962 .59419 .76982 .56998 Metetra
.432 .684 0 r
.76982 .56998 .77962 .59419 .80038 .596 .79063 .57232 Metetra
.552 .716 0 r
.79063 .57232 .80038 .596 .82143 .59842 .81174 .57538 Metetra
.69 .751 0 r
.81174 .57538 .82143 .59842 .84276 .60127 .83316 .57898 Metetra
.786 .729 0 r
.83316 .57898 .84276 .60127 .86438 .60432 .85488 .5829 Metetra
.822 .634 0 r
.85488 .5829 .86438 .60432 .88625 .60731 .87688 .58689 Metetra
.857 .531 0 r
.87688 .58689 .88625 .60731 .90834 .60994 .89914 .59066 Metetra
.89 .423 0 r
.89914 .59066 .90834 .60994 .93062 .61185 .92162 .59386 Metetra
.92 .318 0 r
.92162 .59386 .93062 .61185 .95302 .61265 .94427 .59611 Metetra
.946 .223 0 r
.94427 .59611 .95302 .61265 .97547 .61191 .96701 .59697 Metetra
.926 .296 0 r
.3449 .75021 .35566 .76372 .37369 .75242 .36306 .7374 Metetra
.895 .406 0 r
.36306 .7374 .37369 .75242 .39181 .73976 .38131 .72336 Metetra
.86 .522 0 r
.38131 .72336 .39181 .73976 .41001 .72614 .39962 .70847 Metetra
.822 .634 0 r
.39962 .70847 .41001 .72614 .42826 .71192 .41796 .69311 Metetra
.782 .738 0 r
.41796 .69311 .42826 .71192 .44654 .69741 .43632 .67757 Metetra
.657 .743 0 r
.43632 .67757 .44654 .69741 .46485 .6829 .4547 .66213 Metetra
.504 .704 0 r
.4547 .66213 .46485 .6829 .48317 .66863 .47308 .64704 Metetra
.369 .666 0 r
.47308 .64704 .48317 .66863 .50152 .65482 .49148 .63251 Metetra
.255 .632 0 r
.49148 .63251 .50152 .65482 .5199 .64166 .5099 .61872 Metetra
.16 .6 0 r
.5099 .61872 .5199 .64166 .53832 .62931 .52835 .60581 Metetra
.084 .572 0 r
.52835 .60581 .53832 .62931 .5568 .61788 .54685 .59392 Metetra
.025 .549 0 r
.54685 .59392 .5568 .61788 .57536 .6075 .56542 .58316 Metetra
0 .53 .018 r
.56542 .58316 .57536 .6075 .59401 .59825 .58408 .57359 Metetra
0 .517 .048 r
.58408 .57359 .59401 .59825 .61277 .5902 .60286 .5653 Metetra
0 .509 .065 r
.60286 .5653 .61277 .5902 .63168 .58337 .62177 .55831 Metetra
0 .506 .071 r
.62177 .55831 .63168 .58337 .65074 .57782 .64084 .55265 Metetra
0 .509 .065 r
.64084 .55265 .65074 .57782 .67 .57353 .66009 .54834 Metetra
0 .517 .048 r
.66009 .54834 .67 .57353 .68946 .5705 .67956 .54536 Metetra
0 .53 .018 r
.67956 .54536 .68946 .5705 .70915 .56869 .69926 .54367 Metetra
.025 .549 0 r
.69926 .54367 .70915 .56869 .7291 .56806 .71921 .54324 Metetra
.084 .572 0 r
.71921 .54324 .7291 .56806 .74932 .56852 .73945 .54398 Metetra
.16 .6 0 r
.73945 .54398 .74932 .56852 .76982 .56998 .75998 .54581 Metetra
.255 .632 0 r
.75998 .54581 .76982 .56998 .79063 .57232 .78083 .5486 Metetra
.369 .666 0 r
.78083 .5486 .79063 .57232 .81174 .57538 .80199 .55222 Metetra
.504 .704 0 r
.80199 .55222 .81174 .57538 .83316 .57898 .82348 .55647 Metetra
.657 .743 0 r
.82348 .55647 .83316 .57898 .85488 .5829 .84529 .56116 Metetra
.782 .738 0 r
.84529 .56116 .85488 .5829 .87688 .58689 .86741 .56604 Metetra
.822 .634 0 r
.86741 .56604 .87688 .58689 .89914 .59066 .88982 .57082 Metetra
.86 .522 0 r
.88982 .57082 .89914 .59066 .92162 .59386 .91248 .57516 Metetra
.895 .406 0 r
.91248 .57516 .92162 .59386 .94427 .59611 .93534 .57869 Metetra
.926 .296 0 r
.93534 .57869 .94427 .59611 .96701 .59697 .95834 .58099 Metetra
.904 .374 0 r
.33406 .73606 .3449 .75021 .36306 .7374 .35236 .72188 Metetra
.868 .495 0 r
.35236 .72188 .36306 .7374 .38131 .72336 .37073 .70659 Metetra
.828 .616 0 r
.37073 .70659 .38131 .72336 .39962 .70847 .38915 .69058 Metetra
.786 .729 0 r
.38915 .69058 .39962 .70847 .41796 .69311 .40759 .67418 Metetra
.657 .743 0 r
.40759 .67418 .41796 .69311 .43632 .67757 .42604 .65771 Metetra
.488 .699 0 r
.42604 .65771 .43632 .67757 .4547 .66213 .44448 .64145 Metetra
.338 .657 0 r
.44448 .64145 .4547 .66213 .47308 .64704 .46293 .62562 Metetra
.211 .617 0 r
.46293 .62562 .47308 .64704 .49148 .63251 .48138 .61044 Metetra
.104 .58 0 r
.48138 .61044 .49148 .63251 .5099 .61872 .49984 .59607 Metetra
.019 .546 0 r
.49984 .59607 .5099 .61872 .52835 .60581 .51833 .58267 Metetra
0 .517 .048 r
.51833 .58267 .52835 .60581 .54685 .59392 .53686 .57036 Metetra
0 .492 .099 r
.53686 .57036 .54685 .59392 .56542 .58316 .55545 .55924 Metetra
0 .473 .135 r
.55545 .55924 .56542 .58316 .58408 .57359 .57413 .54939 Metetra
0 .458 .159 r
.57413 .54939 .58408 .57359 .60286 .5653 .59291 .54087 Metetra
0 .45 .173 r
.59291 .54087 .60286 .5653 .62177 .55831 .61183 .53373 Metetra
0 .447 .177 r
.61183 .53373 .62177 .55831 .64084 .55265 .63091 .52798 Metetra
0 .45 .173 r
.63091 .52798 .64084 .55265 .66009 .54834 .65017 .52363 Metetra
0 .458 .159 r
.65017 .52363 .66009 .54834 .67956 .54536 .66964 .52068 Metetra
0 .473 .135 r
.66964 .52068 .67956 .54536 .69926 .54367 .68935 .51909 Metetra
0 .492 .099 r
.68935 .51909 .69926 .54367 .71921 .54324 .70932 .51882 Metetra
0 .517 .048 r
.70932 .51882 .71921 .54324 .73945 .54398 .72957 .5198 Metetra
.019 .546 0 r
.72957 .5198 .73945 .54398 .75998 .54581 .75013 .52194 Metetra
.104 .58 0 r
.75013 .52194 .75998 .54581 .78083 .5486 .771 .52512 Metetra
.211 .617 0 r
.771 .52512 .78083 .5486 .80199 .55222 .79221 .52921 Metetra
.338 .657 0 r
.79221 .52921 .80199 .55222 .82348 .55647 .81377 .53404 Metetra
.488 .699 0 r
.81377 .53404 .82348 .55647 .84529 .56116 .83566 .5394 Metetra
.657 .743 0 r
.83566 .5394 .84529 .56116 .86741 .56604 .85788 .54505 Metetra
.786 .729 0 r
.85788 .54505 .86741 .56604 .88982 .57082 .88041 .55071 Metetra
.828 .616 0 r
.88041 .55071 .88982 .57082 .91248 .57516 .90323 .55607 Metetra
.868 .495 0 r
.90323 .55607 .91248 .57516 .93534 .57869 .92628 .56073 Metetra
.904 .374 0 r
.92628 .56073 .93534 .57869 .95834 .58099 .9495 .56429 Metetra
.882 .452 0 r
.32313 .72153 .33406 .73606 .35236 .72188 .34156 .70614 Metetra
.841 .58 0 r
.34156 .70614 .35236 .72188 .37073 .70659 .36006 .68973 Metetra
.797 .702 0 r
.36006 .68973 .37073 .70659 .38915 .69058 .37859 .6727 Metetra
.69 .751 0 r
.37859 .6727 .38915 .69058 .40759 .67418 .39713 .65538 Metetra
.504 .704 0 r
.39713 .65538 .40759 .67418 .42604 .65771 .41567 .63809 Metetra
.338 .657 0 r
.41567 .63809 .42604 .65771 .44448 .64145 .43419 .62108 Metetra
.196 .612 0 r
.43419 .62108 .44448 .64145 .46293 .62562 .45271 .6046 Metetra
.077 .57 0 r
.45271 .6046 .46293 .62562 .48138 .61044 .47122 .58883 Metetra
0 .531 .018 r
.47122 .58883 .48138 .61044 .49984 .59607 .48973 .57395 Metetra
0 .495 .093 r
.48973 .57395 .49984 .59607 .51833 .58267 .50826 .56011 Metetra
0 .464 .15 r
.50826 .56011 .51833 .58267 .53686 .57036 .52682 .54742 Metetra
0 .438 .191 r
.52682 .54742 .53686 .57036 .55545 .55924 .54544 .53598 Metetra
0 .417 .219 r
.54544 .53598 .55545 .55924 .57413 .54939 .56414 .52587 Metetra
0 .403 .237 r
.56414 .52587 .57413 .54939 .59291 .54087 .58294 .51715 Metetra
0 .393 .247 r
.58294 .51715 .59291 .54087 .61183 .53373 .60187 .50985 Metetra
0 .39 .25 r
.60187 .50985 .61183 .53373 .63091 .52798 .62096 .504 Metetra
0 .393 .247 r
.62096 .504 .63091 .52798 .65017 .52363 .64023 .49962 Metetra
0 .403 .237 r
.64023 .49962 .65017 .52363 .66964 .52068 .65971 .49668 Metetra
0 .417 .219 r
.65971 .49668 .66964 .52068 .68935 .51909 .67943 .49516 Metetra
0 .438 .191 r
.67943 .49516 .68935 .51909 .70932 .51882 .69941 .49502 Metetra
0 .464 .15 r
.69941 .49502 .70932 .51882 .72957 .5198 .71968 .4962 Metetra
0 .495 .093 r
.71968 .4962 .72957 .5198 .75013 .52194 .74026 .49859 Metetra
0 .531 .018 r
.74026 .49859 .75013 .52194 .771 .52512 .76117 .50211 Metetra
.077 .57 0 r
.76117 .50211 .771 .52512 .79221 .52921 .78242 .50661 Metetra
.196 .612 0 r
.78242 .50661 .79221 .52921 .81377 .53404 .80402 .51192 Metetra
.338 .657 0 r
.80402 .51192 .81377 .53404 .83566 .5394 .82598 .51785 Metetra
.504 .704 0 r
.82598 .51785 .83566 .5394 .85788 .54505 .8483 .52417 Metetra
.69 .751 0 r
.8483 .52417 .85788 .54505 .88041 .55071 .87094 .53061 Metetra
.797 .702 0 r
.87094 .53061 .88041 .55071 .90323 .55607 .89389 .53684 Metetra
.841 .58 0 r
.89389 .53684 .90323 .55607 .92628 .56073 .91711 .5425 Metetra
.882 .452 0 r
.91711 .5425 .92628 .56073 .9495 .56429 .94054 .54717 Metetra
.859 .526 0 r
.31209 .70688 .32313 .72153 .34156 .70614 .33066 .6904 Metetra
.814 .657 0 r
.33066 .6904 .34156 .70614 .36006 .68973 .34929 .67301 Metetra
.755 .766 0 r
.34929 .67301 .36006 .68973 .37859 .6727 .36794 .65507 Metetra
.552 .716 0 r
.36794 .65507 .37859 .6727 .39713 .65538 .38658 .63694 Metetra
.369 .666 0 r
.38658 .63694 .39713 .65538 .41567 .63809 .40521 .61891 Metetra
.211 .617 0 r
.40521 .61891 .41567 .63809 .43419 .62108 .42382 .60125 Metetra
.077 .57 0 r
.42382 .60125 .43419 .62108 .45271 .6046 .44241 .58417 Metetra
0 .525 .03 r
.44241 .58417 .45271 .6046 .47122 .58883 .46098 .56789 Metetra
0 .484 .114 r
.46098 .56789 .47122 .58883 .48973 .57395 .47955 .55255 Metetra
0 .447 .177 r
.47955 .55255 .48973 .57395 .50826 .56011 .49813 .53831 Metetra
0 .414 .223 r
.49813 .53831 .50826 .56011 .52682 .54742 .51673 .52528 Metetra
0 .387 .254 r
.51673 .52528 .52682 .54742 .54544 .53598 .53539 .51355 Metetra
0 .366 .274 r
.53539 .51355 .54544 .53598 .56414 .52587 .55412 .5032 Metetra
0 .35 .286 r
.55412 .5032 .56414 .52587 .58294 .51715 .57294 .49429 Metetra
0 .341 .292 r
.57294 .49429 .58294 .51715 .60187 .50985 .59189 .48685 Metetra
0 .338 .294 r
.59189 .48685 .60187 .50985 .62096 .504 .61099 .48091 Metetra
0 .341 .292 r
.61099 .48091 .62096 .504 .64023 .49962 .63028 .47648 Metetra
0 .35 .286 r
.63028 .47648 .64023 .49962 .65971 .49668 .64977 .47354 Metetra
0 .366 .274 r
.64977 .47354 .65971 .49668 .67943 .49516 .6695 .47207 Metetra
0 .387 .254 r
.6695 .47207 .67943 .49516 .69941 .49502 .6895 .47204 Metetra
0 .414 .223 r
.6895 .47204 .69941 .49502 .71968 .4962 .70978 .47336 Metetra
0 .447 .177 r
.70978 .47336 .71968 .4962 .74026 .49859 .73039 .47597 Metetra
0 .484 .114 r
.73039 .47597 .74026 .49859 .76117 .50211 .75132 .47976 Metetra
0 .525 .03 r
.75132 .47976 .76117 .50211 .78242 .50661 .77262 .4846 Metetra
.077 .57 0 r
.77262 .4846 .78242 .50661 .80402 .51192 .79427 .49033 Metetra
.211 .617 0 r
.79427 .49033 .80402 .51192 .82598 .51785 .81629 .49675 Metetra
.369 .666 0 r
.81629 .49675 .82598 .51785 .8483 .52417 .83869 .50364 Metetra
.552 .716 0 r
.83869 .50364 .8483 .52417 .87094 .53061 .86143 .51074 Metetra
.755 .766 0 r
.86143 .51074 .87094 .53061 .89389 .53684 .88451 .51772 Metetra
.814 .657 0 r
.88451 .51772 .89389 .53684 .91711 .5425 .90788 .52424 Metetra
.859 .526 0 r
.90788 .52424 .91711 .5425 .94054 .54717 .93149 .52988 Metetra
.836 .593 0 r
.30094 .69231 .31209 .70688 .33066 .6904 .31965 .67487 Metetra
.788 .724 0 r
.31965 .67487 .33066 .6904 .34929 .67301 .3384 .65661 Metetra
.633 .737 0 r
.3384 .65661 .34929 .67301 .36794 .65507 .35717 .63788 Metetra
.432 .684 0 r
.35717 .63788 .36794 .65507 .38658 .63694 .37592 .61903 Metetra
.255 .632 0 r
.37592 .61903 .38658 .63694 .40521 .61891 .39465 .60036 Metetra
.105 .58 0 r
.39465 .60036 .40521 .61891 .42382 .60125 .41335 .58211 Metetra
0 .531 .018 r
.41335 .58211 .42382 .60125 .44241 .58417 .43202 .56452 Metetra
0 .484 .114 r
.43202 .56452 .44241 .58417 .46098 .56789 .45066 .54777 Metetra
0 .441 .186 r
.45066 .54777 .46098 .56789 .47955 .55255 .46929 .53203 Metetra
0 .403 .237 r
.46929 .53203 .47955 .55255 .49813 .53831 .48793 .51744 Metetra
0 .369 .271 r
.48793 .51744 .49813 .53831 .51673 .52528 .50658 .5041 Metetra
0 .341 .292 r
.50658 .5041 .51673 .52528 .53539 .51355 .52528 .49211 Metetra
0 .319 .303 r
.52528 .49211 .53539 .51355 .55412 .5032 .54404 .48155 Metetra
0 .296 .303 r
.54404 .48155 .55412 .5032 .57294 .49429 .5629 .47246 Metetra
0 .274 .293 r
.5629 .47246 .57294 .49429 .59189 .48685 .58187 .46489 Metetra
0 .267 .29 r
.58187 .46489 .59189 .48685 .61099 .48091 .601 .45885 Metetra
0 .274 .293 r
.601 .45885 .61099 .48091 .63028 .47648 .6203 .45437 Metetra
0 .296 .303 r
.6203 .45437 .63028 .47648 .64977 .47354 .63982 .45142 Metetra
0 .319 .303 r
.63982 .45142 .64977 .47354 .6695 .47207 .65957 .44998 Metetra
0 .341 .292 r
.65957 .44998 .6695 .47207 .6895 .47204 .67958 .45002 Metetra
0 .369 .271 r
.67958 .45002 .6895 .47204 .70978 .47336 .69989 .45147 Metetra
0 .403 .237 r
.69989 .45147 .70978 .47336 .73039 .47597 .72052 .45425 Metetra
0 .441 .186 r
.72052 .45425 .73039 .47597 .75132 .47976 .74148 .45826 Metetra
0 .484 .114 r
.74148 .45826 .75132 .47976 .77262 .4846 .76281 .46338 Metetra
0 .531 .018 r
.76281 .46338 .77262 .4846 .79427 .49033 .78451 .46944 Metetra
.105 .58 0 r
.78451 .46944 .79427 .49033 .81629 .49675 .8066 .47627 Metetra
.255 .632 0 r
.8066 .47627 .81629 .49675 .83869 .50364 .82906 .48364 Metetra
.432 .684 0 r
.82906 .48364 .83869 .50364 .86143 .51074 .8519 .4913 Metetra
.633 .737 0 r
.8519 .4913 .86143 .51074 .88451 .51772 .87509 .49892 Metetra
.788 .724 0 r
.87509 .49892 .88451 .51772 .90788 .52424 .89859 .50617 Metetra
.836 .593 0 r
.89859 .50617 .90788 .52424 .93149 .52988 .92237 .51263 Metetra
.815 .652 0 r
.28965 .67799 .30094 .69231 .31965 .67487 .3085 .65973 Metetra
.747 .764 0 r
.3085 .65973 .31965 .67487 .3384 .65661 .32738 .64071 Metetra
.528 .71 0 r
.32738 .64071 .3384 .65661 .35717 .63788 .34627 .62129 Metetra
.331 .655 0 r
.34627 .62129 .35717 .63788 .37592 .61903 .36514 .60182 Metetra
.16 .6 0 r
.36514 .60182 .37592 .61903 .39465 .60036 .38397 .58258 Metetra
.019 .546 0 r
.38397 .58258 .39465 .60036 .41335 .58211 .40277 .56383 Metetra
0 .495 .093 r
.40277 .56383 .41335 .58211 .43202 .56452 .42152 .54579 Metetra
0 .447 .177 r
.42152 .54579 .43202 .56452 .45066 .54777 .44024 .52864 Metetra
0 .403 .237 r
.44024 .52864 .45066 .54777 .46929 .53203 .45895 .51254 Metetra
0 .363 .276 r
.45895 .51254 .46929 .53203 .48793 .51744 .47764 .49763 Metetra
0 .328 .299 r
.47764 .49763 .48793 .51744 .50658 .5041 .49635 .48402 Metetra
0 .289 .299 r
.49635 .48402 .50658 .5041 .52528 .49211 .5151 .4718 Metetra
0 .239 .277 r
.5151 .4718 .52528 .49211 .54404 .48155 .53391 .46104 Metetra
0 .206 .26 r
.53391 .46104 .54404 .48155 .5629 .47246 .5528 .45179 Metetra
0 .187 .25 r
.5528 .45179 .5629 .47246 .58187 .46489 .57182 .44409 Metetra
0 .181 .247 r
.57182 .44409 .58187 .46489 .601 .45885 .59097 .43796 Metetra
0 .187 .25 r
.59097 .43796 .601 .45885 .6203 .45437 .6103 .43342 Metetra
0 .206 .26 r
.6103 .43342 .6203 .45437 .63982 .45142 .62984 .43044 Metetra
0 .239 .277 r
.62984 .43044 .63982 .45142 .65957 .44998 .64962 .42902 Metetra
0 .289 .299 r
.64962 .42902 .65957 .44998 .67958 .45002 .66966 .42911 Metetra
0 .328 .299 r
.66966 .42911 .67958 .45002 .69989 .45147 .68999 .43064 Metetra
0 .363 .276 r
.68999 .43064 .69989 .45147 .72052 .45425 .71065 .43355 Metetra
0 .403 .237 r
.71065 .43355 .72052 .45425 .74148 .45826 .73165 .43774 Metetra
0 .447 .177 r
.73165 .43774 .74148 .45826 .76281 .46338 .75301 .44308 Metetra
0 .495 .093 r
.75301 .44308 .76281 .46338 .78451 .46944 .77476 .44942 Metetra
.019 .546 0 r
.77476 .44942 .78451 .46944 .8066 .47627 .7969 .45659 Metetra
.16 .6 0 r
.7969 .45659 .8066 .47627 .82906 .48364 .81943 .46435 Metetra
.331 .655 0 r
.81943 .46435 .82906 .48364 .8519 .4913 .84236 .47246 Metetra
.528 .71 0 r
.84236 .47246 .8519 .4913 .87509 .49892 .86565 .48062 Metetra
.747 .764 0 r
.86565 .48062 .87509 .49892 .89859 .50617 .88927 .48847 Metetra
.815 .652 0 r
.88927 .48847 .89859 .50617 .92237 .51263 .91319 .49562 Metetra
.797 .702 0 r
.27821 .66407 .28965 .67799 .3085 .65973 .2972 .64511 Metetra
.657 .743 0 r
.2972 .64511 .3085 .65973 .32738 .64071 .31622 .62545 Metetra
.44 .686 0 r
.31622 .62545 .32738 .64071 .34627 .62129 .33523 .60545 Metetra
.247 .629 0 r
.33523 .60545 .34627 .62129 .36514 .60182 .35422 .58544 Metetra
.084 .572 0 r
.35422 .58544 .36514 .60182 .38397 .58258 .37316 .56572 Metetra
0 .517 .048 r
.37316 .56572 .38397 .58258 .40277 .56383 .39205 .54653 Metetra
0 .464 .15 r
.39205 .54653 .40277 .56383 .42152 .54579 .4109 .52809 Metetra
0 .414 .223 r
.4109 .52809 .42152 .54579 .44024 .52864 .42971 .51059 Metetra
0 .369 .271 r
.42971 .51059 .44024 .52864 .45895 .51254 .44849 .49419 Metetra
0 .328 .299 r
.44849 .49419 .45895 .51254 .47764 .49763 .46726 .479 Metetra
0 .274 .293 r
.46726 .479 .47764 .49763 .49635 .48402 .48604 .46515 Metetra
0 .213 .263 r
.48604 .46515 .49635 .48402 .5151 .4718 .50484 .45272 Metetra
0 .169 .24 r
.50484 .45272 .5151 .4718 .53391 .46104 .52371 .44178 Metetra
0 .141 .223 r
.52371 .44178 .53391 .46104 .5528 .45179 .54265 .43238 Metetra
0 .125 .213 r
.54265 .43238 .5528 .45179 .57182 .44409 .5617 .42456 Metetra
0 .12 .209 r
.5617 .42456 .57182 .44409 .59097 .43796 .5809 .41834 Metetra
0 .125 .213 r
.5809 .41834 .59097 .43796 .6103 .43342 .60027 .41374 Metetra
0 .141 .223 r
.60027 .41374 .6103 .43342 .62984 .43044 .61984 .41073 Metetra
0 .169 .24 r
.61984 .41073 .62984 .43044 .64962 .42902 .63964 .4093 Metetra
0 .213 .263 r
.63964 .4093 .64962 .42902 .66966 .42911 .65972 .40941 Metetra
0 .274 .293 r
.65972 .40941 .66966 .42911 .68999 .43064 .68008 .41101 Metetra
0 .328 .299 r
.68008 .41101 .68999 .43064 .71065 .43355 .70077 .41401 Metetra
0 .369 .271 r
.70077 .41401 .71065 .43355 .73165 .43774 .72181 .41833 Metetra
0 .414 .223 r
.72181 .41833 .73165 .43774 .75301 .44308 .74322 .42384 Metetra
0 .464 .15 r
.74322 .42384 .75301 .44308 .77476 .44942 .76501 .4304 Metetra
0 .517 .048 r
.76501 .4304 .77476 .44942 .7969 .45659 .78721 .43782 Metetra
.084 .572 0 r
.78721 .43782 .7969 .45659 .81943 .46435 .80981 .44589 Metetra
.247 .629 0 r
.80981 .44589 .81943 .46435 .84236 .47246 .83281 .45437 Metetra
.44 .686 0 r
.83281 .45437 .84236 .47246 .86565 .48062 .85619 .46295 Metetra
.657 .743 0 r
.85619 .46295 .86565 .48062 .88927 .48847 .87993 .47129 Metetra
.797 .702 0 r
.87993 .47129 .88927 .48847 .91319 .49562 .90398 .479 Metetra
.781 .742 0 r
.2666 .6507 .27821 .66407 .2972 .64511 .28573 .63115 Metetra
.584 .725 0 r
.28573 .63115 .2972 .64511 .31622 .62545 .30488 .61095 Metetra
.369 .666 0 r
.30488 .61095 .31622 .62545 .33523 .60545 .32403 .59046 Metetra
.182 .607 0 r
.32403 .59046 .33523 .60545 .35422 .58544 .34313 .57 Metetra
.025 .549 0 r
.34313 .57 .35422 .58544 .37316 .56572 .36219 .54987 Metetra
0 .492 .099 r
.36219 .54987 .37316 .56572 .39205 .54653 .3812 .53032 Metetra
0 .438 .191 r
.3812 .53032 .39205 .54653 .4109 .52809 .40015 .51155 Metetra
0 .387 .254 r
.40015 .51155 .4109 .52809 .42971 .51059 .41905 .49375 Metetra
0 .341 .292 r
.41905 .49375 .42971 .51059 .44849 .49419 .43792 .47707 Metetra
0 .289 .299 r
.43792 .47707 .44849 .49419 .46726 .479 .45677 .46165 Metetra
0 .213 .263 r
.45677 .46165 .46726 .479 .48604 .46515 .47562 .44758 Metetra
0 .158 .233 r
.47562 .44758 .48604 .46515 .50484 .45272 .49449 .43497 Metetra
0 .12 .209 r
.49449 .43497 .50484 .45272 .52371 .44178 .51342 .42386 Metetra
0 .096 .192 r
.51342 .42386 .52371 .44178 .54265 .43238 .53242 .41433 Metetra
0 .082 .182 r
.53242 .41433 .54265 .43238 .5617 .42456 .55153 .4064 Metetra
0 .078 .178 r
.55153 .4064 .5617 .42456 .5809 .41834 .57077 .40009 Metetra
0 .082 .182 r
.57077 .40009 .5809 .41834 .60027 .41374 .59018 .39541 Metetra
0 .096 .192 r
.59018 .39541 .60027 .41374 .61984 .41073 .6098 .39236 Metetra
0 .12 .209 r
.6098 .39236 .61984 .41073 .63964 .4093 .62964 .39091 Metetra
0 .158 .233 r
.62964 .39091 .63964 .4093 .65972 .40941 .64975 .39103 Metetra
0 .213 .263 r
.64975 .39103 .65972 .40941 .68008 .41101 .67016 .39266 Metetra
0 .289 .299 r
.67016 .39266 .68008 .41101 .70077 .41401 .69088 .39572 Metetra
0 .341 .292 r
.69088 .39572 .70077 .41401 .72181 .41833 .71196 .40013 Metetra
0 .387 .254 r
.71196 .40013 .72181 .41833 .74322 .42384 .73342 .40576 Metetra
0 .438 .191 r
.73342 .40576 .74322 .42384 .76501 .4304 .75526 .41247 Metetra
0 .492 .099 r
.75526 .41247 .76501 .4304 .78721 .43782 .77752 .42008 Metetra
.025 .549 0 r
.77752 .42008 .78721 .43782 .80981 .44589 .80018 .42839 Metetra
.182 .607 0 r
.80018 .42839 .80981 .44589 .83281 .45437 .82326 .43715 Metetra
.369 .666 0 r
.82326 .43715 .83281 .45437 .85619 .46295 .84673 .44605 Metetra
.584 .725 0 r
.84673 .44605 .85619 .46295 .87993 .47129 .87057 .45477 Metetra
.781 .742 0 r
.87057 .45477 .87993 .47129 .90398 .479 .89475 .4629 Metetra
.763 .768 0 r
.2548 .63796 .2666 .6507 .28573 .63115 .27407 .61795 Metetra
.528 .71 0 r
.27407 .61795 .28573 .63115 .30488 .61095 .29337 .59731 Metetra
.315 .65 0 r
.29337 .59731 .30488 .61095 .32403 .59046 .31264 .57642 Metetra
.132 .59 0 r
.31264 .57642 .32403 .59046 .34313 .57 .33188 .5556 Metetra
0 .53 .018 r
.33188 .5556 .34313 .57 .36219 .54987 .35106 .53513 Metetra
0 .473 .135 r
.35106 .53513 .36219 .54987 .3812 .53032 .37018 .51527 Metetra
0 .417 .219 r
.37018 .51527 .3812 .53032 .40015 .51155 .38924 .49622 Metetra
0 .366 .274 r
.38924 .49622 .40015 .51155 .41905 .49375 .40824 .47817 Metetra
0 .319 .303 r
.40824 .47817 .41905 .49375 .43792 .47707 .42721 .46127 Metetra
0 .239 .277 r
.42721 .46127 .43792 .47707 .45677 .46165 .44615 .44564 Metetra
0 .169 .24 r
.44615 .44564 .45677 .46165 .47562 .44758 .46508 .43139 Metetra
0 .12 .209 r
.46508 .43139 .47562 .44758 .49449 .43497 .48403 .41861 Metetra
0 .087 .185 r
.48403 .41861 .49449 .43497 .51342 .42386 .50303 .40736 Metetra
0 .066 .168 r
.50303 .40736 .51342 .42386 .53242 .41433 .5221 .3977 Metetra
0 .055 .157 r
.5221 .3977 .53242 .41433 .55153 .4064 .54127 .38966 Metetra
0 .051 .154 r
.54127 .38966 .55153 .4064 .57077 .40009 .56057 .38327 Metetra
0 .055 .157 r
.56057 .38327 .57077 .40009 .59018 .39541 .58004 .37852 Metetra
0 .066 .168 r
.58004 .37852 .59018 .39541 .6098 .39236 .5997 .37542 Metetra
0 .087 .185 r
.5997 .37542 .6098 .39236 .62964 .39091 .6196 .37393 Metetra
0 .12 .209 r
.6196 .37393 .62964 .39091 .64975 .39103 .63975 .37403 Metetra
0 .169 .24 r
.63975 .37403 .64975 .39103 .67016 .39266 .6602 .37566 Metetra
0 .239 .277 r
.6602 .37566 .67016 .39266 .69088 .39572 .68098 .37875 Metetra
0 .319 .303 r
.68098 .37875 .69088 .39572 .71196 .40013 .70211 .38321 Metetra
0 .366 .274 r
.70211 .38321 .71196 .40013 .73342 .40576 .72361 .38891 Metetra
0 .417 .219 r
.72361 .38891 .73342 .40576 .75526 .41247 .74551 .39573 Metetra
0 .473 .135 r
.74551 .39573 .75526 .41247 .77752 .42008 .76782 .40347 Metetra
0 .53 .018 r
.76782 .40347 .77752 .42008 .80018 .42839 .79055 .41194 Metetra
.132 .59 0 r
.79055 .41194 .80018 .42839 .82326 .43715 .8137 .42089 Metetra
.315 .65 0 r
.8137 .42089 .82326 .43715 .84673 .44605 .83726 .43002 Metetra
.528 .71 0 r
.83726 .43002 .84673 .44605 .87057 .45477 .86121 .439 Metetra
.763 .768 0 r
.86121 .439 .87057 .45477 .89475 .4629 .88549 .44744 Metetra
.722 .758 0 r
.2428 .62593 .2548 .63796 .27407 .61795 .26222 .60556 Metetra
.488 .699 0 r
.26222 .60556 .27407 .61795 .29337 .59731 .28165 .5846 Metetra
.277 .639 0 r
.28165 .5846 .29337 .59731 .31264 .57642 .30106 .5634 Metetra
.098 .577 0 r
.30106 .5634 .31264 .57642 .33188 .5556 .32043 .5423 Metetra
0 .517 .048 r
.32043 .5423 .33188 .5556 .35106 .53513 .33973 .52157 Metetra
0 .458 .159 r
.33973 .52157 .35106 .53513 .37018 .51527 .35898 .50146 Metetra
0 .403 .237 r
.35898 .50146 .37018 .51527 .38924 .49622 .37815 .48219 Metetra
0 .35 .286 r
.37815 .48219 .38924 .49622 .40824 .47817 .39727 .46393 Metetra
0 .296 .303 r
.39727 .46393 .40824 .47817 .42721 .46127 .41634 .44684 Metetra
0 .206 .26 r
.41634 .44684 .42721 .46127 .44615 .44564 .43538 .43103 Metetra
0 .141 .223 r
.43538 .43103 .44615 .44564 .46508 .43139 .45441 .41663 Metetra
0 .096 .192 r
.45441 .41663 .46508 .43139 .48403 .41861 .47345 .40371 Metetra
0 .066 .168 r
.47345 .40371 .48403 .41861 .50303 .40736 .49252 .39233 Metetra
0 .048 .15 r
.49252 .39233 .50303 .40736 .5221 .3977 .51167 .38256 Metetra
0 .038 .139 r
.51167 .38256 .5221 .3977 .54127 .38966 .53091 .37442 Metetra
0 .035 .136 r
.53091 .37442 .54127 .38966 .56057 .38327 .55028 .36793 Metetra
0 .038 .139 r
.55028 .36793 .56057 .38327 .58004 .37852 .56981 .36311 Metetra
0 .048 .15 r
.56981 .36311 .58004 .37852 .5997 .37542 .58954 .35994 Metetra
0 .066 .168 r
.58954 .35994 .5997 .37542 .6196 .37393 .60949 .35841 Metetra
0 .096 .192 r
.60949 .35841 .6196 .37393 .63975 .37403 .62971 .35848 Metetra
0 .141 .223 r
.62971 .35848 .63975 .37403 .6602 .37566 .65021 .36009 Metetra
0 .206 .26 r
.65021 .36009 .6602 .37566 .68098 .37875 .67104 .36317 Metetra
0 .296 .303 r
.67104 .36317 .68098 .37875 .70211 .38321 .69222 .36764 Metetra
0 .35 .286 r
.69222 .36764 .70211 .38321 .72361 .38891 .71378 .37337 Metetra
0 .403 .237 r
.71378 .37337 .72361 .38891 .74551 .39573 .73574 .38023 Metetra
0 .458 .159 r
.73574 .38023 .74551 .39573 .76782 .40347 .75812 .38804 Metetra
0 .517 .048 r
.75812 .38804 .76782 .40347 .79055 .41194 .78092 .3966 Metetra
.098 .577 0 r
.78092 .3966 .79055 .41194 .8137 .42089 .80415 .40565 Metetra
.277 .639 0 r
.80415 .40565 .8137 .42089 .83726 .43002 .82779 .41492 Metetra
.488 .699 0 r
.82779 .41492 .83726 .43002 .86121 .439 .85183 .42406 Metetra
.722 .758 0 r
.85183 .42406 .86121 .439 .88549 .44744 .87622 .43269 Metetra
.698 .752 0 r
.23058 .61466 .2428 .62593 .26222 .60556 .25013 .59406 Metetra
.464 .693 0 r
.25013 .59406 .26222 .60556 .28165 .5846 .26971 .57287 Metetra
.255 .632 0 r
.26971 .57287 .28165 .5846 .30106 .5634 .28926 .55145 Metetra
.077 .57 0 r
.28926 .55145 .30106 .5634 .32043 .5423 .30876 .53014 Metetra
0 .509 .065 r
.30876 .53014 .32043 .5423 .33973 .52157 .3282 .50922 Metetra
0 .45 .173 r
.3282 .50922 .33973 .52157 .35898 .50146 .34757 .48893 Metetra
0 .393 .247 r
.34757 .48893 .35898 .50146 .37815 .48219 .36687 .46949 Metetra
0 .341 .292 r
.36687 .46949 .37815 .48219 .39727 .46393 .38611 .45107 Metetra
0 .274 .293 r
.38611 .45107 .39727 .46393 .41634 .44684 .40529 .43382 Metetra
0 .187 .25 r
.40529 .43382 .41634 .44684 .43538 .43103 .42444 .41788 Metetra
0 .125 .213 r
.42444 .41788 .43538 .43103 .45441 .41663 .44357 .40334 Metetra
0 .082 .182 r
.44357 .40334 .45441 .41663 .47345 .40371 .46271 .3903 Metetra
0 .055 .157 r
.46271 .3903 .47345 .40371 .49252 .39233 .48188 .37881 Metetra
0 .038 .139 r
.48188 .37881 .49252 .39233 .51167 .38256 .50112 .36893 Metetra
0 .029 .129 r
.50112 .36893 .51167 .38256 .53091 .37442 .52044 .3607 Metetra
0 .026 .125 r
.52044 .3607 .53091 .37442 .55028 .36793 .53989 .35412 Metetra
0 .029 .129 r
.53989 .35412 .55028 .36793 .56981 .36311 .5595 .34922 Metetra
0 .038 .139 r
.5595 .34922 .56981 .36311 .58954 .35994 .5793 .34599 Metetra
0 .055 .157 r
.5793 .34599 .58954 .35994 .60949 .35841 .59932 .34439 Metetra
0 .082 .182 r
.59932 .34439 .60949 .35841 .62971 .35848 .6196 .3444 Metetra
0 .125 .213 r
.6196 .3444 .62971 .35848 .65021 .36009 .64017 .34597 Metetra
0 .187 .25 r
.64017 .34597 .65021 .36009 .67104 .36317 .66106 .34902 Metetra
0 .274 .293 r
.66106 .34902 .67104 .36317 .69222 .36764 .68231 .35346 Metetra
0 .341 .292 r
.68231 .35346 .69222 .36764 .71378 .37337 .70393 .35918 Metetra
0 .393 .247 r
.70393 .35918 .71378 .37337 .73574 .38023 .72595 .36603 Metetra
0 .45 .173 r
.72595 .36603 .73574 .38023 .75812 .38804 .7484 .37385 Metetra
0 .509 .065 r
.7484 .37385 .75812 .38804 .78092 .3966 .77127 .38242 Metetra
.077 .57 0 r
.77127 .38242 .78092 .3966 .80415 .40565 .79457 .39151 Metetra
.255 .632 0 r
.79457 .39151 .80415 .40565 .82779 .41492 .8183 .40082 Metetra
.464 .693 0 r
.8183 .40082 .82779 .41492 .85183 .42406 .84243 .41001 Metetra
.698 .752 0 r
.84243 .41001 .85183 .42406 .87622 .43269 .86692 .4187 Metetra
.69 .751 0 r
.21812 .6042 .23058 .61466 .25013 .59406 .23781 .58347 Metetra
.456 .691 0 r
.23781 .58347 .25013 .59406 .26971 .57287 .25753 .56215 Metetra
.247 .629 0 r
.25753 .56215 .26971 .57287 .28926 .55145 .27722 .54061 Metetra
.071 .567 0 r
.27722 .54061 .28926 .55145 .30876 .53014 .29686 .51917 Metetra
0 .506 .071 r
.29686 .51917 .30876 .53014 .3282 .50922 .31644 .49812 Metetra
0 .447 .177 r
.31644 .49812 .3282 .50922 .34757 .48893 .33595 .47771 Metetra
0 .39 .25 r
.33595 .47771 .34757 .48893 .36687 .46949 .35538 .45815 Metetra
0 .338 .294 r
.35538 .45815 .36687 .46949 .38611 .45107 .37474 .43961 Metetra
0 .267 .29 r
.37474 .43961 .38611 .45107 .40529 .43382 .39405 .42225 Metetra
0 .181 .247 r
.39405 .42225 .40529 .43382 .42444 .41788 .41332 .4062 Metetra
0 .12 .209 r
.41332 .4062 .42444 .41788 .44357 .40334 .43256 .39156 Metetra
0 .078 .178 r
.43256 .39156 .44357 .40334 .46271 .3903 .45181 .37841 Metetra
0 .051 .154 r
.45181 .37841 .46271 .3903 .48188 .37881 .47108 .36683 Metetra
0 .035 .136 r
.47108 .36683 .48188 .37881 .50112 .36893 .49042 .35685 Metetra
0 .026 .125 r
.49042 .35685 .50112 .36893 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .026 .125 r
.52938 .34187 .53989 .35412 .5595 .34922 .54907 .33688 Metetra
0 .035 .136 r
.54907 .33688 .5595 .34922 .5793 .34599 .56895 .33357 Metetra
0 .051 .154 r
.56895 .33357 .5793 .34599 .59932 .34439 .58905 .3319 Metetra
0 .078 .178 r
.58905 .3319 .59932 .34439 .6196 .3444 .60941 .33184 Metetra
0 .12 .209 r
.60941 .33184 .6196 .3444 .64017 .34597 .63005 .33333 Metetra
0 .181 .247 r
.63005 .33333 .64017 .34597 .66106 .34902 .65102 .33632 Metetra
0 .267 .29 r
.65102 .33632 .66106 .34902 .68231 .35346 .67233 .3407 Metetra
0 .338 .294 r
.67233 .3407 .68231 .35346 .70393 .35918 .69403 .34635 Metetra
0 .39 .25 r
.69403 .34635 .70393 .35918 .72595 .36603 .71613 .35315 Metetra
0 .447 .177 r
.71613 .35315 .72595 .36603 .7484 .37385 .73865 .36091 Metetra
0 .506 .071 r
.73865 .36091 .7484 .37385 .77127 .38242 .7616 .36943 Metetra
.071 .567 0 r
.7616 .36943 .77127 .38242 .79457 .39151 .78498 .37847 Metetra
.247 .629 0 r
.78498 .37847 .79457 .39151 .8183 .40082 .80879 .38773 Metetra
.456 .691 0 r
.80879 .38773 .8183 .40082 .84243 .41001 .83301 .39687 Metetra
.69 .751 0 r
.83301 .39687 .84243 .41001 .86692 .4187 .8576 .4055 Metetra
.698 .752 0 r
.20541 .59453 .21812 .6042 .23781 .58347 .22524 .57379 Metetra
.464 .693 0 r
.22524 .57379 .23781 .58347 .25753 .56215 .24509 .55245 Metetra
.255 .632 0 r
.24509 .55245 .25753 .56215 .27722 .54061 .26492 .53087 Metetra
.077 .57 0 r
.26492 .53087 .27722 .54061 .29686 .51917 .28471 .50938 Metetra
0 .509 .065 r
.28471 .50938 .29686 .51917 .31644 .49812 .30443 .48828 Metetra
0 .45 .173 r
.30443 .48828 .31644 .49812 .33595 .47771 .32408 .46781 Metetra
0 .393 .247 r
.32408 .46781 .33595 .47771 .35538 .45815 .34365 .44817 Metetra
0 .341 .292 r
.34365 .44817 .35538 .45815 .37474 .43961 .36315 .42957 Metetra
0 .274 .293 r
.36315 .42957 .37474 .43961 .39405 .42225 .38259 .41213 Metetra
0 .187 .25 r
.38259 .41213 .39405 .42225 .41332 .4062 .40198 .396 Metetra
0 .125 .213 r
.40198 .396 .41332 .4062 .43256 .39156 .42135 .38128 Metetra
0 .082 .182 r
.42135 .38128 .43256 .39156 .45181 .37841 .44072 .36805 Metetra
0 .055 .157 r
.44072 .36805 .45181 .37841 .47108 .36683 .46011 .35639 Metetra
0 .038 .139 r
.46011 .35639 .47108 .36683 .49042 .35685 .47955 .34633 Metetra
0 .029 .129 r
.47955 .34633 .49042 .35685 .50984 .34853 .49908 .33792 Metetra
0 .026 .125 r
.49908 .33792 .50984 .34853 .52938 .34187 .51872 .33117 Metetra
0 .029 .129 r
.51872 .33117 .52938 .34187 .54907 .33688 .53851 .3261 Metetra
0 .038 .139 r
.53851 .3261 .54907 .33688 .56895 .33357 .55848 .3227 Metetra
0 .055 .157 r
.55848 .3227 .56895 .33357 .58905 .3319 .57867 .32094 Metetra
0 .082 .182 r
.57867 .32094 .58905 .3319 .60941 .33184 .59912 .32079 Metetra
0 .125 .213 r
.59912 .32079 .60941 .33184 .63005 .33333 .61985 .32219 Metetra
0 .187 .25 r
.61985 .32219 .63005 .33333 .65102 .33632 .6409 .32508 Metetra
0 .274 .293 r
.6409 .32508 .65102 .33632 .67233 .3407 .6623 .32936 Metetra
0 .341 .292 r
.6623 .32936 .67233 .3407 .69403 .34635 .68407 .33491 Metetra
0 .393 .247 r
.68407 .33491 .69403 .34635 .71613 .35315 .70625 .3416 Metetra
0 .45 .173 r
.70625 .3416 .71613 .35315 .73865 .36091 .72885 .34925 Metetra
0 .509 .065 r
.72885 .34925 .73865 .36091 .7616 .36943 .75188 .35765 Metetra
.077 .57 0 r
.75188 .35765 .7616 .36943 .78498 .37847 .77535 .36655 Metetra
.255 .632 0 r
.77535 .36655 .78498 .37847 .80879 .38773 .79925 .37566 Metetra
.464 .693 0 r
.79925 .37566 .80879 .38773 .83301 .39687 .82355 .38465 Metetra
.698 .752 0 r
.82355 .38465 .83301 .39687 .8576 .4055 .84823 .39311 Metetra
.722 .758 0 r
.19243 .58565 .20541 .59453 .22524 .57379 .21239 .56502 Metetra
.488 .699 0 r
.21239 .56502 .22524 .57379 .24509 .55245 .23238 .54376 Metetra
.277 .639 0 r
.23238 .54376 .24509 .55245 .26492 .53087 .25236 .52223 Metetra
.098 .577 0 r
.25236 .52223 .26492 .53087 .28471 .50938 .27229 .50078 Metetra
0 .517 .048 r
.27229 .50078 .28471 .50938 .30443 .48828 .29216 .47969 Metetra
0 .458 .159 r
.29216 .47969 .30443 .48828 .32408 .46781 .31195 .45922 Metetra
0 .403 .237 r
.31195 .45922 .32408 .46781 .34365 .44817 .33167 .43957 Metetra
0 .35 .286 r
.33167 .43957 .34365 .44817 .36315 .42957 .35131 .42093 Metetra
0 .296 .303 r
.35131 .42093 .36315 .42957 .38259 .41213 .37089 .40347 Metetra
0 .206 .26 r
.37089 .40347 .38259 .41213 .40198 .396 .39042 .38729 Metetra
0 .141 .223 r
.39042 .38729 .40198 .396 .42135 .38128 .40993 .37251 Metetra
0 .096 .192 r
.40993 .37251 .42135 .38128 .44072 .36805 .42942 .35922 Metetra
0 .066 .168 r
.42942 .35922 .44072 .36805 .46011 .35639 .44894 .34749 Metetra
0 .048 .15 r
.44894 .34749 .46011 .35639 .47955 .34633 .4685 .33736 Metetra
0 .038 .139 r
.4685 .33736 .47955 .34633 .49908 .33792 .48815 .32887 Metetra
0 .035 .136 r
.48815 .32887 .49908 .33792 .51872 .33117 .5079 .32204 Metetra
0 .038 .139 r
.5079 .32204 .51872 .33117 .53851 .3261 .5278 .31687 Metetra
0 .048 .15 r
.5278 .31687 .53851 .3261 .55848 .3227 .54788 .31337 Metetra
0 .066 .168 r
.54788 .31337 .55848 .3227 .57867 .32094 .56817 .31151 Metetra
0 .096 .192 r
.56817 .31151 .57867 .32094 .59912 .32079 .58871 .31125 Metetra
0 .141 .223 r
.58871 .31125 .59912 .32079 .61985 .32219 .60954 .31254 Metetra
0 .206 .26 r
.60954 .31254 .61985 .32219 .6409 .32508 .63068 .3153 Metetra
0 .296 .303 r
.63068 .3153 .6409 .32508 .6623 .32936 .65217 .31944 Metetra
0 .35 .286 r
.65217 .31944 .6623 .32936 .68407 .33491 .67404 .32485 Metetra
0 .403 .237 r
.67404 .32485 .68407 .33491 .70625 .3416 .69631 .33137 Metetra
0 .458 .159 r
.69631 .33137 .70625 .3416 .72885 .34925 .71899 .33884 Metetra
0 .517 .048 r
.71899 .33884 .72885 .34925 .75188 .35765 .74211 .34705 Metetra
.098 .577 0 r
.74211 .34705 .75188 .35765 .77535 .36655 .76567 .35574 Metetra
.277 .639 0 r
.76567 .35574 .77535 .36655 .79925 .37566 .78965 .36461 Metetra
.488 .699 0 r
.78965 .36461 .79925 .37566 .82355 .38465 .81405 .37333 Metetra
.722 .758 0 r
.81405 .37333 .82355 .38465 .84823 .39311 .83882 .3815 Metetra
.763 .768 0 r
.17918 .57752 .19243 .58565 .21239 .56502 .19927 .55712 Metetra
.528 .71 0 r
.19927 .55712 .21239 .56502 .23238 .54376 .21939 .53603 Metetra
.315 .65 0 r
.21939 .53603 .23238 .54376 .25236 .52223 .23951 .51466 Metetra
.132 .59 0 r
.23951 .51466 .25236 .52223 .27229 .50078 .25958 .49332 Metetra
0 .53 .018 r
.25958 .49332 .27229 .50078 .29216 .47969 .2796 .47232 Metetra
0 .473 .135 r
.2796 .47232 .29216 .47969 .31195 .45922 .29954 .45191 Metetra
0 .417 .219 r
.29954 .45191 .31195 .45922 .33167 .43957 .31941 .43231 Metetra
0 .366 .274 r
.31941 .43231 .33167 .43957 .35131 .42093 .33921 .41369 Metetra
0 .319 .303 r
.33921 .41369 .35131 .42093 .37089 .40347 .35893 .39622 Metetra
0 .239 .277 r
.35893 .39622 .37089 .40347 .39042 .38729 .37861 .38004 Metetra
0 .169 .24 r
.37861 .38004 .39042 .38729 .40993 .37251 .39826 .36523 Metetra
0 .12 .209 r
.39826 .36523 .40993 .37251 .42942 .35922 .41789 .3519 Metetra
0 .087 .185 r
.41789 .3519 .42942 .35922 .44894 .34749 .43755 .34012 Metetra
0 .066 .168 r
.43755 .34012 .44894 .34749 .4685 .33736 .45724 .32992 Metetra
0 .055 .157 r
.45724 .32992 .4685 .33736 .48815 .32887 .47702 .32136 Metetra
0 .051 .154 r
.47702 .32136 .48815 .32887 .5079 .32204 .4969 .31444 Metetra
0 .055 .157 r
.4969 .31444 .5079 .32204 .5278 .31687 .51692 .30918 Metetra
0 .066 .168 r
.51692 .30918 .5278 .31687 .54788 .31337 .53711 .30558 Metetra
0 .087 .185 r
.53711 .30558 .54788 .31337 .56817 .31151 .55752 .3036 Metetra
0 .12 .209 r
.55752 .3036 .56817 .31151 .58871 .31125 .57817 .30321 Metetra
0 .169 .24 r
.57817 .30321 .58871 .31125 .60954 .31254 .59911 .30435 Metetra
0 .239 .277 r
.59911 .30435 .60954 .31254 .63068 .3153 .62035 .30695 Metetra
0 .319 .303 r
.62035 .30695 .63068 .3153 .65217 .31944 .64195 .31092 Metetra
0 .366 .274 r
.64195 .31092 .65217 .31944 .67404 .32485 .66391 .31613 Metetra
0 .417 .219 r
.66391 .31613 .67404 .32485 .69631 .33137 .68628 .32244 Metetra
0 .473 .135 r
.68628 .32244 .69631 .33137 .71899 .33884 .70906 .32967 Metetra
0 .53 .018 r
.70906 .32967 .71899 .33884 .74211 .34705 .73227 .33761 Metetra
.132 .59 0 r
.73227 .33761 .74211 .34705 .76567 .35574 .75592 .34599 Metetra
.315 .65 0 r
.75592 .34599 .76567 .35574 .78965 .36461 .78 .35453 Metetra
.528 .71 0 r
.78 .35453 .78965 .36461 .81405 .37333 .80448 .36288 Metetra
.763 .768 0 r
.80448 .36288 .81405 .37333 .83882 .3815 .82934 .37062 Metetra
.781 .742 0 r
.16565 .57007 .17918 .57752 .19927 .55712 .18585 .55001 Metetra
.584 .725 0 r
.18585 .55001 .19927 .55712 .21939 .53603 .2061 .52923 Metetra
.369 .666 0 r
.2061 .52923 .21939 .53603 .23951 .51466 .22635 .5081 Metetra
.182 .607 0 r
.22635 .5081 .23951 .51466 .25958 .49332 .24657 .48697 Metetra
.025 .549 0 r
.24657 .48697 .25958 .49332 .2796 .47232 .26674 .46613 Metetra
0 .492 .099 r
.26674 .46613 .2796 .47232 .29954 .45191 .28684 .44585 Metetra
0 .438 .191 r
.28684 .44585 .29954 .45191 .31941 .43231 .30686 .42634 Metetra
0 .387 .254 r
.30686 .42634 .31941 .43231 .33921 .41369 .32681 .4078 Metetra
0 .341 .292 r
.32681 .4078 .33921 .41369 .35893 .39622 .3467 .39037 Metetra
0 .289 .299 r
.3467 .39037 .35893 .39622 .37861 .38004 .36653 .37421 Metetra
0 .213 .263 r
.36653 .37421 .37861 .38004 .39826 .36523 .38633 .3594 Metetra
0 .158 .233 r
.38633 .3594 .39826 .36523 .41789 .3519 .40612 .34606 Metetra
0 .12 .209 r
.40612 .34606 .41789 .3519 .43755 .34012 .42592 .33423 Metetra
0 .096 .192 r
.42592 .33423 .43755 .34012 .45724 .32992 .44576 .32399 Metetra
0 .082 .182 r
.44576 .32399 .45724 .32992 .47702 .32136 .46567 .31535 Metetra
0 .078 .178 r
.46567 .31535 .47702 .32136 .4969 .31444 .48568 .30835 Metetra
0 .082 .182 r
.48568 .30835 .4969 .31444 .51692 .30918 .50584 .303 Metetra
0 .096 .192 r
.50584 .303 .51692 .30918 .53711 .30558 .52616 .29927 Metetra
0 .12 .209 r
.52616 .29927 .53711 .30558 .55752 .3036 .5467 .29716 Metetra
0 .158 .233 r
.5467 .29716 .55752 .3036 .57817 .30321 .56747 .29662 Metetra
0 .213 .263 r
.56747 .29662 .57817 .30321 .59911 .30435 .58852 .29759 Metetra
0 .289 .299 r
.58852 .29759 .59911 .30435 .62035 .30695 .60989 .3 Metetra
0 .341 .292 r
.60989 .3 .62035 .30695 .64195 .31092 .63159 .30375 Metetra
0 .387 .254 r
.63159 .30375 .64195 .31092 .66391 .31613 .65367 .30872 Metetra
0 .438 .191 r
.65367 .30872 .66391 .31613 .68628 .32244 .67614 .31475 Metetra
0 .492 .099 r
.67614 .31475 .68628 .32244 .70906 .32967 .69903 .32168 Metetra
.025 .549 0 r
.69903 .32168 .70906 .32967 .73227 .33761 .72234 .32927 Metetra
.182 .607 0 r
.72234 .32927 .73227 .33761 .75592 .34599 .74609 .33726 Metetra
.369 .666 0 r
.74609 .33726 .75592 .34599 .78 .35453 .77026 .34537 Metetra
.584 .725 0 r
.77026 .34537 .78 .35453 .80448 .36288 .79484 .35322 Metetra
.781 .742 0 r
.79484 .35322 .80448 .36288 .82934 .37062 .81978 .36041 Metetra
.797 .702 0 r
.15182 .56321 .16565 .57007 .18585 .55001 .17212 .54363 Metetra
.657 .743 0 r
.17212 .54363 .18585 .55001 .2061 .52923 .19249 .52325 Metetra
.44 .686 0 r
.19249 .52325 .2061 .52923 .22635 .5081 .21288 .50247 Metetra
.247 .629 0 r
.21288 .50247 .22635 .5081 .24657 .48697 .23324 .48164 Metetra
.084 .572 0 r
.23324 .48164 .24657 .48697 .26674 .46613 .25356 .46105 Metetra
0 .517 .048 r
.25356 .46105 .26674 .46613 .28684 .44585 .27382 .44096 Metetra
0 .464 .15 r
.27382 .44096 .28684 .44585 .30686 .42634 .294 .42161 Metetra
0 .414 .223 r
.294 .42161 .30686 .42634 .32681 .4078 .31411 .40319 Metetra
0 .369 .271 r
.31411 .40319 .32681 .4078 .3467 .39037 .33416 .38586 Metetra
0 .328 .299 r
.33416 .38586 .3467 .39037 .36653 .37421 .35416 .36975 Metetra
0 .274 .293 r
.35416 .36975 .36653 .37421 .38633 .3594 .37412 .35497 Metetra
0 .213 .263 r
.37412 .35497 .38633 .3594 .40612 .34606 .39406 .34163 Metetra
0 .169 .24 r
.39406 .34163 .40612 .34606 .42592 .33423 .41402 .32979 Metetra
0 .141 .223 r
.41402 .32979 .42592 .33423 .44576 .32399 .43402 .3195 Metetra
0 .125 .213 r
.43402 .3195 .44576 .32399 .46567 .31535 .45408 .31081 Metetra
0 .12 .209 r
.45408 .31081 .46567 .31535 .48568 .30835 .47424 .30372 Metetra
0 .125 .213 r
.47424 .30372 .48568 .30835 .50584 .303 .49454 .29826 Metetra
0 .141 .223 r
.49454 .29826 .50584 .303 .52616 .29927 .51501 .29441 Metetra
0 .169 .24 r
.51501 .29441 .52616 .29927 .5467 .29716 .53568 .29215 Metetra
0 .213 .263 r
.53568 .29215 .5467 .29716 .56747 .29662 .55659 .29143 Metetra
0 .274 .293 r
.55659 .29143 .56747 .29662 .58852 .29759 .57777 .2922 Metetra
0 .328 .299 r
.57777 .2922 .58852 .29759 .60989 .3 .59926 .29438 Metetra
0 .369 .271 r
.59926 .29438 .60989 .3 .63159 .30375 .62109 .29787 Metetra
0 .414 .223 r
.62109 .29787 .63159 .30375 .65367 .30872 .64329 .30255 Metetra
0 .464 .15 r
.64329 .30255 .65367 .30872 .67614 .31475 .66588 .30825 Metetra
0 .517 .048 r
.66588 .30825 .67614 .31475 .69903 .32168 .68888 .31479 Metetra
.084 .572 0 r
.68888 .31479 .69903 .32168 .72234 .32927 .7123 .32195 Metetra
.247 .629 0 r
.7123 .32195 .72234 .32927 .74609 .33726 .73615 .32946 Metetra
.44 .686 0 r
.73615 .32946 .74609 .33726 .77026 .34537 .76042 .33702 Metetra
.657 .743 0 r
.76042 .33702 .77026 .34537 .79484 .35322 .78509 .34426 Metetra
.797 .702 0 r
.78509 .34426 .79484 .35322 .81978 .36041 .81012 .35076 Metetra
.815 .652 0 r
.13771 .55681 .15182 .56321 .17212 .54363 .1581 .53784 Metetra
.747 .764 0 r
.1581 .53784 .17212 .54363 .19249 .52325 .17857 .518 Metetra
.528 .71 0 r
.17857 .518 .19249 .52325 .21288 .50247 .19908 .49768 Metetra
.331 .655 0 r
.19908 .49768 .21288 .50247 .23324 .48164 .21959 .47724 Metetra
.16 .6 0 r
.21959 .47724 .23324 .48164 .25356 .46105 .24005 .45698 Metetra
.019 .546 0 r
.24005 .45698 .25356 .46105 .27382 .44096 .26047 .43717 Metetra
0 .495 .093 r
.26047 .43717 .27382 .44096 .294 .42161 .28081 .41804 Metetra
0 .447 .177 r
.28081 .41804 .294 .42161 .31411 .40319 .30109 .39979 Metetra
0 .403 .237 r
.30109 .39979 .31411 .40319 .33416 .38586 .32131 .38259 Metetra
0 .363 .276 r
.32131 .38259 .33416 .38586 .35416 .36975 .34147 .36658 Metetra
0 .328 .299 r
.34147 .36658 .35416 .36975 .37412 .35497 .3616 .35187 Metetra
0 .289 .299 r
.3616 .35187 .37412 .35497 .39406 .34163 .38172 .33856 Metetra
0 .239 .277 r
.38172 .33856 .39406 .34163 .41402 .32979 .40184 .32672 Metetra
0 .206 .26 r
.40184 .32672 .41402 .32979 .43402 .3195 .422 .3164 Metetra
0 .187 .25 r
.422 .3164 .43402 .3195 .45408 .31081 .44223 .30765 Metetra
0 .181 .247 r
.44223 .30765 .45408 .31081 .47424 .30372 .46255 .30048 Metetra
0 .187 .25 r
.46255 .30048 .47424 .30372 .49454 .29826 .48301 .29491 Metetra
0 .206 .26 r
.48301 .29491 .49454 .29826 .51501 .29441 .50363 .29092 Metetra
0 .239 .277 r
.50363 .29092 .51501 .29441 .53568 .29215 .52445 .28849 Metetra
0 .289 .299 r
.52445 .28849 .53568 .29215 .55659 .29143 .54551 .28757 Metetra
0 .328 .299 r
.54551 .28757 .55659 .29143 .57777 .2922 .56683 .28811 Metetra
0 .363 .276 r
.56683 .28811 .57777 .2922 .59926 .29438 .58846 .29003 Metetra
0 .403 .237 r
.58846 .29003 .59926 .29438 .62109 .29787 .61043 .29321 Metetra
0 .447 .177 r
.61043 .29321 .62109 .29787 .64329 .30255 .63276 .29753 Metetra
0 .495 .093 r
.63276 .29753 .64329 .30255 .66588 .30825 .65547 .30283 Metetra
.019 .546 0 r
.65547 .30283 .66588 .30825 .68888 .31479 .67859 .30891 Metetra
.16 .6 0 r
.67859 .30891 .68888 .31479 .7123 .32195 .70213 .31555 Metetra
.331 .655 0 r
.70213 .31555 .7123 .32195 .73615 .32946 .72609 .32248 Metetra
.528 .71 0 r
.72609 .32248 .73615 .32946 .76042 .33702 .75046 .32938 Metetra
.747 .764 0 r
.75046 .32938 .76042 .33702 .78509 .34426 .77522 .33588 Metetra
.815 .652 0 r
.77522 .33588 .78509 .34426 .81012 .35076 .80033 .34154 Metetra
.836 .593 0 r
.12331 .55072 .13771 .55681 .1581 .53784 .14377 .53251 Metetra
.788 .724 0 r
.14377 .53251 .1581 .53784 .17857 .518 .16434 .51333 Metetra
.633 .737 0 r
.16434 .51333 .17857 .518 .19908 .49768 .18496 .49359 Metetra
.432 .684 0 r
.18496 .49359 .19908 .49768 .21959 .47724 .2056 .47364 Metetra
.255 .632 0 r
.2056 .47364 .21959 .47724 .24005 .45698 .22621 .4538 Metetra
.105 .58 0 r
.22621 .4538 .24005 .45698 .26047 .43717 .24677 .43434 Metetra
0 .531 .018 r
.24677 .43434 .26047 .43717 .28081 .41804 .26728 .41551 Metetra
0 .484 .114 r
.26728 .41551 .28081 .41804 .30109 .39979 .28773 .3975 Metetra
0 .441 .186 r
.28773 .3975 .30109 .39979 .32131 .38259 .30812 .38049 Metetra
0 .403 .237 r
.30812 .38049 .32131 .38259 .34147 .36658 .32846 .36461 Metetra
0 .369 .271 r
.32846 .36461 .34147 .36658 .3616 .35187 .34877 .35 Metetra
0 .341 .292 r
.34877 .35 .3616 .35187 .38172 .33856 .36906 .33675 Metetra
0 .319 .303 r
.36906 .33675 .38172 .33856 .40184 .32672 .38936 .32492 Metetra
0 .296 .303 r
.38936 .32492 .40184 .32672 .422 .3164 .4097 .31459 Metetra
0 .274 .293 r
.4097 .31459 .422 .3164 .44223 .30765 .4301 .30579 Metetra
0 .267 .29 r
.4301 .30579 .44223 .30765 .46255 .30048 .45059 .29854 Metetra
0 .274 .293 r
.45059 .29854 .46255 .30048 .48301 .29491 .47122 .29285 Metetra
0 .296 .303 r
.47122 .29285 .48301 .29491 .50363 .29092 .492 .28871 Metetra
0 .319 .303 r
.492 .28871 .50363 .29092 .52445 .28849 .51298 .28609 Metetra
0 .341 .292 r
.51298 .28609 .52445 .28849 .54551 .28757 .5342 .28495 Metetra
0 .369 .271 r
.5342 .28495 .54551 .28757 .56683 .28811 .55568 .28522 Metetra
0 .403 .237 r
.55568 .28522 .56683 .28811 .58846 .29003 .57746 .28682 Metetra
0 .441 .186 r
.57746 .28682 .58846 .29003 .61043 .29321 .59957 .28964 Metetra
0 .484 .114 r
.59957 .28964 .61043 .29321 .63276 .29753 .62204 .29355 Metetra
0 .531 .018 r
.62204 .29355 .63276 .29753 .65547 .30283 .64489 .29837 Metetra
.105 .58 0 r
.64489 .29837 .65547 .30283 .67859 .30891 .66814 .30392 Metetra
.255 .632 0 r
.66814 .30392 .67859 .30891 .70213 .31555 .6918 .30995 Metetra
.432 .684 0 r
.6918 .30995 .70213 .31555 .72609 .32248 .71587 .31619 Metetra
.633 .737 0 r
.71587 .31619 .72609 .32248 .75046 .32938 .74035 .3223 Metetra
.788 .724 0 r
.74035 .3223 .75046 .32938 .77522 .33588 .7652 .32791 Metetra
.836 .593 0 r
.7652 .32791 .77522 .33588 .80033 .34154 .7904 .3326 Metetra
.859 .526 0 r
.10863 .54476 .12331 .55072 .14377 .53251 .12914 .52745 Metetra
.814 .657 0 r
.12914 .52745 .14377 .53251 .16434 .51333 .14978 .50908 Metetra
.755 .766 0 r
.14978 .50908 .16434 .51333 .18496 .49359 .17051 .49003 Metetra
.552 .716 0 r
.17051 .49003 .18496 .49359 .2056 .47364 .19126 .47069 Metetra
.369 .666 0 r
.19126 .47069 .2056 .47364 .22621 .4538 .21201 .45137 Metetra
.211 .617 0 r
.21201 .45137 .22621 .4538 .24677 .43434 .23273 .43235 Metetra
.077 .57 0 r
.23273 .43235 .24677 .43434 .26728 .41551 .2534 .41389 Metetra
0 .525 .03 r
.2534 .41389 .26728 .41551 .28773 .3975 .27402 .39618 Metetra
0 .484 .114 r
.27402 .39618 .28773 .3975 .30812 .38049 .29458 .37941 Metetra
0 .447 .177 r
.29458 .37941 .30812 .38049 .32846 .36461 .31511 .36372 Metetra
0 .414 .223 r
.31511 .36372 .32846 .36461 .34877 .35 .3356 .34924 Metetra
0 .387 .254 r
.3356 .34924 .34877 .35 .36906 .33675 .35607 .33607 Metetra
0 .366 .274 r
.35607 .33607 .36906 .33675 .38936 .32492 .37656 .32429 Metetra
0 .35 .286 r
.37656 .32429 .38936 .32492 .4097 .31459 .39708 .31396 Metetra
0 .341 .292 r
.39708 .31396 .4097 .31459 .4301 .30579 .41766 .30511 Metetra
0 .338 .294 r
.41766 .30511 .4301 .30579 .45059 .29854 .43834 .29778 Metetra
0 .341 .292 r
.43834 .29778 .45059 .29854 .47122 .29285 .45914 .29197 Metetra
0 .35 .286 r
.45914 .29197 .47122 .29285 .492 .28871 .4801 .28766 Metetra
0 .366 .274 r
.4801 .28766 .492 .28871 .51298 .28609 .50126 .28483 Metetra
0 .387 .254 r
.50126 .28483 .51298 .28609 .5342 .28495 .52264 .28343 Metetra
0 .414 .223 r
.52264 .28343 .5342 .28495 .55568 .28522 .54429 .2834 Metetra
0 .447 .177 r
.54429 .2834 .55568 .28522 .57746 .28682 .56623 .28464 Metetra
0 .484 .114 r
.56623 .28464 .57746 .28682 .59957 .28964 .5885 .28704 Metetra
0 .525 .03 r
.5885 .28704 .59957 .28964 .62204 .29355 .61112 .29047 Metetra
.077 .57 0 r
.61112 .29047 .62204 .29355 .64489 .29837 .63412 .29474 Metetra
.211 .617 0 r
.63412 .29474 .64489 .29837 .66814 .30392 .6575 .29966 Metetra
.369 .666 0 r
.6575 .29966 .66814 .30392 .6918 .30995 .6813 .30498 Metetra
.552 .716 0 r
.6813 .30498 .6918 .30995 .71587 .31619 .70549 .3104 Metetra
.755 .766 0 r
.70549 .3104 .71587 .31619 .74035 .3223 .73007 .3156 Metetra
.814 .657 0 r
.73007 .3156 .74035 .3223 .7652 .32791 .75502 .32019 Metetra
.859 .526 0 r
.75502 .32019 .7652 .32791 .7904 .3326 .78029 .32372 Metetra
.882 .452 0 r
.0937 .5387 .10863 .54476 .12914 .52745 .11423 .52246 Metetra
.841 .58 0 r
.11423 .52246 .12914 .52745 .14978 .50908 .13493 .50503 Metetra
.797 .702 0 r
.13493 .50503 .14978 .50908 .17051 .49003 .15574 .48682 Metetra
.69 .751 0 r
.15574 .48682 .17051 .49003 .19126 .47069 .1766 .4682 Metetra
.504 .704 0 r
.1766 .4682 .19126 .47069 .21201 .45137 .19747 .4495 Metetra
.338 .657 0 r
.19747 .4495 .21201 .45137 .23273 .43235 .21833 .43102 Metetra
.196 .612 0 r
.21833 .43102 .23273 .43235 .2534 .41389 .23916 .41301 Metetra
.077 .57 0 r
.23916 .41301 .2534 .41389 .27402 .39618 .25995 .39567 Metetra
0 .531 .018 r
.25995 .39567 .27402 .39618 .29458 .37941 .28069 .3792 Metetra
0 .495 .093 r
.28069 .3792 .29458 .37941 .31511 .36372 .30139 .36375 Metetra
0 .464 .15 r
.30139 .36375 .31511 .36372 .3356 .34924 .32207 .34945 Metetra
0 .438 .191 r
.32207 .34945 .3356 .34924 .35607 .33607 .34274 .3364 Metetra
0 .417 .219 r
.34274 .3364 .35607 .33607 .37656 .32429 .36342 .32469 Metetra
0 .403 .237 r
.36342 .32469 .37656 .32429 .39708 .31396 .38413 .31437 Metetra
0 .393 .247 r
.38413 .31437 .39708 .31396 .41766 .30511 .40491 .30549 Metetra
0 .39 .25 r
.40491 .30549 .41766 .30511 .43834 .29778 .42577 .29807 Metetra
0 .393 .247 r
.42577 .29807 .43834 .29778 .45914 .29197 .44677 .29212 Metetra
0 .403 .237 r
.44677 .29212 .45914 .29197 .4801 .28766 .46792 .28763 Metetra
0 .417 .219 r
.46792 .28763 .4801 .28766 .50126 .28483 .48926 .28456 Metetra
0 .438 .191 r
.48926 .28456 .50126 .28483 .52264 .28343 .51082 .28288 Metetra
0 .464 .15 r
.51082 .28288 .52264 .28343 .54429 .2834 .53265 .2825 Metetra
0 .495 .093 r
.53265 .2825 .54429 .2834 .56623 .28464 .55476 .28333 Metetra
0 .531 .018 r
.55476 .28333 .56623 .28464 .5885 .28704 .5772 .28525 Metetra
.077 .57 0 r
.5772 .28525 .5885 .28704 .61112 .29047 .59998 .28812 Metetra
.196 .612 0 r
.59998 .28812 .61112 .29047 .63412 .29474 .62313 .29176 Metetra
.338 .657 0 r
.62313 .29176 .63412 .29474 .6575 .29966 .64666 .29595 Metetra
.504 .704 0 r
.64666 .29595 .6575 .29966 .6813 .30498 .67059 .30043 Metetra
.69 .751 0 r
.67059 .30043 .6813 .30498 .70549 .3104 .6949 .30492 Metetra
.797 .702 0 r
.6949 .30492 .70549 .3104 .73007 .3156 .7196 .30906 Metetra
.841 .58 0 r
.7196 .30906 .73007 .3156 .75502 .32019 .74464 .31246 Metetra
.882 .452 0 r
.74464 .31246 .75502 .32019 .78029 .32372 .76999 .31467 Metetra
.904 .374 0 r
.07854 .53228 .0937 .5387 .11423 .52246 .09906 .51728 Metetra
.868 .495 0 r
.09906 .51728 .11423 .52246 .13493 .50503 .11978 .50095 Metetra
.828 .616 0 r
.11978 .50095 .13493 .50503 .15574 .48682 .14065 .48371 Metetra
.786 .729 0 r
.14065 .48371 .15574 .48682 .1766 .4682 .1616 .46595 Metetra
.657 .743 0 r
.1616 .46595 .1766 .4682 .19747 .4495 .18259 .44799 Metetra
.488 .699 0 r
.18259 .44799 .19747 .4495 .21833 .43102 .20358 .43014 Metetra
.338 .657 0 r
.20358 .43014 .21833 .43102 .23916 .41301 .22456 .41267 Metetra
.211 .617 0 r
.22456 .41267 .23916 .41301 .25995 .39567 .24551 .39578 Metetra
.104 .58 0 r
.24551 .39578 .25995 .39567 .28069 .3792 .26643 .37968 Metetra
.019 .546 0 r
.26643 .37968 .28069 .3792 .30139 .36375 .28732 .36452 Metetra
0 .517 .048 r
.28732 .36452 .30139 .36375 .32207 .34945 .30819 .35044 Metetra
0 .492 .099 r
.30819 .35044 .32207 .34945 .34274 .3364 .32905 .33755 Metetra
0 .473 .135 r
.32905 .33755 .34274 .3364 .36342 .32469 .34992 .32593 Metetra
0 .458 .159 r
.34992 .32593 .36342 .32469 .38413 .31437 .37084 .31564 Metetra
0 .45 .173 r
.37084 .31564 .38413 .31437 .40491 .30549 .39181 .30673 Metetra
0 .447 .177 r
.39181 .30673 .40491 .30549 .42577 .29807 .41288 .29923 Metetra
0 .45 .173 r
.41288 .29923 .42577 .29807 .44677 .29212 .43407 .29314 Metetra
0 .458 .159 r
.43407 .29314 .44677 .29212 .46792 .28763 .45542 .28844 Metetra
0 .473 .135 r
.45542 .28844 .46792 .28763 .48926 .28456 .47696 .28512 Metetra
0 .492 .099 r
.47696 .28512 .48926 .28456 .51082 .28288 .49872 .2831 Metetra
0 .517 .048 r
.49872 .2831 .51082 .28288 .53265 .2825 .52073 .28232 Metetra
.019 .546 0 r
.52073 .28232 .53265 .2825 .55476 .28333 .54303 .28268 Metetra
.104 .58 0 r
.54303 .28268 .55476 .28333 .5772 .28525 .56564 .28406 Metetra
.211 .617 0 r
.56564 .28406 .5772 .28525 .59998 .28812 .58859 .28629 Metetra
.338 .657 0 r
.58859 .28629 .59998 .28812 .62313 .29176 .6119 .2892 Metetra
.488 .699 0 r
.6119 .2892 .62313 .29176 .64666 .29595 .63559 .29255 Metetra
.657 .743 0 r
.63559 .29255 .64666 .29595 .67059 .30043 .65966 .29609 Metetra
.786 .729 0 r
.65966 .29609 .67059 .30043 .6949 .30492 .6841 .2995 Metetra
.828 .616 0 r
.6841 .2995 .6949 .30492 .7196 .30906 .7089 .30244 Metetra
.868 .495 0 r
.7089 .30244 .7196 .30906 .74464 .31246 .73404 .30448 Metetra
.904 .374 0 r
.73404 .30448 .74464 .31246 .76999 .31467 .75946 .30518 Metetra
.926 .296 0 r
.06319 .5252 .07854 .53228 .09906 .51728 .08366 .51162 Metetra
.895 .406 0 r
.08366 .51162 .09906 .51728 .11978 .50095 .10438 .49656 Metetra
.86 .522 0 r
.10438 .49656 .11978 .50095 .14065 .48371 .12528 .48044 Metetra
.822 .634 0 r
.12528 .48044 .14065 .48371 .1616 .46595 .1463 .46366 Metetra
.782 .738 0 r
.1463 .46366 .1616 .46595 .18259 .44799 .16738 .44657 Metetra
.657 .743 0 r
.16738 .44657 .18259 .44799 .20358 .43014 .18849 .42947 Metetra
.504 .704 0 r
.18849 .42947 .20358 .43014 .22456 .41267 .20961 .41263 Metetra
.369 .666 0 r
.20961 .41263 .22456 .41267 .24551 .39578 .23072 .39628 Metetra
.255 .632 0 r
.23072 .39628 .24551 .39578 .26643 .37968 .2518 .38062 Metetra
.16 .6 0 r
.2518 .38062 .26643 .37968 .28732 .36452 .27287 .36581 Metetra
.084 .572 0 r
.27287 .36581 .28732 .36452 .30819 .35044 .29393 .352 Metetra
.025 .549 0 r
.29393 .352 .30819 .35044 .32905 .33755 .31499 .3393 Metetra
0 .53 .018 r
.31499 .3393 .32905 .33755 .34992 .32593 .33607 .3278 Metetra
0 .517 .048 r
.33607 .3278 .34992 .32593 .37084 .31564 .35719 .31757 Metetra
0 .509 .065 r
.35719 .31757 .37084 .31564 .39181 .30673 .37837 .30864 Metetra
0 .506 .071 r
.37837 .30864 .39181 .30673 .41288 .29923 .39965 .30105 Metetra
0 .509 .065 r
.39965 .30105 .41288 .29923 .43407 .29314 .42105 .29481 Metetra
0 .517 .048 r
.42105 .29481 .43407 .29314 .45542 .28844 .4426 .28989 Metetra
0 .53 .018 r
.4426 .28989 .45542 .28844 .47696 .28512 .46435 .28627 Metetra
.025 .549 0 r
.46435 .28627 .47696 .28512 .49872 .2831 .48631 .28388 Metetra
.084 .572 0 r
.48631 .28388 .49872 .2831 .52073 .28232 .50852 .28266 Metetra
.16 .6 0 r
.50852 .28266 .52073 .28232 .54303 .28268 .53101 .28248 Metetra
.255 .632 0 r
.53101 .28248 .54303 .28268 .56564 .28406 .55381 .28323 Metetra
.369 .666 0 r
.55381 .28323 .56564 .28406 .58859 .28629 .57694 .28474 Metetra
.504 .704 0 r
.57694 .28474 .58859 .28629 .6119 .2892 .60042 .28681 Metetra
.657 .743 0 r
.60042 .28681 .6119 .2892 .63559 .29255 .62427 .28921 Metetra
.782 .738 0 r
.62427 .28921 .63559 .29255 .65966 .29609 .64848 .29166 Metetra
.822 .634 0 r
.64848 .29166 .65966 .29609 .6841 .2995 .67305 .29386 Metetra
.86 .522 0 r
.67305 .29386 .6841 .2995 .7089 .30244 .69797 .29542 Metetra
.895 .406 0 r
.69797 .29542 .7089 .30244 .73404 .30448 .72319 .29593 Metetra
.926 .296 0 r
.72319 .29593 .73404 .30448 .75946 .30518 .74867 .29491 Metetra
.946 .223 0 r
.0477 .51711 .06319 .5252 .08366 .51162 .06807 .50514 Metetra
.92 .318 0 r
.06807 .50514 .08366 .51162 .10438 .49656 .08875 .49152 Metetra
.89 .423 0 r
.08875 .49152 .10438 .49656 .12528 .48044 .10965 .47669 Metetra
.857 .531 0 r
.10965 .47669 .12528 .48044 .1463 .46366 .13071 .46105 Metetra
.822 .634 0 r
.13071 .46105 .1463 .46366 .16738 .44657 .15186 .44495 Metetra
.786 .729 0 r
.15186 .44495 .16738 .44657 .18849 .42947 .17307 .42871 Metetra
.69 .751 0 r
.17307 .42871 .18849 .42947 .20961 .41263 .19432 .41261 Metetra
.552 .716 0 r
.19432 .41261 .20961 .41263 .23072 .39628 .21557 .39689 Metetra
.432 .684 0 r
.21557 .39689 .23072 .39628 .2518 .38062 .23682 .38175 Metetra
.331 .655 0 r
.23682 .38175 .2518 .38062 .27287 .36581 .25807 .36736 Metetra
.247 .629 0 r
.25807 .36736 .27287 .36581 .29393 .352 .27931 .35388 Metetra
.182 .607 0 r
.27931 .35388 .29393 .352 .31499 .3393 .30057 .34142 Metetra
.132 .59 0 r
.30057 .34142 .31499 .3393 .33607 .3278 .32185 .33007 Metetra
.098 .577 0 r
.32185 .33007 .33607 .3278 .35719 .31757 .34318 .3199 Metetra
.077 .57 0 r
.34318 .3199 .35719 .31757 .37837 .30864 .36457 .31097 Metetra
.071 .567 0 r
.36457 .31097 .37837 .30864 .39965 .30105 .38607 .30329 Metetra
.077 .57 0 r
.38607 .30329 .39965 .30105 .42105 .29481 .40768 .29688 Metetra
.098 .577 0 r
.40768 .29688 .42105 .29481 .4426 .28989 .42945 .29172 Metetra
.132 .59 0 r
.42945 .29172 .4426 .28989 .46435 .28627 .45141 .28777 Metetra
.182 .607 0 r
.45141 .28777 .46435 .28627 .48631 .28388 .47358 .28497 Metetra
.247 .629 0 r
.47358 .28497 .48631 .28388 .50852 .28266 .496 .28323 Metetra
.331 .655 0 r
.496 .28323 .50852 .28266 .53101 .28248 .51869 .28245 Metetra
.432 .684 0 r
.51869 .28245 .53101 .28248 .55381 .28323 .54168 .28249 Metetra
.552 .716 0 r
.54168 .28249 .55381 .28323 .57694 .28474 .565 .28317 Metetra
.69 .751 0 r
.565 .28317 .57694 .28474 .60042 .28681 .58866 .28429 Metetra
.786 .729 0 r
.58866 .28429 .60042 .28681 .62427 .28921 .61267 .28561 Metetra
.822 .634 0 r
.61267 .28561 .62427 .28921 .64848 .29166 .63703 .28684 Metetra
.857 .531 0 r
.63703 .28684 .64848 .29166 .67305 .29386 .66174 .28765 Metetra
.89 .423 0 r
.66174 .28765 .67305 .29386 .69797 .29542 .68677 .28766 Metetra
.92 .318 0 r
.68677 .28766 .69797 .29542 .72319 .29593 .71208 .28644 Metetra
.946 .223 0 r
.71208 .28644 .72319 .29593 .74867 .29491 .73762 .28351 Metetra
.961 .161 0 r
.03213 .50762 .0477 .51711 .06807 .50514 .05236 .49745 Metetra
.942 .235 0 r
.05236 .49745 .06807 .50514 .08875 .49152 .07295 .48546 Metetra
.918 .325 0 r
.07295 .48546 .08875 .49152 .10965 .47669 .09381 .47208 Metetra
.89 .423 0 r
.09381 .47208 .10965 .47669 .13071 .46105 .11487 .45773 Metetra
.86 .522 0 r
.11487 .45773 .13071 .46105 .15186 .44495 .13607 .44277 Metetra
.828 .616 0 r
.13607 .44277 .15186 .44495 .17307 .42871 .15736 .42753 Metetra
.797 .702 0 r
.15736 .42753 .17307 .42871 .19432 .41261 .17871 .41228 Metetra
.755 .766 0 r
.17871 .41228 .19432 .41261 .21557 .39689 .20009 .39729 Metetra
.633 .737 0 r
.20009 .39729 .21557 .39689 .23682 .38175 .22149 .38275 Metetra
.528 .71 0 r
.22149 .38275 .23682 .38175 .25807 .36736 .2429 .36886 Metetra
.44 .686 0 r
.2429 .36886 .25807 .36736 .27931 .35388 .26433 .35576 Metetra
.369 .666 0 r
.26433 .35576 .27931 .35388 .30057 .34142 .28578 .34358 Metetra
.315 .65 0 r
.28578 .34358 .30057 .34142 .32185 .33007 .30727 .33242 Metetra
.277 .639 0 r
.30727 .33242 .32185 .33007 .34318 .3199 .32881 .32235 Metetra
.255 .632 0 r
.32881 .32235 .34318 .3199 .36457 .31097 .35042 .31342 Metetra
.247 .629 0 r
.35042 .31342 .36457 .31097 .38607 .30329 .37213 .30565 Metetra
.255 .632 0 r
.37213 .30565 .38607 .30329 .40768 .29688 .39397 .29906 Metetra
.277 .639 0 r
.39397 .29906 .40768 .29688 .42945 .29172 .41596 .29363 Metetra
.315 .65 0 r
.41596 .29363 .42945 .29172 .45141 .28777 .43814 .28931 Metetra
.369 .666 0 r
.43814 .28931 .45141 .28777 .47358 .28497 .46053 .28604 Metetra
.44 .686 0 r
.46053 .28604 .47358 .28497 .496 .28323 .48316 .28373 Metetra
.528 .71 0 r
.48316 .28373 .496 .28323 .51869 .28245 .50606 .28226 Metetra
.633 .737 0 r
.50606 .28226 .51869 .28245 .54168 .28249 .52926 .28149 Metetra
.755 .766 0 r
.52926 .28149 .54168 .28249 .565 .28317 .55277 .28124 Metetra
.797 .702 0 r
.55277 .28124 .565 .28317 .58866 .28429 .57661 .28129 Metetra
.828 .616 0 r
.57661 .28129 .58866 .28429 .61267 .28561 .60079 .28138 Metetra
.86 .522 0 r
.60079 .28138 .61267 .28561 .63703 .28684 .62531 .28123 Metetra
.89 .423 0 r
.62531 .28123 .63703 .28684 .66174 .28765 .65014 .28049 Metetra
.918 .325 0 r
.65014 .28049 .66174 .28765 .68677 .28766 .67528 .27876 Metetra
.942 .235 0 r
.67528 .27876 .68677 .28766 .71208 .28644 .70067 .27561 Metetra
.961 .161 0 r
.70067 .27561 .71208 .28644 .73762 .28351 .72626 .27056 Metetra
.972 .117 0 r
.01657 .4963 .03213 .50762 .05236 .49745 .0366 .48813 Metetra
.96 .165 0 r
.0366 .48813 .05236 .49745 .07295 .48546 .05705 .47795 Metetra
.942 .235 0 r
.05705 .47795 .07295 .48546 .09381 .47208 .07782 .46621 Metetra
.92 .318 0 r
.07782 .46621 .09381 .47208 .11487 .45773 .09884 .45332 Metetra
.895 .406 0 r
.09884 .45332 .11487 .45773 .13607 .44277 .12005 .43964 Metetra
.868 .495 0 r
.12005 .43964 .13607 .44277 .15736 .42753 .14139 .42553 Metetra
.841 .58 0 r
.14139 .42553 .15736 .42753 .17871 .41228 .16282 .41126 Metetra
.814 .657 0 r
.16282 .41126 .17871 .41228 .20009 .39729 .18431 .3971 Metetra
.788 .724 0 r
.18431 .3971 .20009 .39729 .22149 .38275 .20584 .38326 Metetra
.746 .764 0 r
.20584 .38326 .22149 .38275 .2429 .36886 .22741 .36994 Metetra
.657 .743 0 r
.22741 .36994 .2429 .36886 .26433 .35576 .24901 .35729 Metetra
.584 .725 0 r
.24901 .35729 .26433 .35576 .28578 .34358 .27065 .34545 Metetra
.528 .71 0 r
.27065 .34545 .28578 .34358 .30727 .33242 .29234 .33451 Metetra
.488 .699 0 r
.29234 .33451 .30727 .33242 .32881 .32235 .31409 .32456 Metetra
.464 .693 0 r
.31409 .32456 .32881 .32235 .35042 .31342 .33591 .31564 Metetra
.456 .691 0 r
.33591 .31564 .35042 .31342 .37213 .30565 .35785 .30778 Metetra
.464 .693 0 r
.35785 .30778 .37213 .30565 .39397 .29906 .37991 .301 Metetra
.488 .699 0 r
.37991 .301 .39397 .29906 .41596 .29363 .40213 .29526 Metetra
.528 .71 0 r
.40213 .29526 .41596 .29363 .43814 .28931 .42453 .29053 Metetra
.584 .725 0 r
.42453 .29053 .43814 .28931 .46053 .28604 .44715 .28673 Metetra
.657 .743 0 r
.44715 .28673 .46053 .28604 .48316 .28373 .47 .28377 Metetra
.746 .764 0 r
.47 .28377 .48316 .28373 .50606 .28226 .49312 .28154 Metetra
.788 .724 0 r
.49312 .28154 .50606 .28226 .52926 .28149 .51653 .27986 Metetra
.814 .657 0 r
.51653 .27986 .52926 .28149 .55277 .28124 .54024 .27856 Metetra
.841 .58 0 r
.54024 .27856 .55277 .28124 .57661 .28129 .56426 .2774 Metetra
.868 .495 0 r
.56426 .2774 .57661 .28129 .60079 .28138 .58861 .27612 Metetra
.895 .406 0 r
.58861 .27612 .60079 .28138 .62531 .28123 .61328 .27442 Metetra
.92 .318 0 r
.61328 .27442 .62531 .28123 .65014 .28049 .63825 .27194 Metetra
.942 .235 0 r
.63825 .27194 .65014 .28049 .67528 .27876 .66349 .26828 Metetra
.96 .165 0 r
.66349 .26828 .67528 .27876 .70067 .27561 .68895 .26299 Metetra
.972 .117 0 r
.68895 .26299 .70067 .27561 .72626 .27056 .71457 .25558 Metetra
.976 .099 0 r
.00111 .48265 .01657 .4963 .0366 .48813 .02087 .47669 Metetra
.972 .117 0 r
.02087 .47669 .0366 .48813 .05705 .47795 .04112 .46852 Metetra
.961 .161 0 r
.04112 .46852 .05705 .47795 .07782 .46621 .06175 .4586 Metetra
.946 .223 0 r
.06175 .4586 .07782 .46621 .09884 .45332 .08269 .44733 Metetra
.926 .296 0 r
.08269 .44733 .09884 .45332 .12005 .43964 .10387 .43511 Metetra
.904 .374 0 r
.10387 .43511 .12005 .43964 .14139 .42553 .12521 .42226 Metetra
.882 .452 0 r
.12521 .42226 .14139 .42553 .16282 .41126 .14669 .4091 Metetra
.859 .526 0 r
.14669 .4091 .16282 .41126 .18431 .3971 .16827 .39589 Metetra
.836 .593 0 r
.16827 .39589 .18431 .3971 .20584 .38326 .18992 .38285 Metetra
.815 .652 0 r
.18992 .38285 .20584 .38326 .22741 .36994 .21162 .37018 Metetra
.797 .702 0 r
.21162 .37018 .22741 .36994 .24901 .35729 .23339 .35806 Metetra
.781 .742 0 r
.23339 .35806 .24901 .35729 .27065 .34545 .2552 .34661 Metetra
.763 .768 0 r
.2552 .34661 .27065 .34545 .29234 .33451 .27708 .33594 Metetra
.722 .758 0 r
.27708 .33594 .29234 .33451 .31409 .32456 .29903 .32613 Metetra
.698 .752 0 r
.29903 .32613 .31409 .32456 .33591 .31564 .32107 .31723 Metetra
.69 .75 0 r
.32107 .31723 .33591 .31564 .35785 .30778 .34323 .30928 Metetra
.698 .752 0 r
.34323 .30928 .35785 .30778 .37991 .301 .36552 .30228 Metetra
.722 .758 0 r
.36552 .30228 .37991 .301 .40213 .29526 .38797 .29621 Metetra
.763 .768 0 r
.38797 .29621 .40213 .29526 .42453 .29053 .4106 .29101 Metetra
.781 .742 0 r
.4106 .29101 .42453 .29053 .44715 .28673 .43344 .28663 Metetra
.797 .702 0 r
.43344 .28663 .44715 .28673 .47 .28377 .45652 .28295 Metetra
.815 .652 0 r
.45652 .28295 .47 .28377 .49312 .28154 .47986 .27984 Metetra
.836 .593 0 r
.47986 .27984 .49312 .28154 .51653 .27986 .50348 .27715 Metetra
.859 .526 0 r
.50348 .27715 .51653 .27986 .54024 .27856 .52739 .27466 Metetra
.882 .452 0 r
.52739 .27466 .54024 .27856 .56426 .2774 .55161 .27216 Metetra
.904 .374 0 r
.55161 .27216 .56426 .2774 .58861 .27612 .57613 .26935 Metetra
.926 .296 0 r
.57613 .26935 .58861 .27612 .61328 .27442 .60095 .26592 Metetra
.946 .223 0 r
.60095 .26592 .61328 .27442 .63825 .27194 .62604 .26151 Metetra
.961 .161 0 r
.62604 .26151 .63825 .27194 .66349 .26828 .65138 .25571 Metetra
.972 .117 0 r
.65138 .25571 .66349 .26828 .68895 .26299 .67691 .24806 Metetra
.976 .099 0 r
.67691 .24806 .68895 .26299 .71457 .25558 .70256 .23806 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00Z?ooool3o`0000Cooooo0_l0001_ooooo`00ZOooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0006kooooo002Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000K_ooool00:Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Doooo
o`;o0000F?ooool00:Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Aoooo
o`?o000000?oooooo`000?ooool0Eoooool00:Sooooo0_l00004ooooo`04o`000?ooooooooooo`00
00oooooo0_l00004ooooo`;o0000Eoooool00:Wooooo00?o0000ooooooooool00oooool2o`0000go
oooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`00001Fooooo`00_?ooool2o`00
00Wooooo00Co0000ooooool0003o0000EOooool00;Wooooo0ol0000;ooooo`04o`000?oooooooooo
o`0005Gooooo002fooooo`?o00003_ooool01Ol0003ooooooooooooooooo000005Cooooo002doooo
o`;o00004Oooool01Ol0003ooooooooooooooooo000005Cooooo002aooooo`?o00004oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo057ooooo002_ooooo`;o00000oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool3o`0000Co
oooo0_l0000looooo`00[?ooool3o`0001Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool00:[ooooo
0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool5o`0000?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000kooooo`00Yoooool3o`0001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000>oooool00:Gooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003_o
oooo002Rooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`;o00002Oooool2o`0000Cooooo
00Co0000oooooooooooo0000>oooool00:3ooooo0_l0000Vooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooool000002_ooool00ol0003oooooooooo`03ooooo`;o0000??ooool009gooooo0ol0
000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0C?ooool009[ooooo0ol0000[
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Boooool009Sooooo0_l0000^oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B_ooool009Gooooo0ol0000`ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0B_ooool009?ooooo0_l000000ooooooo0000
ooooo`0`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0BOooool0093ooooo0ol0
000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0BOooool008kooooo0_l0000h
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B?ooool008_ooooo0ol0000joooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Aoooool008Wooooo0_l0000mooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Aoooool006Gooooo0_l0000Oooooo`?o0000
@?ooool00ol0003oooooooooo`0;ooooo`;o0000Aoooool006Cooooo00Co0000oooooooooooo0000
7?ooool2o`0000;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04Gooooo001Tooooo`04o`000?ooooooooooo`0001Wooooo0ol00015ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0AOooool006Cooooo00Co0000oooooooooooo0000
5_ooool3o`0004Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`14ooooo`00I?oo
ool01?l0003oooooooooool0000Dooooo`;o0000Boooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04?ooooo001Tooooo`04o`000?ooooooooooo`00017ooooo0ol0001=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0@oooool006Gooooo0_l0000@ooooo`;o000000?o
ooooo`000?ooool0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo001d
ooooo`?o0000D_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo047ooooo001boooo
o`;o0000EOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo047ooooo001_ooooo`?o
0000Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo043ooooo001]ooooo`;o0000
F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo001Zooooo`?o0000G?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo001Xooooo`;o00000_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?_ooool0
06Gooooo0ol0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?Oooool006?o
oooo0_l0001Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?Oooool0063ooooo
0ol0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0??ooool005gooooo0ol0
001Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>oooool005_ooooo0_l00000
0ooooooo0000ooooo`1Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>oooool0
05Sooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>_ooool005Ko
oooo0_l0001booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>Oooool005?ooooo
0ol0001dooooo`03o`000?oooooooooo01Oooooo0_l0000jooooo`00D?ooool3o`0007Oooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0hooooo`00C_ooool4o`0007Sooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0gooooo`00C?ooool2o`0007cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0gooooo`00BOooool3o`0007kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0fooooo`00Aoooool2o`00087ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0eooooo`007Oooool3o`0000Cooooo0_l0000Mooooo`Co0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Gooooo000Nooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00006_ooool4o`0008Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0dooooo`005_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Hooooo`;o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03?ooooo000Nooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005Ooo
ool3o`0008_ooooo00?o0000ooooooooool07Oooool2o`0003Cooooo000Nooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00004oooool2o`0008kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0booooo`007Oooool2o`0000Cooooo00Co0000oooooooooooo00004?oo
ool3o`00093ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0aooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o00003oooool3o`0009;ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0aooooo`00<_ooool3o`0009Kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`06ooooo`;o0000:?ooool0033ooooo0_l0002Iooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Wooooo`00;Oooool3o`0009_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
02Oooooo000Zooooo`?o0000W_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00009oooool002Sooooo0ol0002Pooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Wooooo`009Oooool3o`0000?o
oooo00?o0000ooooooooool0W?ooool2o`0002Cooooo0_l00003ooooo`04o`000?ooooooooooo`00
02Oooooo000Sooooo`;o0000X_ooool3o`000003ooTI0?l0003ooooo02;ooooo00?o0000ooooool0
00001?ooool2o`0002Sooooo000Pooooo`?o0000X_ooool2o`0000?onAT00ol0000Tooooo`03o`00
0?oooooooooo02cooooo000Nooooo`;o0000Xoooool2o`0000;onAT00ol000001?oi6@3o0000ooTI
0?l0000Tooooo`03o`000?oooooooooo02_ooooo000Kooooo`?o000000?oooooo`000?ooool0Wooo
ool3o`000004ooPM0?l0003o0000o`0000GonAT00_l0000Uooooo`03o`000?oooooooooo02[ooooo
000Jooooo`;o0000X?ooool4o`000004ooPM0?l0003o0000o`0000;on1d000?o0000ooTI0?oi6@00
1?oi6@02o`0002Cooooo00?o0000ooooooooool0:_ooool001Wooooo1?l0002Looooo`?o00000_of
:@03o`0000Kon1d000?o0000ooTI0?oi6@000ol000000ooh7@3o0000ooooo`0Tooooo`03o`000?oo
oooooooo02Wooooo000Booooo`;o00001_ooool01?l0003oooooooooool0002Fooooo`Go00000_of
:@03o`0000;omRT000?o0000ooPM0?oh7@000_oh7@05o`0000Con1d00_l0000Uooooo`03o`000?oo
oooooooo02Sooooo000Aooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooooooooooooooo
o`00002>ooooo`Oo00001?ob>@03o`0000?omRT01ol00004ooDZ0003o`000?oh7@3on1d000?on1d0
0_l0000Tooooo`03o`000?oooooooooo02Sooooo000Aooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1nooooo`go00001Oo]B`000ol0003olST0
oo8i0009o`0000ColC`000?o0000ooDZ0?oe:P001Ooe:P001?l0003on1d0ooPM0?oh7@05o`0002?o
oooo0_l0000Xooooo`004Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0M_ooool7o`0000GohG<000?o0000onMO0?oWG`000_oWG`0=o`0000Co
je4000?o0000oo4l0?oa?0001Ooa?0000ol0003omBX0ooDZ0002ooDZ00Ko00000oof:@000ol0003o
mRT0o`00000Sooooo`03o`000?oooooooooo02Kooooo000Aooooo`04o`000?ooooooooooo`0000Co
oooo0_l00006ooooo`03o`000?oooooooooo06Wooooo7Ol00005omin00Co00000_oUI`02o`0000Go
je4000?o0000oo4l0?oa?0000_oa?007o`0000ColC`000?o0000ooHY0?of:@000_of:@001?l0003o
mRT0ooHY0?l0000Rooooo`03o`000?oooooooooo02Kooooo000Aooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Roooooc[o00001?o[D`000ol0
003olC`0oo4l0005oo4l0003o`000?of:@3omRT000;omRT01?l0000Rooooo`03o`000?oooooooooo
02Gooooo000Booooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[o
oooo?_l000000ooSK03o0000on]C0005on]C0003o`000?oa?03olC`000;olC`01ol000001?ob>@3o
0000oo8i0?l0000Sooooo`03o`000?oooooooooo02Cooooo000Iooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0EOooool@o`000003o`1W??l0003o0000013o00001?l0BD`00ol0003o
05=<o`00000Eo`000003om:R0?l0003ofhL000go00001?o[D@001Ol0003olST0oo8i0?ob>@3o0000
00;olST000?o0000ooooooooool08?ooool00ol0003oooooooooo`0Tooooo`006?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo057ooooo0ol000000oo3a03o0000o`00000Eo`0000?o
03A2<Ol000000ooSK03o0000on]A0005on]A0004o`000?ob>@3olST0oo8i00Co00008_ooool00ol0
003oooooooooo`0Sooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04_o
oooo2ol000000ol0PQ3o0000o`000009o`0000;o04I;0ol00003o`0_?`Co00001?l093T01?l0003o
02/mo`0[?Ol0:cdCo`0000;o05i54?l000001?oBXP3o0000omb50?oLQ@0<o`000005one;0?l0003o
kD/0one;0?l000008_ooool00ol0003oooooooooo`0Rooooo`006?ooool2o`0000gooooo00?o0000
ooooooooool0A_ooool@o`000003o`1S?ol0003o000000Co00000ol0A4X4o`0000;o02lo0ol00003
o`0O=P04o`000?l093Wo02@io`0T>@Oo00000_l07SD00ol0003o02Pko`0X>`03o`0X>`03o`000?l0
=T?o03I300?o03I300?o0000o`19C?l000001?l000000ol0GTGo0000o`1Y>@0Io`000005onEW0?l0
003okD/0one;0?l000000_o]B`000ol0003oooooooooo`0Oooooo`;o00008oooool001Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`12ooooo`?o000000?o//00o`000?l000001_l0
00000ol0PA;o0000o`000009o`0000;o04A:0ol00003o`0^?`Co00000ol07cH6o`0000;o01Pa6Ol0
00000ol0Ed[o0000o`000004o`000003o`1Y>Ol0003o000000oo000000Codid0o`000?oNOP3ogWh0
2Ol0000Pooooo`;o00008oooool001Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0nooooo`So000000?o?j40o`000?l000001_l000001?l0I3oo0000o`000?l0EdX2o`0000Co04I;
1?l000001?l0;Soo0000o`000?l00003o`0N=@Co00001Ol052h4o`0000Co010[00?o0000o`0F;ol0
5Rl00_l05Rl00ol0003o01heo`0N=@03o`0N=@03o`000?l0:cgo02/m00;o02/m00?o0000o`0mA_l0
?DH01Ol000000ol0Ed[o0000o`1S@@0@o`0000;oc;<01_l000001?oNOP3o0000onMO0?l00003onMO
0003o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool001Sooooo00?o0000oooooooo
ool03oooool2o`0003_ooooo0ol000000on`_`3o0000o`00000<o`0000;o06@o00Co0000o`1GB_l0
Ed[o00000ol0AT/3o`0000?o02lo1?l000001?l07SGo0000o`000?l00003o`0C;@03o`000?l052ko
01@^00?o00000ol03RP01?l0003o010[o`0@:ol042/Fo`000003o`0mA_l0003o055=00Ko000000?o
06=1o`000?l000003ol000000oo</`3o0000omND0007o`000003onMO0?l0003ooooo01oooooo00?o
0000ooooooooool08?ooool001Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0e
ooooo`So000000?o@J40o`000?l000005?l00002o`0_?`?o00000ol07cH4o`0000?o01<]1?l00006
o`0>:0Co00000ol032H00ol0003o010[o`0@:`03o`0@:`03o`000?l0637o01Pa00?o01Pa00Go0000
o`0T>Ol093Wo02@io`000002o`0d@PKo000000?o055=o`000?l0GDH06?l000001?oGU03o0000o`00
0?oQL`04o`0001oooooo00?o0000ooooooooool07oooool001Oooooo0_l0000Dooooo`03o`000?oo
oooooooo03;ooooo0_l000000onb`03o0000o`000007o`0000;o08@<1Ol000000ol0Icco0000o`00
0004o`000003o`1;COl0003o000000Co03A21?l000001?l07cKo0000o`000?l00003o`0D;PGo0000
0ol03BL00ol0003o00hXo`0>:003o`000003o`098ol0003o00`V00Go00`V00Co0000o`0@:ol042_o
010[3Ol00005o`0d@P03o`000?l0Bdgo000000Go000000?o05e6o`000?l000001Ol000000olETP3o
0000o`000004o`000004oj:l0?l0003o0000o`0000;od:P01ol000000ooQL`3o0000ooooo`0Noooo
o`03o`000?oooooooooo01kooooo000Gooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0<?ooool;o`0000;o08@<3Ol000000ol0Bdgo0000o`0d@P03o`0d@P;o00000ol093T3o`0000?o
01@^1Ol00005o`0=9`?o00001Ol02B<01?l0003o00`Vo`0<9_l032H6o`0000?o00hX00?o0000o`0D
;_l052h00_l052h01?l0003o01lfo`0O=_l07cH9o`000003o`1;COl0003o05U900;o05U92ol00000
0olETP3o0000o`000004o`000003oj:l0?l0003o000000Go00000_oKQP04o`0001gooooo00?o0000
ooooooooool07_ooool001Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]oooo
o`Oo000000?oAZ<0o`000?l000001ol000000ol0JSSo0000o`000003o`1MAP04o`000?l0DDgo055=
o`1AC@Co000000?o03A2o`000?l000000ol093T2o`0000?o01Pa1?l00004o`0>:003o`000?l03BOo
000000;o00000ol022801?l0003o00TSo`098ol02B<5o`0000Co00TS00?o0000o`0>:?l03RP00ol0
3RP00ol0003o01@^o`0D;P02o`0D;P03o`000?l07cKo01lf00;o01lf00?o0000o`0_?ol0;cl00_l0
;cl00ol0003o04I;o`000002o`0000Co05U900?o0000o`1W??l0Ic`02Ol000000oloX@3o0000o`00
0005o`0000;obKT01ol000000ooKQP3o0000ooooo`0Looooo`03o`000?oooooooooo01gooooo000G
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool<o`0000;o08L40_l00000
1Ol0NB;o0000o`000?l0JSSo000000?o05e60_l00002o`1AC@;o00000ol0?DH4o`000003o`0T>Ol0
003o000000?o01Pa1Ol00005o`0>:0?o00001Ol02284o`0000?o00LQ00?o0000o`098ol02B<01?l0
2B<01?l0003o00hXo`0>:?l03RP;o`000003o`0O=_l0003o02lo00?o02lo00Co0000o`16Bol0AT_o
04I;1?l000000ol0FDWo0000o`1W?003o`1W?0Wo000000?o?j40o`000?l000001ol000001?o9^@3o
0000omJG0?oFU`03o`0001gooooo00?o0000ooooooooool07?ooool001Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Uooooo`So00000_m@YP03o`0000?o08L400?o0000o`1i8_l0
NB801_l000000ol0GDKo0000o`1AC@02o`1AC@04o`000?l0?DKo03e6o`0mAP;o00000ol0:cd3o`00
00;o01Pa1?l00003o`0@:`03o`000?l03RSo000000;o00000ol02B<00ol0003o00PRo`000002o`00
00;o00HO00?o0000o`078Ol01b400ol01b401?l0003o00TSo`098ol02B<6o`0000;o00dW00?o0000
o`0C;Ol04bd00_l04bd01?l0003o01heo`0N=Ol07SD:o`000004o`16Bol0003o05M:o`1GBPGo0000
00Co06Llo`000?l0MBSo07DX3_l000000ono``3o0000o`000004o`000003omJG0?l0003ooooo01co
oooo0_l0000Mooooo`005oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02;ooooo
0_l00002ol?400Co00000_m@YP0=o`0000?o06=12?l000000ol0?DKo0000o`0[?@02o`0[?@;o0000
0_l07SD5o`0000Go010[0ol00005o`098`;o00001_l01Ql01?l0003o00LQo`078Ol01b45o`0000?o
00PR00?o0000o`0=9ol03BL00ol03BL00ol0003o01<]o`0C;@02o`0C;@03o`000?l07SGo01he00?o
01he00Go0000o`0^?ol0;Soo02hoo`000002o`14BP?o00001?l0EdX00ol0003o06@oo`000002o`00
00Co07DX3_l000001?no``3o0000om2V0?o@YP03o`0001gooooo00?o0000ooooooooool06oooool0
01Kooooo0ol0000Jooooo`03o`000?oooooooooo01oooooo0_l00002ol?400[o00000_l6S002o`00
0004o`1m6Ol0003o0000o`1`<0;o00000_l0Hd42o`0000?o05M:00Co0000o`19C?l0BDco04U<1?l0
00000ol0:cgo0000o`0N=@03o`000003o`0N=Ol0003o000000;o00000_l042/3o`0000?o00`V00?o
0000o`098ol000000_l00002o`078@03o`000?l01Qoo00HO00?o00HO1?l00003o`067`03o`000?l0
22;o00PR00?o00PR00?o0000o`0=9ol03BL00ol03BL00ol0003o01<]o`0C;@02o`0C;@03o`000?l0
7SGo01he00?o01he00Go0000o`0^?ol0;Soo02hoo`000004o`14BPCo000000?o05M:o`000?l0I3l0
0_l0I3l3o`000004o`1e:?l0003o08@<o`2430Ko000000GoGZX0o`000?l0003o0000ojRn0003o`00
00Cod:H00_l0000Looooo`03o`000?oooooooooo01[ooooo0007ooooo`Go00000oooool2o`0000Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`So00000_mNZP02o`000004
objK0?l0003o0000o`J<00;o00000_l0OAT01?l0003o070`o`1`<?l00003o`1S@@04o`000?l0Ed[o
05M:o`1GBP;o00000_l0BD`2o`0000?o03I31?l00002o`0N=@;o00001?l05Rl2o`0000Ko00`V0_l0
0006o`078@03o`000?l01Qoo000000;o00000_l01Ah00ol0003o00HOo`067`03o`067`04o`000?l0
22;o00PRo`088QSo00001?l0A4X00ol0003o05I;o`1FB`05o`000003o`1T?ol0003o07</00?o0000
1?l0Q0`2o`000005ob6G0?l0003o0000o`000?mNZP000ol000000onX_P3o0000o`000003o`000003
om2V0?l0003ooooo01[ooooo00?o0000ooooooooool06_ooool000Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06Oooool2o`0000;oakd00_l000001?nE^@3o0000o`000?mNZP02o`0000;o;Y/04Ol00000
0ol0Ed[o0000o`19C002o`19C004o`000?l0=T?o03I3o`0f@`?o00000_l0:3/00ol0003o01heo`00
0005o`0F;`03o`000?l042_o000000Co00`V0_l00002o`098`03o`000?l01b7o00LQ00?o00LQ0_l0
0006o`057P04o`000?l01Qoo00HOo`067`Go00000_l02B<00ol0003o00hXo`0>:003o`0>:003o`00
0?l052ko01@^00?o01@^00?o0000o`0O=_l07cH00_l07cH01?l0003o02loo`0_?ol0;cl5o`000003
o`14B_l0003o05I;00;o05I;00?o0000o`1S?ol0Hcl00ol00003o`1c;0?o000000?o08@<o`000?lI
T`000ol000000om@YP3o0000o`000006o`0000;oc;<00ol0000Kooooo`03o`000?oooooooooo01Wo
oooo0009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo0_l00002olNm00;o00000_nE^@0:o`0000?o
08@<00Co0000o`1f9_l0MRKo00000ol0JCT01?l0003o05i5o`1NAOl0GTD;o`0000Co02Pk0ol00003
o`0F;`;o00000ol042/01?l0003o00`Vo`000?l00005o`098`03o`000?l01b7o000000;o00000_l0
1Ql00ol0003o00DNo`057P03o`057PCo00000_l01b400ol0003o00TSo`098`03o`098`03o`000?l0
3RSo00hX00?o00hX00?o0000o`0D;_l052h00ol052h00ol0003o01lfo`0O=P02o`0O=P05o`000?l0
;coo02loo`0_?ol000000ol0AT/5o`000003o`1FBol0003o06<o00?o06<o0ol000000ol0Lbco0000
o`224003o`0000;o6I<00_l00003oe2V00?o000000?oUKT0o`000?l000000_l000000oo</`3o0000
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo000:ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
4oooool<o`0000;o?j400_l000000olETP3o0000o`000002o`2430;o00000_l0MRH00ol0003o06Ti
o`1Y>@02o`0000?o05i500Co0000o`1CC?l0Ddco05=<1Ol000000ol0=T?o0000o`0X>`02o`0X>`;o
00000ol07SD00ol0003o01H_o`000005o`0@:`;o00001ol02B<2o`0000Ko00HO00?o0000o`057_l0
00000_l000000ol01Qoo0000o`078@04o`078@03o`000?l02B?o00TS00?o00TS00Co0000o`0>:?l0
3RSo00hX3Ol00004o`0_?`03o`000?l0AT_o04I;00;o04I;00?o0000o`1GB_l0EdX00ol00003o`1S
?`03o`000?l0LRgo078]00?o00000ol0PQ02o`0000;o6I<00ol000000om@YP3o0000o`000003o`00
00;oakd00ol0000Kooooo`03o`000?oooooooooo01Sooooo0007ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool04Oooool00ol0003oc;<0olbc0002o`0000;oZ;h00_l00002og2_0004o`000?loX@3o
?j40o`0000;o5I8000Go0000o`243?l0Q0co08@<o`000003o`1f9P04o`000?l0JCWo06Tio`0000Co
05i500?o0000o`1CC?l0Dd`00ol00003o`16B`Co000000?o02Pko`000?l07SD01?l07SD3o`0000?o
010[0_l00002o`0>:003o`000?l02B?o00TS00;o00TS0_l000000ol022;o0000o`067`05o`067`;o
00001Ol01Ql00ol0003o00LQo`078@03o`078@04o`000?l02B?o00TSo`098`Go00000_l042/00ol0
003o01Pao`0H<@03o`0H<@04o`000?l093Wo02@io`0T>@Go000000?o02loo`000?l0AT/00ol0AT/0
0ol0003o05M:o`1GBP02o`1GBPGo00001?l0LRd3o`000003o`224?l0003o000000?o000000CoAZ<0
o`000?l0003o00000_n7]@02o`0000Coakd000?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Gooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0oooool2o`0002;ooooo00?o0000ooooooooool03_ooool2o`000003olbc0?l0003o000000?oZ;h0
00Co0000og2_0?m`[`3oL:l05?l00002o`1NA@Co00001Ol0AT/01?l0003o03I3o`0f@ol0=T<3o`00
00?o01he0_l00003o`0H<@03o`000?l042_o000000Go00hX00Co0000o`098ol0003o00001?l02280
0ol0003o00HOo`067`03o`000003o`078Ol0003o00HO00Go00HO00Co0000o`078Ol01b7o00LQ1Ol0
0002o`0<9P03o`000?l042_o010[00?o010[00?o0000o`0H<Ol063400ol063401Ol0003o02@io`0T
>Ol093Wo000000?o03A21ol00004o`1GBP04o`000?l0I3oo06@oo`1T?`?o00000_l0LRd00ol0003o
084Bo`214P03o`0000;o4i400_l00003odJS00?o000000CoQkD0o`000?l0003o00000_o7_@000ol0
003oooooooooo`0Hooooo`;o00006?ooool000Sooooo0ol00004ooooo`;o00001?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00cooooo3ol00002obRI0005o`000?l4R`3o18/0o`B;
0?l000000ol0OQL01?l0003o078]o`1b;Ol00004o`1W?0Ko00001?l0AT/01Ol0003o03I3o`0f@ol0
=T?o000000?o02/m00?o0000o`0N=Ol000001Ol06342o`0000Ko00hX0_l00006o`088P?o00001Ol0
1b400ol0003o00HOo`067`03o`067`Co00000_l02B<00ol0003o00`Vo`0<9P03o`0<9P03o`000?l0
42_o010[00?o010[00?o0000o`0H<Ol063400_l063400ol0003o02@io`0T>@02o`0T>@03o`000?l0
=4;o03A200;o03A200Co0000o`1;COl0Bdgo04]=1Ol000000ol0Ed[o0000o`1T?`02o`1T?`06o`00
0?l0Lbco0000o`000?l0LRgo00001?l0PA82o`0000;o4i400ol000000om6X`3o0000ogbb0008o`00
01[ooooo00?o0000ooooooooool05_ooool001Gooooo00?o0000ooooooooool08oooool2o`0000[o
oooo1?l00004okk30006o`000?n7]@3oQkD0ohNe0?l0003oE:L00_l00002obRI0005o`000?l4R`3o
18/0o`B;0?l000000_l0OQL2o`0000;o078]00Co0000o`1W??l0Icco06Ll0ol00002o`1LAP03o`00
0?l0Ddco05=<00;o000000?o04I;o`000?l0=T<00_l0=T<00ol0003o02/mo`0[?@02o`0[?@?o0000
0ol06342o`0000;o01@^00Co0000o`0>:?l03RSo00hX0_l00002o`0=9`04o`000?l022;o00PRo`08
8P;o000000?o00TSo`000?l01b401Ol01b400ol0003o00HOo`067`03o`000003o`088_l0003o00TS
00Co00TS00?o0000o`0<9_l032H00ol032H00ol0003o010[o`0@:`02o`0@:`03o`000?l0637o01Pa
00;o01Pa00?o0000o`0T>Ol093T00ol093T00ol0003o03A2o`0d@P02o`0d@P05o`000?l0Bdgo04]=
o`1;COl000000ol0FDT5o`000004o`1T?ol0003o07</o`1c;0;o00001?l0PA800ol0003o4Y40o`00
0002o`0000;o@J400ol00003ogbb00?o000000?o`l@0o`000?l000006_ooool00ol0003ooooooooo
o`05ooooo`?o00001?ooool2o`0000Oooooo000Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01Oooool2o`0000;od:H000Co0000okk30?nn``3o_/<00_l00002ohNe00;o000000?o
E:L0o`000?lXV@000_lXV@001Ol0003o18/0o`B;0?l4R`3o000000;o07hG00Ko0000o`1b;Ol0LRgo
078]o`000?l0Ic`4o`0000?o05a600?o0000o`1CC?l0Dd`00_l0Dd`4o`000003o`0f@ol0003o02/m
00?o02/m00Oo0000o`0T>Ol093Wo02@io`000?l0637o000000Go01@^00?o0000o`0>:?l000001Ol0
3BL00ol0003o00PRo`000004o`098`03o`000?l01b7o00LQ00?o00LQ0ol00005o`088P03o`000?l0
2B?o00TS00;o00TS00Co0000o`0<9_l032Ko00`V6?l00004o`1;C@03o`000?l0FDWo05U900;o05U9
00?o0000o`1W??l0Ic`00ol00003o`1c;0?o00000_l0PA800ol0003o4Y40oa:A0002o`0000?o@J40
1?l000000oml/P3o0000okS20004o`0001Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Eooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool00_ooool2o`0000?od:H000Go0000okk30?nn``3o_/<0o`000003ohNe01Go
000000?o06Llo`000?l0G4H00ol0G4H00ol0003o05=<o`1CC002o`1CC004o`000?l0BDco04U<o`19
C0?o00000ol0:cd00ol0003o02@io`0T>@02o`0T>@;o00001_l052h2o`0000Ko00dW0_l00006o`09
8`03o`000?l01b7o000000;o000000?o00TSo`000?l022801Ol022801?l0003o00TSo`098ol02B<5
o`0000?o010[00?o0000o`0F;ol05Rl00_l05Rl00ol0003o01heo`0N=@02o`0N=@03o`000?l0:cgo
02/m00?o02/m00Co0000o`0mA_l0?DKo03e61Ol000000ol0Bdgo0000o`1IB@03o`1IB@03o`000?l0
Icco06Ll00;o06Ll0ol000000ol0Lbco0000o`224003o`0000Co4Y400ol000001?m1X@3o0000o`00
0?mf/@03o`0000?o^<800_l0000Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00006ooooo`005Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooo0000013o00000om1X@001Ol0003o6Y@0oaZD0?lJU03o000000;o08L400?o0000o`1k7Ol0
Nad00ol00002o`1`;`Co00000_l0G4H01?l0003o05=<o`1CC?l0Dd`2o`0000?o04U<00Oo0000o`0m
A_l0?DKo03e6o`000?l0:cgo000000Co02@i00Co0000o`0O=_l07cKo00000ol052h2o`0000;o01<]
00Co0000o`0=9ol03BOo00dW0_l00002o`0>:003o`000?l02B?o00TS00?o00TS0_l00005o`098`03
o`000?l022;o00PR00?o00PR1?l00002o`0>:003o`000?l042_o010[00Co010[00?o0000o`0F;ol0
5Rl00_l05Rl00ol0003o01heo`0N=@02o`0N=@03o`000?l0:cgo02/m00?o02/m00Go0000o`0mA_l0
?DKo03e6o`000003o`1AC@Go00000_l0FDT01Ol0003o06Llo`1W??l0Icco000000;o07DX0ol00003
o`2240?o00000_lBT@000ol0003o?j40o`000003o`0000?oM[400_l00003okS20003o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Kooooo000Dooooo`;o0000:Oooool2o`0000CoeYL000Go0000olVi0?o9^@3obKT0o`00
0003oj:l0004o`000?m^[`3o0000o`0000;o@J400_l00002oaZD00;o00000_l0Q`@5o`0000?o070_
00?o0000o`1W??l0Ic`00_l0Ic`4o`000003o`1CC?l0003o04U<00;o04U<0_l00004o`0mAP?o0000
0ol093T00ol0003o01lfo`0O=P02o`0O=P03o`000?l052ko000000Go01<]00?o0000o`0=9ol00000
1Ol03RP00ol0003o00TSo`000002o`000003o`0<9_l0003o00TS00Go00TS00?o0000o`088_l00000
0_l000000ol03BOo0000o`0>:004o`0>:003o`000?l042_o010[00?o010[00?o0000o`0F;ol05Rl0
0ol05Rl00ol0003o01heo`0N=@02o`0N=@03o`000?l0:cgo02/m00?o02/m00Go0000o`0mA_l0?DKo
03e6o`000004o`1AC@03o`000?l0GDKo05e600?o00001?l0Ic`00ol0003o07DXo`1e:002o`1e:0;o
000000Co088@o`000?lCT@3o4i401?l00003ocnQ00?o000000?oM[40o`000?nb`0001?l0000Ioooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006
ooooo`005?ooool00ol0003oooooooooo`0Wooooo`03o`000?oFU`3oeYL000;oeYL00_l00002olVi
00;o00000_nR_002o`000003ofj_0?l0003o@J4000;o@J4000Go0000oaZD0?lJU03o6Y@0o`000002
o`2710?o00000_l0Nad01Ol0003o070_o`1`;ol0L2oo000000Co06Ll00?o0000o`1NAOl0GTD00_l0
GTD3o`000003o`19C?l0003o03e600Co03e600Oo0000o`0d@_l0=4;o03A2o`000?l093Wo000000Go
01lf0_l00006o`0C;@;o00001_l03RP2o`0000Go00`V00?o0000o`098ol02B<00ol02B<2o`0000Go
00dW00?o0000o`0>:?l03RP00ol03RP01?l0003o010[o`0@:ol042/Ao`000003o`0[?Ol0003o03e6
00?o03e600?o0000o`1ACOl0DDd00_l0DDd00ol0003o05e6o`1MAP02o`1MAPCo000000?o06Llo`00
0?l0MBP00_l0MBP00ol0003o08@<o`000002o`0000Co4i400ol000001?loX@3o0000o`000?md/003
o`0000?o//000_l0000Iooooo`;o00000oooool2o`0000Cooooo00Co0000oooooooooooo00001_oo
ool001Cooooo00?o0000ooooooooool09Oooool4o`0000;oeYL000Go0000olVi0?o9^@3obKT0o`00
0003oj:l01;o000000?o07/Mo`000?l0L2l00_l0L2l00ol0003o06Llo`1W?002o`1W?003o`000?l0
GTGo05i500;o05i500Co0000o`1GB_l0Ed[o05M:0_l00004o`0mAP03o`000?l0=4;o03A200?o03A2
00?o0000o`0O=_l07cH00ol07cH01?l0003o01heo`0N=Ol00003o`0C;@;o00000_l052h01?l0003o
00hXo`0>:?l03RP2o`000003o`0@:ol0003o00`V00Go00`V00?o0000o`098ol000000_l000000ol0
3RSo0000o`0=9`05o`0=9`03o`000?l03RSo00hX00;o00hX1?l00002o`0H<@03o`000?l07SGo01he
00?o01he00?o0000o`0X>ol0:3/00_l0:3/01?l0003o03I3o`0f@ol0=T<:o`0000;o055=00Go0000
o`1MA_l0GDKo05e6o`000003o`1Z>0Go000000Co07DXo`000?l0Q0co08@<0_l00004oa>A0003o`00
0?m1X@3o000000?o00000_md/002o`0000Co//0000?o0000ooooooooool05Oooool00ol0003ooooo
o`000004ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`005?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oKQP3ofhH000;ofhH02ol000000on=]`3o0000oejZ0002oejZ0004o`000?lf
W@3o=Yd0ocJM00;o000000?o4i40o`000?l0QPL00ol0QPL7o`0000;o06Ll00?o0000o`1NAOl0GTD0
0_l0GTD01Ol0003o05M:o`1GB_l0Ed[o000000;o055=0_l000000ol0?DKo0000o`0d@P04o`0d@P03
o`000?l0;coo000000?o01lf00?o0000o`0N=Ol07SD00_l07SD00ol0003o01<]o`000005o`0D;P03
o`000?l03RSo000000Co010[00?o0000o`0<9_l032H00ol032H2o`0000Go00hX00?o0000o`0=9ol0
3BL00ol03BL00ol0003o00hXo`000002o`000003o`0D;_l0003o01Pa00Co01Pa00?o0000o`0N=Ol0
7SD00ol07SD00ol0003o02Pko`0X>`02o`0X>`03o`000?l0=T?o03I300;o03I300?o0000o`19C?l0
BD`00_l0BD`00ol0003o05M:o`1GBP03o`0000Co05e600?o0000o`1Z>?l0JSP00_l0JSP00ol0003o
07TRo`1i8P03o`0000?o08@<0ol00002oa>A0003o`000?m1X@3o@J4000;o00001?md/003o`0000;o
//0000?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`005?ooool00ol0003ooooo
ooooo`0Rooooo`;o00000ooKQP02o`0000?od:P000Go0000ol740?o1a03o`L@0o`000003ohfg0006
o`000?mNZP3oGZX0oejZ0?l0003o=Yd00ol00002oa>A0003o`000?l0QPOo08H700;o08H700Go0000
o`1k7Ol0Nago07/Mo`000003o`1b;@?o00000ol0GTD01Ol0003o05M:o`1GB_l0Ed[o000000Co055=
0_l00005o`0d@P07o`000?l0;coo02loo`0_?ol0003o01lfo`000005o`0N=@;o00001_l052h2o`00
00Ko010[00?o0000o`0<9_l000000_l000000ol042_o0000o`0>:005o`0>:004o`000?l03BOo00dW
o`0=9`?o00001Ol052h00ol0003o01Pao`0H<@03o`0H<@03o`000?l07SGo01he00;o01he00?o0000
o`0X>ol0:3/00ol0:3/00ol0003o03I3o`0f@`02o`0f@`03o`000?l0BDco04U<00;o04U<00?o0000
o`1GB_l0EdX00_l0EdX5o`0000Go06Xh00?o0000o`1i8_l0NB800_l0NB82o`000004o`243?l0003o
6I<0oaVC00?o00000om1X@04o`000004ogB`0?l0003o/<00ok3000Co00006?ooool00ol0003ooooo
ooooo`0@ooooo`005?ooool00ol0003oooooooooo`0Qooooo`04o`000?oKQP3ofhH0om^600;o0000
0oo@Z002o`0000?o`L@000Go0000ohfg0?n=]`3oSKL0o`000003oejZ00?o000000Go=Yd0o`000?lC
T@3o4i40o`000004o`261`05o`000?l0Nago07/Mo`1k7Ol000000ol0LRd01ol0003o06Tio`1Y>Ol0
JCWo0000o`1NAOl000000ol0EdX00ol0003o055=o`1AC@02o`1AC@04o`000?l0Bdgo04]=o`0000?o
03A200?o0000o`0_?ol0;cl00_l0;cl2o`0000Go01he00?o0000o`0O=_l000001Ol052h00ol0003o
01Pao`000006o`0@:`;o00001Ol042/00ol0003o00hXo`0>:003o`0>:0Co00000_l04bd00ol0003o
01@^o`0D;P04o`0D;P03o`000?l0637o01Pa00;o01Pa00?o0000o`0N=Ol07SD00_l07SD00ol0003o
02Pko`0X>`03o`0X>`03o`000?l0=T?o03I300;o03I300?o0000o`19C?l0BD`00ol0BD`01Ol0003o
05M:o`1GB_l0Ed[o000000?o06=11?l00002o`1Z>003o`000?l0NB;o07TR00;o07TR00?o0000o`27
1?l000000_l00004oaVC00?o000000Co@J40o`000?l0003oM[400ol00004ok3000;o00006?ooool0
0ol0003oooooooooo`0?ooooo`004oooool2o`00027ooooo2?l00002om2X0003o`000?o1a03o`L@0
00;o`L@000Ko0000ohfg0?n=]`3oSKL0o`000?mNZP03o`0000?o=Yd000Co0000oa>A0?lCT@3o0000
1?l0QPL01Ol0003o07/Mo`1k7Ol0Nago000000?o078]00?o0000o`1Y>Ol0JCT00ol0JCT3o`000003
o`1GB_l0003o055=00?o055=00?o0000o`1;COl0Bdd00_l0Bdd00ol0003o03A2o`000004o`0_?`04
o`000?l0;Soo02hoo`0000?o01he00Go0000o`0O=_l07cKo01lfo`000003o`0D;P05o`000?l0637o
01Pao`0H<Ol000000ol042/2o`000003o`0F;ol0003o010[00Go010[00?o0000o`0>:?l000000_l0
00000ol052ko0000o`0C;@04o`0C;@03o`000?l052ko01@^00?o01@^00Co0000o`0H<Ol0637o01Pa
5_l000000ol0BDco0000o`1GBP03o`1GBP05o`000?l0Hd7o06=1o`1S@Ol000000_l0L303o`0000Go
07TR00?o0000o`271?l0Q`@00_l00003oaVC0003o`000?m6X`3oAZ<000Co00000omf/@03o`0000;o
/<0000?o0000ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`004oooool00ol0003ooooo
ooooo`0Nooooo`;o00000ooQL`000ol0003oei@0omND0002omND01So00000_l0QPL01Ol0003o07/M
o`1k7Ol0Nago000000?o078]00?o0000o`1Y>Ol0JCT00ol0JCT01?l0003o06=1o`1S@Ol0Hd42o`00
00?o055=00?o0000o`1;COl0Bdd00ol0Bdd3o`0000?o02lo00?o0000o`0^?ol0;Sl00_l0;Sl00ol0
003o01heo`000005o`0O=P03o`000?l052ko000000Go01Pa00?o0000o`0@:ol000001?l05Rl00ol0
003o010[o`0@:`03o`0@:`;o00001Ol052h00ol0003o01<]o`0C;@03o`0C;@04o`000?l052ko01@^
o`0D;PGo00000_l093T00ol0003o02/mo`0[?@02o`0[?@03o`000?l0=T?o03I300?o03I300?o0000
o`16Bol0AT/00_l0AT/01?l0003o05=<o`1CC?l0Dd`7o`0000Co06=100?o0000o`1`<?l0L3000_l0
L303o`0000;o07TR00?o0000o`271?l0Q`@00_l0Q`@3o`000003oaVC0?l0003oAZ<000?oAZ<00ol0
00001?mf/@3o0000ok;00?nb`004o`0001Sooooo00?o0000ooooooooool03_ooool001?ooooo00?o
0000ooooooooool07?ooool2o`0000?ohG<00_l00004omND0003o`000?o</`3oc;<000;oc;<000?o
0000ok300?n``0000ol00002oh6d0005o`000?mFZ03oEZP0oeJX0?l000000olbW0001?l0003o4i40
oa>A0?lCT@08o`000003o`1b;Ol0003o06Ti00Co06Ti00Go0000o`1S@Ol0Hd7o06=1o`000002o`1M
AP03o`000?l0DDgo000000Go04]=00Oo0000o`16Bol0AT_o04I;o`000?l0;coo000000Go02ho0_l0
0006o`0O=P;o00001_l06342o`0000Ko01H_00?o0000o`0@:ol042/00_l000000ol0637o0000o`0D
;P05o`0D;P03o`000?l04bgo01<]00;o01<]1?l00002o`0O=P03o`000?l093Wo02@i00?o02@i00?o
0000o`0[?Ol0:cd00_l0:cd00ol0003o03I3o`0f@`03o`0f@`03o`000?l0AT_o04I;00;o04I;00?o
0000o`1CC?l0Dd`00_l0Dd`01?l0003o05i5o`1NAOl0GTD4o`0000;o06=100Go0000o`1`<?l0L33o
070`o`000002o`1m6@?o00001?l0Q`@00ol0003o8IL0ob6G0003o`0000?oAZ<00_l000001?ml/P3o
0000o`000?l00004ok;000;o00006?ooool00ol0003oooooooooo`0=ooooo`004oooool00ol0003o
ooooooooo`0Jooooo`Co00000_oQL`000ol0003oei@0omND0003omND0004o`000?o</`3oc;<0olbc
00Ko00000on1]0001Ol0003oEZP0oeJX0?mFZ03o000000?o<Y`000?o0000oa>A0?lCT@000_lCT@00
1?l0003o08L4o`271?l00004o`1n5`;o00001?l0JCT01Ol0003o06=1o`1S@Ol0Hd7o000000Co05e6
0_l00004o`1;C@03o`000?l0AT_o04I;00?o04I;00?o0000o`0^?ol0;Sl00ol0;Sl00ol0003o02lo
o`000005o`0O=P03o`000?l093Wo000000Go01Pa00?o0000o`0N=Ol000001_l05Rl00ol0003o010[
o`000004o`0H<@03o`000?l052ko01@^00?o01@^00?o0000o`0C;Ol000000_l000000ol07SGo0000
o`0O=P04o`0O=P03o`000?l093Wo02@i00;o02@i00?o0000o`0[?Ol0:cd00ol0:cd00ol0003o03I3
o`0f@`02o`0f@`03o`000?l0AT_o04I;00;o04I;00?o0000o`1CC?l0Dd`00ol0Dd`01Ol0003o05i5
o`1NAOl0GTGo000000;o06Ti0ol00004o`1`<003o`000?l0OAWo07dI00;o07dI0ol00002o`271003
o`000?lQU`3o8IL000;o8IL00ol000000om6X`3o0000o`000002ogbb00;o00001?nb`0000ol0003o
ooooooooo`0Fooooo`;o00003_ooool001?ooooo00?o0000ooooooooool06Oooool00ol0003oiel0
onMO0002onMO00Go00000_oGU0001?l0003oc;<0olbc0?o</`03o`000003ok300?l0003oPK@000?o
PK@000Go0000oeJX0?mFZ03oEZP0o`000003oc:L0003o`000?lCT@3o4i4000;o4i4000Co0000o`27
1?l0Q`Co00001?l0OQL00ol0003o07HVo`1f9P02o`000003o`1Y>Ol0003o06=100;o06=100?o0000
o`1MA_l0GDH00_l0GDH00ol0003o05U9o`1IB@02o`000003o`1;COl0003o04I;00Co04I;00?o0000
o`14B_l000000ol0;Sl01Ol0003o02loo`0_?ol0;coo000000?o01lf00Go0000o`0T>Ol093Wo02@i
o`000003o`0H<@05o`000?l07SGo01heo`0N=Ol000001Ol05Rl2o`0000Ko01Pa00?o0000o`0D;_l0
52h00_l052h2o`0000Go01he00?o0000o`0O=_l07cH00ol07cH00ol0003o02@io`0T>@02o`0T>@03
o`000?l0:cgo02/m00;o02/m00?o0000o`0f@ol0=T<00_l0=T<00ol0003o04I;o`16B`03o`16B`03
o`000?l0Ddco05=<00;o05=<00?o0000o`1NAOl0GTD00_l0GTD00ol0003o06Tio`1Y>@02o`1Y>@?o
00000_l0L3001Ol0003o07dIo`1m6Ol0OAWo000000;o1X`00ol00004ob6G0003o`000?m@YP3oD:H0
00?o00001?ml/P03o`0000;o//0000?o0000ooooooooool05_ooool00ol0003oooooooooo`0<oooo
o`004oooool00ol0003oooooooooo`0Gooooo`;o00001?oWG`000ol0003ogWh0omin0003omin00co
00000_n1]0001Ol0003oEZP0oeJX0?mFZ03o000000?o<Y`000?o0000oa>A0?lCT@000_lCT@001?l0
003o08L4o`271?l00004o`1n5`03o`000?l0MRKo07HV00;o07HV1?l000000ol0Hd7o0000o`1MAP03
o`1MAP03o`000?l0FDWo05U900;o05U90_l00005o`16B`07o`000?l0A4[o04A:o`14B_l0003o02ho
o`000005o`0_?`03o`000?l07cKo000000Go02@i00?o0000o`0H<Ol000001Ol07SD00ol0003o01H_
o`0F;`02o`000003o`0N=Ol0003o01Pa00Go01Pa00?o0000o`0D;_l000000_l000000ol07cKo0000
o`0N=@04o`0N=@03o`000?l07cKo01lf00?o01lf00?o0000o`0T>Ol093T00_l093T01?l0003o02/m
o`0[?Ol0:cd;o`000003o`16Bol0003o05=<00?o05=<00?o0000o`1NAOl0GTD00_l0GTD00ol0003o
06Tio`1Y>@02o`1Y>@03o`000?l0MRKo07HV00?o00001?l0OAT00ol0003o1X`0o`J<0002o`J<00?o
00000_lQU`000ol0003oD:H0oe2V0002oe2V00;o00000_ml/P000ol0003o^<80okS20003o`0001Oo
oooo0ol0000=ooooo`004_ooool3o`0001Oooooo00?o0000onMO0?oWG`000ooWG`000ol0003ogWh0
omin0003omin0003o`000?oCW@3o000000;o00000oo9^P000ol0003oZ;h0ojRn0002ojRn00co0000
0_lCT@001?l0003o08L4o`271?l00004o`1n5`03o`000?l0MRKo07HV00;o07HV00?o0000o`1`<?l0
L3000_l0L302o`0000?o05e600?o0000o`1IBOl0FDT00_l0FDT01?l0003o05M:o`1GB_l00003o`16
B`03o`000?l0A4[o04A:00?o04A:00?o0000o`0_?ol0;cl01?l0;cl2o`0000Ko02@i0_l00006o`0N
=@03o`000?l05Roo000000Co01he00?o0000o`0H<Ol063400ol06342o`0000Go01lf00?o0000o`0N
=Ol07SD00_l07SD00ol0003o01lfo`0O=P03o`0O=PWo00000_l0?DH00ol0003o04U<o`19C002o`19
C004o`000?l0Ddco05=<o`1CC0[o00000_l0GTD00ol0003o06Tio`1Y>@02o`1Y>@03o`000?l0MRKo
07HV00;o07HV0ol00002o`1m6@05o`000?l6S03o1X`0o`J<0?l000000_l^V`03o`0000CoD:H000Ko
0000ohNe0?l0003o0000ogbb0?l00004okS20003o`000?oooooooooo017ooooo0ol00002ooooo`03
o`000?oooooooooo00_ooooo0005ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool0
5Oooool5o`0000;oiel000?o0000omin0?oNOP000_oNOP06o`0000?obKX000?o0000ojRn0?nX_P00
0_nX_P001Ol0003oO;80ogbb0?ml/P3o000000?oEZP000?o0000ocJM0?lfW@000_lfW@07o`0000;o
07hG00?o0000o`1f9_l0MRH00_l0MRH00ol0003o070`o`1`<002o`1`<006o`000?l0JSSo06Xho`00
0?l0GDKo00001?l0FDT00ol0003o05M:o`1GBP02o`1GBP03o`000?l0AT_o000000Go04A:0_l00005
o`0_?`03o`000?l0=4;o000000Go02@i00?o0000o`0[?Ol000001_l07SD2o`0000Go01he00Co0000
o`0H<Ol0637o01Pa0_l000000ol093Wo0000o`0O=P04o`0O=P03o`000?l07SGo01he00?o01he00?o
0000o`0O=_l000000_l000000ol0;coo0000o`0d@P03o`0d@P03o`000?l0?DKo03e600?o03e600?o
0000o`19C?l0BD`00_l0BD`00ol0003o05=<o`1CC002o`1CC003o`000?l0G4Ko05a600;o05a600?o
0000o`1W??l0Ic`00ol00005o`1Y>@05o`000?l0MRKo07HVo`1f9_l000000_l0Q0`3o`0000Co1X`0
00?o0000objK0?l^V`000_l^V`02o`0000?oD:H000?o0000ohNe0?n7]@000_l00004okS20003o`00
0?oooooooooo00kooooo0ol00005ooooo`03o`000?oooooooooo00_ooooo0006ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
0_l00005one;00Co000000CogWh0o`000?l0003o00000_oCW@000ol0003obKX0olVj0002olVj0004
o`000?nX_P3oZ;h0ojRn00;o00000oml/P001Ol0003oEZP0oeJX0?mFZ03o000000Co=Yd000?o0000
oaZD0?lJU0000_lJU0000ol0003o18/0o`B;0003o`0000?o07HV00?o0000o`1`<?l0L3000_l0L300
0ol0003o06Xho`1Z>002o`1Z>0;o00000ol0FDT00ol0003o05M:o`1GBP04o`1GBP03o`000?l0A4[o
04A:00?o04A:00Co0000o`16Bol0AT_o00000ol0;cl01Ol0003o03A2o`0d@_l0=4;o000000?o02@i
00Go0000o`0[?Ol0:cgo02/mo`000003o`0N=@;o000000?o02Pko`000?l07SD01?l07SD01?l0003o
01Pao`000?l00004o`0T>@03o`000?l07cKo01lf00;o01lf00Co0000o`0N=Ol07SGo01he1?l00005
o`0_?`03o`000?l0=4;o03A200;o03A200?o0000o`0mA_l0?DH00_l0?DH00ol0003o04U<o`19C002
o`19C003o`000?l0Ddco05=<00?o05=<00?o0000o`1LA_l0G4H00_l0G4H00ol0003o06Llo`1W?002
o`1W?0Co000000?o06Tio`000?l0MRH00ol0MRH00ol0003o08@<o`243002o`2430?o00000_l6S000
1_l0003o;Y/0objK0?l^V`3o0000oejZ00?o000000?oD:H0o`000?n7]@000_n7]@03o`0000;o^<80
00?o0000ooooooooool02_ooool3o`0000Sooooo00?o0000ooooooooool02oooool000?ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04_ooool00ol0003okD/0
one;0004one;0003o`000?oUI`3oiFL000[o00000_o9^P001Ol0003oZ;h0ojRn0?nX_P3o000000Co
O;8000Go0000oeJX0?mFZ03oEZP0o`000004ocJM0003o`000?lJU03o6Y@000;o6Y@000Go0000o`B;
0?l4R`3o18/0o`000002o`243003o`000?l0MRKo000000Co070`00?o0000o`1Z>?l0JSP00_l0JSP0
1_l0003o06Llo`1W??l0003o05U9o`0000Ko05M:00?o0000o`1FBol000000ol0A4X00ol0003o04I;
o`16B`02o`16B`03o`000?l0;coo000000Go03A200?o0000o`0T>Ol000001Ol0:cd00ol0003o01he
o`000004o`0X>`03o`000?l07SGo01he00;o01he0_l00006o`0T>@03o`000?l07cKo01lf00;o01lf
1?l00002o`0^?`03o`000?l0;coo02lo00Co02lo00?o0000o`0d@_l0=4800_l0=4800ol0003o03e6
o`0mAP03o`0mAP03o`000?l0BDco04U<00;o04U<00?o0000o`1CC?l0Dd`00_l0Dd`00ol0003o05a6
o`1LAP02o`1LAP03o`000?l0Icco06Ll00;o06Ll00Co0000o`1b;Ol0LRgo078]1?l00002o`1f9P03
o`000?l0Q0co08@<00;o08@<00?o0000oaFB0?lETP000ol00004objK0004o`000?mNZP3oGZX0oejZ
00?o00000_n7]@000ol0003o`l@0ol?40004o`0000Oooooo1?l0000<ooooo`03o`000?oooooooooo
00[ooooo0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0@ooooo`?o00001?o]B`05o`000003onEW0?l0003og8D000?og8D000Co0000
om:R0?oBXP3odZ802?l00002ogbb0005o`000?mFZ03oEZP0oeJX0?l000001?lfW@000ol0003o6Y@0
oaZD0002oaZD0005o`000?l4R`3o18/0o`B;0?l000001?l0Q0`3o`0000;o070`00?o0000o`1Z>?l0
JSP00_l0JSP00ol0003o06Llo`1W?002o`1W?0;o00001Ol0EdX01ol0003o05I;o`1FBol0ET_o0000
o`14B_l000001_l0AT/00ol0003o03A2o`0d@P04o`0d@P;o00001_l0:cd2o`0000Go02Pk00?o0000
o`0N=Ol07SD00_l000000ol0:cgo0000o`0T>@05o`0T>@03o`000?l07cKo000000;o000000?o02lo
o`000?l0;Sl01?l0;Sl00ol0003o02loo`0_?`03o`0_?`03o`000?l0=4;o03A200;o03A200?o0000
o`0mA_l0?DH00ol0?DH00ol0003o04U<o`19C002o`19C003o`000?l0Ddco05=<00;o05=<00?o0000
o`1LA_l0G4H00ol0G4H00ol0003o06Llo`1W?002o`1W?003o`000?l0LRgo078]00;o078]00?o0000
o`1n5ol000000_l00005o`243003o`000?lETP3o5I8000;o5I800ol00002objK0003o`000?mNZP3o
GZX000;oGZX00ol000000on7]@3o0000ol?40003ol?400;o00000oooool3o`00013ooooo00?o0000
ooooooooool02_ooool000Cooooo00?o0000ooooool000000oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00kooooo0_l00003oo8i00;o000000CokD/0o`000?l0003o00000_oU
I`02o`0000Cog8D000Go0000om:R0?oBXP3odZ80o`000004olRl0004o`000?nX_P3oZ;h0ojRn00So
00000_lfW@000ol0003o6Y@0oaZD0002oaZD0005o`000?l4R`3o18/0o`B;0?l000001?l0Q0`01?l0
003o07dIo`1m6Ol0OAT3o`0000?o06Xh00?o0000o`1W??l0Ic`00ol0Ic`00ol0003o06@oo`000003
o`1GBP03o`000?l0ET_o05I;00?o05I;00?o0000o`16Bol0AT/01?l0AT/2o`0000Go03A200?o0000
o`0mA_l000001Ol0:cd00ol0003o03I3o`000005o`0X>`03o`000?l07SGo000000Co02/m00?o0000
o`0T>Ol093T00ol093T2o`0000Go02lo00?o0000o`0^?ol0;Sl00ol0;Sl00ol0003o02loo`0_?`03
o`0_?`03o`000?l0=4;o03A201Ko000000?o05a6o`000?l0Ic`01?l0Ic`00ol0003o078]o`1b;@02
o`1b;@04o`000?l0OQOo07hGo`1n5`?o00000_l0Q0`00ol0003o5I80oaFB0002oaFB0003o`000?lo
X@3o?j4000?o00001?mNZP02o`000004oiFi0?l0003o0000o`0000Co`l@01?l0000Cooooo`03o`00
0?oooooooooo00[ooooo0005ooooo`;o00000oooool01?l0003oooooooooool00003ooooo`;o0000
3_ooool2o`0000GolST01Ol00002onEW0003o`000?oLQ@3og8D000?og8D000Go0000om:R0?oBXP3o
dZ80o`000004olRl0003o`000?nX_P3oZ;h000;oZ;h000Go0000oh6d0?n1]03oPK@0o`000003oejZ
00Co00000_lJU0001Ol0003o18/0o`B;0?l4R`3o000000Co08@<00?o0000o`1m6Ol0OAT00_l0OAT0
1_l0003o07TRo`1i8_l0003o06Xho`0000Go06Ll00Oo0000o`1T?ol0I3oo06@oo`000?l0Ed[o0000
00Go05I;0_l00005o`16B`04o`000?l0Bdgo04]=o`0000?o03A200Go0000o`0mA_l0?DKo03e6o`00
0003o`0[?@05o`000?l0=T?o03I3o`0f@ol000001?l0:3/2o`0000Ko02/m00?o0000o`0T>Ol093T0
0_l000000ol0=4;o0000o`0_?`04o`0_?`03o`000?l0;Soo02ho00?o02ho00Co0000o`0_?ol0;coo
02lo1Ol00002o`1;C@03o`000?l0DDgo055=00?o055=00?o0000o`1GB_l0EdX00_l0EdX00ol0003o
05i5o`1NA@02o`1NA@04o`000?l0Icco06Llo`1W?0Ko000000?o06Llo`000?l0LRd00ol0LRd01Ol0
003o07hGo`1n5ol0OQOo000000;o18/00ol00005oaFB0003o`000?loX@3o?j4000;o?j400ol00002
oejZ00;o00000onE^@03o`0000;o`l@000?o0000ooooooooool04oooool00ol0003oooooooooo`0:
ooooo`001_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`0;oooo
o`?o00001?ob>@03o`0000Coje401Ol00002omb50005o`000?oBXP3odZ80om:R0?l000001?o8_000
0ol0003oZ;h0ojRn0002ojRn0005o`000?n1]03oPK@0oh6d0?l000001?mNZP001?l0003o@J40od6Q
0?m1X@04o`000003o`B;0?l0003o08@<00?o08@<00?o0000o`1m6Ol0OAT00_l0OAT00ol0003o07TR
o`1i8P02o`1i8P03o`000?l0Icco06Ll00?o06Ll00?o0000o`1T?ol0I3l00_l0I3l2o`0000Go05I;
00Co0000o`1GB_l0Ed[o00000ol0AT/00ol0003o04]=o`1;C@02o`1;C@03o`000?l0=4;o000000Go
03e600?o0000o`0[?Ol000001?l0=T<00ol0003o02Pko`0X>`02o`000003o`0f@ol0003o02/m00Go
02/m00?o0000o`0T>Ol000001?l0=4800ol0003o02loo`0_?`03o`0_?`03o`000?l0;Soo02ho00;o
02ho1?l00002o`16B`03o`000?l0Bdgo04]=00?o04]=00?o0000o`1ACOl0DDd00ol0DDd00ol0003o
05M:o`1GBP02o`1GBP03o`000?l0GTGo05i500;o05i500?o0000o`1W??l0Ic`00_l0Ic`01?l0003o
070_o`1`;ol0L2l7o`0000Co07hG00?o0000o`B;0?l4R`000_l4R`03o`0000;o5I8000?o0000ocnQ
0?loX@000_loX@000ol0003oL:l0og2_0004o`0000?oUKT000?o0000olNm0?o7_@000ol0000Eoooo
o`03o`000?oooooooooo00[ooooo000Aooooo`03o`000?oooooooooo00Wooooo0_l00003ooHY00Go
00001Oo[D@000ol0003ohf`0on=/0003on=/00So00000_o8_0000ol0003oZ;h0ojRn0002ojRn0005
o`000?n1]03oPK@0oh6d0?l000001?mNZP001Ol0003o@J40od6Q0?m1X@3o000000Co:9T00ol00002
o`243003o`000?l0OAWo07dI00;o07dI00?o0000o`1i8_l0NB800ol0NB82o`0000?o06Ll00?o0000
o`1T?ol0I3l00_l0I3l01?l0003o06<oo`1S?ol00003o`1FB`03o`000?l0Ed[o05M:00;o05M:00?o
0000o`16Bol000001Ol0Bdd2o`0000Ko03e60_l00005o`0f@`03o`000?l0:3_o000000Co03I300?o
0000o`0[?Ol0:cd00ol0:cd2o`0000Go03A200?o0000o`0_?ol0;cl00ol0;cl00ol0003o02hoo`00
0002o`000003o`14B_l0003o04I;00Co04I;00?o0000o`1;COl0Bdd00_l0Bdd00ol0003o055=o`1A
C@03o`1AC@03o`000?l0Ed[o05M:00;o05M:00?o0000o`1NAOl0GTD00_l0GTD00ol0003o06Llo`1W
?003o`1W?003o`000?l0L2oo070_00;o070_00Co0000o`1k7Ol0Nago07/M1?l00002o`1n5`05o`00
0?l4R`3o18/0o`B;0?l000000_lXV@03o`0000Go?j4000?o0000og2_0?m`[`000_m`[`03o`0000;o
UKT000?o0000olNm0?o7_@000_o7_@000ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[o
oooo000Aooooo`03o`000?oooooooooo00Sooooo00Co0000ooHY0?of:@3omRT01_l00005on]A0003
o`000?oSK03ohf`000?ohf`000Go0000om^70?oKQ`3ofhL0o`000004om:R00Co00000_nX_P001Ol0
003oPK@0oh6d0?n1]03o000000CoGZX000Go0000od6Q0?m1X@3o@J40o`000004obRI0004o`000?lE
TP3o5I80oaFB00?o00000ol0OAT00ol0003o07TRo`1i8P03o`1i8P06o`000?l0MBSo07DXo`000?l0
Icco00001?l0I3l00ol0003o06<oo`1S?`02o`1S?`03o`000?l0ET_o000000Go05M:0_l00005o`1;
C@03o`000?l0DDgo000000Go03e600?o0000o`19C?l000001Ol0=T<2o`0000Ko03I300?o0000o`0[
?Ol0:cd00_l000000ol0?DKo0000o`0d@P05o`0d@P03o`000?l0;coo02lo00;o02lo0_l00005o`14
BP03o`000?l0AT_o04I;00;o04I;00?o0000o`1;COl0Bdd00ol0Bdd00ol0003o055=o`1AC@02o`1A
C@03o`000?l0Ed[o05M:00?o05M:00?o0000o`1NAOl0GTD00_l0GTD00ol0003o06Llo`1W?002o`1W
?003o`000?l0L2oo070_00?o070_00Go0000o`1k7Ol0Nago07/Mo`000002o`2710?o00001?l4R`00
0ol0003o:9T0obRI0002obRI00?o00000_loX@000ol0003oL:l0og2_0002og2_0003o`000?nX_P3o
000000?o00001?o7_@000ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo000Aoooo
o`03o`000?oooooooooo00Kooooo1_l000000oof:@3o0000o`000003oo4l00?o000000?oje40o`00
0?oSK0000ooSK002o`0000?ofhL000?o0000om:R0?oBXP000_oBXP000ol0003obKX0olVj0002olVj
00So00000_mNZP001Ol0003o@J40od6Q0?m1X@3o000000Co:9T000?o0000oaFB0?lETP000olETP00
1Ol0003o1X`0o`000?l0OAWo000000Go07TR00?o0000o`1e:?l0MBP00_l0MBP2o`0000?o06@o00?o
0000o`1S?ol0Hcl00ol0Hcl2o`0000Go05M:00Co0000o`1IBOl0FDWo00000ol0Bdd01Ol0003o055=
o`1ACOl0DDgo000000?o03e600Go0000o`19C?l0BDco04U<o`000003o`0f@`03o`000?l0AT_o0000
00Ko03I300?o0000o`0[?Ol000001?l0?DH00ol0003o03A2o`0d@P03o`0d@P03o`000?l0;coo0000
00;o000000?o04I;o`000?l0A4X01?l0A4X00ol0003o04I;o`16B`03o`16B`03o`000?l0Bdgo04]=
00;o04]=00?o0000o`1ACOl0DDd00ol0DDd00ol0003o05M:o`1GBP02o`1GBP03o`000?l0GTGo05i5
00;o05i500?o0000o`1W??l0Ic`00ol0Ic`00ol0003o070_o`1`;`02o`1`;`03o`000?l0Nago07/M
00;o07/M00?o0000o`271?l0Q`@00_l0Q`@3o`0000;o18/000Go0000obRI0?lXV@3o:9T0o`000002
oeBW00?o00001Om`[`000ol0003oZ;h0o`000002ojRn00;o00000oo7_@000ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooooooo00?ooooo2?l000000oof
:@3o0000oo4l0006oo4l00Co00000_oSK0000ol0003ofhL0om^70002om^70003o`000?oBXP3odZ80
00;odZ8000?o0000olVj0?o9^P000_o9^P001Ol0003o/<00ok300?n``03o000000CoSKL01?l00000
0om1X@3o0000obRI0003obRI0003o`000?lETP3o5I8000?o5I8000Co0000o`J<0?l6S03o1X`00_l0
0004o`1i8P03o`000?l0MBSo07DX00;o07DX00Ko0000o`1c;?l0Lbco0000o`1T?ol00005o`1S?`04
o`000?l0I3oo06@oo`0000?o05M:00?o0000o`1IBOl0FDT00_l0FDT00ol0003o04]=o`000005o`1A
C@03o`000?l0?DKo000000Co04U<00Co0000o`0f@ol0=T?o00000ol0AT/00ol0003o03I3o`0f@`03
o`0f@`;o00001_l0?DH00ol0003o03A2o`0d@P02o`0d@P;o00001Ol0AT/00ol0003o04A:o`14BP03
o`14BP03o`000?l0AT_o04I;00;o04I;00Co0000o`1;COl0Bdgo04]=5_l000000ol0Icco0000o`1`
;`03o`1`;`03o`000?l0Nago07/M00;o07/M00?o0000o`271?l0Q`@00_l0Q`@00ol0003o6Y@0oaZD
0003o`0000Co:9T000?o0000oeBW0?mDY`000_mDY`03o`0000?oL:l00_l00002ojRn0003o`000?o<
/`3o000000;o000000?oakd0o`000?ooool04_ooool00ol0003oooooooooo`09ooooo`004?ooool2
o`0000;ooooo1_l00004ooPM00?o00001Ooa?002o`0000Coje<01?l00002om^70003o`000?oBXP3o
dZ8000;odZ8000?o0000olVj0?o9^P000_o9^P001Ol0003o/<00ok300?n``03o000000CoSKL000?o
0000ofj_0?m^[`000_m^[`03o`0000;o:9T000?o0000oaFB0?lETP000olETP001Ol0003o1X`0o`J<
0?l6S03o000000;o08L40_l000000ol0NB;o0000o`1e:003o`1e:003o`000?l0Lbco07</00;o07</
00?o0000o`1S?ol0Hcl00ol0Hcl00ol0003o06@oo`1T?`02o`1T?`03o`000?l0Ed[o000000Ko05U9
00?o0000o`1ACOl0DDd01?l0DDd2o`0000Go04U<00?o0000o`0f@ol000001Ol0AT/00ol0003o03I3
o`0f@`02o`000003o`19C?l0003o03e600Go03e600?o0000o`0d@_l000000_l000000ol0Bdgo0000
o`16B`04o`16B`03o`000?l0A4[o04A:00?o04A:00Co0000o`16Bol0AT_o04I;1Ol00002o`1IB@03
o`000?l0GDKo05e600;o05e600?o0000o`1S@Ol0Hd400ol0Hd400ol0003o06Tio`1Y>@02o`1Y>@04
o`000?l0LRgo078]o`1b;@Ko000000?o070_o`000?l0Nad00ol0Nad00ol0003o08L4o`271002o`27
1003o`000?lJU03o6Y@000;o6Y@00ol00002obRI0005o`000?mDY`3oE:L0oeBW0?l000000_n7]@04
o`000005ojRn0?l0003oZ;h0ojRn0?l000000oo</`02o`0001?ooooo00?o0000ooooooooool02Ooo
ool0013ooooo2Ol00003ooPM00;o00000ooe:P02o`000003oo4l0?l0003o000000Goje<000?o0000
on=/0?oSK0000_oSK004o`0000;odZ8000?o0000olVj0?o9^P000_o9^P001Ol0003o/<00ok300?n`
`03o000000CoSKL000?o0000ofj_0?m^[`000om^[`000ol0003oE:L0oeBW0003o`0000Co5I8000Go
0000o`J<0?l6S03o1X`0o`000004o`2710?o00000ol0MBP00ol0003o07</o`1c;003o`1c;0;o0000
0ol0Hcl00ol0003o06@oo`1T?`04o`1T?`03o`000?l0FDWo05U900Co05U90_l00005o`1AC@03o`00
0?l0Ed[o000000Go04U<0_l00006o`16B`03o`000?l0=T?o000000Co04U<00?o0000o`0mA_l0?DH0
0ol0?DH2o`0000Go04]=00?o0000o`16Bol0AT/00ol0AT/00ol0003o04A:o`14BP02o`14BPCo0000
0_l0EdX00ol0003o05U9o`1IB@03o`1IB@03o`000?l0GDKo05e600;o05e600?o0000o`1S@Ol0Hd40
0ol0Hd400ol0003o06Tio`1Y>@02o`1Y>@03o`000?l0LRgo078]00;o078]00Co0000o`1k7Ol0Nago
07/M1Ol000000ol0Nago0000o`271003o`271003o`000?lJU03o6Y@000;o6Y@000?o0000od6Q0?m1
X@000ol00004oeBW0003o`000?n7]@3oQkD000;oQkD01?l00002ojRn0003o`000?o</`3oc;<000;o
c;<000?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`004?ooool4o`0000GonAT0
00?o0000ooPM0?l000001_oe:P03o`0000Coje<00_l00004on=/0003o`000?oLQ@3og8D000;og8D0
1?l00002olVj0005o`000?n``03o/<00ok300?l000001?n=]`000ol0003oKZl0ofj_0003ofj_0003
o`000?mDY`3oE:L000;oE:L000Ko0000ocnQ0?l0003o0000oaFB0?l00003o`J<0003o`000?l0Q`Co
08L400;o08L400Oo0000o`243?l0Q0co08@<o`000?l0MBSo000000Go07</00Ko0000o`1b;Ol0LRgo
0000o`1S?ol00007o`1T?`03o`000?l0FDWo05U900?o05U900Co0000o`1MA_l0GDKo00000ol0DDd0
1Ol0003o05M:o`1GB_l0Ed[o000000?o04U<00?o0000o`1CC?l000001_l0AT/2o`0000Ko04U<00?o
0000o`0mA_l0?DH00_l000000ol0DDgo0000o`1;C@04o`1;C@03o`000?l0AT_o04I;00?o04I;00?o
0000o`14B_l000000_l000000ol0ET_o0000o`1GBP04o`1GBP03o`000?l0FDWo05U900;o05U900?o
0000o`1MA_l0GDH00_l0GDH00ol0003o06=1o`1S@@03o`1S@@03o`000?l0JCWo06Ti00;o06Ti00?o
0000o`1b;Ol0LRd00ol0LRd01Ol0003o07/Mo`1k7Ol0Nago000000?o08H71Ol00002o`271003o`00
0?lJU03o6Y@000;o6Y@000?o0000od6Q0?m1X@000_m1X@03o`0000;oE:L000?o0000ohNe0?n7]@00
0_n7]@000ol0003o_l<0oko30003o`0000Coc;<000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`004?ooool3o`0000KonAT00ol00004ooDZ00;o00000ooa?002o`000003on]C0?l0
003ohf`000Cohf`000?o0000omb50?oLQ@000_oLQ@000ol0003odid0om>M0002om>M00So00000_n=
]`000ol0003oKZl0ofj_0003ofj_0003o`000?mDY`3oE:L000;oE:L000Co0000ocnQ0?loX@3o?j40
1?l000000ol6S03o0000o`271003o`271003o`000?l0Q0co08@<00?o08@<00?o0000o`1c;?l0Lb`0
0ol0Lb`00ol0003o078]o`1b;@02o`1b;@03o`000?l0I3oo06@o00Go06@o00?o0000o`1W??l00000
0ol0FDT00ol0003o05e6o`1MAP02o`1MAP03o`000?l0DDgo000000Co05M:00Co0000o`19C?l0BDco
00000ol0Dd`00ol0003o04I;o`16B`02o`16B`03o`000?l0Ddco000000Ko04U<00?o0000o`0mA_l0
00001?l0DDd00ol0003o04]=o`1;C@03o`1;C@03o`000?l0AT_o04I;00;o04I;0_l00005o`1FB`03
o`000?l0Ed[o05M:00;o05M:00?o0000o`1IBOl0FDT00ol0FDT00ol0003o05e6o`1MAP02o`1MAP03
o`000?l0Hd7o06=100;o06=100?o0000o`1Y>Ol0JCT00ol0JCT00ol0003o078]o`1b;@02o`1b;@03
o`000?l0Nago07/M00;o07/M00?o0000o`261ol0QPL00_l0QPL00ol0003o4i40oa>A0003o`0000Go
6Y@000Go0000od6Q0?m1X@3o@J40o`000002ofj_00?o00001On7]@000ol0003o_l<0o`000002oko3
00?o00000_o</`000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo000Booooo`;o
00000_oi6@03o`0000?on1d00_l000000ooe:P3o0000oo4l0005oo4l00Go00000_oSK0000ol0003o
g8D0omb50002omb50003o`000?oCW@3odid000;odid000?o0000olbc0?o</`000oo</`000ol0003o
`L@0ol740003o`0000CoKZl000?o0000oeBW0?mDY`000_mDY`001Ol0003o?j40ocnQ0?loX@3o0000
00Co;Y/00_l00003o`271003o`000?l0Q0co08@<00Co08@<0_l00003o`1c;003o`000?l0LRgo078]
00?o078]0_l00005o`1T?`07o`000?l0Icco06Llo`1W??l0003o05U9o`000005o`1MAP;o00001Ol0
EdX00ol0003o04U<o`000005o`1CC004o`000?l0AT_o04I;o`0000?o05=<00?o0000o`19C?l0BD`0
0ol0BD`2o`0000Go055=00?o0000o`1;COl0Bdd00ol0Bdd00ol0003o04I;o`000002o`000003o`1G
B_l0003o05I;00Co05I;00?o0000o`1GB_l0EdX00ol0EdX00ol0003o05U9o`1IB@02o`1IB@03o`00
0?l0GDKo05e600;o05e600?o0000o`1S@Ol0Hd400ol0Hd400ol0003o06Tio`1Y>@02o`1Y>@03o`00
0?l0LRgo078]00;o078]00?o0000o`1k7Ol0Nad00_l0Nad00ol0003o08H7o`261`03o`261`03o`00
0?lCT@3o4i4000;o4i401?l000000olJU03o0000od6Q0003od6Q0003o`000?m^[`3oKZl000;oKZl0
0ol00002ohNe0006o`000?no``3o_l<0o`000?no``3o00000_o@YP03o`00017ooooo00?o0000oooo
ooooool02Oooool001?ooooo0ol00007ooPM00?o00001Ooa?0000ol0003oje40on]A0003on]A00Co
00000_oLQ@000ol0003odid0om>M0002om>M0003o`000?o</`3oc;<000?oc;<000?o0000ol740?o1
a0000_o1a0001_l0003oX[`0o`000?l0003oKZl0o`0000CoE:L000Go0000ocnQ0?loX@3o?j40o`00
0005objK0005o`000?lQU`3o0000o`271?l000001_l0Q0`01_l0003o088@o`224?l0003o07</o`00
00Go078]00Co0000o`1c;?l0Lbco00000ol0I3l00ol0003o06Llo`1W?002o`1W?0;o00001Ol0GDH0
0ol0003o06=1o`000005o`1GBP;o00001_l0Dd`00ol0003o04I;o`000005o`1CC003o`000?l0BDco
04U<00;o000000?o05M:o`000?l0DDd01Ol0DDd00ol0003o04]=o`1;C@02o`1;C@;o00001Ol0EdX0
0ol0003o05I;o`1FB`02o`1FB`03o`000?l0Ed[o05M:00?o05M:00Co0000o`1IBOl0FDWo05U95_l0
00000ol0LRgo0000o`1k7@03o`1k7@03o`000?l0QPOo08H700;o08H700?o0000oa>A0?lCT@000_lC
T@001?l0003o=Yd0ocJM0?lfW@04o`0000;o@J4000?o0000ofj_0?m^[`000_m^[`000ol0003oX[`0
oj:l0003o`0000?o_l<000?o0000oko30?l000001?o@YP000ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Sooooo000Dooooo`03o`000?oooooo000000Con1d00_l00003ooHY0005o`000?oa
?03olC`0oo4l0?l000001Oo[D@000ol0003oiFL0onEW0002onEW00Co00000_oCW@000ol0003oc;<0
olbc0003olbc0003o`000?o1a03o`L@000;o`L@000Co0000oj:l0?nR_03oX[`01?l00002oeBW0005
o`000?loX@3o?j40ocnQ0?l000001Ol^V`001?l0003o8IL0ob6G0?lQU`02o`0000Go08@<00?o0000
o`224?l0PQ000_l0PQ000ol0003o078]o`1b;@03o`1b;@03o`000?l0Lbco07</00;o07</00?o0000
o`1T?ol000001?l0Ic`00ol0003o06Xho`000004o`1MAP05o`000?l0Hd7o06=1o`1S@Ol000000ol0
EdX00ol0003o05i5o`000006o`1CC0;o00001_l0Dd`00ol0003o04U<o`000004o`1GBP03o`000?l0
DDgo055=00?o055=00?o0000o`1;COl000000_l000000ol0FDWo0000o`1GBP04o`1GBP03o`000?l0
ET_o05I;00?o05I;00?o0000o`1GB_l0EdX01_l00002o`1W?003o`000?l0JSSo06Xh00;o06Xh00?o
0000o`1`<?l0L3000_l0L3000ol0003o07HVo`1f9P03o`1f9P04o`000?l0OQOo07hGo`1n5`Go0000
00?o07/Mo`000?l0QPL00ol0QPL00ol0003o4i40oa>A0003oa>A0003o`000?lfW@3o=Yd000;o=Yd0
00?o0000oejZ0?l000000_l00005ofj_0003o`000?nR_03oX[`000;oX[`00ol000000ono``3o0000
o`000004om2V0003o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool001Gooooo0ol0
00000ooh7@3o0000o`000006ooHY0003o`000?oa?03o000000Coje400_l00004onEW0003o`000?oN
OP3ogWh000;ogWh00ol00004olbc0003o`000?o1a03o`L@000;o`L@000Go0000oj:l0?nR_03oX[`0
o`000004ohNe00Co000000?o?j40o`000?l^V`001?l^V`000ol0003o8IL0ob6G0002ob6G0003o`00
0?lIT`3o000000?o08@<00?o0000o`224?l0PQ000_l0PQ000ol0003o084Bo`000003o`1b;@03o`00
0?l0Lbco07</00?o07</0_l00004o`1W?005o`000?l0JSSo06Xho`1Z>?l000000_l0GDH00ol0003o
06=1o`1S@@02o`1S@@04o`000?l0Ed[o05M:o`0000?o05i500?o0000o`1CC?l0Dd`00_l0Dd`00ol0
003o05a6o`000006o`1CC0;o00001Ol0EdX00ol0003o055=o`1AC@03o`1AC@;o00001Ol0FDT00ol0
003o05M:o`1GBP02o`1GBP03o`000?l0ET_o05I;00;o05I;1?l00003o`1T?`03o`000?l0Icco06Ll
00;o06Ll00?o0000o`1Z>?l0JSP00ol0JSP00ol0003o070`o`1`<002o`1`<003o`000?l0MRKo07HV
00?o07HV00Go0000o`1n5ol0OQOo07hGo`000003o`2710Ko000000?o08H7o`000?lCT@000olCT@00
0ol0003o=Yd0ocJM0003ocJM0004o`000?mNZP3oGZX0oejZ00?o00000om^[`001Ol0003oX[`0oj:l
0?nR_03o000000;obKT00ol00005om2V0003o`000?oooooooooo00kooooo00?o0000ooooooooool0
2?ooool001Oooooo0ol00007ooHY00Co00000_o[D@000ol0003oiFL0onEW0003onEW0003o`000?oN
OP3ogWh000;ogWh000Co0000omND0?oGU03oei@00_l000000oo</`3o0000ol740003ol740005o`00
0?nR_03oX[`0oj:l0?l000001?n7]@000ol0003oL:l0og2_0002og2_00;o00001?l^V`000ol0003o
8IL0ob6G0002ob6G0007o`000?lIT`3o6I<0oaVC0?l0003o08@<o`000004o`224007o`000?l0PA;o
084Bo`214_l0003o078]o`000005o`1c;003o`000?l0MBSo000000?o06Ll00?o0000o`1Z>?l0JSP0
0_l0JSP00ol0003o05e6o`000005o`1S@@03o`000?l0Ed[o000000Go05i500Co0000o`1CC?l0Ddco
00000ol0G4H00ol0003o05=<o`1CC002o`1CC003o`000?l0GTGo000000Ko05M:00?o0000o`1ACOl0
DDd00_l000000ol0GDKo0000o`1IB@04o`1IB@03o`000?l0Ed[o05M:00?o05M:1?l000000ol0Hcoo
0000o`1T?`05o`1T?`03o`000?l0Icco06Ll00;o06Ll00?o0000o`1Z>?l0JSP00_l0JSP00ol0003o
070`o`1`<002o`1`<003o`000?l0MRKo07HV00?o07HV00?o0000o`1n5ol0OQL00_l0OQL00ol0003o
08L4o`271002o`271004o`000?lCT@3o4i40oa>A00Go000000?o4i40o`000?lfW@001?lfW@001Ol0
003oGZX0oejZ0?mNZP3o000000;oSKL01?l00004oj:l0004o`000?o9^@3obKT0olVi00Co00000oo@
YP000ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooo
000000ComRT00_l00004oo8i00?o00001?oUI`000ol0003ogWh0omin0002omin0003o`000?oGU03o
ei@000?oei@01?l00002ol740005o`000?nR_03oX[`0oj:l0?l000001?n7]@000ol0003oL:l0og2_
0003og2_0006o`000?mNZP3o0000o`000?l^V`3o00001?lQU`000ol0003o6I<0oaVC0002oaVC00?o
00000ol0PQ000ol0003o084Bo`214P03o`214P03o`000?l0Lbco07</00?o07</00Oo0000o`1e:?l0
MBSo07DXo`000?l0Icco000000Ko06Xh00?o0000o`1S@Ol0Hd401Ol0Hd400ol0003o05i5o`1NA@04
o`1NA@03o`000?l0Ddco000000Go05a600Co0000o`1CC?l0Ddco00000ol0GTD00ol0003o05M:o`1G
BP03o`1GBP03o`000?l0DDgo000000Co05e600?o0000o`1IBOl0FDT00_l0FDT00ol0003o05M:o`1G
BP02o`1GBP;o00001Ol0Hcl00ol0003o06@oo`1T?`03o`1T?`03o`000?l0Icco06Ll00;o06Ll00?o
0000o`1Z>?l0JSP00ol0JSP00ol0003o070`o`1`<002o`1`<003o`000?l0MRKo07HV00;o07HV00?o
0000o`1n5ol0OQL00_l0OQL00ol0003o08L4o`271003o`271005o`000?lCT@3o4i40oa>A0?l00000
0olbW005o`0000;o=Yd000?o0000oejZ0?mNZP000_mNZP000ol0003oSKL0ohfg0002ohfg00Co0000
0_nR_0001Ol0003obKT0olVi0?o9^@3o000000;oeYL01?l0000?ooooo`03o`000?oooooooooo00So
oooo000Iooooo`04o`000?oooooo0000ooHY00;o00001Oob>@001?l0003okD/0one;0?o]B`02o`00
0003onEW0?l0003ogWh000?ogWh000?o0000omND0?oGU0000ooGU0000ol0003od:P0om2X0002om2X
00Co000000?oX[`0o`000?n7]@000on7]@000ol0003oL:l0og2_0003og2_0003o`000?mNZP3oGZX0
00;oGZX00_l00003ob6G0003o`000?lIT`3o6I<000;o6I<000Oo0000oa>A0?lCT@3o4i40o`000?l0
PQ3o000000Go084B00?o0000o`224?l000000ol0Lb`00ol0003o07DXo`1e:003o`1e:003o`000?l0
JSSo06Xh00Co06Xh0_l00006o`1S@@;o00001_l0GTD2o`0000Ko05a600?o0000o`1CC?l000001?l0
GTD00ol0003o05M:o`1GBP03o`1GBP;o00001Ol0GDH00ol0003o05U9o`1IB@03o`1IB@Co000000?o
06@oo`000?l0Hcl01?l0Hcl00ol0003o06@oo`1T?`03o`1T?`03o`000?l0Icco06Ll00;o06Ll00?o
0000o`1Z>?l0JSP00ol0JSP00ol0003o070`o`1`<002o`1`<003o`000?l0MRKo07HV00?o07HV00?o
0000o`1n5ol0OQL00_l0OQL00ol0003o08L4o`271002o`271003o`000?lCT@3o4i4000;o4i4000?o
0000oc:L0?lbW0000_lbW0000ol0003oEZP0oeJX0004o`0000?oGZX000?o0000ohfg0?n=]`000on=
]`000ol0003o`L@0ol740003o`0000?obKT00_l00004omJG00;o00003_ooool00ol0003ooooooooo
o`08ooooo`006_ooool01?l0003oooooo`000?l00005oo8i0003o`000?o]B`3okD/000?okD/01?l0
0002omin0003o`000?oGU03oei@000;oei@00_l00004om2X0003o`000?o9^@3obKT000;obKT00ol0
0002ohNe0003o`000?m`[`3oL:l000?oL:l000?o0000oejZ0?mNZP000_mNZP001_l0003oD:H0oe2V
0?l0003o8IL0o`0000Co6I<000?o0000oa>A0?lCT@000olCT@000ol0003o084Bo`214P03o`214P07
o`000?l0PQ3o088@o`224?l0003o07</o`000006o`1e:003o`000?l0JSSo06Xh00?o06Xh00Co0000
o`1`<?l0L33o00001?l0Hd401?l0003o06Tio`1Y>Ol00004o`1NA@03o`000?l0Icco000000Ko05a6
0_l00006o`1NA@03o`000?l0Ed[o05M:00;o000000?o06=1o`000?l0GDH01?l0GDH00ol0003o05U9
o`1IB@02o`1IB@;o00001Ol0I3l00ol0003o06<oo`1S?`03o`1S?`03o`000?l0I3oo06@o00?o06@o
00?o0000o`1W??l0Ic`00_l0Ic`00ol0003o06Xho`1Z>00Ao`000003o`1n5ol0003o08L400?o08L4
00?o0000oa>A0?lCT@000_lCT@000ol0003o<Y`0oc:L0003oc:L0003o`000?mFZ03oEZP000;oEZP0
0ol00002oejZ0003o`000?n=]`3oSKL000?oSKL000?o0000ol740?o1a0000_o1a003o`000003olVi
0?l0003o000000CoeYL000?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`000006ooooool0003o0000o`000?ob>@3o00001Oo]B`000ol0003oiel0onMO0002onMO00Co
00000_oGU0000ol0003od:P0om2X0003om2X0003o`000?o9^@3obKT000;obKT000Co0000oko30?no
``3o_l<00ol00004og2_0003o`000?mNZP3oGZX000;oGZX000?o0000oe2V0?m@YP000_m@YP02o`00
00?o6I<000?o0000oa>A0?lCT@001?lCT@02o`0000?o084B00?o0000o`224?l0PQ000ol0PQ000ol0
003o07DXo`1e:004o`1e:003o`000?l0NB;o000000?o06Xh00?o0000o`1`<?l0L3000_l0L3001?l0
003o06=1o`1S@Ol00004o`1Y>@04o`000?l0GTGo05i5o`0000?o06Ll00?o0000o`1LA_l0G4H00_l0
G4H00ol0003o06Llo`000006o`1NA@03o`000?l0Ed[o000000Co06=100?o0000o`1MA_l0GDH00ol0
GDH4o`000003o`1W??l0003o06@o00Co06@o00?o0000o`1S?ol0Hcl00ol0Hcl00ol0003o06@oo`1T
?`02o`1T?`Wo00000ol0NB800ol0003o07dIo`1m6@02o`1m6@03o`000?l0Q0co08@<00;o08@<00Co
0000o`B;0?l4R`3o18/01_l000000ol0Q`Co0000oa>A0003oa>A0003o`000?lbW03o<Y`000;o<Y`0
00?o0000oeJX0?mFZ0000_mFZ0000ol0003oPK@0oh6d0003o`0000GoSKL000?o0000ol740?o1a000
0_o1a0000ol0003od:P0om2X0003o`0000GoeYL000?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`07ooooo`007Oooool01?l0003oooooooooooooool2o`0000CokD/000?o0000onMO0?oWG`00
0_oWG`000ol0003ohG<0on5c0002on5c00?o00001?o@Z0000ol0003obKT0olVi0002olVi0003o`00
0?no``3o_l<000?o_l<000Ko0000ojRn0?l0003o0000og2_0?l00004oejZ0003o`000?m@YP3oD:H0
00?oD:H000Go0000odJS0?l0003o6I<0o`000006oa>A0006o`000?lBT@3o4Y40o`000?l0PA;o0000
1Ol0PQ02o`0000Go07DX00Oo0000o`1i8_l0NB;o07TRo`000?l0JSSo000000Go070`00?o0000o`1S
@Ol000001Ol0JCT00ol0003o05i5o`000005o`1W?004o`000?l0G4Ko05a6o`0000?o06Ll00?o0000
o`1NAOl0GTD00ol0GTD2o`0000Go06=100?o0000o`1MA_l0GDH00_l0GDH2o`0000Go06Ll00?o0000
o`1T?ol0I3l00ol0I3l00ol0003o06<oo`1S?`02o`1S?`03o`000?l0I3oo000000;o000000?o07</
o`000?l0MBP00ol0MBP00ol0003o07TRo`1i8P03o`1i8P03o`000?l0OAWo07dI00?o07dI00?o0000
o`243?l0Q0`00_l0Q0`00ol0003o18/0o`B;0002o`B;0004o`000?lJU03o6Y@0oaZD00Go000000?o
4i40o`000?lbW0001?lbW0000ol0003oEZP0oeJX0002oeJX0003o`000?n1]03oPK@000;oPK@01?l0
00000on=]`3o0000ol740004ol740003o`000?o@Z03od:P000;od:P01?l000000ooFU`3o0000oooo
o`0=ooooo`03o`000?oooooooooo00Oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00000
0oo]B`3o0000onMO0003onMO0003o`000?oQL`3ohG<000?ohG<000?o0000om^60?oKQP000_l00000
0oo@Z03o0000olVi0003olVi0003o`000?no``3o_l<000?o_l<000Co0000ojRn0?nX_P3oZ;h00ol0
0003oejZ0003o`000?m@YP3oD:H000?oD:H000Co0000odJS0?m6X`3oAZ<00_l00005oa>A0003o`00
0?lBT@3o4Y4000;o4Y4000?o0000o`224?l0PQ000ol0PQ001?l0003o08@<o`243?l00003o`1e:003
o`000?l0NB;o07TR00?o07TR00?o0000o`1`<?l0L3001Ol0L3000ol0003o06Tio`1Y>@04o`1Y>@;o
00001_l0Ic`00ol0003o05a6o`000005o`1W?003o`000?l0GTGo05i500;o000000?o06Tio`000?l0
Hd401?l0Hd400ol0003o05e6o`1MAP02o`000003o`1Z>?l0003o06Ll00Co06Ll00?o0000o`1T?ol0
I3l00ol0I3l01?l0003o06<oo`1S?ol0Hcl3o`0000Go07</00?o0000o`1e:?l0MBP00_l0MBP00ol0
003o07TRo`1i8P03o`1i8P03o`000?l0OAWo07dI00;o07dI00?o0000o`243?l0Q0`00_l0Q0`00ol0
003o18/0o`B;0003o`B;0005o`000?lJU03o6Y@0oaZD0?l000000olfW@06o`000003oc:L0?l0003o
EZP000?oEZP000?o0000oh6d0?n1]0000_n1]0001?l0003o/<00ok300?n``005o`0000;o`L@000?o
0000om2X0?o@Z0000_o@Z0001?l0003ofhH0om^60?oKQP03o`0000gooooo00?o0000ooooooooool0
1oooool001oooooo00?o0000ooooooooool00oooool3o`0000;oiel000?o0000on5c0?oQL`000ooQ
L`000ol0003ofhH0om^60003om^600?o00000_o9^@000ol0003o_l<0oko30003oko30005o`000?nX
_P3oZ;h0ojRn0?l000000onE^@000ol0003oGZX0o`000005oe2V0003o`000?m6X`3oAZ<000;oAZ<0
00?o0000od6Q0?l000000olCT@000ol0003o4Y40oa:A0003oa:A00;o00000ol0PQ000ol0003o08@<
o`243002o`243003o`000?l0MBSo000000Go07TR0_l00006o`1`<0;o00001Ol0JCT00ol0003o078]
o`000006o`1W?0;o00001_l0Ic`00ol0003o05i5o`000004o`1Y>@03o`000?l0Hd7o06=100?o06=1
0_l00004o`1Z>003o`000?l0Icco06Ll00?o06Ll00?o0000o`1T?ol0I3l00_l0I3l4o`0000;o078]
00?o0000o`1c;?l0Lb`00ol0Lb`00ol0003o07DXo`1e:002o`1e:003o`000?l0NB;o07TR00?o07TR
00?o0000o`1m6Ol0OAT00ol0OAT00ol0003o08@<o`243002o`243003o`000?l4R`3o18/000;o18/0
00?o0000oaZD0?lJU0000_lJU0000ol0003o=Yd0ocJM0002ocJM0004o`000?mFZ03oEZP0oeJX00Go
00000_mFZ0000ol0003oPK@0oh6d0002oh6d0003o`000?n``03o/<0000;o/<0000?o0000olbc0?o<
/`000ol00005om2X0003o`000?oKQP3ofhH000;ofhH000?o0000ooooooooool02oooool00ol0003o
ooooooooo`07ooooo`008?ooool2o`0000Kooooo0ol00004on5c0003o`000?oKQP3ofhH000?ofhH0
00Co0000omJG0?oFU`3oeYL00ol00004oko30005o`000?nX_P3oZ;h0ojRn0?l000001OnE^@02o`00
00CoD:H000?o0000odJS0?m6X`000_m6X`001ol0003o@J40od6Q0?m1X@3o0000oa>A0?l000001OlB
T@001_l0003o4i40oa>A0?l0003o088@o`0000Ko08@<00?o0000o`1i8_l0NB800ol0NB801?l0003o
07dIo`1m6Ol00004o`1`<004o`000?l0MRKo07HVo`0000?o06Ti00Go0000o`1b;Ol0LRgo078]o`00
0004o`1W?003o`000?l0L2oo000000Ko06Ll0_l00005o`1Y>@03o`000?l0Hd7o06=100;o06=10_l0
0005o`1Z>003o`000?l0Icco06Ll00?o06Ll00?o0000o`1T?ol000000_l000000ol0Lbco0000o`1b
;@04o`1b;@03o`000?l0Lbco07</00?o07</00?o0000o`1e:?l0MBP00_l0MBP00ol0003o07TRo`1i
8P02o`1i8P03o`000?l0OAWo07dI00?o07dI00?o0000o`243?l0Q0`00_l0Q0`00ol0003o18/0o`B;
0002o`B;0003o`000?lJU03o6Y@000;o6Y@000?o0000ocJM0?lfW@000olfW@000ol0003oEZP0oeJX
0002oeJX0003o`000?ml/P3oO;8000?o00001On1]0000ol0003o/<00ok300002ok300003o`000?o<
/`3oc;<000;oc;<01?l000000oo@Z03o0000o`000004om^60003o`000?oooooooooo00[ooooo00?o
0000ooooooooool01oooool002;ooooo00?o0000ooooooooool01_ooool2o`000003on5c0?l0003o
fhH000CofhH000Go0000omJG0?oFU`3oeYL0o`000003om2V00;o000000?o_l<0o`000?nX_P000_nX
_P000ol0003oUKT0oiFi0003oiFi0003o`000?n7]@3oQkD000;o000000?oD:H0o`000?m6X`000om6
X`000ol0003o@J40od6Q0003od6Q0003o`000?lBT@3o4Y4000?o4Y4000?o0000oa>A0?lCT@000_lC
T@000ol0003o08@<o`243004o`243003o`000?l0Q`Co000000?o07TR00?o0000o`1m6Ol0OAT00_l0
OAT01?l0003o070`o`1`<?l00004o`1f9P03o`000?l0JCWo000000Go078]00Co0000o`1W??l0Icco
00000ol0L2l00ol0003o06Llo`1W?002o`1W?003o`000?l0LRgo000000Go06Ti00?o0000o`1S@Ol0
Hd400_l000000ol0L33o0000o`1Z>005o`1Z>003o`000?l0Icco06Ll00;o06Ll0_l00005o`1c;003
o`000?l0LRgo078]00;o078]00?o0000o`1c;?l0Lb`00ol0Lb`00ol0003o07DXo`1e:002o`1e:003
o`000?l0NB;o07TR00?o07TR00?o0000o`1m6Ol0OAT00_l0OAT00ol0003o08@<o`243002o`243003
o`000?l4R`3o18/000?o18/000?o0000oaZD0?lJU0000_lJU0000ol0003o=Yd0ocJM0002ocJM0003
o`000?mFZ03oEZP000?oEZP000?o0000ogbb0?ml/P000_ml/P04o`000003oh6d0?l0003o/<0000?o
/<0000?o0000olbc0?o</`000_o</`001?l0003oei@0omND0?oGU005o`0000?ofhH000?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`008oooool00ol0003oooooooooo`07ooooo`;o
00001?oKQP001Ol0003oeYL0omJG0?oFU`3o000000God:H01?l000000onX_P3o0000oiFi0004oiFi
0003o`000?n7]@3oQkD000?oQkD00_l00003odJS0003o`000?m1X@3o@J4000?o@J4000?o0000ocnQ
0?l000000olBT@000ol0003o4i40oa>A0003oa>A0003o`000?l0Q0co08@<00?o08@<00Oo0000o`27
1?l0Q`Co08L4o`000?l0NB;o000000Go07dI00?o0000o`1`<?l000001_l0MRH00ol0003o078]o`1b
;@04o`1b;@03o`000?l0Icco000000Go070_00Co0000o`1W??l0Icco00000ol0LRd00ol0003o06Ti
o`1Y>@03o`1Y>@;o00001?l0L3000ol0003o06Xho`1Z>003o`1Z>003o`000?l0Icco000000;o0000
00?o07DXo`000?l0Lb`01?l0Lb`00ol0003o078]o`1b;@03o`1b;@03o`000?l0Lbco07</00;o07</
00Co0000o`1e:?l0MBSo07DX6ol000000olJU03o0000ocJM0004ocJM0003o`000?mFZ03oEZP000;o
EZP000?o0000ogbb0?ml/P000_ml/P001?l0003oZ;h0ojRn0?nX_P05o`0000;o/<0000?o0000olbc
0?o</`000_o</`000ol0003oei@0omND0002omND00;o000000?ohG<0o`000?l000000_l0000<oooo
o`03o`000?oooooooooo00Kooooo000Tooooo`03o`000?oooooooooo00Sooooo0_l000000ooKQP3o
0000omJG0002omJG0003o`000?o@YP3od:H000?od:H000?o0000olbc0?o</`000_o</`02o`0000Co
UKT000?o0000ohNe0?n7]@000on7]@001_l0003oO;80ogbb0?l0003oAZ<0o`0000Go@J4000Oo0000
ocnQ0?loX@3o?j40o`000?lBT@3o000000Go4i4000?o0000oaVC0?l000000ol0Q0`00ol0003o08L4
o`271003o`271003o`000?l0OAWo07dI00Go07dI00?o0000o`1f9_l0MRH01?l0MRH2o`0000Ko078]
0_l00006o`1`;`03o`000?l0Icco000000Co078]00?o0000o`1Y>Ol0JCT00_l0JCT2o`0000Go070`
00?o0000o`1Z>?l0JSP00ol0JSP2o`0000Go07DX00?o0000o`1c;?l0Lb`00ol0Lb`00ol0003o078]
o`1b;@02o`1b;@04o`000?l0Lbco07</o`1c;0Go00000_l0Q0`00ol0003o08L4o`271002o`271003
o`000?l6S03o1X`000?o1X`000?o0000oaFB0?lETP000_lETP000ol0003o:9T0obRI0002obRI0004
o`000?m1X@3o@J40od6Q00Ko000000?o=Yd0o`000?mFZ0000omFZ0000ol0003oO;80ogbb0003ogbb
0003o`000?nX_P3oZ;h000;oZ;h000?o0000olVj0?o9^P000ol00005olbc0003o`000?oGU03oei@0
00;oei@00_l00003on5c00;o00002oooool00ol0003oooooooooo`06ooooo`009Oooool2o`0000[o
oooo0ol000000ooFU`3o0000om2V0004om2V0003o`000?o</`3oc;<000?oc;<000Ko0000olNm0?l0
003o0000oiFi0?l00005ohNe0003o`000?ml/P3oO;8000;oO;8000?o0000od6Q0?m1X@000om1X@00
0ol0003o?j40ocnQ0003ocnQ0003o`000?lCT@3o4i4000?o4i4000Oo0000oaVC0?lIT`3o6I<0o`00
0?l0Q0co000000Ko08L400?o0000o`1m6Ol0OAT01?l0OAT2o`0000Go07HV00Co0000o`1n5ol0OQOo
00001?l0LRd00ol0003o07/Mo`000006o`1`;`;o00001Ol0LRd00ol0003o06Tio`1Y>@02o`000003
o`1f9_l0003o070`00Go070`00?o0000o`1Z>?l0JSP00_l000000ol0NB;o0000o`1e:004o`1e:003
o`000?l0Lbco07</00?o07</00?o0000o`1b;Ol0LRd00_l0LRd4o`0000;o088@00?o0000o`243?l0
Q0`00ol0Q0`00ol0003o08L4o`271002o`271003o`000?l6S03o1X`000?o1X`000?o0000oaFB0?lE
TP000_lETP000ol0003o:9T0obRI0002obRI0003o`000?m1X@3o@J4000;o@J4000Co0000oejZ0?mN
ZP3oGZX01_l000000omFZ03o0000ogbb0003ogbb0003o`000?nX_P3oZ;h000?oZ;h000?o0000olVj
0?o9^P000_o9^P04o`000003olbc0?l0003oei@000Coei@00_l00003on5c0003o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool02_ooool2o`0000Co
d:H000?o0000olbc0?o</`000oo</`000ol0003oakd0olNm0002olNm0003o`000?n7]@3oQkD000?o
QkD000?o0000ogbb0?ml/P000oml/P02o`0000?o@J4000?o0000ocnQ0?loX@001?loX@02o`0000?o
4i4000?o0000oaVC0?lIT`000olIT`000ol0003o08L4o`271004o`271003o`000?l6S03o000000Co
07dI00Co0000o`243?l0Q0co00000ol0MRH00ol0003o07hGo`1n5`02o`1n5`04o`000?l0LRgo078]
o`0000?o07/M00?o0000o`1`;ol0L2l00_l0L2l00ol0003o07/Mo`000006o`1b;@;o00001?l0MRH0
0ol0003o070`o`1`<003o`1`<003o`000?l0JSSo000000Co07TR00?o0000o`1e:?l0MBP00ol0MBP0
0ol0003o07</o`1c;002o`1c;003o`000?l0LRgo000000;o000000?o084Bo`000?l0PQ000ol0PQ00
0ol0003o08@<o`243003o`243003o`000?l0Q`Co08L400;o08L400?o0000o`J<0?l6S0000ol6S000
0ol0003o5I80oaFB0002oaFB0003o`000?lXV@3o:9T000;o:9T000?o0000od6Q0?m1X@000om1X@00
0ol0003oGZX0oejZ0002oejZ0004o`000?n1]03oPK@0oh6d00Go000000?oO;80o`000?nX_P001?nX
_P000ol0003obKX0olVj0002olVj0004o`000?oCW@3odid0om>M00Ko000000Coei@0o`000?oQL`3o
00000ooQL`000ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`00
0?oooooooooo00_ooooo0_l000000oo@YP3o0000olbc0004olbc0003o`000?o7_@3oakd000?oakd0
0_l00003ohNe0003o`000?ml/P3oO;8000?oO;8000Ko0000ogJa0?mf/@3o0000od6Q0?l00006ocnQ
0006o`000?m1X@3o@J40o`000?lCT@3o00001_lIT`000ol0003o08L4o`271003o`271005o`000?l6
S03o1X`0o`J<0?l000000_l0OAT00ol0003o08@<o`243002o`243003o`000?l0MRKo000000Go07hG
00?o0000o`1b;Ol000001Ol0Nad01?l0003o070_o`1`;ol00003o`1k7@03o`000?l0LRgo078]00;o
078]0_l00005o`1f9P03o`000?l0L33o070`00?o070`0_l00005o`1i8P03o`000?l0MBSo07DX00?o
07DX00?o0000o`1c;?l0Lb`00_l0Lb`2o`0000Co084B00?o0000o`224?l0PQ000ol0PQ000ol0003o
08@<o`243003o`243003o`000?l0Q`Co08L400;o08L400?o0000o`J<0?l6S0000_l6S0000ol0003o
5I80oaFB0003oaFB0003o`000?lXV@3o:9T000;o:9T000?o0000od6Q0?m1X@000_m1X@000ol0003o
GZX0oejZ0003oejZ0005o`000?n1]03oPK@0oh6d0?l000000onX_P05o`0000;oZ;h000?o0000olVj
0?o9^P000oo9^P000ol0003odid0om>M0002om>M0004o`000?oNOP3ogWh0omin00Ko000000?ohG<0
o`000?ooool02Oooool00ol0003oooooooooo`06ooooo`00:Oooool00ol0003oooooooooo`0<oooo
o`;o00001?o</`000ol0003oakd0olNm0003olNm0006o`000?o3a03o`l@0o`000?n7]@3o00001Oml
/P000ol0003oM[40ogJa0002ogJa00;o00001OloX@000ol0003o@J40od6Q0002od6Q0003o`000?lI
T`3o6I<000Co6I<000?o0000ob6G0?l000000ol0Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?l0
OAWo000000Ko08@<00?o0000o`1n5ol0OQL01Ol0OQL00ol0003o07/Mo`1k7@04o`1k7@03o`000?l0
L2oo000000Co07/M00Oo0000o`1b;Ol0LRgo078]o`000?l0OQOo000000Ko07HV00?o0000o`1`<?l0
L3000_l000000ol0OAWo0000o`1i8P05o`1i8P03o`000?l0MBSo07DX00;o07DX00?o0000o`1c;?l0
00000_l000000ol0PQ3o0000o`214P04o`214P03o`000?l0PQ3o088@00;o088@00?o0000o`243?l0
Q0`00ol0Q0`00ol0003o08L4o`271002o`271003o`000?l6S03o1X`000?o1X`000?o0000oaFB0?lE
TP000_lETP000ol0003o:9T0obRI0002obRI0003o`000?m1X@3o@J4000?o@J4000?o0000oejZ0?mN
ZP000_mNZP000ol0003oPK@0oh6d0002oh6d0003o`000?nX_P3oZ;h000;oZ;h000?o0000olRl0?o8
_0001?l00004olVj0003o`000?oCW@3odid000?odid000?o0000omin0?oNOP000_oNOP001?l0003o
iel0o`000?oWG`03o`0000Wooooo00?o0000ooooooooool01_ooool002[ooooo0_l0000>ooooo`;o
000000?oc;<0o`000?o7_@001?o7_@000ol0003o`l@0ol?40002ol?400;o00001?ml/P000ol0003o
M[40ogJa0002ogJa0004o`000?md/03oM;00o`0000?o?j4000?o0000od6Q0?m1X@000om1X@000ol0
003o6I<0oaVC0003oaVC0007o`000?lQU`3o8IL0ob6G0?l0003o08L4o`000006o`J<0003o`000?l0
Q0co08@<00Co08@<0_l00006o`1n5`;o00001ol0Nad00ol0003o07/Mo`1k7@03o`1k7@04o`000?l0
LRgo078]o`0000?o07hG00?o0000o`1f9_l0MRH00ol0MRH00ol0003o070`o`000004o`1m6@03o`00
0?l0NB;o07TR00?o07TR00?o0000o`1e:?l0MBP00_l0MBP2o`0000Go088@00?o0000o`214_l0PA80
0_l0PA800ol0003o088@o`224002o`224003o`000?l0Q0co08@<00?o08@<00Co0000o`271?l0Q`Co
08L44_l00005od6Q0003o`000?mNZP3oGZX000;oGZX000?o0000oh6d0?n1]0000_n1]0000ol0003o
Z;h0ojRn0003ojRn0003o`000?o8_03ob;`000;ob;`01?l000000oo9^P3o0000om>M0004om>M0003
o`000?oNOP3ogWh000?ogWh000?o0000onMO0?l000000_oWG`000ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo000/ooooo`03o`000?oooooooooo00gooooo0_l00004olNm0003o`00
0?o3a03o`l@000;o`l@000?o0000okS20?nh`P000_l000000oml/P3o0000ogJa0003ogJa0003o`00
0?md/03oM;0000;oM;0000?o0000ocnQ0?l000001Om1X@000ol0003oAZ<0o`000003oaVC0003o`00
0?lQU`3o8IL000?o8IL000?o0000o`J<0?l6S0001?l6S002o`0000Go08@<00Co0000o`B;0?l4R`3o
00001?l0OQL01?l0003o08L4o`271?l00005o`1k7@;o00001_l0Nad2o`0000Co07hG00?o0000o`1f
9_l0MRH00ol0MRH2o`0000Go07dI00?o0000o`1i8_l0NB800ol0NB800ol0003o07DXo`000002o`00
0003o`243?l0003o088@00Co088@00?o0000o`214_l0PA800_l0PA800ol0003o088@o`224003o`22
4003o`000?l0Q0co08@<00Ko00000_lQU`000ol0003o;Y/0objK0002objK0003o`000?loX@3o?j40
00?o?j4000Co0000oeBW0?mDY`3oE:L02ol000000omNZP3o0000oh6d0003oh6d0003o`000?nX_P3o
Z;h000;oZ;h000?o0000olRl0?o8_0000_o8_0001?l0003odZ80om:R0?oBXP06o`000003om>M0?l0
003ogWh000CogWh000?o0000onMO0?l000000ooWG`000ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo000]ooooo`03o`000?oooooooooo00kooooo0_l000000oo7_@3o0000ol?40003
ol?40003o`000?nh`P3o^<8000?o^<800_l00003ogJa0003o`000?md/03oM;0000?oM;000_l00005
od6Q0007o`000?m6X`3oAZ<0odJS0?l0003o6I<0o`000005ob6G00;o00001Ol6S0001?l0003o5I80
oaFB0?l00003o`243003o`000?l4R`3o18/000;o18/000Co0000o`1n5ol0OQOo00000ol0Q`@00ol0
003o07/Mo`1k7@02o`1k7@04o`000?l0QPOo08H7o`0000Co07/M0_l00006o`1n5`03o`000?l0MRKo
07HV00;o000000?o08@<o`000?l0OAT01Ol0OAT00ol0003o07TRo`1i8P02o`1i8P;o00001Ol0Q0`0
0ol0003o088@o`224002o`224003o`000?l0PA;o084B00?o084B00?o0000o`224?l0PQ001Ol00003
oaVC0003o`000?lQU`3o8IL000?o8IL000?o0000objK0?l^V`000_l^V`000ol0003o?j40ocnQ0002
ocnQ0003o`000?mDY`3oE:L000;oE:L000?o0000ofj_0?m^[`000om^[`001?l0003oSKL0ohfg0?n=
]`05o`000003oh6d0?l0003oZ;h000CoZ;h000?o0000olRl0?o8_0000_o8_0000ol0003odZ80om:R
0002om:R0004o`000?oLQ@3og8D0omb500Ko000000GogWh0o`000?oWG`3oiel0o`000002onMO0003
o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool002kooooo00?o0000ooooooooool0
3oooool2o`0000?o`l@000?o0000okS20?nh`P000onh`P001_l0003o//00ok;00?l0003oM[40o`00
00GoM;0000Co0000ogJa0?mf/@3o00000om1X@000ol0003oAZ<0odJS0003odJS0003o`000?lQU`3o
8IL000?o8IL000Co0000objK0?l^V`3o00000ol6S0000ol0003o5I80oaFB0002oaFB0003o`000?l0
Q0co000000Go18/000?o0000o`1n5ol000001Ol0Q`@01?l0003o07/Mo`1k7Ol00003o`261`07o`00
0?l0Nago07/Mo`1k7Ol0003o08L4o`000006o`1n5`03o`000?l0MRKo000000Co08@<00?o0000o`1m
6Ol0OAT00ol0OAT00ol0003o07TRo`000002o`000003o`271?l0003o08@<00Co08@<00?o0000o`22
4?l0PQ000ol0PQ000ol0003o084Bo`214P05o`0000;o4i4000?o0000oaVC0?lIT`000olIT`000ol0
003o8IL0ob6G0003ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o0000ocnQ0?loX@000oloX@000ol0
003oE:L0oeBW0002oeBW0003o`000?m^[`3oKZl000;oKZl000?o0000ohfg0?n=]`000_n=]`001?l0
003o/<00ok300?n``006o`000003ojRn0?l0003ob;`000Cob;`000?o0000om:R0?oBXP000_oBXP00
0ol0003og8D0omb50002omb50004o`000?oUI`3oiFL0onEW00Ko000000?oiel0o`000?ooool02?oo
ool00ol0003oooooooooo`05ooooo`00;oooool00ol0003oooooooooo`0@ooooo`03o`000?o3a03o
000000Go^<8000?o0000ok;00?nb`0000_nb`0000ol0003oM;00ogB`0003ogB`0003o`000?mf/@3o
M[4000;oM[4000?o0000od6Q0?l000001Om6X`000ol0003oD:H0o`000003ob6G0003o`000?l^V`3o
;Y/000;o;Y/000?o0000o`J<0?l000001_lETP000ol0003o18/0o`B;0005o`B;0003o`000?l0Q`Co
08L400Co08L400?o0000o`1k7Ol000001?l0QPL01?l0003o07/Mo`1k7Ol00003o`271003o`000?l0
OQOo07hG00?o07hG0_l00005o`243003o`000?l0OAWo07dI00?o07dI0_l00005o`271003o`000?l0
Q0co08@<00;o08@<00?o0000o`224?l0PQ000_l0PQ04o`0000;o4Y4000?o0000oa>A0?lCT@000olC
T@000ol0003o6I<0oaVC0003oaVC0003o`000?lQU`3o8IL000?o8IL000?o0000objK0?l^V`000_l^
V`000ol0003o?j40ocnQ0002ocnQ0003o`000?mDY`3oE:L000;oE:L000?o0000ofj_0?m^[`000om^
[`000ol0003oSKL0ohfg0002ohfg0003o`000?n``03o/<0000;o/<0000Co0000olVj0?o9^P3obKX0
1_l000000oo8_03o0000om:R0004om:R0003o`000?oLQ@3og8D000;og8D000?o0000onEW0?oUI`00
0_oUI`001?l0003okD/0one;0?o]B`03o`0000Sooooo00?o0000ooooooooool01Oooool0033ooooo
0_l0000Aooooo`;o00001?nh`P000ol0003o//00ok;00003ok;000;o00000omd/0000ol0003oM[40
ogJa0004ogJa0003o`000?m6X`3oAZ<000?oAZ<000Oo0000oe2V0?m@YP3oD:H0o`000?lQU`3o0000
00Ko;Y/000?o0000oaFB0?lETP001?lETP02o`0000Ko18/00_l00006o`2710;o00001_l0QPL2o`00
00Co08L400?o0000o`1n5ol0OQL00_l0OQL00ol0003o18/0o`000006o`243003o`000?l0OAWo07dI
00;o000000?o1X`0o`000?l0Q`@01?l0Q`@00ol0003o08@<o`243003o`2430Co000000?o4i40o`00
0?lBT@001?lBT@000ol0003o4i40oa>A0002oa>A0003o`000?lIT`3o6I<000?o6I<000?o0000ob6G
0?lQU`000olQU`000ol0003o;Y/0objK0002objK0003o`000?loX@3o?j4000;o?j4000?o0000oeBW
0?mDY`000omDY`000ol0003oKZl0ofj_0002ofj_0003o`000?n=]`3oSKL000;oSKL000?o0000ok30
0?n``0000on``0000ol0003obKX0olVj0002olVj0004o`000?oBXP3odZ80om:R00Ko000000?odZ80
o`000?oLQ@001?oLQ@000ol0003oiFL0onEW0002onEW0006o`000?o]B`3okD/0o`000?o]B`3o0000
2?ooool00ol0003oooooooooo`05ooooo`00<_ooool00ol0003oooooooooo`0@ooooo`;o000000?o
^<80o`000?nb`0001?nb`0001_l0003o/<00ok300?l0003oM;00o`0000KoM[4000?o0000ogbb0?l0
00000om6X`000ol0003oD:H0oe2V0003oe2V0003o`000?l^V`3o;Y/000Co;Y/00_l00005oaFB0004
o`000?lXV@3o:9T0o`0000Co18/000Co0000oaZD0?lJU03o00001?l0Q`@00ol0003o4i40o`000006
o`261`03o`000?l0Q`Co08L400Co08L400Co0000o`1n5ol0OQOo00000ol4R`000ol0003o08@<o`24
3003o`243003o`000?l0OAWo000000?o1X`000?o0000o`271?l0Q`@00ol0Q`@00ol0003o08@<o`24
3002o`2430;o00001OlCT@000ol0003o4Y40oa:A0002oa:A0003o`000?lCT@3o4i4000?o4i4000?o
0000oaVC0?lIT`000_lIT`000ol0003o8IL0ob6G0003ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o
0000ocnQ0?loX@000oloX@000ol0003oE:L0oeBW0002oeBW0003o`000?m^[`3oKZl000;oKZl000?o
0000ohfg0?n=]`000on=]`000ol0003o/<00ok300002ok300003o`000?o9^P3obKX000?obKX000?o
0000om:R0?oBXP000_oBXP001?l0003ofhL0om^70?oKQ`06o`000003omb50?l0003oiFL000CoiFL0
00Ko0000one;0?o]B`3o0000one;0?l00007ooooo`03o`000?oooooooooo00Gooooo000cooooo`03
o`000?oooooooooo017ooooo00?o0000ok;00?nb`0000onb`0000ol0003o/<00ok300002ok3000;o
00001Omf/@001ol0003oO;80ogbb0?ml/P3o0000odJS0?l000001_m@YP000ol0003o;Y/0objK0003
objK0004o`000?loX@3o?j40o`0000?o5I8000?o0000obRI0?lXV@000_lXV@001?l0003o18/0o`B;
0?l00004oaZD0004o`000?l0Q`Co08L4o`0000?o4i4000?o0000o`261ol0QPL00_l0QPL2o`0000Ko
08L400?o0000o`1n5ol000001?l4R`000ol0003o08@<o`243003o`2430;o00001Ol6S0000ol0003o
08L4o`271003o`2710Co000000?o6I<0o`000?lCT@001?lCT@000ol0003o4Y40oa:A0003oa:A0003
o`000?lCT@3o4i4000;o4i4000?o0000oaVC0?lIT`000olIT`000ol0003o8IL0ob6G000Go`000003
ofj_0?l0003oSKL000?oSKL000?o0000ok300?n``0000on``0000ol0003obKX0olVj0002olVj0003
o`000?oBXP3odZ8000?odZ8000?o0000om^70?oKQ`000_oKQ`001?l0003ohf`0on=/0?oSK006o`00
0003onEW0?l0003okD/000;okD/000?o0000one;0?l000001oooool00ol0003oooooooooo`04oooo
o`00=?ooool00ol0003oooooooooo`0Aooooo`05o`000?nb`03o//00ok;00?l000001On``0000ol0
003o//00o`000003ogJa0003o`000?ml/P3oO;8000?oO;8000?o0000oe2V0?m@YP001?m@YP000ol0
003oGZX0o`000003objK0003o`000?loX@3o?j4000;o?j4000?o0000oaFB0?l000001OlXV@000ol0
003o18/0o`000005oaZD0003o`000?l0Q`Co000000Go4i4000Co0000o`261ol0QPOo00000_lCT@00
0ol0003o08L4o`271003o`2710;o00001_l4R`000ol0003o08@<o`243002o`000003oaFB0?l0003o
1X`000Co1X`000?o0000o`271?l0Q`@00_l0Q`@2o`0000Go6I<000?o0000oa>A0?lCT@000olCT@00
0ol0003o4Y40oa:A0002oa:A0003o`000?lCT@3o4i4000;o4i4000Co0000oaVC0?lIT`3o6I<01Ol0
0003oe2V0003o`000?mNZP3oGZX000;oGZX000?o0000og2_0?m`[`000_m`[`000ol0003oQkD0ohNe
0003ohNe0004o`000?nR_03oX[`0oj:l00_o000000?o/<00o`000?o9^P000oo9^P000ol0003odZ80
om:R0003om:R0003o`000?oKQ`3ofhL000?ofhL000?o0000on=/0?oSK0000_oSK0001?l0003oje40
on]A0?o[D@09o`0000Kooooo00?o0000ooooooooool01?ooool003Gooooo0_l0000Booooo`03o`00
0?nb`03o000000Go/<0000Oo0000ok;00?nb`03o//00o`000?mf/@3o000000KoO;8000?o0000oe2V
0?m@YP000om@YP001ol0003oGZX0oejZ0?mNZP3o0000objK0?l000001_loX@000ol0003o:9T0obRI
0005obRI0003o`000?lJU03o6Y@000Go6Y@000?o0000oa>A0?lCT@001?lCT@000ol0003o08H7o`00
0003oa>A0003o`000?l0Q`Co08L400;o08L400?o0000oaZD0?l000001_l4R`000ol0003o08@<o`00
0003oaFB0003o`000?l6S03o1X`000?o1X`000?o0000o`271?l0Q`@00_l000000olQU`3o0000oaVC
0004oaVC0003o`000?lCT@3o4i4000?o4i4000?o0000oa:A0?lBT@000_lBT@001?l0003o4i40oa>A
0?lCT@05o`0000;oAZ<000?o0000oe2V0?m@YP000om@YP000ol0003oGZX0oejZ0002oejZ0003o`00
0?m`[`3oL:l000?oL:l000?o0000ohNe0?n7]@000_n7]@000ol0003oX[`0oj:l0002oj:l0003o`00
0?o1a03o`L@000?o`L@000Co0000olbc0?o</`3oc;<01_l000000oo9^P3o0000om:R0003om:R0003
o`000?oKQ`3ofhL000?ofhL000?o0000on=/0?oSK0000ooSK0000ol0003oje40on]A0002on]A0007
o`000?ob>@3olST0oo8i0?l0003olST0o`000006ooooo`03o`000?oooooooooo00Cooooo000goooo
o`03o`000?oooooooooo013ooooo00?o0000ok300?n``0000on``0000ol0003o//00ok;00003ok;0
0003o`000?ml/P3oO;8000CoO;8000?o0000ohNe0?l000000om@YP000ol0003oGZX0oejZ0003oejZ
0003o`000?loX@3o?j4000Go?j4000?o0000obRI0?lXV@001?lXV@02o`0000Ko6Y@00_l00006oa>A
00;o00001OlCT@001?l0003o08L4o`271?l00003oaZD0003o`000?l4R`3o18/000?o18/00_l00005
oaFB0003o`000?l6S03o1X`000?o1X`00_l00004ob6G0003o`000?lIT`3o6I<000?o6I<000?o0000
oa>A0?lCT@000_lCT@001?l0003o4Y40oa:A0?lBT@05o`0000;o@J4000?o0000odJS0?m6X`000om6
X`000ol0003oD:H0oe2V0003oe2V0003o`000?mNZP3oGZX000;oGZX000?o0000og2_0?m`[`000_m`
[`000ol0003oQkD0ohNe0003ohNe0003o`000?nR_03oX[`000;oX[`000?o0000ol740?o1a0000oo1
a0000ol0003oc;<0olbc0002olbc0004o`000?oCW@3odid0om>M00Go00000_oBXP000ol0003ofhL0
om^70002om^70003o`000?oSK03ohf`000?ohf`000?o0000on]A0?o[D@000oo[D@001ol0003olST0
oo8i0?ob>@3o0000oo8i0?l000001Oooool00ol0003oooooooooo`04ooooo`00>?ooool00ol0003o
ooooooooo`0@ooooo`05o`000?n``03o/<00ok300?l000001_nb`0000ol0003oO;80ogbb0003ogbb
0007o`000?n7]@3oQkD0ohNe0?l0003oD:H0o`000006oejZ0003o`000?loX@3o?j4000Co?j4000?o
0000oeBW0?l000001?lXV@001?l0003o@J40od6Q0?l00004oaZD0004o`000?lfW@3o=Yd0o`0000Co
4i4000?o0000oc:L0?l000001OlCT@000ol0003o08L4o`000004oaZD0003o`000?l4R`3o18/000;o
18/000?o0000obRI0?l000001OlETP000ol0003o1X`0o`J<0002o`J<00;o00001OlQU`000ol0003o
6I<0oaVC0003oaVC0003o`000?lCT@3o4i4000;o4i401?l00002ocnQ0003o`000?m1X@3o@J4000?o
@J4000?o0000odJS0?m6X`000_m6X`000ol0003oD:H0oe2V0003oe2V0003o`000?mNZP3oGZX000;o
GZX000?o0000og2_0?m`[`000om`[`000ol0003oQkD0ohNe0002ohNe0003o`000?nR_03oX[`000;o
X[`000?o0000ol740?o1a0000oo1a0000ol0003oc;<0olbc0003olbc0005o`000?oCW@3odid0om>M
0?l000000ooLQ@0<o`000003on=/0?l0003oje4000Coje4000?o0000oo8i0?ob>@000_ob>@02o`00
00Gooooo00?o0000ooooooooool01?ooool003Wooooo00?o0000ooooooooool04?ooool00ol0003o
/<00o`000006ok;00003o`000?nh`P3o000000?oO;8000?o0000ohNe0?n7]@000on7]@000ol0003o
GZX0oejZ0004oejZ0003o`000?m`[`3o000000Co?j4000Go0000oeBW0?mDY`3oE:L0o`000002obRI
0003o`000?m1X@3o@J4000;o@J4000Co0000oaZD0?lJU03o00001?lfW@001?l0003o4i40oa>A0?l0
0003oc:L0003o`000?lCT@3o4i4000;o4i400_l00006oaZD0004o`000?l4R`3o18/0o`0000;o:9T0
00?o0000oaFB0?lETP000olETP000ol0003o1X`0o`J<0002o`000003objK0?l0003o8IL000Go8IL0
00?o0000oaVC0?lIT`000_lIT`000ol0003o4i40o`000002o`000003od6Q0?l0003o?j4000Co?j40
00?o0000od6Q0?m1X@000_m1X@000ol0003oAZ<0odJS0003odJS0003o`000?m@YP3oD:H000;oD:H0
00?o0000oejZ0?mNZP000_mNZP000ol0003oL:l0og2_0003og2_0003o`000?n7]@3oQkD000;oQkD0
00?o0000oj:l0?nR_0000onR_0000ol0003o`L@0ol740002ol740003o`000?o</`3oc;<000?oc;<0
00?o0000om>M0?oCW@000_oCW@000ol0003og8D0omb50002omb50003o`000?oSK03ohf`000?ohf`0
00Co0000on]C0?o[D`3oje<03ol00004ooooo`03o`000?oooooooooo00Cooooo000jooooo`;o0000
4Oooool2o`0000Go//0000Oo0000okS20?nh`P3o^<80o`000?ml/P3o000000GoQkD00_l00005oejZ
0005o`000?m`[`3oL:l0og2_0?l000000_loX@000ol0003oE:L0oeBW0002oeBW0003o`000?lXV@3o
000000Go@J4000?o0000oaZD0?l000001OlfW@000ol0003o4i40o`000004oc:L0007o`000?lCT@3o
4i40oa>A0?l0003o=Yd0o`000006oaZD0003o`000?l4R`3o000000Co:9T000?o0000oaFB0?lETP00
0olETP02o`0000Co;Y/000?o0000ob6G0?lQU`000olQU`000ol0003o6I<0oaVC0002oaVC00;o0000
1Om1X@000ol0003o?j40ocnQ0002ocnQ0003o`000?m1X@3o@J4000?o@J4000?o0000odJS0?m6X`00
0_m6X`000ol0003oD:H0oe2V0003oe2V0003o`000?mNZP3oGZX000;oGZX000?o0000og2_0?m`[`00
0_m`[`000ol0003oQkD0ohNe0003ohNe0003o`000?nR_03oX[`000;oX[`000?o0000ol740?o1a000
0oo1a0000ol0003oc;<0olbc0002olbc0003o`000?oCW@3odid000;odid000?o0000omb50?oLQ@00
0ooLQ@000ol0003ohf`0on=/0003on=/0003o`000?o[D`3oje<000;oje<000?o0000oo4l0?oa?000
0ooa?0000ol0003omRT0ooHY0002ooHY00;o00001?ooool00ol0003oooooooooo`04ooooo`00??oo
ool00ol0003oooooooooo`0@ooooo`05o`000?nb`03o//00ok;00?l000001Onh`P000ol0003oQkD0
ohNe0003ohNe0004o`000?nE^@3oUKT0o`0000?oGZX000?o0000og2_0?m`[`000_m`[`000ol0003o
?j40o`000006oeBW0003o`000?m1X@3o@J4000Go@J4000?o0000ocJM0?lfW@001OlfW@000ol0003o
<Y`0oc:L0003oc:L0004o`000?lCT@3o4i40o`0000?o=Yd000?o0000oaZD0?lJU0000olJU002o`00
00Go:9T000?o0000oaFB0?lETP000_lETP02o`0000Go;Y/000?o0000ob6G0?lQU`000olQU`000ol0
003o6I<0o`000002o`000003odJS0?l0003o@J4000Co@J4000?o0000ocnQ0?loX@000oloX@000ol0
003o@J40od6Q0002od6Q0004o`000?m6X`3oAZ<0odJS02Ko00000_o</`000ol0003odid0om>M0002
om>M0003o`000?oLQ@3og8D000?og8D000?o0000on=/0?oSK0000_oSK0000ol0003oje<0on]C0003
on]C0003o`000?oa?03olC`000?olC`000?o0000ooHY0?of:@000_of:@02o`0000Cooooo00?o0000
ooooooooool00oooool003gooooo00?o0000ooooooooool04?ooool00ol0003o//00o`000005okS2
0003o`000?o3a03o000000?oQkD000?o0000oiFi0?nE^@000_nE^@000ol0003oGZX0o`000006og2_
0003o`000?mDY`3oE:L000CoE:L00_l00006od6Q00;o00001_lfW@02o`0000Ko<Y`00_l00004ocJM
0003o`000?lJU03o6Y@000;o6Y@000?o0000od6Q0?l000001OlXV@000ol0003o5I80oaFB0002o`00
0003ocnQ0?l0003o;Y/000Go;Y/000?o0000ob6G0?lQU`000_lQU`02o`0000CoAZ<000?o0000od6Q
0?m1X@001?m1X@000ol0003o?j40ocnQ0002ocnQ0004o`000?m1X@3o@J40od6Q00Go00000_ml/P00
0ol0003oQkD0ohNe0002ohNe0003o`000?nE^@3oUKT000;oUKT000?o0000ojRn0?nX_P000onX_P00
0ol0003o_/<0okk30002okk30003o`000?o9^@3obKT000?obKT000?o0000om2X0?o@Z0000_o@Z000
1?l0003oei@0omND0?oGU006o`000003om>M0?l0003og8D000Cog8D000?o0000on=/0?oSK0000_oS
K0000ol0003oje<0on]C0003on]C0003o`000?oa?03olC`000?olC`000?o0000ooHY0?of:@000oof
:@000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo000nooooo`03o`000?oooooo
oooo013ooooo00?o0000okS20?nh`P000onh`P001ol0003o`l@0ol?40?o3a03o0000ohNe0?l00000
1_nE^@000ol0003oL:l0og2_0004og2_00;o00001OmDY`001?l0003oKZl0ofj_0?l00004od6Q0004
o`000?mNZP3oGZX0o`0000Co=Yd000Co0000oeJX0?mFZ03o00001?lbW002o`0000Ko=Yd000Co0000
oaZD0?lJU03o00000om1X@000ol0003o:9T0obRI0003obRI00;o00001?loX@000ol0003o;Y/0objK
0003objK0003o`000?lQU`3o000000;o000000?oD:H0o`000?m6X`001?m6X`000ol0003o@J40od6Q
0003od6Q0003o`000?loX@3o?j4000;o?j401?l00002ogJa0003o`000?ml/P3oO;8000?oO;8000?o
0000ohNe0?n7]@000_n7]@000ol0003oUKT0oiFi0002oiFi0003o`000?nX_P3oZ;h000?oZ;h000?o
0000okk30?nn``000_nn``000ol0003obKT0olVi0003olVi0003o`000?o@Z03od:P000;od:P000?o
0000omND0?oGU0000_oGU0001?l0003ogWh0omin0?oNOP0Ao`000003on]C0?l0003olC`000;olC`0
2_l00003ooooo`03o`000?oooooooooo00?ooooo000oooooo`03o`000?oooooooooo013ooooo00Go
0000okS20?nh`P3o^<80o`000005ol?40003o`000?nE^@3oUKT000CoUKT00_l00005og2_0004o`00
0?n7]@3oQkD0o`0000?oE:L000?o0000ofj_0?m^[`000_m^[`001?l0003o@J40od6Q0?l00004oejZ
0004o`000?lfW@3o=Yd0o`0000?oEZP000Oo0000oc:L0?lbW03o<Y`0o`000?mFZ03o000000Ko=Yd0
00?o0000oaZD0?l000001?m1X@000ol0003o:9T0obRI0002obRI00;o00001OloX@000ol0003o;Y/0
objK0003objK00;o00001?m@YP000ol0003oAZ<0odJS0003odJS0003o`000?m1X@3o@J4000?o@J40
00?o0000ocnQ0?l000000_l000000omd/03o0000ogJa0003ogJa0003o`000?ml/P3oO;8000?oO;80
00?o0000ohNe0?n7]@000_n7]@000ol0003oUKT0oiFi0002oiFi0003o`000?nX_P3oZ;h000?oZ;h0
00?o0000okk30?nn``000_nn``000ol0003obKT0olVi0003olVi0003o`000?o@Z03od:P000;od:P0
00?o0000omND0?oGU0000ooGU0000ol0003ogWh0omin0002omin0003o`000?oUI`3oiFL000?oiFL0
00?o0000on]A0?o[D@000_o[D@001?l0003olC`0oo4l0?oa?005o`0000?omBX000?o0000ooPM0?oh
7@000ooh7@001Ol0003ooooooooooooooooo000000Gooooo0010ooooo`;o00004Oooool00ol0003o
^<80o`000005ol?400;o00001OnE^@001?l0003oZ;h0ojRn0?l00003og2_0003o`000?n7]@3oQkD0
00;oQkD000?o0000oeBW0?l000001Om^[`000ol0003o@J40o`000005oejZ0003o`000?lfW@3o0000
00CoEZP000Co0000oc:L0?lbW03o00000omFZ0000ol0003o=Yd0ocJM0003ocJM00;o00001Om1X@00
0ol0003o:9T0obRI0002o`000003oeBW0?l0003o?j4000Go?j4000?o0000objK0?l^V`000_l00000
0omNZP3o0000oe2V0004oe2V0003o`000?m6X`3oAZ<000;oAZ<000?o0000od6Q0?m1X@000om1X@02
o`0000CoM;0000?o0000ogJa0?mf/@000omf/@000ol0003oO;80ogbb0003ogbb0003o`000?n7]@3o
QkD000;oQkD000?o0000oiFi0?nE^@000_nE^@000ol0003oZ;h0ojRn0002ojRn0003o`000?nn``3o
_/<000?o_/<000?o0000olVi0?o9^@000_o9^@000ol0003od:P0om2X0003om2X0003o`000?oGU03o
ei@000;oei@000?o0000omin0?oNOP000ooNOP000ol0003oiFL0onEW0003onEW0003o`000?o[D@3o
je4000;oje4000?o0000oo4l0?oa?0000_oa?0000ol0003omBX0ooDZ0004ooDZ0003o`000?oh7@3o
n1d000?on1d000Co0000oooooooooooo00001Oooool004;ooooo00?o0000ooooooooool03oooool0
0ol0003o`l@0ol?40003ol?40004o`000?o7_@3oakd0o`0000?oUKT000?o0000ojRn0?nX_P000_nX
_P000ol0003oL:l0o`000006ohNe0003o`000?m^[`3oKZl000GoKZl000?o0000oejZ0?mNZP001OmN
ZP000ol0003oEZP0oeJX0004oeJX00;o00001OmFZ0000ol0003o=Yd0ocJM0002o`000003oejZ0?l0
003o@J4000Go@J400_l00004oeBW0003o`000?loX@3o?j4000?o?j4000?o0000objK0?l000001?mN
ZP000ol0003oD:H0oe2V0002oe2V0003o`000?m6X`3oAZ<000?oAZ<000?o0000od6Q0?l000000_l0
00000omf/@3o0000ogB`0004ogB`0003o`000?mf/@3oM[4000;oM[4000?o0000ogbb0?ml/P000oml
/P000ol0003oQkD0ohNe0002ohNe0003o`000?nE^@3oUKT000;oUKT000?o0000ojRn0?nX_P000onX
_P000ol0003o_/<0okk30002okk30003o`000?o9^@3obKT000?obKT000?o0000om2X0?o@Z0000_o@
Z0000ol0003oei@0omND0003omND0003o`000?oNOP3ogWh000;ogWh000?o0000onEW0?oUI`000ooU
I`000ol0003oje40on]A0003on]A0003o`000?oa?03olC`000;olC`000?o0000ooDZ0?oe:P000ooe
:P001?l0003on1d0ooPM0?oh7@04o`000003ooooool0003ooooo00Cooooo0013ooooo`03o`000?oo
oooooooo00oooooo00Go0000ol?40?o3a03o`l@0o`000004olNm0003o`000?nE^@3o000000KoZ;h0
00?o0000ohNe0?n7]@001?n7]@02o`0000KoKZl00_l00006oejZ00;o00001OmFZ002o`0000KoEZP0
00?o0000ocJM0?l000001?mNZP000ol0003o@J40od6Q0002od6Q00;o00001OmDY`000ol0003o?j40
ocnQ0003ocnQ00;o00001OmNZP000ol0003oD:H0oe2V0002oe2V0003o`000?m6X`3oAZ<000;oAZ<0
0ol00004ogJa0003o`000?md/03oM;0000?oM;0000?o0000ogJa0?mf/@000_mf/@000ol0003oO;80
ogbb0003ogbb0004o`000?n7]@3oQkD0ohNe027o000000?oei@0o`000?oNOP000ooNOP000ol0003o
iFL0onEW0003onEW0003o`000?o[D@3oje4000?oje4000?o0000oo4l0?oa?0000ooa?0001?l0003o
mBX0ooDZ0?oe:P05o`0000?onAT00ol00005ooooo`00A?ooool00ol0003oooooooooo`0?ooooo`03
o`000?o3a03o000000Koakd000?o0000ojRn0?nX_P001?nX_P02o`0000GoQkD000Co0000oj:l0?nR
_03o00001?m^[`001?l0003oSKL0ohfg0?l00004oejZ0004o`000?n1]03oPK@0o`0000?oEZP000?o
0000ogbb0?l000001_mFZ002o`0000KoGZX000Ko0000od6Q0?m1X@3o0000ofj_0?l00006oeBW0003
o`000?loX@3o?j4000;o000000?oL:l0o`000?mNZP001OmNZP000ol0003oD:H0oe2V0002oe2V00Co
000000?oO;80o`000?mf/@001Omf/@000ol0003oM;00ogB`0002ogB`0003o`000?mf/@3oM[4000?o
M[4000?o0000ogbb0?ml/P001_l00002ol?40003o`000?o7_@3oakd000;oakd000?o0000olbc0?o<
/`000_o</`000ol0003od:H0om2V0003om2V0003o`000?oFU`3oeYL000;oeYL000?o0000om^60?oK
QP000ooKQP001?l0003ohG<0on5c0?oQL`0Lo`0000?on1d000?o0000ooTI0?oi6@000ooi6@03o`00
00Cooooo0015ooooo`;o00004?ooool00ol0003oakd0olNm0004olNm00;o00001OnX_P001?l0003o
_l<0oko30?l00003ohNe0003o`000?nR_03oX[`000;oX[`000Co0000ofj_0?m^[`3o00001?n=]`00
1?l0003oGZX0oejZ0?l00003oh6d0004o`000?mFZ03oEZP0o`0000?oO;8000?o0000oeJX0?mFZ000
0_mFZ0000ol0003oPK@0o`000006oejZ0003o`000?m1X@3o000000?oKZl000?o0000oeBW0?mDY`00
0omDY`000ol0003o?j40o`000004og2_0003o`000?mNZP3oGZX000?oGZX000Co0000oe2V0?m@YP3o
D:H00_l00005ogbb0003o`000?mf/@3oM[4000?oM[4000?o0000ogB`0?md/0000omd/0000ol0003o
M[40ogJa0005o`0000?o^<8000?o0000ol?40?o3a0000_o3a0000ol0003oakd0olNm0003olNm0003
o`000?o</`3oc;<000;oc;<000?o0000om2V0?o@YP000oo@YP000ol0003oeYL0omJG0002omJG0003
o`000?oKQP3ofhH000?ofhH000?o0000on5c0?oQL`000_oQL`000ol0003oiel0onMO0002onMO0003
o`000?o]B`3okD/000?okD/000?o0000oo8i0?ob>@000oob>@000ol0003omRT0ooHY0003ooHY0003
o`000?oh7@3on1d000Con1d000?o0000ooTI0?l000000_l000000ooooooo0000o`000004ooooo`00
Aoooool00ol0003oooooooooo`0=ooooo`03o`000?o7_@3oakd000?oakd000Co0000olbc0?o</`3o
00000onX_P000ol0003o_l<0oko30002oko30003o`000?n7]@3o000000GoX[`000?o0000ofj_0?l0
00001On=]`000ol0003oGZX0o`000004oh6d0003o`000?mFZ03o000000GoO;8000Co0000oeJX0?mF
Z03o00000on1]0000ol0003oGZX0oejZ0003oejZ00;o00001?m^[`000ol0003oE:L0oeBW0003oeBW
00;o00001Om`[`000ol0003oGZX0oejZ0003oejZ0006o`000?m@YP3o0000o`000?n7]@3o00001Oml
/P000ol0003oM[40ogJa0003ogJa0003o`000?md/03oM;0000;oM;001?l00002ok;00003o`000?nh
`P3o^<8000?o^<8000?o0000ol?40?o3a0000oo3a0000ol0003oakd0olNm0002olNm0003o`000?o<
/`3oc;<000;oc;<000?o0000om2V0?o@YP000oo@YP000ol0003oeYL0omJG0002omJG0003o`000?oK
QP3ofhH000?ofhH000?o0000on5c0?oQL`000ooQL`000ol0003oiel0onMO0002onMO0003o`000?o]
B`3okD/000?okD/000?o0000oo8i0?ob>@000oob>@000ol0003omRT0ooHY0003ooHY0004o`000?oh
7@3on1d0ooPM00Co00000oooool3o`0000Cooooo0018ooooo`03o`000?oooooooooo00gooooo00Go
0000olNm0?o7_@3oakd0o`000004olbc0003o`000?nX_P3o000000Ko_l<000?o0000oj:l0?nR_000
1?nR_002o`0000KoSKL00_l00006oh6d0003o`000?ml/P3oO;8000CoO;8000?o0000oeJX0?l00000
1?n1]0000ol0003oGZX0oejZ0002oejZ0003o`000?n=]`3o000000GoKZl000?o0000oeBW0?mDY`00
0_l000000on7]@3o0000og2_0005og2_0003o`000?mNZP3oGZX000;oGZX00_l00004ohNe0003o`00
0?ml/P3oO;8000?oO;8000?o0000ogJa0?mf/@000omf/@04o`000003ok2o0?l0003o//0000Co//00
00?o0000okS20?nh`P000onh`P000ol0003o`l@0ol?40002ol?40003o`000?o7_@3oakd000?oakd0
00?o0000olbc0?o</`000_o</`000ol0003od:H0om2V0002om2V0003o`000?oFU`3oeYL000?oeYL0
00?o0000om^60?oKQP000_oKQP000ol0003ohG<0on5c0003on5c0003o`000?oWG`3oiel000?oiel0
00?o0000one;0?o]B`000_o]B`000ol0003olST0oo8i0003oo8i0004o`000?of:@3omRT0ooHY00Ko
00000oooool4o`0000Oooooo0019ooooo`03o`000?oooooooooo00gooooo00?o0000olNm0?l00000
1_o</`000ol0003o_l<0oko30004oko300;o00001OnR_0000ol0003o`L@0o`000005ohfg0003o`00
0?n``03o000000GoPK@00_l00007ogbb0003o`000?n1]03oPK@000CoPK@000Co0000oejZ0?mNZP3o
00000on=]`000ol0003oKZl0ofj_0002ofj_0003o`000?mDY`3o000000CoQkD000?o0000og2_0?m`
[`000om`[`000ol0003oGZX0o`000002o`000003oiFi0?l0003oQkD000?oQkD000?o0000ogbb0?ml
/P000oml/P001?l0003oM[40ogJa0?mf/@03o`0000Go/;l000?o0000ok;00?nb`0000_nb`0000ol0
003o^<80okS20003okS20003o`000?o3a03o`l@000;o`l@000?o0000olNm0?o7_@000oo7_@000ol0
003oc;<0olbc0002olbc0003o`000?o@YP3od:H000?od:H000?o0000omJG0?oFU`000_oFU`000ol0
003ofhH0om^60003om^60003o`000?oQL`3ohG<000;ohG<000?o0000onMO0?oWG`000ooWG`001?l0
003okD/0one;0?o]B`0;o`0000Gooooo1?l0000;ooooo`00B_ooool2o`0000kooooo00?o0000olbc
0?o</`001?o</`02o`0000Go_l<000Co0000olVi0?o9^@3o00000onR_0001Ol0003o`L@0ol740?o1
a03o000000?oSKL000Go0000ok300?n``03o/<00o`000003oh6d0004o`000?nX_P3oZ;h0o`0000Go
O;800_l00006oh6d0003o`000?mNZP3o000000CoSKL000?o0000ofj_0?m^[`000_m^[`02o`0000Go
QkD000?o0000og2_0?m`[`000om`[`02o`0000GoUKT000?o0000ohNe0?n7]@000_n7]@000ol0003o
O;80ogbb0002ogbb00Co00000_nb`0000ol0003o/;l0ok2o0003ok2o0003o`000?nb`03o//0000?o
//0000?o0000okS20?nh`P000_nh`P000ol0003o`l@0ol?40003ol?40003o`000?o7_@3oakd002Oo
00003Oooool3o`0000oooooo001<ooooo`03o`000?oooooooooo00_ooooo00?o0000olbc0?o</`00
0oo</`001?l0003od:H0om2V0?l00003oko30003o`000?o9^@3obKT000;obKT000?o0000oj:l0?l0
00001Oo1a0000ol0003oSKL0o`000004ok300004o`000?n1]03oPK@0o`0000?oZ;h000?o0000ogbb
0?ml/P000_ml/P001?l0003oZ;h0ojRn0?l00005oh6d00;o00001On=]`000ol0003oKZl0ofj_0002
o`000003oj:l0?l0003oQkD000GoQkD000?o0000og2_0?m`[`000_l000000onX_P3o0000oiFi0004
oiFi0003o`000?n7]@3oQkD000;oQkD000?o0000ogbb0?l000000_l000000onh`P3o0000ok;00004
ok;00003o`000?n`_`3o/;l000?o/;l000?o0000ok;00?nb`0000_nb`0000ol0003o^<80okS20003
okS20003o`000?o3a03o`l@000Go0000<?ooool4o`0001;ooooo001=ooooo`03o`000?oooooooooo
00_ooooo00Go0000olbc0?o</`3oc;<0o`000004om2V0003o`000?no``3o000000KobKT000?o0000
ol740?o1a0001Oo1a0000ol0003o/<00ok300003ok300003o`000?n1]03o000000GoZ;h000Co0000
ogbb0?ml/P3o00000onX_P000ol0003oPK@0oh6d0002oh6d0003o`000?n``03o000000KoSKL00_l0
0004oj:l0003o`000?n7]@3oQkD000?oQkD000?o0000og2_0?l000000onX_P000ol0003oUKT0oiFi
0003oiFi0003o`000?n7]@3oQkD000;oQkD00_l00005okS20003o`000?nb`03o//0000;o//0000?o
0000ok2o0?n`_`000on`_`000ol0003o//00ok;00002ok;000Wo0000<Oooool4o`0001Kooooo001>
ooooo`03o`000?oooooooooo00_ooooo00?o0000olbc0?l000001Oo@YP02o`0000KobKT00_l00006
ol7400;o00001_n``0000ol0003oZ;h0ojRn0004ojRn0003o`000?ml/P3o000000GoZ;h000Co0000
oh6d0?n1]03o00000on``0000ol0003oSKL0ohfg0002ohfg00;o00001OnR_0000ol0003oQkD0ohNe
0003ohNe00;o00001OnX_P000ol0003oUKT0oiFi0003oiFi00Co000000?o`l@0o`000?nh`P001?nh
`P000ol0003o//00ok;00003ok;00003o`000?n`_`3o/;l000;o/;l000?o0000ok;00?l000000_l0
000fooooo`Co00006_ooool004oooooo00?o0000ooooooooool02oooool00ol0003od:H0om2V0003
om2V0003o`000?oFU`3o000000GobKT000Co0000om2X0?o@Z03o00001?o1a0001?l0003oc;<0olbc
0?l00004ok3000;o00001_nX_P02o`0000KoZ;h000?o0000oh6d0?l000001?n``0001ol0003oSKL0
ohfg0?n=]`3o0000ol740?l000001_nR_0000ol0003oQkD0ohNe0002o`000003okk30?l0003oZ;h0
00CoZ;h000?o0000oiFi0?nE^@000_nE^@02o`0000Go`l@000?o0000okS20?nh`P000onh`P000ol0
003o//00ok;00002ok;00004o`000?n`_`3o/;l0ok2o00?o0000=Oooool4o`0001kooooo001@oooo
o`;o00003?ooool01Ol0003od:H0om2V0?o@YP3o000000?oeYL000Go0000olVi0?o9^@3obKT0o`00
0004om2X0004o`000?o1a03o`L@0o`0000Coc;<000Co0000ok300?n``03o00000_o9^P000ol0003o
Z;h0ojRn0002ojRn0003o`000?o8_03o000000KoZ;h00_l00005ok300004o`000?n=]`3oSKL0o`00
00?o`L@000?o0000oj:l0?nR_0000onR_0000ol0003oQkD0o`000004okk30003o`000?nX_P3oZ;h0
00;oZ;h000?o0000oiFi0?nE^@000_l000000oo7_@3o0000ol?40004ol?40003o`000?nh`P3o^<80
00?o^<8000?o0000ok;00?nb`0000_nb`004o`0003Cooooo1?l0000Rooooo`00D_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?o@YP3o000000GoeYL000?o0000olVi0?l000001Oo@Z0000ol0003o
`L@0o`000005olbc0003o`000?n``03o000000CobKX000Co0000ojRn0?nX_P3o00000oo8_0000ol0
003oZ;h0ojRn0002ojRn0003o`000?o9^P3o000000Ko/<000_l00004ol740003o`000?nR_03oX[`0
00?oX[`00_l00005okk30003o`000?nX_P3oZ;h000?oZ;h00_l00004olNm0003o`000?o3a03o`l@0
00?o`l@000?o0000okS20?nh`P000_nh`P000ol0003o//00o`000002o`0003Gooooo0ol0000Voooo
o`00Doooool00ol0003oooooooooo`0:ooooo`03o`000?oFU`3oeYL000CoeYL00_l00006om2X00;o
00001_o</`02o`0000GobKX000?o0000ojRn0?l000001Oo8_0001?l0003oZ;h0ojRn0?l00003olVj
0003o`000?n``03o/<0000;o/<000_l00006ol740003o`000?nR_03oX[`000;o000000?obKT0o`00
0?nn``001?nn``000ol0003oZ;h0ojRn0002ojRn00;o00001Oo7_@000ol0003o`l@0ol?40003ol?4
0004o`000?nh`P3o^<80okS200?o0000=?ooool4o`0002Wooooo001Dooooo`03o`000?oooooooooo
00Wooooo00?o0000omJG0?oFU`000ooFU`000ol0003ofhH0o`000005om2X0003o`000?oGU03o0000
00Goc;<000?o0000om>M0?l000001Oo9^P02o`0000Kob;`000?o0000ojRn0?l000001?o9^P000ol0
003o/<00ok300002o`000003olbc0?l0003o`L@000Go`L@000?o0000oj:l0?l000001?o9^@000ol0
003o_/<0okk30003okk300Co000000?oc;<0o`000?o7_@001Oo7_@000ol0003o`l@0ol?40002ol?4
00Co0000<oooool4o`0002gooooo001Eooooo`;o00002_ooool01Ol0003oeYL0omJG0?oFU`3o0000
00?ofhH000Go0000om2X0?o@Z03od:P0o`000003omND0005o`000?o</`3oc;<0olbc0?l000000ooC
W@001ol0003obKX0olVj0?o9^P3o0000om:R0?l000001_o8_002o`0000GobKX000?o0000ok300?l0
00001?o</`000ol0003o`L@0ol740003ol7400;o00001Oo9^@000ol0003o_/<0okk30002okk300;o
00001Oo</`000ol0003oakd0olNm0003olNm0003o`000?o3a03o`l@000;o0000<oooool4o`00037o
oooo001Gooooo`03o`000?oooooooooo00Sooooo00?o0000omJG0?l000001OoKQP000ol0003od:P0
o`000005omND0003o`000?o</`3o000000Codid000Co0000olVj0?o9^P3o00000ooBXP000ol0003o
b;`0olRl0002olRl0003o`000?oBXP3o000000KobKX000?o0000olbc0?o</`001?o</`000ol0003o
`L@0ol740002o`000003om2X0?l0003obKT000CobKT000?o0000okk30?nn``000_l000000oo@YP3o
0000olbc0004olbc0003o`000?o7_@3oakd000?oakd000?o0000ol?40?l00000<Oooool4o`0003Go
oooo001Hooooo`03o`000?oooooooooo00Sooooo00?o0000om^60?oKQP001?oKQP02o`0000Koei@0
0_l00005om>M0003o`000?o9^P3o000000GodZ8000Co0000olRl0?o8_03o00000ooBXP000ol0003o
bKX0olVj0002olVj00;o00001_o</`000ol0003o`L@0o`000004om2X0003o`000?o9^@3obKT000?o
bKT00_l00004om2V0003o`000?o</`3oc;<000?oc;<000?o0000olNm0?o7_@000_o7_@02o`0002ko
oooo1?l0000iooooo`00FOooool00ol0003oooooooooo`07ooooo`03o`000?oKQP3ofhH000?ofhH0
00?o0000on5c0?l000001OoGU0000ol0003ogWh0o`000005om>M00;o00001_oBXP000ol0003ob;`0
o`000005om:R0004o`000?o9^P3obKX0o`0000;odid000?o0000olbc0?o</`000oo</`02o`0000Go
d:P000?o0000olVi0?o9^@000_o9^@02o`0000God:H000?o0000olbc0?o</`000oo</`000ol0003o
akd0o`000002o`0002gooooo0ol0000mooooo`00F_ooool2o`0000Sooooo00Go0000om^60?oKQP3o
fhH0o`000003on5c0005o`000?oGU03oei@0omND0?l000000ooNOP001ol0003odid0om>M0?oCW@3o
0000omb50?l000001_oBXP02o`0000KodZ8000?o0000olVj0?l000000ooCW@000ol0003oc;<0olbc
0002olbc0003o`000?oGU03o000000God:P000?o0000olVi0?o9^@000_l000000ooFU`3o0000om2V
0005om2V0003o`000?o</`3oc;<000;oc;<00_l0000/ooooo`Co0000@?ooool005cooooo00?o0000
ooooooooool01_ooool00ol0003ofhH0o`000005on5c0003o`000?oGU03o000000CogWh000Co0000
om>M0?oCW@3o00000ooLQ@001?l0003odZ80om:R0?oBXP02o`000003om^70?l0003odZ8000GodZ80
0_l00005om>M0004o`000?o</`3oc;<0o`0000?oei@000?o0000om2X0?o@Z0000oo@Z002o`0000Co
eYL000?o0000om2V0?o@YP000oo@YP000ol0003oc;<0o`000002o`0002[ooooo1?l00014ooooo`00
GOooool00ol0003oooooooooo`06ooooo`03o`000?oQL`3ohG<000CohG<00_l00005omin0003o`00
0?oCW@3o000000Gog8D000?o0000om:R0?l000001?oKQ`000ol0003odZ80om:R0002om:R0003o`00
0?oLQ@3o000000Godid000?o0000olbc0?l000001?oGU0000ol0003od:P0om2X0002om2X00;o0000
1OoFU`000ol0003od:H0om2V0003om2V00;o0000:Oooool4o`0004Sooooo001Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000on5c0?oQL`000ooQL`000ol0003oiel0o`000005omin00;o00001_oL
Q@02o`0000KofhL000Co0000om:R0?oBXP3o00000ooLQ@000ol0003odid0om>M0002om>M00;o0000
1_oGU0001_l0003od:P0om2X0?l0003ofhH0o`0000KoeYL000?o0000om2V0?o@YP000_l0000Woooo
o`Co0000C?ooool005oooooo0_l00006ooooo`05o`000?oQL`3ohG<0on5c0?l000000ooWG`001ol0
003ogWh0omin0?oNOP3o0000onEW0?l000001OoLQ@000ol0003ohf`0o`000006om^70003o`000?oB
XP3o000000Cog8D000?o0000om>M0?oCW@000_l000000ooNOP3o0000omND0005omND0003o`000?o@
Z03o000000?ofhH000?o0000omJG0?oFU`000ooFU`000ol0003od:H0o`00000Uooooo`Co0000D?oo
ool0067ooooo00?o0000ooooooooool01?ooool00ol0003ohG<0o`000005onMO0003o`000?oNOP3o
000000?oiFL000Go0000omb50?oLQ@3og8D0o`000003on=/0003o`000?oKQ`3ofhL000?ofhL00_l0
0005omb50003o`000?oCW@3o000000CogWh000?o0000omND0?oGU0000ooGU002o`0000GofhH000?o
0000omJG0?oFU`000_oFU`02o`0002?ooooo0ol0001Dooooo`00H_ooool00ol0003oooooooooo`04
ooooo`03o`000?oWG`3oiel000Coiel00_l00005onEW0003o`000?oLQ@3o000000Gohf`000?o0000
om^70?oKQ`000_l000000ooSK03o0000omb50004omb500;o00001_oNOP000ol0003oei@0omND0002
o`000003on5c0?l0003ofhH000CofhH000?o0000omJG0?l000000_l0000Qooooo`Co0000Eoooool0
06?ooooo00?o0000ooooooooool00oooool00ol0003oiel0onMO0003onMO0003o`000?o]B`3o0000
00GoiFL00_l00006on=/0003o`000?oKQ`3o000000Cohf`000?o0000omb50?oLQ@000_l000000ooU
I`3o0000omin0005omin0003o`000?oGU03o000000CohG<000?o0000om^60?oKQP000_oKQP02o`00
023ooooo1?l0001Kooooo`00I?ooool00ol0003oooooooooo`03ooooo`05o`000?oWG`3oiel0onMO
0?l000000oo]B`000ol0003oiFL0onEW0002o`000003on]A0?l0003ohf`000Gohf`00_l00005on=/
0003o`000?oLQ@3o000000CoiFL000?o0000omin0?oNOP000ooNOP02o`0000GohG<000?o0000om^6
0?oKQP000_l0000Nooooo`Co0000Goooool006Gooooo0_l00004ooooo`03o`000?oWG`3o000000Co
kD/000?o0000onEW0?l000001?o[D@001?l0003ohf`0on=/0?oSK002o`000003on]C0?l0003ohf`0
00Cohf`00_l00006onEW0003o`000?oNOP3ogWh000;o000000?oiel0o`000?oQL`001?oQL`000ol0
003ofhH0o`00000Looooo`Co0000Hoooool006Oooooo00?o0000ooooooooool00_ooool00ol0003o
kD/0one;0004one;0003o`000?o[D@3oje4000Coje4000?o0000on=/0?l000001?o[D`001ol0003o
hf`0on=/0?oSK03o0000on]A0?l000001_oUI`000ol0003ogWh0o`000004onMO0003o`000?oQL`3o
hG<000;ohG<00_l0000Iooooo`Co0000Ioooool006Sooooo00Go0000ooooooooooooooooo`000005
one;00;o00001_o[D@02o`0000Koje<000?o0000on=/0?l000000oo[D@000ol0003oiFL0onEW0003
onEW00;o00001OoWG`000ol0003ohG<0on5c0002o`0001Sooooo0ol0001[ooooo`00JOooool01Ol0
003ooooooooooooooooo000000?okD/000Co0000oo8i0?ob>@3o00000oo[D@02o`000003oo4l0?l0
003oje<000Goje<00_l00005on]A0003o`000?oUI`3oiFL000;o000000?okD/0o`000?oWG`001?oW
G`000ol0003ohG<0o`00000Fooooo`Co0000K_ooool006[ooooo0_l00002ooooo`03o`000?o]B`3o
000000ColST000?o0000on]A0?l000001?oa?0001?l0003oje<0on]C0?o[D`02o`000003oo4l0?l0
003oje4000Coje4000?o0000onEW0?l000001?o]B`000ol0003oiel0onMO0002onMO00;o00004ooo
ool4o`0007;ooooo001/ooooo`04o`000?ooooooooooo`0000GolST00_l00006oo4l0003o`000?o[
D`3o000000ColC`000?o0000on]A0?o[D@000_o[D@02o`0000KokD/000Co0000onMO0?l0003o0000
4Oooool4o`0007Kooooo001]ooooo`03o`000?oooooo000000?olST00_l000000oof:@3o0000oo4l
0005oo4l00;o00001Ooa?0000ol0003oje40o`000002o`000003oo8i0?l0003okD/000GokD/00_l0
000?ooooo`Co0000N_ooool006kooooo00Go0000ooooool0003olST0o`000004ooHY0004o`000?oa
?03olC`0oo4l00;o000000?omBX0o`000?oa?0001?oa?002o`0000GolST000Co0000one;0?o]B`3o
kD/00_l0000=ooooo`Co0000O_ooool006oooooo0ol00006ooHY0003o`000?oa?03o000000ComBX0
00Oo0000oo4l0?oa?03olC`0o`000?of:@3o000000KolST000?o0000one;0?l000003?ooool3o`00
08;ooooo001aooooo`;o00001Oof:@02o`0000KomBX000?o0000oo4l0?l000000oof:@000ol0003o
lST0oo8i0003oo8i00;o00002Oooool4o`0008Gooooo001booooo`;o000000ComRT0o`000?l0003o
00000_oh7@000ol0003omBX0ooDZ0003ooDZ00;o00001Oof:@000ol0003olST0o`000002o`0000Oo
oooo1?l00029ooooo`00Loooool3o`0000Gon1d000?o0000ooDZ0?l000000_l000000ooh7@3o0000
ooHY0004ooHY00;o00001_ooool4o`0008gooooo001dooooo`03o`000?oooooo000000?on1d00ol0
0005ooPM0003o`000?of:@3o000000;o00001?ooool4o`00097ooooo001eooooo`Go00000ooi6@00
0ol0003on1d0ooPM0002ooPM00;o00000oooool4o`0009Gooooo001gooooo`03o`000?oooooo0000
00ConAT000Co0000ooPM0?l0003o00000_ooool3o`0009Wooooo001hooooo`03o`000?oooooo0000
00Wo0000W?ooool007Wooooo0_l000000ooooooo0000o`000002o`000:3ooooo001jooooo`;o0000
Y?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool002cooooo0ol0002:ooooo`03
o`000?oooooooooo02_ooooo0ol0000Eooooo`03o`000?oooooooooo01kooooo000]ooooo`03o`00
0?oooooooooo08Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01gooooo000Wooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_oo
ool3o`0000?ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000ooo
ool2o`0000;ooooo1_l00006ooooo`Co00000_ooool5o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000ol00002ooooo`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Co
ooooo`000?l0003ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go0000
0_ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o
00001Oooool00ol0003oooooooooo`0Looooo`009_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000cooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0L
ooooo`009_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002
ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo0000
1Oooool5o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;o
oooo0ol00003ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`04o`000?oooooooooooooo
o`Go00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00002ooooo`?o00001Oooool00ol0003oooooooooo`0Looooo`00
9_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?oooooooooo
o`0000Gooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo01cooooo
000Vooooo`06o`000?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Co
oooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00
00;ooooo0_l00003ooooo`Co00000oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03
o`0000Cooooo1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`?o00000_ooool4o`0000?ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02
ooooo`Ko000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003
ooooo`Co00001?ooool00ol0003oooooooooo`0Looooo`009_ooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool07Oooool002Oooooo0ol00009ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?oo
ool2o`0002kooooo00?o0000ooooooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_oo
ool2o`0000_ooooo00?o0000ooooooooool07_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0579699, 0.0510678, \
0.00357065, 0.00357065}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(10.529999999999973`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            
            RowBox[{\(ComponentNumber \[Rule] 2\), 
              ",", \(Energy \[Rule] 100.`\), 
              ",", \(Offset \[Rule] 155.23250625987404`\), ",", 
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                
                TagBox[\(CompiledFunction[
                    If[#1 \[Equal] 0 && #2 \[Equal] 0, 
                      155.23245157878875`, \(\(155.25089886845007`\)\(\
\[InvisibleSpace]\)\) - 
                        2.8838985855792276`*^-9\ Cos[
                            2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                        0.013712112400497804`\ \((\(-1\) + 
                              0.006209067528539418`\ \((#1\^2 + #2\^2)\))\) - 
                        8.658162146957153`*^-7\ Cos[
                            2\ ArcTan[#1, #2]]\ \((\(-0.009313601292809127`\)\
\ \((#1\^2 + #2\^2)\) + 0.0000385525195739626`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                        0.004893482322796429`\ \((1 - 
                              0.018627202585618254`\ \((#1\^2 + #2\^2)\) + 
                              0.00005782877936094391`\ \((#1\^2 + \
#2\^2)\)\^2)\) + 6.378518354310161`*^-6\ Cos[
                            4\ ArcTan[#1, #2]]\ \((\(-0.00004819064946745325`\
\)\ \((#1\^2 + #2\^2)\)\^2 + 
                              1.7953139807255362`*^-7\ \((#1\^2 + \
#2\^2)\)\^3)\) - 4.3494383308015985`*^-7\ Cos[
                            2\ ArcTan[#1, #2]]\ \((0.018627202585618254`\ \
\((#1\^2 + #2\^2)\) - 0.000192762597869813`\ \((#1\^2 + #2\^2)\)\^2 + 
                              4.488284951813841`*^-7\ \((#1\^2 + #2\^2)\)\^3)\
\) - 0.00015830506196050484`\ \((\(-1\) + 
                              0.03725440517123651`\ \((#1\^2 + #2\^2)\) - 
                              0.0002891438968047195`\ \((#1\^2 + #2\^2)\)\^2 \
+ 5.984379935751788`*^-7\ \((#1\^2 + #2\^2)\)\^3)\)], "-CompiledCode-"]\),
                  False,
                  Editable->False]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                
                TagBox[\(CompiledFunction[
                    If[#1 \[Equal] 0 && #2 \[Equal] 
                          0, \(-0.10278399575815439`\), \
\(\(34.57257251087704`\)\(\[InvisibleSpace]\)\) - 
                        5.420859346745704`*^-6\ Cos[
                            2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                        1.5341525684545546`*^-7\ Cos[
                            4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 + 
                        25.774647368542087`\ \((\(-1\) + 
                              0.006209067528539418`\ \((#1\^2 + #2\^2)\))\) - 
                        0.0016274736098964187`\ Cos[
                            2\ ArcTan[#1, #2]]\ \((\(-0.009313601292809127`\)\
\ \((#1\^2 + #2\^2)\) + 0.0000385525195739626`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                        9.198275043751126`\ \((1 - 
                              0.018627202585618254`\ \((#1\^2 + #2\^2)\) + 
                              0.00005782877936094391`\ \((#1\^2 + \
#2\^2)\)\^2)\) + 0.011989695850228327`\ Cos[
                            4\ ArcTan[#1, #2]]\ \((\(-0.00004819064946745325`\
\)\ \((#1\^2 + #2\^2)\)\^2 + 
                              1.7953139807255362`*^-7\ \((#1\^2 + \
#2\^2)\)\^3)\) - 0.0008175630752928467`\ Cos[
                            2\ ArcTan[#1, #2]]\ \((0.018627202585618254`\ \
\((#1\^2 + #2\^2)\) - 0.000192762597869813`\ \((#1\^2 + #2\^2)\)\^2 + 
                              4.488284951813841`*^-7\ \((#1\^2 + #2\^2)\)\^3)\
\) - 0.2975659056580214`\ \((\(-1\) + 
                              0.03725440517123651`\ \((#1\^2 + #2\^2)\) - 
                              0.0002891438968047195`\ \((#1\^2 + #2\^2)\)\^2 \
+ 5.984379935751788`*^-7\ \((#1\^2 + #2\^2)\)\^3)\)], "-CompiledCode-"]\),
                  False,
                  Editable->False]}], 
              ",", \(OpticalPathRange \[Rule] {155.23250625987404`, 
                  155.25963194161014`}\), ",", 
              RowBox[{"OutputGraphics", "\[Rule]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"OpticalLengthFunction", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}], ",", 
                    RowBox[{"WaveFrontIntensity", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}], ",", 
                    RowBox[{"OpticalPathDifference", "\[Rule]", 
                      RowBox[{"(", 
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}]}], "}"}]}], 
              ",", \(RayBoundary \[Rule] {{\(-12.690848135359127`\), 
                    12.690848135359127`}, {\(-12.69062378508626`\), 
                    12.69062378508626`}}\), 
              ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
              ",", \(ResidualFitError \[Rule] 0.003354510990161439`\), 
              ",", \(Source \[Rule] 1\), ",", \(SpatialScale \[Rule] 1\), 
              ",", \(SurfaceNumber \[Rule] 1\), 
              ",", \(WaveFrontID \[Rule] 1\), ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                
                TagBox[\(InterpolatingFunction[{{\(-17.00773585640436`\), 
                        17.00773585640436`}, {\(-17.007511506131493`\), 
                        17.007511506131493`}}, "<>"]\),
                  False,
                  Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
              ",", \(WaveTilt \[Rule] WaveTilt\)}], "}"}], "}"}]}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Next we use ",
  StyleBox["RayTracePrecision->100", "Input"],
  " with ",
  StyleBox["FindWaveFronts", "Input"],
  " to increase the precision of the result to 100 decimal places."
}], "Text"],

Cell[CellGroupData[{

Cell["Timing[wav = FindWaveFronts[sys2D,RayTracePrecision->100]]", "Input"],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 2, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 2, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.24573e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.01479 .32352 -36 -2.79172 ]
[.01479 .32352 0 6.20828 ]
[.00179 .40505 -36 -2.86096 ]
[.00179 .40505 0 6.13904 ]
[-0.01191 .49092 -36 -2.9343 ]
[-0.01191 .49092 0 6.0657 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Length \\(absolute distance\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02706 .31887 m
.03319 .31654 L
s
[(155.24)] .01479 .32352 1 -0.37962 Mshowa
.01412 .40055 m
.02028 .39831 L
s
[(155.25)] .00179 .40505 1 -0.36423 Mshowa
.00048 .4866 m
.00668 .48445 L
s
[(155.26)] -0.01191 .49092 1 -0.34793 Mshowa
.125 Mabswid
.02452 .33487 m
.02821 .33348 L
s
.02196 .35104 m
.02565 .34966 L
s
.01937 .36737 m
.02307 .36601 L
s
.01676 .38388 m
.02045 .38252 L
s
.01145 .4174 m
.01515 .41607 L
s
.00875 .43443 m
.01245 .43311 L
s
.00602 .45164 m
.00973 .45032 L
s
.00326 .46903 m
.00698 .46772 L
s
.02957 .30302 m
.03325 .30162 L
s
.03206 .28734 m
.03573 .28592 L
s
.03452 .27181 m
.03819 .27039 L
s
.03695 .25644 m
.04062 .255 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.977 .099 0 r
.38757 .79726 .39809 .80491 .41556 .80118 .40517 .79141 Metetra
.972 .117 0 r
.40517 .79141 .41556 .80118 .4332 .7955 .42294 .78376 Metetra
.961 .161 0 r
.42294 .78376 .4332 .7955 .45097 .78826 .44082 .77472 Metetra
.945 .223 0 r
.44082 .77472 .45097 .78826 .46885 .77985 .45879 .76466 Metetra
.926 .297 0 r
.45879 .76466 .46885 .77985 .48683 .7706 .47684 .75391 Metetra
.904 .375 0 r
.47684 .75391 .48683 .7706 .50488 .76081 .49496 .74278 Metetra
.881 .453 0 r
.49496 .74278 .50488 .76081 .523 .75075 .51312 .73152 Metetra
.858 .527 0 r
.51312 .73152 .523 .75075 .54118 .74066 .53135 .72037 Metetra
.836 .594 0 r
.53135 .72037 .54118 .74066 .55943 .73075 .54963 .70953 Metetra
.815 .653 0 r
.54963 .70953 .55943 .73075 .57776 .72119 .56798 .69917 Metetra
.796 .702 0 r
.56798 .69917 .57776 .72119 .59618 .71213 .58641 .68944 Metetra
.78 .743 0 r
.58641 .68944 .59618 .71213 .61469 .7037 .60493 .68046 Metetra
.762 .767 0 r
.60493 .68046 .61469 .7037 .63331 .696 .62356 .67232 Metetra
.721 .758 0 r
.62356 .67232 .63331 .696 .65207 .6891 .64232 .6651 Metetra
.697 .752 0 r
.64232 .6651 .65207 .6891 .67096 .68304 .66122 .65884 Metetra
.689 .75 0 r
.66122 .65884 .67096 .68304 .69002 .67786 .68028 .65356 Metetra
.697 .752 0 r
.68028 .65356 .69002 .67786 .70925 .67356 .69952 .64929 Metetra
.721 .758 0 r
.69952 .64929 .70925 .67356 .72867 .67013 .71896 .64599 Metetra
.762 .767 0 r
.71896 .64599 .72867 .67013 .74831 .66751 .73862 .64363 Metetra
.78 .743 0 r
.73862 .64363 .74831 .66751 .76816 .66565 .75851 .64215 Metetra
.796 .702 0 r
.75851 .64215 .76816 .66565 .78824 .66446 .77864 .64146 Metetra
.815 .653 0 r
.77864 .64146 .78824 .66446 .80855 .66381 .79902 .64145 Metetra
.836 .594 0 r
.79902 .64145 .80855 .66381 .8291 .66356 .81965 .64197 Metetra
.858 .527 0 r
.81965 .64197 .8291 .66356 .84987 .66353 .84053 .64285 Metetra
.881 .453 0 r
.84053 .64285 .84987 .66353 .87085 .66351 .86165 .6439 Metetra
.904 .375 0 r
.86165 .6439 .87085 .66351 .89202 .66324 .88299 .64486 Metetra
.926 .297 0 r
.88299 .64486 .89202 .66324 .91334 .66245 .90452 .64546 Metetra
.945 .223 0 r
.90452 .64546 .91334 .66245 .93478 .6608 .92621 .64539 Metetra
.961 .161 0 r
.92621 .64539 .93478 .6608 .95627 .65794 .948 .64428 Metetra
.972 .117 0 r
.948 .64428 .95627 .65794 .97774 .65345 .96981 .64172 Metetra
.977 .099 0 r
.96981 .64172 .97774 .65345 .99909 .64688 .99158 .63727 Metetra
.972 .117 0 r
.37699 .78759 .38757 .79726 .40517 .79141 .39474 .77976 Metetra
.96 .165 0 r
.39474 .77976 .40517 .79141 .42294 .78376 .41262 .7703 Metetra
.942 .235 0 r
.41262 .7703 .42294 .78376 .44082 .77472 .43061 .75959 Metetra
.92 .318 0 r
.43061 .75959 .44082 .77472 .45879 .76466 .44868 .74802 Metetra
.895 .407 0 r
.44868 .74802 .45879 .76466 .47684 .75391 .4668 .7359 Metetra
.868 .496 0 r
.4668 .7359 .47684 .75391 .49496 .74278 .48498 .72353 Metetra
.841 .58 0 r
.48498 .72353 .49496 .74278 .51312 .73152 .50319 .71117 Metetra
.814 .657 0 r
.50319 .71117 .51312 .73152 .53135 .72037 .52146 .69905 Metetra
.788 .725 0 r
.52146 .69905 .53135 .72037 .54963 .70953 .53977 .68736 Metetra
.746 .764 0 r
.53977 .68736 .54963 .70953 .56798 .69917 .55814 .67628 Metetra
.656 .742 0 r
.55814 .67628 .56798 .69917 .58641 .68944 .57659 .66593 Metetra
.583 .724 0 r
.57659 .66593 .58641 .68944 .60493 .68046 .59512 .65644 Metetra
.527 .71 0 r
.59512 .65644 .60493 .68046 .62356 .67232 .61375 .6479 Metetra
.487 .699 0 r
.61375 .6479 .62356 .67232 .64232 .6651 .63251 .64038 Metetra
.463 .693 0 r
.63251 .64038 .64232 .6651 .66122 .65884 .65141 .63392 Metetra
.455 .691 0 r
.65141 .63392 .66122 .65884 .68028 .65356 .67048 .62855 Metetra
.463 .693 0 r
.67048 .62855 .68028 .65356 .69952 .64929 .68972 .62428 Metetra
.487 .699 0 r
.68972 .62428 .69952 .64929 .71896 .64599 .70918 .6211 Metetra
.527 .71 0 r
.70918 .6211 .71896 .64599 .73862 .64363 .72885 .61896 Metetra
.583 .724 0 r
.72885 .61896 .73862 .64363 .75851 .64215 .74876 .6178 Metetra
.656 .742 0 r
.74876 .6178 .75851 .64215 .77864 .64146 .76893 .61755 Metetra
.746 .764 0 r
.76893 .61755 .77864 .64146 .79902 .64145 .78936 .6181 Metetra
.788 .725 0 r
.78936 .6181 .79902 .64145 .81965 .64197 .81006 .61931 Metetra
.814 .657 0 r
.81006 .61931 .81965 .64197 .84053 .64285 .83103 .62101 Metetra
.841 .58 0 r
.83103 .62101 .84053 .64285 .86165 .6439 .85227 .62301 Metetra
.868 .496 0 r
.85227 .62301 .86165 .6439 .88299 .64486 .87376 .62508 Metetra
.895 .407 0 r
.87376 .62508 .88299 .64486 .90452 .64546 .89547 .62694 Metetra
.92 .318 0 r
.89547 .62694 .90452 .64546 .92621 .64539 .91738 .62829 Metetra
.942 .235 0 r
.91738 .62829 .92621 .64539 .948 .64428 .93943 .62877 Metetra
.96 .165 0 r
.93943 .62877 .948 .64428 .96981 .64172 .96156 .62797 Metetra
.972 .117 0 r
.96156 .62797 .96981 .64172 .99158 .63727 .98368 .62547 Metetra
.961 .161 0 r
.36636 .77628 .37699 .78759 .39474 .77976 .38424 .76664 Metetra
.942 .235 0 r
.38424 .76664 .39474 .77976 .41262 .7703 .40225 .7555 Metetra
.918 .325 0 r
.40225 .7555 .41262 .7703 .43061 .75959 .42034 .74327 Metetra
.89 .423 0 r
.42034 .74327 .43061 .75959 .44868 .74802 .4385 .73031 Metetra
.86 .522 0 r
.4385 .73031 .44868 .74802 .4668 .7359 .4567 .71694 Metetra
.828 .616 0 r
.4567 .71694 .4668 .7359 .48498 .72353 .47494 .70344 Metetra
.797 .702 0 r
.47494 .70344 .48498 .72353 .50319 .71117 .49321 .69009 Metetra
.754 .766 0 r
.49321 .69009 .50319 .71117 .52146 .69905 .51151 .67708 Metetra
.632 .737 0 r
.51151 .67708 .52146 .69905 .53977 .68736 .52986 .66462 Metetra
.527 .71 0 r
.52986 .66462 .53977 .68736 .55814 .67628 .54826 .65287 Metetra
.439 .686 0 r
.54826 .65287 .55814 .67628 .57659 .66593 .56672 .64196 Metetra
.369 .666 0 r
.56672 .64196 .57659 .66593 .59512 .65644 .58526 .632 Metetra
.315 .65 0 r
.58526 .632 .59512 .65644 .61375 .6479 .6039 .62309 Metetra
.277 .638 0 r
.6039 .62309 .61375 .6479 .63251 .64038 .62266 .61529 Metetra
.254 .631 0 r
.62266 .61529 .63251 .64038 .65141 .63392 .64156 .60865 Metetra
.247 .629 0 r
.64156 .60865 .65141 .63392 .67048 .62855 .66063 .60319 Metetra
.254 .631 0 r
.66063 .60319 .67048 .62855 .68972 .62428 .67988 .59891 Metetra
.277 .638 0 r
.67988 .59891 .68972 .62428 .70918 .6211 .69933 .59581 Metetra
.315 .65 0 r
.69933 .59581 .70918 .6211 .72885 .61896 .71902 .59386 Metetra
.369 .666 0 r
.71902 .59386 .72885 .61896 .74876 .6178 .73895 .59298 Metetra
.439 .686 0 r
.73895 .59298 .74876 .6178 .76893 .61755 .75915 .59312 Metetra
.527 .71 0 r
.75915 .59312 .76893 .61755 .78936 .6181 .77962 .59415 Metetra
.632 .737 0 r
.77962 .59415 .78936 .6181 .81006 .61931 .80038 .59597 Metetra
.754 .766 0 r
.80038 .59597 .81006 .61931 .83103 .62101 .82143 .59839 Metetra
.797 .702 0 r
.82143 .59839 .83103 .62101 .85227 .62301 .84276 .60124 Metetra
.828 .616 0 r
.84276 .60124 .85227 .62301 .87376 .62508 .86437 .6043 Metetra
.86 .522 0 r
.86437 .6043 .87376 .62508 .89547 .62694 .88624 .60729 Metetra
.89 .423 0 r
.88624 .60729 .89547 .62694 .91738 .62829 .90834 .60991 Metetra
.918 .325 0 r
.90834 .60991 .91738 .62829 .93943 .62877 .93062 .61182 Metetra
.942 .235 0 r
.93062 .61182 .93943 .62877 .96156 .62797 .95302 .61263 Metetra
.961 .161 0 r
.95302 .61263 .96156 .62797 .98368 .62547 .97547 .6119 Metetra
.945 .223 0 r
.35566 .7637 .36636 .77628 .38424 .76664 .37369 .7524 Metetra
.92 .318 0 r
.37369 .7524 .38424 .76664 .40225 .7555 .39181 .73974 Metetra
.89 .423 0 r
.39181 .73974 .40225 .7555 .42034 .74327 .41001 .72612 Metetra
.857 .531 0 r
.41001 .72612 .42034 .74327 .4385 .73031 .42826 .71189 Metetra
.822 .634 0 r
.42826 .71189 .4385 .73031 .4567 .71694 .44654 .69738 Metetra
.786 .729 0 r
.44654 .69738 .4567 .71694 .47494 .70344 .46485 .68287 Metetra
.689 .75 0 r
.46485 .68287 .47494 .70344 .49321 .69009 .48317 .6686 Metetra
.552 .716 0 r
.48317 .6686 .49321 .69009 .51151 .67708 .50152 .65479 Metetra
.432 .684 0 r
.50152 .65479 .51151 .67708 .52986 .66462 .5199 .64163 Metetra
.33 .655 0 r
.5199 .64163 .52986 .66462 .54826 .65287 .53832 .62927 Metetra
.247 .629 0 r
.53832 .62927 .54826 .65287 .56672 .64196 .5568 .61785 Metetra
.181 .607 0 r
.5568 .61785 .56672 .64196 .58526 .632 .57536 .60747 Metetra
.132 .59 0 r
.57536 .60747 .58526 .632 .6039 .62309 .59401 .59822 Metetra
.097 .577 0 r
.59401 .59822 .6039 .62309 .62266 .61529 .61277 .59016 Metetra
.077 .57 0 r
.61277 .59016 .62266 .61529 .64156 .60865 .63168 .58334 Metetra
.07 .567 0 r
.63168 .58334 .64156 .60865 .66063 .60319 .65074 .57778 Metetra
.077 .57 0 r
.65074 .57778 .66063 .60319 .67988 .59891 .66999 .5735 Metetra
.097 .577 0 r
.66999 .5735 .67988 .59891 .69933 .59581 .68946 .57046 Metetra
.132 .59 0 r
.68946 .57046 .69933 .59581 .71902 .59386 .70915 .56866 Metetra
.181 .607 0 r
.70915 .56866 .71902 .59386 .73895 .59298 .7291 .56802 Metetra
.247 .629 0 r
.7291 .56802 .73895 .59298 .75915 .59312 .74931 .56849 Metetra
.33 .655 0 r
.74931 .56849 .75915 .59312 .77962 .59415 .76982 .56995 Metetra
.432 .684 0 r
.76982 .56995 .77962 .59415 .80038 .59597 .79062 .57229 Metetra
.552 .716 0 r
.79062 .57229 .80038 .59597 .82143 .59839 .81174 .57535 Metetra
.689 .75 0 r
.81174 .57535 .82143 .59839 .84276 .60124 .83315 .57895 Metetra
.786 .729 0 r
.83315 .57895 .84276 .60124 .86437 .6043 .85487 .58287 Metetra
.822 .634 0 r
.85487 .58287 .86437 .6043 .88624 .60729 .87688 .58687 Metetra
.857 .531 0 r
.87688 .58687 .88624 .60729 .90834 .60991 .89914 .59063 Metetra
.89 .423 0 r
.89914 .59063 .90834 .60991 .93062 .61182 .92162 .59383 Metetra
.92 .318 0 r
.92162 .59383 .93062 .61182 .95302 .61263 .94427 .59608 Metetra
.945 .223 0 r
.94427 .59608 .95302 .61263 .97547 .6119 .96701 .59694 Metetra
.926 .297 0 r
.3449 .75018 .35566 .7637 .37369 .7524 .36306 .73737 Metetra
.895 .407 0 r
.36306 .73737 .37369 .7524 .39181 .73974 .38131 .72333 Metetra
.86 .522 0 r
.38131 .72333 .39181 .73974 .41001 .72612 .39962 .70845 Metetra
.822 .634 0 r
.39962 .70845 .41001 .72612 .42826 .71189 .41796 .69308 Metetra
.782 .738 0 r
.41796 .69308 .42826 .71189 .44654 .69738 .43632 .67754 Metetra
.657 .743 0 r
.43632 .67754 .44654 .69738 .46485 .68287 .4547 .6621 Metetra
.503 .704 0 r
.4547 .6621 .46485 .68287 .48317 .6686 .47308 .64701 Metetra
.369 .666 0 r
.47308 .64701 .48317 .6686 .50152 .65479 .49148 .63248 Metetra
.255 .631 0 r
.49148 .63248 .50152 .65479 .5199 .64163 .5099 .61869 Metetra
.16 .6 0 r
.5099 .61869 .5199 .64163 .53832 .62927 .52835 .60578 Metetra
.084 .572 0 r
.52835 .60578 .53832 .62927 .5568 .61785 .54685 .5939 Metetra
.025 .549 0 r
.54685 .5939 .5568 .61785 .57536 .60747 .56542 .58313 Metetra
0 .53 .019 r
.56542 .58313 .57536 .60747 .59401 .59822 .58408 .57357 Metetra
0 .517 .048 r
.58408 .57357 .59401 .59822 .61277 .59016 .60286 .56527 Metetra
0 .509 .066 r
.60286 .56527 .61277 .59016 .63168 .58334 .62177 .55828 Metetra
0 .506 .071 r
.62177 .55828 .63168 .58334 .65074 .57778 .64083 .55263 Metetra
0 .509 .066 r
.64083 .55263 .65074 .57778 .66999 .5735 .66009 .54831 Metetra
0 .517 .048 r
.66009 .54831 .66999 .5735 .68946 .57046 .67955 .54533 Metetra
0 .53 .019 r
.67955 .54533 .68946 .57046 .70915 .56866 .69925 .54364 Metetra
.025 .549 0 r
.69925 .54364 .70915 .56866 .7291 .56802 .71921 .54321 Metetra
.084 .572 0 r
.71921 .54321 .7291 .56802 .74931 .56849 .73945 .54395 Metetra
.16 .6 0 r
.73945 .54395 .74931 .56849 .76982 .56995 .75998 .54578 Metetra
.255 .631 0 r
.75998 .54578 .76982 .56995 .79062 .57229 .78083 .54857 Metetra
.369 .666 0 r
.78083 .54857 .79062 .57229 .81174 .57535 .80199 .55219 Metetra
.503 .704 0 r
.80199 .55219 .81174 .57535 .83315 .57895 .82348 .55645 Metetra
.657 .743 0 r
.82348 .55645 .83315 .57895 .85487 .58287 .84529 .56114 Metetra
.782 .738 0 r
.84529 .56114 .85487 .58287 .87688 .58687 .86741 .56601 Metetra
.822 .634 0 r
.86741 .56601 .87688 .58687 .89914 .59063 .88982 .57079 Metetra
.86 .522 0 r
.88982 .57079 .89914 .59063 .92162 .59383 .91248 .57513 Metetra
.895 .407 0 r
.91248 .57513 .92162 .59383 .94427 .59608 .93534 .57866 Metetra
.926 .297 0 r
.93534 .57866 .94427 .59608 .96701 .59694 .95833 .58095 Metetra
.904 .375 0 r
.33406 .73602 .3449 .75018 .36306 .73737 .35236 .72185 Metetra
.868 .496 0 r
.35236 .72185 .36306 .73737 .38131 .72333 .37073 .70656 Metetra
.828 .616 0 r
.37073 .70656 .38131 .72333 .39962 .70845 .38915 .69055 Metetra
.786 .729 0 r
.38915 .69055 .39962 .70845 .41796 .69308 .40759 .67415 Metetra
.657 .743 0 r
.40759 .67415 .41796 .69308 .43632 .67754 .42604 .65768 Metetra
.487 .699 0 r
.42604 .65768 .43632 .67754 .4547 .6621 .44448 .64142 Metetra
.338 .657 0 r
.44448 .64142 .4547 .6621 .47308 .64701 .46293 .6256 Metetra
.21 .617 0 r
.46293 .6256 .47308 .64701 .49148 .63248 .48138 .61041 Metetra
.104 .58 0 r
.48138 .61041 .49148 .63248 .5099 .61869 .49984 .59605 Metetra
.019 .546 0 r
.49984 .59605 .5099 .61869 .52835 .60578 .51833 .58265 Metetra
0 .517 .048 r
.51833 .58265 .52835 .60578 .54685 .5939 .53686 .57034 Metetra
0 .492 .099 r
.53686 .57034 .54685 .5939 .56542 .58313 .55545 .55922 Metetra
0 .472 .135 r
.55545 .55922 .56542 .58313 .58408 .57357 .57413 .54937 Metetra
0 .458 .159 r
.57413 .54937 .58408 .57357 .60286 .56527 .59291 .54085 Metetra
0 .45 .173 r
.59291 .54085 .60286 .56527 .62177 .55828 .61183 .53371 Metetra
0 .447 .178 r
.61183 .53371 .62177 .55828 .64083 .55263 .63091 .52796 Metetra
0 .45 .173 r
.63091 .52796 .64083 .55263 .66009 .54831 .65017 .52361 Metetra
0 .458 .159 r
.65017 .52361 .66009 .54831 .67955 .54533 .66964 .52066 Metetra
0 .472 .135 r
.66964 .52066 .67955 .54533 .69925 .54364 .68935 .51907 Metetra
0 .492 .099 r
.68935 .51907 .69925 .54364 .71921 .54321 .70931 .5188 Metetra
0 .517 .048 r
.70931 .5188 .71921 .54321 .73945 .54395 .72957 .51977 Metetra
.019 .546 0 r
.72957 .51977 .73945 .54395 .75998 .54578 .75012 .52191 Metetra
.104 .58 0 r
.75012 .52191 .75998 .54578 .78083 .54857 .771 .5251 Metetra
.21 .617 0 r
.771 .5251 .78083 .54857 .80199 .55219 .79221 .52919 Metetra
.338 .657 0 r
.79221 .52919 .80199 .55219 .82348 .55645 .81376 .53401 Metetra
.487 .699 0 r
.81376 .53401 .82348 .55645 .84529 .56114 .83565 .53937 Metetra
.657 .743 0 r
.83565 .53937 .84529 .56114 .86741 .56601 .85787 .54502 Metetra
.786 .729 0 r
.85787 .54502 .86741 .56601 .88982 .57079 .88041 .55068 Metetra
.828 .616 0 r
.88041 .55068 .88982 .57079 .91248 .57513 .90322 .55603 Metetra
.868 .496 0 r
.90322 .55603 .91248 .57513 .93534 .57866 .92627 .5607 Metetra
.904 .375 0 r
.92627 .5607 .93534 .57866 .95833 .58095 .9495 .56426 Metetra
.881 .453 0 r
.32313 .72149 .33406 .73602 .35236 .72185 .34156 .7061 Metetra
.841 .58 0 r
.34156 .7061 .35236 .72185 .37073 .70656 .36006 .6897 Metetra
.797 .702 0 r
.36006 .6897 .37073 .70656 .38915 .69055 .37859 .67267 Metetra
.689 .75 0 r
.37859 .67267 .38915 .69055 .40759 .67415 .39713 .65535 Metetra
.503 .704 0 r
.39713 .65535 .40759 .67415 .42604 .65768 .41567 .63806 Metetra
.338 .657 0 r
.41567 .63806 .42604 .65768 .44448 .64142 .43419 .62106 Metetra
.196 .612 0 r
.43419 .62106 .44448 .64142 .46293 .6256 .45271 .60457 Metetra
.077 .57 0 r
.45271 .60457 .46293 .6256 .48138 .61041 .47122 .58881 Metetra
0 .53 .019 r
.47122 .58881 .48138 .61041 .49984 .59605 .48973 .57393 Metetra
0 .495 .093 r
.48973 .57393 .49984 .59605 .51833 .58265 .50826 .56009 Metetra
0 .464 .15 r
.50826 .56009 .51833 .58265 .53686 .57034 .52682 .5474 Metetra
0 .438 .191 r
.52682 .5474 .53686 .57034 .55545 .55922 .54544 .53596 Metetra
0 .417 .219 r
.54544 .53596 .55545 .55922 .57413 .54937 .56414 .52585 Metetra
0 .402 .237 r
.56414 .52585 .57413 .54937 .59291 .54085 .58294 .51713 Metetra
0 .393 .247 r
.58294 .51713 .59291 .54085 .61183 .53371 .60187 .50983 Metetra
0 .39 .251 r
.60187 .50983 .61183 .53371 .63091 .52796 .62096 .50399 Metetra
0 .393 .247 r
.62096 .50399 .63091 .52796 .65017 .52361 .64023 .4996 Metetra
0 .402 .237 r
.64023 .4996 .65017 .52361 .66964 .52066 .65971 .49666 Metetra
0 .417 .219 r
.65971 .49666 .66964 .52066 .68935 .51907 .67943 .49514 Metetra
0 .438 .191 r
.67943 .49514 .68935 .51907 .70931 .5188 .69941 .495 Metetra
0 .464 .15 r
.69941 .495 .70931 .5188 .72957 .51977 .71968 .49617 Metetra
0 .495 .093 r
.71968 .49617 .72957 .51977 .75012 .52191 .74026 .49857 Metetra
0 .53 .019 r
.74026 .49857 .75012 .52191 .771 .5251 .76116 .50209 Metetra
.077 .57 0 r
.76116 .50209 .771 .5251 .79221 .52919 .78242 .50658 Metetra
.196 .612 0 r
.78242 .50658 .79221 .52919 .81376 .53401 .80402 .51189 Metetra
.338 .657 0 r
.80402 .51189 .81376 .53401 .83565 .53937 .82598 .51783 Metetra
.503 .704 0 r
.82598 .51783 .83565 .53937 .85787 .54502 .84829 .52414 Metetra
.689 .75 0 r
.84829 .52414 .85787 .54502 .88041 .55068 .87094 .53058 Metetra
.797 .702 0 r
.87094 .53058 .88041 .55068 .90322 .55603 .89389 .5368 Metetra
.841 .58 0 r
.89389 .5368 .90322 .55603 .92627 .5607 .91711 .54246 Metetra
.881 .453 0 r
.91711 .54246 .92627 .5607 .9495 .56426 .94054 .54713 Metetra
.858 .527 0 r
.31209 .70684 .32313 .72149 .34156 .7061 .33067 .69036 Metetra
.814 .657 0 r
.33067 .69036 .34156 .7061 .36006 .6897 .34929 .67297 Metetra
.754 .766 0 r
.34929 .67297 .36006 .6897 .37859 .67267 .36794 .65504 Metetra
.552 .716 0 r
.36794 .65504 .37859 .67267 .39713 .65535 .38658 .63691 Metetra
.369 .666 0 r
.38658 .63691 .39713 .65535 .41567 .63806 .40521 .61888 Metetra
.21 .617 0 r
.40521 .61888 .41567 .63806 .43419 .62106 .42382 .60122 Metetra
.077 .57 0 r
.42382 .60122 .43419 .62106 .45271 .60457 .44241 .58415 Metetra
0 .525 .031 r
.44241 .58415 .45271 .60457 .47122 .58881 .46098 .56787 Metetra
0 .484 .115 r
.46098 .56787 .47122 .58881 .48973 .57393 .47955 .55253 Metetra
0 .447 .178 r
.47955 .55253 .48973 .57393 .50826 .56009 .49813 .53829 Metetra
0 .414 .223 r
.49813 .53829 .50826 .56009 .52682 .5474 .51673 .52526 Metetra
0 .387 .254 r
.51673 .52526 .52682 .5474 .54544 .53596 .53539 .51354 Metetra
0 .366 .274 r
.53539 .51354 .54544 .53596 .56414 .52585 .55412 .50319 Metetra
0 .35 .286 r
.55412 .50319 .56414 .52585 .58294 .51713 .57294 .49427 Metetra
0 .341 .292 r
.57294 .49427 .58294 .51713 .60187 .50983 .59189 .48684 Metetra
0 .338 .294 r
.59189 .48684 .60187 .50983 .62096 .50399 .61099 .4809 Metetra
0 .341 .292 r
.61099 .4809 .62096 .50399 .64023 .4996 .63028 .47646 Metetra
0 .35 .286 r
.63028 .47646 .64023 .4996 .65971 .49666 .64977 .47353 Metetra
0 .366 .274 r
.64977 .47353 .65971 .49666 .67943 .49514 .6695 .47206 Metetra
0 .387 .254 r
.6695 .47206 .67943 .49514 .69941 .495 .6895 .47202 Metetra
0 .414 .223 r
.6895 .47202 .69941 .495 .71968 .49617 .70978 .47335 Metetra
0 .447 .178 r
.70978 .47335 .71968 .49617 .74026 .49857 .73039 .47596 Metetra
0 .484 .115 r
.73039 .47596 .74026 .49857 .76116 .50209 .75132 .47974 Metetra
0 .525 .031 r
.75132 .47974 .76116 .50209 .78242 .50658 .77261 .48458 Metetra
.077 .57 0 r
.77261 .48458 .78242 .50658 .80402 .51189 .79427 .4903 Metetra
.21 .617 0 r
.79427 .4903 .80402 .51189 .82598 .51783 .81629 .49672 Metetra
.369 .666 0 r
.81629 .49672 .82598 .51783 .84829 .52414 .83868 .50361 Metetra
.552 .716 0 r
.83868 .50361 .84829 .52414 .87094 .53058 .86143 .5107 Metetra
.754 .766 0 r
.86143 .5107 .87094 .53058 .89389 .5368 .8845 .51768 Metetra
.814 .657 0 r
.8845 .51768 .89389 .5368 .91711 .54246 .90787 .5242 Metetra
.858 .527 0 r
.90787 .5242 .91711 .54246 .94054 .54713 .93148 .52983 Metetra
.836 .594 0 r
.30094 .69226 .31209 .70684 .33067 .69036 .31965 .67483 Metetra
.788 .725 0 r
.31965 .67483 .33067 .69036 .34929 .67297 .33841 .65657 Metetra
.632 .737 0 r
.33841 .65657 .34929 .67297 .36794 .65504 .35717 .63784 Metetra
.432 .684 0 r
.35717 .63784 .36794 .65504 .38658 .63691 .37592 .619 Metetra
.255 .631 0 r
.37592 .619 .38658 .63691 .40521 .61888 .39465 .60033 Metetra
.104 .58 0 r
.39465 .60033 .40521 .61888 .42382 .60122 .41335 .58209 Metetra
0 .53 .019 r
.41335 .58209 .42382 .60122 .44241 .58415 .43202 .5645 Metetra
0 .484 .115 r
.43202 .5645 .44241 .58415 .46098 .56787 .45066 .54775 Metetra
0 .441 .186 r
.45066 .54775 .46098 .56787 .47955 .55253 .46929 .53202 Metetra
0 .402 .237 r
.46929 .53202 .47955 .55253 .49813 .53829 .48793 .51742 Metetra
0 .369 .271 r
.48793 .51742 .49813 .53829 .51673 .52526 .50658 .50409 Metetra
0 .341 .292 r
.50658 .50409 .51673 .52526 .53539 .51354 .52528 .4921 Metetra
0 .319 .304 r
.52528 .4921 .53539 .51354 .55412 .50319 .54404 .48154 Metetra
0 .296 .303 r
.54404 .48154 .55412 .50319 .57294 .49427 .5629 .47245 Metetra
0 .274 .293 r
.5629 .47245 .57294 .49427 .59189 .48684 .58187 .46488 Metetra
0 .267 .29 r
.58187 .46488 .59189 .48684 .61099 .4809 .601 .45884 Metetra
0 .274 .293 r
.601 .45884 .61099 .4809 .63028 .47646 .6203 .45436 Metetra
0 .296 .303 r
.6203 .45436 .63028 .47646 .64977 .47353 .63982 .45141 Metetra
0 .319 .304 r
.63982 .45141 .64977 .47353 .6695 .47206 .65956 .44997 Metetra
0 .341 .292 r
.65956 .44997 .6695 .47206 .6895 .47202 .67958 .45 Metetra
0 .369 .271 r
.67958 .45 .6895 .47202 .70978 .47335 .69989 .45145 Metetra
0 .402 .237 r
.69989 .45145 .70978 .47335 .73039 .47596 .72052 .45423 Metetra
0 .441 .186 r
.72052 .45423 .73039 .47596 .75132 .47974 .74148 .45824 Metetra
0 .484 .115 r
.74148 .45824 .75132 .47974 .77261 .48458 .76281 .46336 Metetra
0 .53 .019 r
.76281 .46336 .77261 .48458 .79427 .4903 .78451 .46942 Metetra
.104 .58 0 r
.78451 .46942 .79427 .4903 .81629 .49672 .8066 .47624 Metetra
.255 .631 0 r
.8066 .47624 .81629 .49672 .83868 .50361 .82906 .48361 Metetra
.432 .684 0 r
.82906 .48361 .83868 .50361 .86143 .5107 .8519 .49126 Metetra
.632 .737 0 r
.8519 .49126 .86143 .5107 .8845 .51768 .87508 .49888 Metetra
.788 .725 0 r
.87508 .49888 .8845 .51768 .90787 .5242 .89859 .50612 Metetra
.836 .594 0 r
.89859 .50612 .90787 .5242 .93148 .52983 .92236 .51258 Metetra
.815 .653 0 r
.28965 .67793 .30094 .69226 .31965 .67483 .3085 .65968 Metetra
.746 .764 0 r
.3085 .65968 .31965 .67483 .33841 .65657 .32739 .64066 Metetra
.527 .71 0 r
.32739 .64066 .33841 .65657 .35717 .63784 .34627 .62125 Metetra
.33 .655 0 r
.34627 .62125 .35717 .63784 .37592 .619 .36514 .60179 Metetra
.16 .6 0 r
.36514 .60179 .37592 .619 .39465 .60033 .38397 .58255 Metetra
.019 .546 0 r
.38397 .58255 .39465 .60033 .41335 .58209 .40277 .56381 Metetra
0 .495 .093 r
.40277 .56381 .41335 .58209 .43202 .5645 .42152 .54577 Metetra
0 .447 .178 r
.42152 .54577 .43202 .5645 .45066 .54775 .44024 .52862 Metetra
0 .402 .237 r
.44024 .52862 .45066 .54775 .46929 .53202 .45895 .51253 Metetra
0 .363 .276 r
.45895 .51253 .46929 .53202 .48793 .51742 .47764 .49762 Metetra
0 .328 .299 r
.47764 .49762 .48793 .51742 .50658 .50409 .49635 .48401 Metetra
0 .289 .299 r
.49635 .48401 .50658 .50409 .52528 .4921 .5151 .47179 Metetra
0 .239 .276 r
.5151 .47179 .52528 .4921 .54404 .48154 .53391 .46103 Metetra
0 .206 .26 r
.53391 .46103 .54404 .48154 .5629 .47245 .5528 .45178 Metetra
0 .187 .25 r
.5528 .45178 .5629 .47245 .58187 .46488 .57182 .44408 Metetra
0 .181 .247 r
.57182 .44408 .58187 .46488 .601 .45884 .59097 .43796 Metetra
0 .187 .25 r
.59097 .43796 .601 .45884 .6203 .45436 .6103 .43341 Metetra
0 .206 .26 r
.6103 .43341 .6203 .45436 .63982 .45141 .62984 .43044 Metetra
0 .239 .276 r
.62984 .43044 .63982 .45141 .65956 .44997 .64962 .42901 Metetra
0 .289 .299 r
.64962 .42901 .65956 .44997 .67958 .45 .66965 .4291 Metetra
0 .328 .299 r
.66965 .4291 .67958 .45 .69989 .45145 .68999 .43063 Metetra
0 .363 .276 r
.68999 .43063 .69989 .45145 .72052 .45423 .71064 .43354 Metetra
0 .402 .237 r
.71064 .43354 .72052 .45423 .74148 .45824 .73165 .43772 Metetra
0 .447 .178 r
.73165 .43772 .74148 .45824 .76281 .46336 .75301 .44306 Metetra
0 .495 .093 r
.75301 .44306 .76281 .46336 .78451 .46942 .77476 .4494 Metetra
.019 .546 0 r
.77476 .4494 .78451 .46942 .8066 .47624 .7969 .45656 Metetra
.16 .6 0 r
.7969 .45656 .8066 .47624 .82906 .48361 .81943 .46432 Metetra
.33 .655 0 r
.81943 .46432 .82906 .48361 .8519 .49126 .84235 .47242 Metetra
.527 .71 0 r
.84235 .47242 .8519 .49126 .87508 .49888 .86564 .48057 Metetra
.746 .764 0 r
.86564 .48057 .87508 .49888 .89859 .50612 .88927 .48842 Metetra
.815 .653 0 r
.88927 .48842 .89859 .50612 .92236 .51258 .91319 .49556 Metetra
.796 .702 0 r
.27821 .66402 .28965 .67793 .3085 .65968 .2972 .64507 Metetra
.656 .742 0 r
.2972 .64507 .3085 .65968 .32739 .64066 .31622 .6254 Metetra
.439 .686 0 r
.31622 .6254 .32739 .64066 .34627 .62125 .33523 .60541 Metetra
.247 .629 0 r
.33523 .60541 .34627 .62125 .36514 .60179 .35422 .58541 Metetra
.084 .572 0 r
.35422 .58541 .36514 .60179 .38397 .58255 .37316 .56569 Metetra
0 .517 .048 r
.37316 .56569 .38397 .58255 .40277 .56381 .39205 .54651 Metetra
0 .464 .15 r
.39205 .54651 .40277 .56381 .42152 .54577 .4109 .52807 Metetra
0 .414 .223 r
.4109 .52807 .42152 .54577 .44024 .52862 .42971 .51058 Metetra
0 .369 .271 r
.42971 .51058 .44024 .52862 .45895 .51253 .44849 .49417 Metetra
0 .328 .299 r
.44849 .49417 .45895 .51253 .47764 .49762 .46726 .47899 Metetra
0 .274 .293 r
.46726 .47899 .47764 .49762 .49635 .48401 .48604 .46514 Metetra
0 .213 .263 r
.48604 .46514 .49635 .48401 .5151 .47179 .50484 .45271 Metetra
0 .169 .24 r
.50484 .45271 .5151 .47179 .53391 .46103 .52371 .44177 Metetra
0 .141 .223 r
.52371 .44177 .53391 .46103 .5528 .45178 .54265 .43238 Metetra
0 .125 .213 r
.54265 .43238 .5528 .45178 .57182 .44408 .5617 .42456 Metetra
0 .12 .209 r
.5617 .42456 .57182 .44408 .59097 .43796 .5809 .41834 Metetra
0 .125 .213 r
.5809 .41834 .59097 .43796 .6103 .43341 .60027 .41373 Metetra
0 .141 .223 r
.60027 .41373 .6103 .43341 .62984 .43044 .61984 .41072 Metetra
0 .169 .24 r
.61984 .41072 .62984 .43044 .64962 .42901 .63964 .40929 Metetra
0 .213 .263 r
.63964 .40929 .64962 .42901 .66965 .4291 .65972 .4094 Metetra
0 .274 .293 r
.65972 .4094 .66965 .4291 .68999 .43063 .68008 .411 Metetra
0 .328 .299 r
.68008 .411 .68999 .43063 .71064 .43354 .70077 .414 Metetra
0 .369 .271 r
.70077 .414 .71064 .43354 .73165 .43772 .72181 .41832 Metetra
0 .414 .223 r
.72181 .41832 .73165 .43772 .75301 .44306 .74321 .42382 Metetra
0 .464 .15 r
.74321 .42382 .75301 .44306 .77476 .4494 .76501 .43037 Metetra
0 .517 .048 r
.76501 .43037 .77476 .4494 .7969 .45656 .78721 .43779 Metetra
.084 .572 0 r
.78721 .43779 .7969 .45656 .81943 .46432 .8098 .44586 Metetra
.247 .629 0 r
.8098 .44586 .81943 .46432 .84235 .47242 .8328 .45433 Metetra
.439 .686 0 r
.8328 .45433 .84235 .47242 .86564 .48057 .85619 .46291 Metetra
.656 .742 0 r
.85619 .46291 .86564 .48057 .88927 .48842 .87993 .47124 Metetra
.796 .702 0 r
.87993 .47124 .88927 .48842 .91319 .49556 .90398 .47894 Metetra
.78 .743 0 r
.2666 .65064 .27821 .66402 .2972 .64507 .28573 .6311 Metetra
.584 .724 0 r
.28573 .6311 .2972 .64507 .31622 .6254 .30489 .61091 Metetra
.369 .666 0 r
.30489 .61091 .31622 .6254 .33523 .60541 .32403 .59042 Metetra
.181 .607 0 r
.32403 .59042 .33523 .60541 .35422 .58541 .34314 .56997 Metetra
.025 .549 0 r
.34314 .56997 .35422 .58541 .37316 .56569 .36219 .54985 Metetra
0 .492 .099 r
.36219 .54985 .37316 .56569 .39205 .54651 .3812 .53029 Metetra
0 .438 .191 r
.3812 .53029 .39205 .54651 .4109 .52807 .40015 .51153 Metetra
0 .387 .254 r
.40015 .51153 .4109 .52807 .42971 .51058 .41905 .49373 Metetra
0 .341 .292 r
.41905 .49373 .42971 .51058 .44849 .49417 .43792 .47706 Metetra
0 .289 .299 r
.43792 .47706 .44849 .49417 .46726 .47899 .45677 .46164 Metetra
0 .213 .263 r
.45677 .46164 .46726 .47899 .48604 .46514 .47562 .44758 Metetra
0 .158 .233 r
.47562 .44758 .48604 .46514 .50484 .45271 .49449 .43496 Metetra
0 .12 .209 r
.49449 .43496 .50484 .45271 .52371 .44177 .51342 .42386 Metetra
0 .096 .192 r
.51342 .42386 .52371 .44177 .54265 .43238 .53242 .41433 Metetra
0 .082 .182 r
.53242 .41433 .54265 .43238 .5617 .42456 .55153 .40639 Metetra
0 .078 .178 r
.55153 .40639 .5617 .42456 .5809 .41834 .57077 .40009 Metetra
0 .082 .182 r
.57077 .40009 .5809 .41834 .60027 .41373 .59018 .39541 Metetra
0 .096 .192 r
.59018 .39541 .60027 .41373 .61984 .41072 .6098 .39236 Metetra
0 .12 .209 r
.6098 .39236 .61984 .41072 .63964 .40929 .62964 .39091 Metetra
0 .158 .233 r
.62964 .39091 .63964 .40929 .65972 .4094 .64975 .39102 Metetra
0 .213 .263 r
.64975 .39102 .65972 .4094 .68008 .411 .67016 .39265 Metetra
0 .289 .299 r
.67016 .39265 .68008 .411 .70077 .414 .69088 .39571 Metetra
0 .341 .292 r
.69088 .39571 .70077 .414 .72181 .41832 .71196 .40011 Metetra
0 .387 .254 r
.71196 .40011 .72181 .41832 .74321 .42382 .73342 .40574 Metetra
0 .438 .191 r
.73342 .40574 .74321 .42382 .76501 .43037 .75526 .41245 Metetra
0 .492 .099 r
.75526 .41245 .76501 .43037 .78721 .43779 .77751 .42006 Metetra
.025 .549 0 r
.77751 .42006 .78721 .43779 .8098 .44586 .80018 .42836 Metetra
.181 .607 0 r
.80018 .42836 .8098 .44586 .8328 .45433 .82325 .43711 Metetra
.369 .666 0 r
.82325 .43711 .8328 .45433 .85619 .46291 .84673 .44601 Metetra
.584 .724 0 r
.84673 .44601 .85619 .46291 .87993 .47124 .87057 .45472 Metetra
.78 .743 0 r
.87057 .45472 .87993 .47124 .90398 .47894 .89474 .46284 Metetra
.762 .767 0 r
.2548 .63789 .2666 .65064 .28573 .6311 .27408 .61789 Metetra
.527 .71 0 r
.27408 .61789 .28573 .6311 .30489 .61091 .29337 .59726 Metetra
.315 .65 0 r
.29337 .59726 .30489 .61091 .32403 .59042 .31264 .57638 Metetra
.132 .59 0 r
.31264 .57638 .32403 .59042 .34314 .56997 .33188 .55557 Metetra
0 .53 .019 r
.33188 .55557 .34314 .56997 .36219 .54985 .35106 .53511 Metetra
0 .472 .135 r
.35106 .53511 .36219 .54985 .3812 .53029 .37018 .51525 Metetra
0 .417 .219 r
.37018 .51525 .3812 .53029 .40015 .51153 .38924 .49621 Metetra
0 .366 .274 r
.38924 .49621 .40015 .51153 .41905 .49373 .40824 .47816 Metetra
0 .319 .304 r
.40824 .47816 .41905 .49373 .43792 .47706 .42721 .46125 Metetra
0 .239 .276 r
.42721 .46125 .43792 .47706 .45677 .46164 .44615 .44563 Metetra
0 .169 .24 r
.44615 .44563 .45677 .46164 .47562 .44758 .46508 .43138 Metetra
0 .12 .209 r
.46508 .43138 .47562 .44758 .49449 .43496 .48403 .41861 Metetra
0 .087 .185 r
.48403 .41861 .49449 .43496 .51342 .42386 .50303 .40736 Metetra
0 .066 .168 r
.50303 .40736 .51342 .42386 .53242 .41433 .5221 .3977 Metetra
0 .055 .157 r
.5221 .3977 .53242 .41433 .55153 .40639 .54127 .38966 Metetra
0 .051 .154 r
.54127 .38966 .55153 .40639 .57077 .40009 .56057 .38327 Metetra
0 .055 .157 r
.56057 .38327 .57077 .40009 .59018 .39541 .58004 .37852 Metetra
0 .066 .168 r
.58004 .37852 .59018 .39541 .6098 .39236 .5997 .37541 Metetra
0 .087 .185 r
.5997 .37541 .6098 .39236 .62964 .39091 .6196 .37393 Metetra
0 .12 .209 r
.6196 .37393 .62964 .39091 .64975 .39102 .63975 .37403 Metetra
0 .169 .24 r
.63975 .37403 .64975 .39102 .67016 .39265 .6602 .37566 Metetra
0 .239 .276 r
.6602 .37566 .67016 .39265 .69088 .39571 .68098 .37874 Metetra
0 .319 .304 r
.68098 .37874 .69088 .39571 .71196 .40011 .70211 .3832 Metetra
0 .366 .274 r
.70211 .3832 .71196 .40011 .73342 .40574 .72361 .3889 Metetra
0 .417 .219 r
.72361 .3889 .73342 .40574 .75526 .41245 .74551 .3957 Metetra
0 .472 .135 r
.74551 .3957 .75526 .41245 .77751 .42006 .76782 .40344 Metetra
0 .53 .019 r
.76782 .40344 .77751 .42006 .80018 .42836 .79055 .4119 Metetra
.132 .59 0 r
.79055 .4119 .80018 .42836 .82325 .43711 .8137 .42084 Metetra
.315 .65 0 r
.8137 .42084 .82325 .43711 .84673 .44601 .83726 .42997 Metetra
.527 .71 0 r
.83726 .42997 .84673 .44601 .87057 .45472 .8612 .43895 Metetra
.762 .767 0 r
.8612 .43895 .87057 .45472 .89474 .46284 .88549 .44737 Metetra
.721 .758 0 r
.2428 .62586 .2548 .63789 .27408 .61789 .26222 .60551 Metetra
.487 .699 0 r
.26222 .60551 .27408 .61789 .29337 .59726 .28165 .58455 Metetra
.277 .638 0 r
.28165 .58455 .29337 .59726 .31264 .57638 .30106 .56336 Metetra
.097 .577 0 r
.30106 .56336 .31264 .57638 .33188 .55557 .32043 .54226 Metetra
0 .517 .048 r
.32043 .54226 .33188 .55557 .35106 .53511 .33973 .52154 Metetra
0 .458 .159 r
.33973 .52154 .35106 .53511 .37018 .51525 .35898 .50144 Metetra
0 .402 .237 r
.35898 .50144 .37018 .51525 .38924 .49621 .37815 .48217 Metetra
0 .35 .286 r
.37815 .48217 .38924 .49621 .40824 .47816 .39727 .46392 Metetra
0 .296 .303 r
.39727 .46392 .40824 .47816 .42721 .46125 .41634 .44683 Metetra
0 .206 .26 r
.41634 .44683 .42721 .46125 .44615 .44563 .43538 .43103 Metetra
0 .141 .223 r
.43538 .43103 .44615 .44563 .46508 .43138 .45441 .41662 Metetra
0 .096 .192 r
.45441 .41662 .46508 .43138 .48403 .41861 .47345 .4037 Metetra
0 .066 .168 r
.47345 .4037 .48403 .41861 .50303 .40736 .49252 .39233 Metetra
0 .048 .15 r
.49252 .39233 .50303 .40736 .5221 .3977 .51167 .38256 Metetra
0 .038 .139 r
.51167 .38256 .5221 .3977 .54127 .38966 .53091 .37442 Metetra
0 .035 .136 r
.53091 .37442 .54127 .38966 .56057 .38327 .55028 .36793 Metetra
0 .038 .139 r
.55028 .36793 .56057 .38327 .58004 .37852 .56981 .36311 Metetra
0 .048 .15 r
.56981 .36311 .58004 .37852 .5997 .37541 .58954 .35994 Metetra
0 .066 .168 r
.58954 .35994 .5997 .37541 .6196 .37393 .60949 .35841 Metetra
0 .096 .192 r
.60949 .35841 .6196 .37393 .63975 .37403 .62971 .35847 Metetra
0 .141 .223 r
.62971 .35847 .63975 .37403 .6602 .37566 .65021 .36008 Metetra
0 .206 .26 r
.65021 .36008 .6602 .37566 .68098 .37874 .67104 .36316 Metetra
0 .296 .303 r
.67104 .36316 .68098 .37874 .70211 .3832 .69222 .36763 Metetra
0 .35 .286 r
.69222 .36763 .70211 .3832 .72361 .3889 .71378 .37335 Metetra
0 .402 .237 r
.71378 .37335 .72361 .3889 .74551 .3957 .73574 .38021 Metetra
0 .458 .159 r
.73574 .38021 .74551 .3957 .76782 .40344 .75812 .38801 Metetra
0 .517 .048 r
.75812 .38801 .76782 .40344 .79055 .4119 .78092 .39656 Metetra
.097 .577 0 r
.78092 .39656 .79055 .4119 .8137 .42084 .80414 .40561 Metetra
.277 .638 0 r
.80414 .40561 .8137 .42084 .83726 .42997 .82778 .41487 Metetra
.487 .699 0 r
.82778 .41487 .83726 .42997 .8612 .43895 .85182 .42401 Metetra
.721 .758 0 r
.85182 .42401 .8612 .43895 .88549 .44737 .87621 .43262 Metetra
.697 .752 0 r
.23058 .6146 .2428 .62586 .26222 .60551 .25014 .59401 Metetra
.463 .693 0 r
.25014 .59401 .26222 .60551 .28165 .58455 .26971 .57282 Metetra
.254 .631 0 r
.26971 .57282 .28165 .58455 .30106 .56336 .28926 .55141 Metetra
.077 .57 0 r
.28926 .55141 .30106 .56336 .32043 .54226 .30876 .53011 Metetra
0 .509 .066 r
.30876 .53011 .32043 .54226 .33973 .52154 .3282 .50919 Metetra
0 .45 .173 r
.3282 .50919 .33973 .52154 .35898 .50144 .34757 .48891 Metetra
0 .393 .247 r
.34757 .48891 .35898 .50144 .37815 .48217 .36687 .46947 Metetra
0 .341 .292 r
.36687 .46947 .37815 .48217 .39727 .46392 .38611 .45105 Metetra
0 .274 .293 r
.38611 .45105 .39727 .46392 .41634 .44683 .40529 .43381 Metetra
0 .187 .25 r
.40529 .43381 .41634 .44683 .43538 .43103 .42444 .41787 Metetra
0 .125 .213 r
.42444 .41787 .43538 .43103 .45441 .41662 .44357 .40334 Metetra
0 .082 .182 r
.44357 .40334 .45441 .41662 .47345 .4037 .46271 .3903 Metetra
0 .055 .157 r
.46271 .3903 .47345 .4037 .49252 .39233 .48188 .37881 Metetra
0 .038 .139 r
.48188 .37881 .49252 .39233 .51167 .38256 .50112 .36893 Metetra
0 .029 .129 r
.50112 .36893 .51167 .38256 .53091 .37442 .52044 .3607 Metetra
0 .026 .125 r
.52044 .3607 .53091 .37442 .55028 .36793 .53989 .35412 Metetra
0 .029 .129 r
.53989 .35412 .55028 .36793 .56981 .36311 .5595 .34922 Metetra
0 .038 .139 r
.5595 .34922 .56981 .36311 .58954 .35994 .57929 .34598 Metetra
0 .055 .157 r
.57929 .34598 .58954 .35994 .60949 .35841 .59932 .34439 Metetra
0 .082 .182 r
.59932 .34439 .60949 .35841 .62971 .35847 .6196 .3444 Metetra
0 .125 .213 r
.6196 .3444 .62971 .35847 .65021 .36008 .64017 .34596 Metetra
0 .187 .25 r
.64017 .34596 .65021 .36008 .67104 .36316 .66106 .34901 Metetra
0 .274 .293 r
.66106 .34901 .67104 .36316 .69222 .36763 .6823 .35345 Metetra
0 .341 .292 r
.6823 .35345 .69222 .36763 .71378 .37335 .70393 .35916 Metetra
0 .393 .247 r
.70393 .35916 .71378 .37335 .73574 .38021 .72595 .36601 Metetra
0 .45 .173 r
.72595 .36601 .73574 .38021 .75812 .38801 .7484 .37382 Metetra
0 .509 .066 r
.7484 .37382 .75812 .38801 .78092 .39656 .77127 .38239 Metetra
.077 .57 0 r
.77127 .38239 .78092 .39656 .80414 .40561 .79457 .39146 Metetra
.254 .631 0 r
.79457 .39146 .80414 .40561 .82778 .41487 .8183 .40077 Metetra
.463 .693 0 r
.8183 .40077 .82778 .41487 .85182 .42401 .84242 .40995 Metetra
.697 .752 0 r
.84242 .40995 .85182 .42401 .87621 .43262 .86692 .41863 Metetra
.689 .75 0 r
.21812 .60413 .23058 .6146 .25014 .59401 .23782 .58341 Metetra
.455 .691 0 r
.23782 .58341 .25014 .59401 .26971 .57282 .25753 .5621 Metetra
.247 .629 0 r
.25753 .5621 .26971 .57282 .28926 .55141 .27722 .54057 Metetra
.07 .567 0 r
.27722 .54057 .28926 .55141 .30876 .53011 .29686 .51914 Metetra
0 .506 .071 r
.29686 .51914 .30876 .53011 .3282 .50919 .31644 .49809 Metetra
0 .447 .178 r
.31644 .49809 .3282 .50919 .34757 .48891 .33595 .47769 Metetra
0 .39 .251 r
.33595 .47769 .34757 .48891 .36687 .46947 .35538 .45813 Metetra
0 .338 .294 r
.35538 .45813 .36687 .46947 .38611 .45105 .37474 .43959 Metetra
0 .267 .29 r
.37474 .43959 .38611 .45105 .40529 .43381 .39405 .42224 Metetra
0 .181 .247 r
.39405 .42224 .40529 .43381 .42444 .41787 .41332 .40619 Metetra
0 .12 .209 r
.41332 .40619 .42444 .41787 .44357 .40334 .43256 .39155 Metetra
0 .078 .178 r
.43256 .39155 .44357 .40334 .46271 .3903 .45181 .37841 Metetra
0 .051 .154 r
.45181 .37841 .46271 .3903 .48188 .37881 .47108 .36683 Metetra
0 .035 .136 r
.47108 .36683 .48188 .37881 .50112 .36893 .49042 .35685 Metetra
0 .026 .125 r
.49042 .35685 .50112 .36893 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .026 .125 r
.52938 .34187 .53989 .35412 .5595 .34922 .54907 .33688 Metetra
0 .035 .136 r
.54907 .33688 .5595 .34922 .57929 .34598 .56895 .33356 Metetra
0 .051 .154 r
.56895 .33356 .57929 .34598 .59932 .34439 .58905 .33189 Metetra
0 .078 .178 r
.58905 .33189 .59932 .34439 .6196 .3444 .60941 .33183 Metetra
0 .12 .209 r
.60941 .33183 .6196 .3444 .64017 .34596 .63005 .33333 Metetra
0 .181 .247 r
.63005 .33333 .64017 .34596 .66106 .34901 .65102 .33631 Metetra
0 .267 .29 r
.65102 .33631 .66106 .34901 .6823 .35345 .67233 .34068 Metetra
0 .338 .294 r
.67233 .34068 .6823 .35345 .70393 .35916 .69403 .34634 Metetra
0 .39 .251 r
.69403 .34634 .70393 .35916 .72595 .36601 .71613 .35313 Metetra
0 .447 .178 r
.71613 .35313 .72595 .36601 .7484 .37382 .73864 .36088 Metetra
0 .506 .071 r
.73864 .36088 .7484 .37382 .77127 .38239 .76159 .3694 Metetra
.07 .567 0 r
.76159 .3694 .77127 .38239 .79457 .39146 .78498 .37843 Metetra
.247 .629 0 r
.78498 .37843 .79457 .39146 .8183 .40077 .80879 .38768 Metetra
.455 .691 0 r
.80879 .38768 .8183 .40077 .84242 .40995 .833 .39681 Metetra
.689 .75 0 r
.833 .39681 .84242 .40995 .86692 .41863 .85759 .40544 Metetra
.697 .752 0 r
.20541 .59447 .21812 .60413 .23782 .58341 .22524 .57374 Metetra
.463 .693 0 r
.22524 .57374 .23782 .58341 .25753 .5621 .2451 .5524 Metetra
.254 .631 0 r
.2451 .5524 .25753 .5621 .27722 .54057 .26493 .53083 Metetra
.077 .57 0 r
.26493 .53083 .27722 .54057 .29686 .51914 .28471 .50935 Metetra
0 .509 .066 r
.28471 .50935 .29686 .51914 .31644 .49809 .30443 .48825 Metetra
0 .45 .173 r
.30443 .48825 .31644 .49809 .33595 .47769 .32408 .46778 Metetra
0 .393 .247 r
.32408 .46778 .33595 .47769 .35538 .45813 .34365 .44816 Metetra
0 .341 .292 r
.34365 .44816 .35538 .45813 .37474 .43959 .36315 .42955 Metetra
0 .274 .293 r
.36315 .42955 .37474 .43959 .39405 .42224 .38259 .41212 Metetra
0 .187 .25 r
.38259 .41212 .39405 .42224 .41332 .40619 .40198 .396 Metetra
0 .125 .213 r
.40198 .396 .41332 .40619 .43256 .39155 .42135 .38128 Metetra
0 .082 .182 r
.42135 .38128 .43256 .39155 .45181 .37841 .44072 .36805 Metetra
0 .055 .157 r
.44072 .36805 .45181 .37841 .47108 .36683 .46011 .35638 Metetra
0 .038 .139 r
.46011 .35638 .47108 .36683 .49042 .35685 .47955 .34633 Metetra
0 .029 .129 r
.47955 .34633 .49042 .35685 .50984 .34853 .49908 .33792 Metetra
0 .026 .125 r
.49908 .33792 .50984 .34853 .52938 .34187 .51872 .33117 Metetra
0 .029 .129 r
.51872 .33117 .52938 .34187 .54907 .33688 .53851 .3261 Metetra
0 .038 .139 r
.53851 .3261 .54907 .33688 .56895 .33356 .55848 .32269 Metetra
0 .055 .157 r
.55848 .32269 .56895 .33356 .58905 .33189 .57867 .32093 Metetra
0 .082 .182 r
.57867 .32093 .58905 .33189 .60941 .33183 .59912 .32078 Metetra
0 .125 .213 r
.59912 .32078 .60941 .33183 .63005 .33333 .61985 .32218 Metetra
0 .187 .25 r
.61985 .32218 .63005 .33333 .65102 .33631 .6409 .32507 Metetra
0 .274 .293 r
.6409 .32507 .65102 .33631 .67233 .34068 .6623 .32934 Metetra
0 .341 .292 r
.6623 .32934 .67233 .34068 .69403 .34634 .68407 .33489 Metetra
0 .393 .247 r
.68407 .33489 .69403 .34634 .71613 .35313 .70625 .34158 Metetra
0 .45 .173 r
.70625 .34158 .71613 .35313 .73864 .36088 .72885 .34922 Metetra
0 .509 .066 r
.72885 .34922 .73864 .36088 .76159 .3694 .75188 .35761 Metetra
.077 .57 0 r
.75188 .35761 .76159 .3694 .78498 .37843 .77535 .36651 Metetra
.254 .631 0 r
.77535 .36651 .78498 .37843 .80879 .38768 .79924 .37562 Metetra
.463 .693 0 r
.79924 .37562 .80879 .38768 .833 .39681 .82355 .38459 Metetra
.697 .752 0 r
.82355 .38459 .833 .39681 .85759 .40544 .84823 .39305 Metetra
.721 .758 0 r
.19244 .58559 .20541 .59447 .22524 .57374 .2124 .56497 Metetra
.487 .699 0 r
.2124 .56497 .22524 .57374 .2451 .5524 .23239 .54371 Metetra
.277 .638 0 r
.23239 .54371 .2451 .5524 .26493 .53083 .25236 .52219 Metetra
.097 .577 0 r
.25236 .52219 .26493 .53083 .28471 .50935 .27229 .50075 Metetra
0 .517 .048 r
.27229 .50075 .28471 .50935 .30443 .48825 .29216 .47966 Metetra
0 .458 .159 r
.29216 .47966 .30443 .48825 .32408 .46778 .31195 .45919 Metetra
0 .402 .237 r
.31195 .45919 .32408 .46778 .34365 .44816 .33167 .43955 Metetra
0 .35 .286 r
.33167 .43955 .34365 .44816 .36315 .42955 .35131 .42092 Metetra
0 .296 .303 r
.35131 .42092 .36315 .42955 .38259 .41212 .37089 .40345 Metetra
0 .206 .26 r
.37089 .40345 .38259 .41212 .40198 .396 .39042 .38728 Metetra
0 .141 .223 r
.39042 .38728 .40198 .396 .42135 .38128 .40993 .37251 Metetra
0 .096 .192 r
.40993 .37251 .42135 .38128 .44072 .36805 .42942 .35922 Metetra
0 .066 .168 r
.42942 .35922 .44072 .36805 .46011 .35638 .44894 .34749 Metetra
0 .048 .15 r
.44894 .34749 .46011 .35638 .47955 .34633 .4685 .33736 Metetra
0 .038 .139 r
.4685 .33736 .47955 .34633 .49908 .33792 .48815 .32887 Metetra
0 .035 .136 r
.48815 .32887 .49908 .33792 .51872 .33117 .5079 .32203 Metetra
0 .038 .139 r
.5079 .32203 .51872 .33117 .53851 .3261 .5278 .31687 Metetra
0 .048 .15 r
.5278 .31687 .53851 .3261 .55848 .32269 .54788 .31337 Metetra
0 .066 .168 r
.54788 .31337 .55848 .32269 .57867 .32093 .56817 .31151 Metetra
0 .096 .192 r
.56817 .31151 .57867 .32093 .59912 .32078 .58871 .31124 Metetra
0 .141 .223 r
.58871 .31124 .59912 .32078 .61985 .32218 .60954 .31253 Metetra
0 .206 .26 r
.60954 .31253 .61985 .32218 .6409 .32507 .63068 .31529 Metetra
0 .296 .303 r
.63068 .31529 .6409 .32507 .6623 .32934 .65217 .31943 Metetra
0 .35 .286 r
.65217 .31943 .6623 .32934 .68407 .33489 .67404 .32483 Metetra
0 .402 .237 r
.67404 .32483 .68407 .33489 .70625 .34158 .69631 .33135 Metetra
0 .458 .159 r
.69631 .33135 .70625 .34158 .72885 .34922 .71899 .33882 Metetra
0 .517 .048 r
.71899 .33882 .72885 .34922 .75188 .35761 .74211 .34701 Metetra
.097 .577 0 r
.74211 .34701 .75188 .35761 .77535 .36651 .76567 .3557 Metetra
.277 .638 0 r
.76567 .3557 .77535 .36651 .79924 .37562 .78965 .36456 Metetra
.487 .699 0 r
.78965 .36456 .79924 .37562 .82355 .38459 .81404 .37328 Metetra
.721 .758 0 r
.81404 .37328 .82355 .38459 .84823 .39305 .83881 .38143 Metetra
.762 .767 0 r
.17919 .57746 .19244 .58559 .2124 .56497 .19927 .55706 Metetra
.527 .71 0 r
.19927 .55706 .2124 .56497 .23239 .54371 .21939 .53599 Metetra
.315 .65 0 r
.21939 .53599 .23239 .54371 .25236 .52219 .23951 .51462 Metetra
.132 .59 0 r
.23951 .51462 .25236 .52219 .27229 .50075 .25959 .49329 Metetra
0 .53 .019 r
.25959 .49329 .27229 .50075 .29216 .47966 .2796 .4723 Metetra
0 .472 .135 r
.2796 .4723 .29216 .47966 .31195 .45919 .29955 .45189 Metetra
0 .417 .219 r
.29955 .45189 .31195 .45919 .33167 .43955 .31941 .43229 Metetra
0 .366 .274 r
.31941 .43229 .33167 .43955 .35131 .42092 .33921 .41368 Metetra
0 .319 .304 r
.33921 .41368 .35131 .42092 .37089 .40345 .35894 .39621 Metetra
0 .239 .276 r
.35894 .39621 .37089 .40345 .39042 .38728 .37861 .38003 Metetra
0 .169 .24 r
.37861 .38003 .39042 .38728 .40993 .37251 .39826 .36523 Metetra
0 .12 .209 r
.39826 .36523 .40993 .37251 .42942 .35922 .4179 .3519 Metetra
0 .087 .185 r
.4179 .3519 .42942 .35922 .44894 .34749 .43755 .34011 Metetra
0 .066 .168 r
.43755 .34011 .44894 .34749 .4685 .33736 .45724 .32992 Metetra
0 .055 .157 r
.45724 .32992 .4685 .33736 .48815 .32887 .47702 .32135 Metetra
0 .051 .154 r
.47702 .32135 .48815 .32887 .5079 .32203 .4969 .31444 Metetra
0 .055 .157 r
.4969 .31444 .5079 .32203 .5278 .31687 .51692 .30918 Metetra
0 .066 .168 r
.51692 .30918 .5278 .31687 .54788 .31337 .53711 .30557 Metetra
0 .087 .185 r
.53711 .30557 .54788 .31337 .56817 .31151 .55752 .30359 Metetra
0 .12 .209 r
.55752 .30359 .56817 .31151 .58871 .31124 .57817 .3032 Metetra
0 .169 .24 r
.57817 .3032 .58871 .31124 .60954 .31253 .59911 .30434 Metetra
0 .239 .276 r
.59911 .30434 .60954 .31253 .63068 .31529 .62035 .30694 Metetra
0 .319 .304 r
.62035 .30694 .63068 .31529 .65217 .31943 .64195 .3109 Metetra
0 .366 .274 r
.64195 .3109 .65217 .31943 .67404 .32483 .66391 .31611 Metetra
0 .417 .219 r
.66391 .31611 .67404 .32483 .69631 .33135 .68628 .32242 Metetra
0 .472 .135 r
.68628 .32242 .69631 .33135 .71899 .33882 .70906 .32964 Metetra
0 .53 .019 r
.70906 .32964 .71899 .33882 .74211 .34701 .73227 .33757 Metetra
.132 .59 0 r
.73227 .33757 .74211 .34701 .76567 .3557 .75592 .34595 Metetra
.315 .65 0 r
.75592 .34595 .76567 .3557 .78965 .36456 .77999 .35449 Metetra
.527 .71 0 r
.77999 .35449 .78965 .36456 .81404 .37328 .80448 .36282 Metetra
.762 .767 0 r
.80448 .36282 .81404 .37328 .83881 .38143 .82934 .37056 Metetra
.78 .743 0 r
.16565 .57001 .17919 .57746 .19927 .55706 .18585 .54996 Metetra
.584 .724 0 r
.18585 .54996 .19927 .55706 .21939 .53599 .2061 .52918 Metetra
.369 .666 0 r
.2061 .52918 .21939 .53599 .23951 .51462 .22635 .50806 Metetra
.181 .607 0 r
.22635 .50806 .23951 .51462 .25959 .49329 .24657 .48693 Metetra
.025 .549 0 r
.24657 .48693 .25959 .49329 .2796 .4723 .26674 .4661 Metetra
0 .492 .099 r
.26674 .4661 .2796 .4723 .29955 .45189 .28684 .44583 Metetra
0 .438 .191 r
.28684 .44583 .29955 .45189 .31941 .43229 .30686 .42632 Metetra
0 .387 .254 r
.30686 .42632 .31941 .43229 .33921 .41368 .32681 .40778 Metetra
0 .341 .292 r
.32681 .40778 .33921 .41368 .35894 .39621 .3467 .39036 Metetra
0 .289 .299 r
.3467 .39036 .35894 .39621 .37861 .38003 .36653 .3742 Metetra
0 .213 .263 r
.36653 .3742 .37861 .38003 .39826 .36523 .38633 .3594 Metetra
0 .158 .233 r
.38633 .3594 .39826 .36523 .4179 .3519 .40612 .34605 Metetra
0 .12 .209 r
.40612 .34605 .4179 .3519 .43755 .34011 .42592 .33423 Metetra
0 .096 .192 r
.42592 .33423 .43755 .34011 .45724 .32992 .44576 .32398 Metetra
0 .082 .182 r
.44576 .32398 .45724 .32992 .47702 .32135 .46567 .31535 Metetra
0 .078 .178 r
.46567 .31535 .47702 .32135 .4969 .31444 .48568 .30835 Metetra
0 .082 .182 r
.48568 .30835 .4969 .31444 .51692 .30918 .50584 .30299 Metetra
0 .096 .192 r
.50584 .30299 .51692 .30918 .53711 .30557 .52616 .29927 Metetra
0 .12 .209 r
.52616 .29927 .53711 .30557 .55752 .30359 .5467 .29715 Metetra
0 .158 .233 r
.5467 .29715 .55752 .30359 .57817 .3032 .56747 .29661 Metetra
0 .213 .263 r
.56747 .29661 .57817 .3032 .59911 .30434 .58852 .29758 Metetra
0 .289 .299 r
.58852 .29758 .59911 .30434 .62035 .30694 .60989 .29999 Metetra
0 .341 .292 r
.60989 .29999 .62035 .30694 .64195 .3109 .63159 .30373 Metetra
0 .387 .254 r
.63159 .30373 .64195 .3109 .66391 .31611 .65367 .3087 Metetra
0 .438 .191 r
.65367 .3087 .66391 .31611 .68628 .32242 .67614 .31473 Metetra
0 .492 .099 r
.67614 .31473 .68628 .32242 .70906 .32964 .69903 .32165 Metetra
.025 .549 0 r
.69903 .32165 .70906 .32964 .73227 .33757 .72234 .32923 Metetra
.181 .607 0 r
.72234 .32923 .73227 .33757 .75592 .34595 .74609 .33722 Metetra
.369 .666 0 r
.74609 .33722 .75592 .34595 .77999 .35449 .77026 .34532 Metetra
.584 .724 0 r
.77026 .34532 .77999 .35449 .80448 .36282 .79483 .35317 Metetra
.78 .743 0 r
.79483 .35317 .80448 .36282 .82934 .37056 .81978 .36035 Metetra
.796 .702 0 r
.15183 .56315 .16565 .57001 .18585 .54996 .17213 .54358 Metetra
.656 .742 0 r
.17213 .54358 .18585 .54996 .2061 .52918 .1925 .52321 Metetra
.439 .686 0 r
.1925 .52321 .2061 .52918 .22635 .50806 .21288 .50244 Metetra
.247 .629 0 r
.21288 .50244 .22635 .50806 .24657 .48693 .23325 .48161 Metetra
.084 .572 0 r
.23325 .48161 .24657 .48693 .26674 .4661 .25356 .46102 Metetra
0 .517 .048 r
.25356 .46102 .26674 .4661 .28684 .44583 .27382 .44094 Metetra
0 .464 .15 r
.27382 .44094 .28684 .44583 .30686 .42632 .294 .42159 Metetra
0 .414 .223 r
.294 .42159 .30686 .42632 .32681 .40778 .31411 .40317 Metetra
0 .369 .271 r
.31411 .40317 .32681 .40778 .3467 .39036 .33416 .38584 Metetra
0 .328 .299 r
.33416 .38584 .3467 .39036 .36653 .3742 .35416 .36973 Metetra
0 .274 .293 r
.35416 .36973 .36653 .3742 .38633 .3594 .37412 .35496 Metetra
0 .213 .263 r
.37412 .35496 .38633 .3594 .40612 .34605 .39406 .34162 Metetra
0 .169 .24 r
.39406 .34162 .40612 .34605 .42592 .33423 .41402 .32978 Metetra
0 .141 .223 r
.41402 .32978 .42592 .33423 .44576 .32398 .43402 .31949 Metetra
0 .125 .213 r
.43402 .31949 .44576 .32398 .46567 .31535 .45408 .3108 Metetra
0 .12 .209 r
.45408 .3108 .46567 .31535 .48568 .30835 .47424 .30372 Metetra
0 .125 .213 r
.47424 .30372 .48568 .30835 .50584 .30299 .49454 .29825 Metetra
0 .141 .223 r
.49454 .29825 .50584 .30299 .52616 .29927 .51501 .2944 Metetra
0 .169 .24 r
.51501 .2944 .52616 .29927 .5467 .29715 .53568 .29214 Metetra
0 .213 .263 r
.53568 .29214 .5467 .29715 .56747 .29661 .55659 .29142 Metetra
0 .274 .293 r
.55659 .29142 .56747 .29661 .58852 .29758 .57777 .29219 Metetra
0 .328 .299 r
.57777 .29219 .58852 .29758 .60989 .29999 .59926 .29437 Metetra
0 .369 .271 r
.59926 .29437 .60989 .29999 .63159 .30373 .62109 .29786 Metetra
0 .414 .223 r
.62109 .29786 .63159 .30373 .65367 .3087 .64329 .30253 Metetra
0 .464 .15 r
.64329 .30253 .65367 .3087 .67614 .31473 .66588 .30822 Metetra
0 .517 .048 r
.66588 .30822 .67614 .31473 .69903 .32165 .68888 .31476 Metetra
.084 .572 0 r
.68888 .31476 .69903 .32165 .72234 .32923 .7123 .32192 Metetra
.247 .629 0 r
.7123 .32192 .72234 .32923 .74609 .33722 .73615 .32942 Metetra
.439 .686 0 r
.73615 .32942 .74609 .33722 .77026 .34532 .76042 .33698 Metetra
.656 .742 0 r
.76042 .33698 .77026 .34532 .79483 .35317 .78509 .34421 Metetra
.796 .702 0 r
.78509 .34421 .79483 .35317 .81978 .36035 .81011 .3507 Metetra
.815 .653 0 r
.13771 .55676 .15183 .56315 .17213 .54358 .1581 .53779 Metetra
.746 .764 0 r
.1581 .53779 .17213 .54358 .1925 .52321 .17858 .51796 Metetra
.527 .71 0 r
.17858 .51796 .1925 .52321 .21288 .50244 .19909 .49764 Metetra
.33 .655 0 r
.19909 .49764 .21288 .50244 .23325 .48161 .21959 .4772 Metetra
.16 .6 0 r
.21959 .4772 .23325 .48161 .25356 .46102 .24006 .45695 Metetra
.019 .546 0 r
.24006 .45695 .25356 .46102 .27382 .44094 .26047 .43714 Metetra
0 .495 .093 r
.26047 .43714 .27382 .44094 .294 .42159 .28081 .41802 Metetra
0 .447 .178 r
.28081 .41802 .294 .42159 .31411 .40317 .30109 .39977 Metetra
0 .402 .237 r
.30109 .39977 .31411 .40317 .33416 .38584 .32131 .38258 Metetra
0 .363 .276 r
.32131 .38258 .33416 .38584 .35416 .36973 .34147 .36657 Metetra
0 .328 .299 r
.34147 .36657 .35416 .36973 .37412 .35496 .36161 .35186 Metetra
0 .289 .299 r
.36161 .35186 .37412 .35496 .39406 .34162 .38172 .33855 Metetra
0 .239 .276 r
.38172 .33855 .39406 .34162 .41402 .32978 .40184 .32671 Metetra
0 .206 .26 r
.40184 .32671 .41402 .32978 .43402 .31949 .422 .31639 Metetra
0 .187 .25 r
.422 .31639 .43402 .31949 .45408 .3108 .44223 .30764 Metetra
0 .181 .247 r
.44223 .30764 .45408 .3108 .47424 .30372 .46255 .30047 Metetra
0 .187 .25 r
.46255 .30047 .47424 .30372 .49454 .29825 .48301 .2949 Metetra
0 .206 .26 r
.48301 .2949 .49454 .29825 .51501 .2944 .50363 .29091 Metetra
0 .239 .276 r
.50363 .29091 .51501 .2944 .53568 .29214 .52445 .28848 Metetra
0 .289 .299 r
.52445 .28848 .53568 .29214 .55659 .29142 .54551 .28756 Metetra
0 .328 .299 r
.54551 .28756 .55659 .29142 .57777 .29219 .56683 .2881 Metetra
0 .363 .276 r
.56683 .2881 .57777 .29219 .59926 .29437 .58846 .29001 Metetra
0 .402 .237 r
.58846 .29001 .59926 .29437 .62109 .29786 .61043 .29319 Metetra
0 .447 .178 r
.61043 .29319 .62109 .29786 .64329 .30253 .63275 .2975 Metetra
0 .495 .093 r
.63275 .2975 .64329 .30253 .66588 .30822 .65547 .3028 Metetra
.019 .546 0 r
.65547 .3028 .66588 .30822 .68888 .31476 .67859 .30888 Metetra
.16 .6 0 r
.67859 .30888 .68888 .31476 .7123 .32192 .70213 .31552 Metetra
.33 .655 0 r
.70213 .31552 .7123 .32192 .73615 .32942 .72609 .32245 Metetra
.527 .71 0 r
.72609 .32245 .73615 .32942 .76042 .33698 .75046 .32934 Metetra
.746 .764 0 r
.75046 .32934 .76042 .33698 .78509 .34421 .77522 .33583 Metetra
.815 .653 0 r
.77522 .33583 .78509 .34421 .81011 .3507 .80033 .34149 Metetra
.836 .594 0 r
.12331 .55067 .13771 .55676 .1581 .53779 .14377 .53247 Metetra
.788 .725 0 r
.14377 .53247 .1581 .53779 .17858 .51796 .16434 .51329 Metetra
.632 .737 0 r
.16434 .51329 .17858 .51796 .19909 .49764 .18496 .49355 Metetra
.432 .684 0 r
.18496 .49355 .19909 .49764 .21959 .4772 .2056 .47361 Metetra
.255 .631 0 r
.2056 .47361 .21959 .4772 .24006 .45695 .22621 .45377 Metetra
.104 .58 0 r
.22621 .45377 .24006 .45695 .26047 .43714 .24678 .43432 Metetra
0 .53 .019 r
.24678 .43432 .26047 .43714 .28081 .41802 .26728 .41549 Metetra
0 .484 .115 r
.26728 .41549 .28081 .41802 .30109 .39977 .28773 .39748 Metetra
0 .441 .186 r
.28773 .39748 .30109 .39977 .32131 .38258 .30812 .38047 Metetra
0 .402 .237 r
.30812 .38047 .32131 .38258 .34147 .36657 .32846 .3646 Metetra
0 .369 .271 r
.32846 .3646 .34147 .36657 .36161 .35186 .34877 .34998 Metetra
0 .341 .292 r
.34877 .34998 .36161 .35186 .38172 .33855 .36906 .33673 Metetra
0 .319 .304 r
.36906 .33673 .38172 .33855 .40184 .32671 .38936 .32491 Metetra
0 .296 .303 r
.38936 .32491 .40184 .32671 .422 .31639 .4097 .31458 Metetra
0 .274 .293 r
.4097 .31458 .422 .31639 .44223 .30764 .4301 .30577 Metetra
0 .267 .29 r
.4301 .30577 .44223 .30764 .46255 .30047 .45059 .29852 Metetra
0 .274 .293 r
.45059 .29852 .46255 .30047 .48301 .2949 .47122 .29283 Metetra
0 .296 .303 r
.47122 .29283 .48301 .2949 .50363 .29091 .492 .28869 Metetra
0 .319 .304 r
.492 .28869 .50363 .29091 .52445 .28848 .51298 .28607 Metetra
0 .341 .292 r
.51298 .28607 .52445 .28848 .54551 .28756 .5342 .28493 Metetra
0 .369 .271 r
.5342 .28493 .54551 .28756 .56683 .2881 .55568 .2852 Metetra
0 .402 .237 r
.55568 .2852 .56683 .2881 .58846 .29001 .57746 .2868 Metetra
0 .441 .186 r
.57746 .2868 .58846 .29001 .61043 .29319 .59957 .28962 Metetra
0 .484 .115 r
.59957 .28962 .61043 .29319 .63275 .2975 .62204 .29352 Metetra
0 .53 .019 r
.62204 .29352 .63275 .2975 .65547 .3028 .64489 .29835 Metetra
.104 .58 0 r
.64489 .29835 .65547 .3028 .67859 .30888 .66814 .30389 Metetra
.255 .631 0 r
.66814 .30389 .67859 .30888 .70213 .31552 .6918 .30992 Metetra
.432 .684 0 r
.6918 .30992 .70213 .31552 .72609 .32245 .71587 .31615 Metetra
.632 .737 0 r
.71587 .31615 .72609 .32245 .75046 .32934 .74035 .32226 Metetra
.788 .725 0 r
.74035 .32226 .75046 .32934 .77522 .33583 .7652 .32787 Metetra
.836 .594 0 r
.7652 .32787 .77522 .33583 .80033 .34149 .79039 .33254 Metetra
.858 .527 0 r
.10864 .54471 .12331 .55067 .14377 .53247 .12914 .52741 Metetra
.814 .657 0 r
.12914 .52741 .14377 .53247 .16434 .51329 .14979 .50904 Metetra
.754 .766 0 r
.14979 .50904 .16434 .51329 .18496 .49355 .17051 .49 Metetra
.552 .716 0 r
.17051 .49 .18496 .49355 .2056 .47361 .19127 .47066 Metetra
.369 .666 0 r
.19127 .47066 .2056 .47361 .22621 .45377 .21202 .45134 Metetra
.21 .617 0 r
.21202 .45134 .22621 .45377 .24678 .43432 .23273 .43233 Metetra
.077 .57 0 r
.23273 .43233 .24678 .43432 .26728 .41549 .2534 .41386 Metetra
0 .525 .031 r
.2534 .41386 .26728 .41549 .28773 .39748 .27402 .39616 Metetra
0 .484 .115 r
.27402 .39616 .28773 .39748 .30812 .38047 .29459 .37939 Metetra
0 .447 .178 r
.29459 .37939 .30812 .38047 .32846 .3646 .31511 .3637 Metetra
0 .414 .223 r
.31511 .3637 .32846 .3646 .34877 .34998 .3356 .34922 Metetra
0 .387 .254 r
.3356 .34922 .34877 .34998 .36906 .33673 .35607 .33605 Metetra
0 .366 .274 r
.35607 .33605 .36906 .33673 .38936 .32491 .37656 .32427 Metetra
0 .35 .286 r
.37656 .32427 .38936 .32491 .4097 .31458 .39708 .31394 Metetra
0 .341 .292 r
.39708 .31394 .4097 .31458 .4301 .30577 .41766 .3051 Metetra
0 .338 .294 r
.41766 .3051 .4301 .30577 .45059 .29852 .43834 .29776 Metetra
0 .341 .292 r
.43834 .29776 .45059 .29852 .47122 .29283 .45914 .29195 Metetra
0 .35 .286 r
.45914 .29195 .47122 .29283 .492 .28869 .4801 .28764 Metetra
0 .366 .274 r
.4801 .28764 .492 .28869 .51298 .28607 .50126 .28481 Metetra
0 .387 .254 r
.50126 .28481 .51298 .28607 .5342 .28493 .52264 .28341 Metetra
0 .414 .223 r
.52264 .28341 .5342 .28493 .55568 .2852 .54429 .28338 Metetra
0 .447 .178 r
.54429 .28338 .55568 .2852 .57746 .2868 .56623 .28462 Metetra
0 .484 .115 r
.56623 .28462 .57746 .2868 .59957 .28962 .5885 .28702 Metetra
0 .525 .031 r
.5885 .28702 .59957 .28962 .62204 .29352 .61112 .29044 Metetra
.077 .57 0 r
.61112 .29044 .62204 .29352 .64489 .29835 .63412 .29472 Metetra
.21 .617 0 r
.63412 .29472 .64489 .29835 .66814 .30389 .6575 .29963 Metetra
.369 .666 0 r
.6575 .29963 .66814 .30389 .6918 .30992 .68129 .30494 Metetra
.552 .716 0 r
.68129 .30494 .6918 .30992 .71587 .31615 .70549 .31037 Metetra
.754 .766 0 r
.70549 .31037 .71587 .31615 .74035 .32226 .73007 .31556 Metetra
.814 .657 0 r
.73007 .31556 .74035 .32226 .7652 .32787 .75502 .32014 Metetra
.858 .527 0 r
.75502 .32014 .7652 .32787 .79039 .33254 .78029 .32367 Metetra
.881 .453 0 r
.0937 .53866 .10864 .54471 .12914 .52741 .11423 .52243 Metetra
.841 .58 0 r
.11423 .52243 .12914 .52741 .14979 .50904 .13493 .505 Metetra
.797 .702 0 r
.13493 .505 .14979 .50904 .17051 .49 .15574 .48678 Metetra
.689 .75 0 r
.15574 .48678 .17051 .49 .19127 .47066 .1766 .46817 Metetra
.503 .704 0 r
.1766 .46817 .19127 .47066 .21202 .45134 .19748 .44947 Metetra
.338 .657 0 r
.19748 .44947 .21202 .45134 .23273 .43233 .21834 .43099 Metetra
.196 .612 0 r
.21834 .43099 .23273 .43233 .2534 .41386 .23916 .41298 Metetra
.077 .57 0 r
.23916 .41298 .2534 .41386 .27402 .39616 .25995 .39565 Metetra
0 .53 .019 r
.25995 .39565 .27402 .39616 .29459 .37939 .28069 .37918 Metetra
0 .495 .093 r
.28069 .37918 .29459 .37939 .31511 .3637 .3014 .36373 Metetra
0 .464 .15 r
.3014 .36373 .31511 .3637 .3356 .34922 .32207 .34943 Metetra
0 .438 .191 r
.32207 .34943 .3356 .34922 .35607 .33605 .34274 .33638 Metetra
0 .417 .219 r
.34274 .33638 .35607 .33605 .37656 .32427 .36342 .32466 Metetra
0 .402 .237 r
.36342 .32466 .37656 .32427 .39708 .31394 .38413 .31434 Metetra
0 .393 .247 r
.38413 .31434 .39708 .31394 .41766 .3051 .40491 .30546 Metetra
0 .39 .251 r
.40491 .30546 .41766 .3051 .43834 .29776 .42578 .29805 Metetra
0 .393 .247 r
.42578 .29805 .43834 .29776 .45914 .29195 .44677 .2921 Metetra
0 .402 .237 r
.44677 .2921 .45914 .29195 .4801 .28764 .46792 .28761 Metetra
0 .417 .219 r
.46792 .28761 .4801 .28764 .50126 .28481 .48926 .28454 Metetra
0 .438 .191 r
.48926 .28454 .50126 .28481 .52264 .28341 .51082 .28285 Metetra
0 .464 .15 r
.51082 .28285 .52264 .28341 .54429 .28338 .53265 .28247 Metetra
0 .495 .093 r
.53265 .28247 .54429 .28338 .56623 .28462 .55476 .2833 Metetra
0 .53 .019 r
.55476 .2833 .56623 .28462 .5885 .28702 .5772 .28522 Metetra
.077 .57 0 r
.5772 .28522 .5885 .28702 .61112 .29044 .59998 .28809 Metetra
.196 .612 0 r
.59998 .28809 .61112 .29044 .63412 .29472 .62313 .29173 Metetra
.338 .657 0 r
.62313 .29173 .63412 .29472 .6575 .29963 .64666 .29592 Metetra
.503 .704 0 r
.64666 .29592 .6575 .29963 .68129 .30494 .67059 .3004 Metetra
.689 .75 0 r
.67059 .3004 .68129 .30494 .70549 .31037 .6949 .30489 Metetra
.797 .702 0 r
.6949 .30489 .70549 .31037 .73007 .31556 .7196 .30903 Metetra
.841 .58 0 r
.7196 .30903 .73007 .31556 .75502 .32014 .74464 .31243 Metetra
.881 .453 0 r
.74464 .31243 .75502 .32014 .78029 .32367 .76998 .31463 Metetra
.904 .375 0 r
.07854 .53225 .0937 .53866 .11423 .52243 .09906 .51725 Metetra
.868 .496 0 r
.09906 .51725 .11423 .52243 .13493 .505 .11979 .50092 Metetra
.828 .616 0 r
.11979 .50092 .13493 .505 .15574 .48678 .14065 .48368 Metetra
.786 .729 0 r
.14065 .48368 .15574 .48678 .1766 .46817 .1616 .46592 Metetra
.657 .743 0 r
.1616 .46592 .1766 .46817 .19748 .44947 .18259 .44796 Metetra
.487 .699 0 r
.18259 .44796 .19748 .44947 .21834 .43099 .20359 .43011 Metetra
.338 .657 0 r
.20359 .43011 .21834 .43099 .23916 .41298 .22457 .41264 Metetra
.21 .617 0 r
.22457 .41264 .23916 .41298 .25995 .39565 .24551 .39575 Metetra
.104 .58 0 r
.24551 .39575 .25995 .39565 .28069 .37918 .26643 .37965 Metetra
.019 .546 0 r
.26643 .37965 .28069 .37918 .3014 .36373 .28732 .36449 Metetra
0 .517 .048 r
.28732 .36449 .3014 .36373 .32207 .34943 .30819 .35041 Metetra
0 .492 .099 r
.30819 .35041 .32207 .34943 .34274 .33638 .32905 .33752 Metetra
0 .472 .135 r
.32905 .33752 .34274 .33638 .36342 .32466 .34993 .3259 Metetra
0 .458 .159 r
.34993 .3259 .36342 .32466 .38413 .31434 .37084 .31561 Metetra
0 .45 .173 r
.37084 .31561 .38413 .31434 .40491 .30546 .39181 .3067 Metetra
0 .447 .178 r
.39181 .3067 .40491 .30546 .42578 .29805 .41288 .2992 Metetra
0 .45 .173 r
.41288 .2992 .42578 .29805 .44677 .2921 .43408 .29311 Metetra
0 .458 .159 r
.43408 .29311 .44677 .2921 .46792 .28761 .45542 .28842 Metetra
0 .472 .135 r
.45542 .28842 .46792 .28761 .48926 .28454 .47696 .28509 Metetra
0 .492 .099 r
.47696 .28509 .48926 .28454 .51082 .28285 .49872 .28307 Metetra
0 .517 .048 r
.49872 .28307 .51082 .28285 .53265 .28247 .52073 .28229 Metetra
.019 .546 0 r
.52073 .28229 .53265 .28247 .55476 .2833 .54303 .28265 Metetra
.104 .58 0 r
.54303 .28265 .55476 .2833 .5772 .28522 .56564 .28403 Metetra
.21 .617 0 r
.56564 .28403 .5772 .28522 .59998 .28809 .58859 .28626 Metetra
.338 .657 0 r
.58859 .28626 .59998 .28809 .62313 .29173 .6119 .28917 Metetra
.487 .699 0 r
.6119 .28917 .62313 .29173 .64666 .29592 .63559 .29252 Metetra
.657 .743 0 r
.63559 .29252 .64666 .29592 .67059 .3004 .65965 .29606 Metetra
.786 .729 0 r
.65965 .29606 .67059 .3004 .6949 .30489 .6841 .29947 Metetra
.828 .616 0 r
.6841 .29947 .6949 .30489 .7196 .30903 .7089 .3024 Metetra
.868 .496 0 r
.7089 .3024 .7196 .30903 .74464 .31243 .73404 .30445 Metetra
.904 .375 0 r
.73404 .30445 .74464 .31243 .76998 .31463 .75945 .30514 Metetra
.926 .297 0 r
.06319 .52517 .07854 .53225 .09906 .51725 .08366 .51159 Metetra
.895 .407 0 r
.08366 .51159 .09906 .51725 .11979 .50092 .10438 .49653 Metetra
.86 .522 0 r
.10438 .49653 .11979 .50092 .14065 .48368 .12528 .48041 Metetra
.822 .634 0 r
.12528 .48041 .14065 .48368 .1616 .46592 .1463 .46363 Metetra
.782 .738 0 r
.1463 .46363 .1616 .46592 .18259 .44796 .16738 .44654 Metetra
.657 .743 0 r
.16738 .44654 .18259 .44796 .20359 .43011 .1885 .42944 Metetra
.503 .704 0 r
.1885 .42944 .20359 .43011 .22457 .41264 .20961 .4126 Metetra
.369 .666 0 r
.20961 .4126 .22457 .41264 .24551 .39575 .23072 .39625 Metetra
.255 .631 0 r
.23072 .39625 .24551 .39575 .26643 .37965 .25181 .38059 Metetra
.16 .6 0 r
.25181 .38059 .26643 .37965 .28732 .36449 .27288 .36578 Metetra
.084 .572 0 r
.27288 .36578 .28732 .36449 .30819 .35041 .29393 .35197 Metetra
.025 .549 0 r
.29393 .35197 .30819 .35041 .32905 .33752 .31499 .33927 Metetra
0 .53 .019 r
.31499 .33927 .32905 .33752 .34993 .3259 .33607 .32777 Metetra
0 .517 .048 r
.33607 .32777 .34993 .3259 .37084 .31561 .35719 .31753 Metetra
0 .509 .066 r
.35719 .31753 .37084 .31561 .39181 .3067 .37837 .30861 Metetra
0 .506 .071 r
.37837 .30861 .39181 .3067 .41288 .2992 .39965 .30102 Metetra
0 .509 .066 r
.39965 .30102 .41288 .2992 .43408 .29311 .42105 .29477 Metetra
0 .517 .048 r
.42105 .29477 .43408 .29311 .45542 .28842 .44261 .28986 Metetra
0 .53 .019 r
.44261 .28986 .45542 .28842 .47696 .28509 .46435 .28624 Metetra
.025 .549 0 r
.46435 .28624 .47696 .28509 .49872 .28307 .48631 .28385 Metetra
.084 .572 0 r
.48631 .28385 .49872 .28307 .52073 .28229 .50852 .28262 Metetra
.16 .6 0 r
.50852 .28262 .52073 .28229 .54303 .28265 .53101 .28245 Metetra
.255 .631 0 r
.53101 .28245 .54303 .28265 .56564 .28403 .55381 .2832 Metetra
.369 .666 0 r
.55381 .2832 .56564 .28403 .58859 .28626 .57694 .28471 Metetra
.503 .704 0 r
.57694 .28471 .58859 .28626 .6119 .28917 .60042 .28678 Metetra
.657 .743 0 r
.60042 .28678 .6119 .28917 .63559 .29252 .62426 .28918 Metetra
.782 .738 0 r
.62426 .28918 .63559 .29252 .65965 .29606 .64848 .29163 Metetra
.822 .634 0 r
.64848 .29163 .65965 .29606 .6841 .29947 .67305 .29383 Metetra
.86 .522 0 r
.67305 .29383 .6841 .29947 .7089 .3024 .69797 .29539 Metetra
.895 .407 0 r
.69797 .29539 .7089 .3024 .73404 .30445 .72319 .2959 Metetra
.926 .297 0 r
.72319 .2959 .73404 .30445 .75945 .30514 .74867 .29489 Metetra
.945 .223 0 r
.0477 .51709 .06319 .52517 .08366 .51159 .06807 .50512 Metetra
.92 .318 0 r
.06807 .50512 .08366 .51159 .10438 .49653 .08875 .49149 Metetra
.89 .423 0 r
.08875 .49149 .10438 .49653 .12528 .48041 .10965 .47666 Metetra
.857 .531 0 r
.10965 .47666 .12528 .48041 .1463 .46363 .13071 .46102 Metetra
.822 .634 0 r
.13071 .46102 .1463 .46363 .16738 .44654 .15186 .44492 Metetra
.786 .729 0 r
.15186 .44492 .16738 .44654 .1885 .42944 .17308 .42868 Metetra
.689 .75 0 r
.17308 .42868 .1885 .42944 .20961 .4126 .19432 .41258 Metetra
.552 .716 0 r
.19432 .41258 .20961 .4126 .23072 .39625 .21557 .39685 Metetra
.432 .684 0 r
.21557 .39685 .23072 .39625 .25181 .38059 .23682 .38171 Metetra
.33 .655 0 r
.23682 .38171 .25181 .38059 .27288 .36578 .25807 .36732 Metetra
.247 .629 0 r
.25807 .36732 .27288 .36578 .29393 .35197 .27931 .35384 Metetra
.181 .607 0 r
.27931 .35384 .29393 .35197 .31499 .33927 .30057 .34138 Metetra
.132 .59 0 r
.30057 .34138 .31499 .33927 .33607 .32777 .32185 .33003 Metetra
.097 .577 0 r
.32185 .33003 .33607 .32777 .35719 .31753 .34318 .31986 Metetra
.077 .57 0 r
.34318 .31986 .35719 .31753 .37837 .30861 .36458 .31093 Metetra
.07 .567 0 r
.36458 .31093 .37837 .30861 .39965 .30102 .38607 .30325 Metetra
.077 .57 0 r
.38607 .30325 .39965 .30102 .42105 .29477 .40768 .29684 Metetra
.097 .577 0 r
.40768 .29684 .42105 .29477 .44261 .28986 .42945 .29168 Metetra
.132 .59 0 r
.42945 .29168 .44261 .28986 .46435 .28624 .45141 .28773 Metetra
.181 .607 0 r
.45141 .28773 .46435 .28624 .48631 .28385 .47358 .28493 Metetra
.247 .629 0 r
.47358 .28493 .48631 .28385 .50852 .28262 .496 .28319 Metetra
.33 .655 0 r
.496 .28319 .50852 .28262 .53101 .28245 .51869 .28241 Metetra
.432 .684 0 r
.51869 .28241 .53101 .28245 .55381 .2832 .54168 .28245 Metetra
.552 .716 0 r
.54168 .28245 .55381 .2832 .57694 .28471 .565 .28313 Metetra
.689 .75 0 r
.565 .28313 .57694 .28471 .60042 .28678 .58866 .28426 Metetra
.786 .729 0 r
.58866 .28426 .60042 .28678 .62426 .28918 .61267 .28558 Metetra
.822 .634 0 r
.61267 .28558 .62426 .28918 .64848 .29163 .63703 .28681 Metetra
.857 .531 0 r
.63703 .28681 .64848 .29163 .67305 .29383 .66174 .28762 Metetra
.89 .423 0 r
.66174 .28762 .67305 .29383 .69797 .29539 .68677 .28763 Metetra
.92 .318 0 r
.68677 .28763 .69797 .29539 .72319 .2959 .71208 .28642 Metetra
.945 .223 0 r
.71208 .28642 .72319 .2959 .74867 .29489 .73761 .28349 Metetra
.961 .161 0 r
.03213 .50762 .0477 .51709 .06807 .50512 .05236 .49744 Metetra
.942 .235 0 r
.05236 .49744 .06807 .50512 .08875 .49149 .07295 .48544 Metetra
.918 .325 0 r
.07295 .48544 .08875 .49149 .10965 .47666 .09382 .47206 Metetra
.89 .423 0 r
.09382 .47206 .10965 .47666 .13071 .46102 .11487 .4577 Metetra
.86 .522 0 r
.11487 .4577 .13071 .46102 .15186 .44492 .13607 .44274 Metetra
.828 .616 0 r
.13607 .44274 .15186 .44492 .17308 .42868 .15736 .42749 Metetra
.797 .702 0 r
.15736 .42749 .17308 .42868 .19432 .41258 .17871 .41224 Metetra
.754 .766 0 r
.17871 .41224 .19432 .41258 .21557 .39685 .20009 .39724 Metetra
.632 .737 0 r
.20009 .39724 .21557 .39685 .23682 .38171 .22149 .38271 Metetra
.527 .71 0 r
.22149 .38271 .23682 .38171 .25807 .36732 .24291 .36881 Metetra
.439 .686 0 r
.24291 .36881 .25807 .36732 .27931 .35384 .26434 .35571 Metetra
.369 .666 0 r
.26434 .35571 .27931 .35384 .30057 .34138 .28579 .34353 Metetra
.315 .65 0 r
.28579 .34353 .30057 .34138 .32185 .33003 .30727 .33237 Metetra
.277 .638 0 r
.30727 .33237 .32185 .33003 .34318 .31986 .32881 .3223 Metetra
.254 .631 0 r
.32881 .3223 .34318 .31986 .36458 .31093 .35042 .31337 Metetra
.247 .629 0 r
.35042 .31337 .36458 .31093 .38607 .30325 .37213 .3056 Metetra
.254 .631 0 r
.37213 .3056 .38607 .30325 .40768 .29684 .39397 .29901 Metetra
.277 .638 0 r
.39397 .29901 .40768 .29684 .42945 .29168 .41596 .29358 Metetra
.315 .65 0 r
.41596 .29358 .42945 .29168 .45141 .28773 .43814 .28926 Metetra
.369 .666 0 r
.43814 .28926 .45141 .28773 .47358 .28493 .46053 .28599 Metetra
.439 .686 0 r
.46053 .28599 .47358 .28493 .496 .28319 .48316 .28368 Metetra
.527 .71 0 r
.48316 .28368 .496 .28319 .51869 .28241 .50606 .28222 Metetra
.632 .737 0 r
.50606 .28222 .51869 .28241 .54168 .28245 .52926 .28145 Metetra
.754 .766 0 r
.52926 .28145 .54168 .28245 .565 .28313 .55277 .2812 Metetra
.797 .702 0 r
.55277 .2812 .565 .28313 .58866 .28426 .57661 .28125 Metetra
.828 .616 0 r
.57661 .28125 .58866 .28426 .61267 .28558 .60079 .28135 Metetra
.86 .522 0 r
.60079 .28135 .61267 .28558 .63703 .28681 .6253 .2812 Metetra
.89 .423 0 r
.6253 .2812 .63703 .28681 .66174 .28762 .65014 .28046 Metetra
.918 .325 0 r
.65014 .28046 .66174 .28762 .68677 .28763 .67528 .27874 Metetra
.942 .235 0 r
.67528 .27874 .68677 .28763 .71208 .28642 .70067 .2756 Metetra
.961 .161 0 r
.70067 .2756 .71208 .28642 .73761 .28349 .72625 .27055 Metetra
.972 .117 0 r
.01657 .4963 .03213 .50762 .05236 .49744 .0366 .48812 Metetra
.96 .165 0 r
.0366 .48812 .05236 .49744 .07295 .48544 .05705 .47794 Metetra
.942 .235 0 r
.05705 .47794 .07295 .48544 .09382 .47206 .07782 .46619 Metetra
.92 .318 0 r
.07782 .46619 .09382 .47206 .11487 .4577 .09885 .45329 Metetra
.895 .407 0 r
.09885 .45329 .11487 .4577 .13607 .44274 .12005 .43961 Metetra
.868 .496 0 r
.12005 .43961 .13607 .44274 .15736 .42749 .14139 .42549 Metetra
.841 .58 0 r
.14139 .42549 .15736 .42749 .17871 .41224 .16282 .41122 Metetra
.814 .657 0 r
.16282 .41122 .17871 .41224 .20009 .39724 .18431 .39705 Metetra
.788 .725 0 r
.18431 .39705 .20009 .39724 .22149 .38271 .20585 .38321 Metetra
.746 .764 0 r
.20585 .38321 .22149 .38271 .24291 .36881 .22742 .36989 Metetra
.656 .742 0 r
.22742 .36989 .24291 .36881 .26434 .35571 .24902 .35724 Metetra
.583 .724 0 r
.24902 .35724 .26434 .35571 .28579 .34353 .27066 .34539 Metetra
.527 .71 0 r
.27066 .34539 .28579 .34353 .30727 .33237 .29234 .33445 Metetra
.487 .699 0 r
.29234 .33445 .30727 .33237 .32881 .3223 .31409 .3245 Metetra
.463 .693 0 r
.31409 .3245 .32881 .3223 .35042 .31337 .33592 .31558 Metetra
.455 .691 0 r
.33592 .31558 .35042 .31337 .37213 .3056 .35785 .30773 Metetra
.463 .693 0 r
.35785 .30773 .37213 .3056 .39397 .29901 .37991 .30094 Metetra
.487 .699 0 r
.37991 .30094 .39397 .29901 .41596 .29358 .40213 .2952 Metetra
.527 .71 0 r
.40213 .2952 .41596 .29358 .43814 .28926 .42453 .29047 Metetra
.583 .724 0 r
.42453 .29047 .43814 .28926 .46053 .28599 .44715 .28668 Metetra
.656 .742 0 r
.44715 .28668 .46053 .28599 .48316 .28368 .47 .28372 Metetra
.746 .764 0 r
.47 .28372 .48316 .28368 .50606 .28222 .49312 .28149 Metetra
.788 .725 0 r
.49312 .28149 .50606 .28222 .52926 .28145 .51653 .27981 Metetra
.814 .657 0 r
.51653 .27981 .52926 .28145 .55277 .2812 .54024 .27851 Metetra
.841 .58 0 r
.54024 .27851 .55277 .2812 .57661 .28125 .56426 .27736 Metetra
.868 .496 0 r
.56426 .27736 .57661 .28125 .60079 .28135 .58861 .27609 Metetra
.895 .407 0 r
.58861 .27609 .60079 .28135 .6253 .2812 .61328 .27439 Metetra
.92 .318 0 r
.61328 .27439 .6253 .2812 .65014 .28046 .63825 .27192 Metetra
.942 .235 0 r
.63825 .27192 .65014 .28046 .67528 .27874 .66349 .26826 Metetra
.96 .165 0 r
.66349 .26826 .67528 .27874 .70067 .2756 .68895 .26298 Metetra
.972 .117 0 r
.68895 .26298 .70067 .2756 .72625 .27055 .71457 .25558 Metetra
.977 .099 0 r
.0011 .48266 .01657 .4963 .0366 .48812 .02087 .47669 Metetra
.972 .117 0 r
.02087 .47669 .0366 .48812 .05705 .47794 .04112 .46851 Metetra
.961 .161 0 r
.04112 .46851 .05705 .47794 .07782 .46619 .06176 .45858 Metetra
.945 .223 0 r
.06176 .45858 .07782 .46619 .09885 .45329 .0827 .44731 Metetra
.926 .297 0 r
.0827 .44731 .09885 .45329 .12005 .43961 .10387 .43508 Metetra
.904 .375 0 r
.10387 .43508 .12005 .43961 .14139 .42549 .12522 .42223 Metetra
.881 .453 0 r
.12522 .42223 .14139 .42549 .16282 .41122 .1467 .40906 Metetra
.858 .527 0 r
.1467 .40906 .16282 .41122 .18431 .39705 .16827 .39584 Metetra
.836 .594 0 r
.16827 .39584 .18431 .39705 .20585 .38321 .18992 .38279 Metetra
.815 .653 0 r
.18992 .38279 .20585 .38321 .22742 .36989 .21163 .37013 Metetra
.796 .702 0 r
.21163 .37013 .22742 .36989 .24902 .35724 .23339 .358 Metetra
.78 .743 0 r
.23339 .358 .24902 .35724 .27066 .34539 .25521 .34654 Metetra
.762 .767 0 r
.25521 .34654 .27066 .34539 .29234 .33445 .27708 .33587 Metetra
.721 .758 0 r
.27708 .33587 .29234 .33445 .31409 .3245 .29904 .32606 Metetra
.697 .752 0 r
.29904 .32606 .31409 .3245 .33592 .31558 .32108 .31716 Metetra
.689 .75 0 r
.32108 .31716 .33592 .31558 .35785 .30773 .34323 .30921 Metetra
.697 .752 0 r
.34323 .30921 .35785 .30773 .37991 .30094 .36552 .30221 Metetra
.721 .758 0 r
.36552 .30221 .37991 .30094 .40213 .2952 .38797 .29614 Metetra
.762 .767 0 r
.38797 .29614 .40213 .2952 .42453 .29047 .4106 .29095 Metetra
.78 .743 0 r
.4106 .29095 .42453 .29047 .44715 .28668 .43344 .28657 Metetra
.796 .702 0 r
.43344 .28657 .44715 .28668 .47 .28372 .45652 .28289 Metetra
.815 .653 0 r
.45652 .28289 .47 .28372 .49312 .28149 .47986 .27979 Metetra
.836 .594 0 r
.47986 .27979 .49312 .28149 .51653 .27981 .50348 .2771 Metetra
.858 .527 0 r
.50348 .2771 .51653 .27981 .54024 .27851 .52739 .27462 Metetra
.881 .453 0 r
.52739 .27462 .54024 .27851 .56426 .27736 .55161 .27212 Metetra
.904 .375 0 r
.55161 .27212 .56426 .27736 .58861 .27609 .57613 .26932 Metetra
.926 .297 0 r
.57613 .26932 .58861 .27609 .61328 .27439 .60095 .2659 Metetra
.945 .223 0 r
.60095 .2659 .61328 .27439 .63825 .27192 .62604 .26149 Metetra
.961 .161 0 r
.62604 .26149 .63825 .27192 .66349 .26826 .65138 .2557 Metetra
.972 .117 0 r
.65138 .2557 .66349 .26826 .68895 .26298 .67691 .24806 Metetra
.977 .099 0 r
.67691 .24806 .68895 .26298 .71457 .25558 .70256 .23807 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00/_ooool3o`0000Cooooo0_l0
001Uooooo`00/oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0006Cooooo002c
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000I?ooool00;?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Cooooo`;o0000Coooool00;?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000@ooooo`?o000000?oooooo`000?ooool0C_oo
ool00;;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000kooooo0_l00004ooooo`;o0000C_oo
ool00;?ooooo00?o0000ooooooooool00oooool2o`0000cooooo0ol00002ooooo`07o`000?oooooo
ooooooooool0003oooooo`00001=ooooo`00aOooool2o`0000Wooooo00Co0000ooooool0003o0000
C?ooool00<;ooooo0ol0000;ooooo`04o`000?ooooooooooo`0004cooooo002oooooo`?o00003_oo
ool01Ol0003ooooooooooooooooo000004_ooooo002mooooo`;o00004Oooool01Ol0003ooooooooo
oooooooo000004_ooooo002jooooo`Co00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00_ooooo0ol00004ooooo`;o0000=?ooool00;Sooooo0_l00004ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000<oooool00;Gooooo0ol0000Iooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool5o`0000?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000cooooo`00/oooool2o`0001cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<ooo
ool00;3ooooo0ol0000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003?ooooo002^ooooo`;o00008Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`04o`000?oooooo
ooooo`0003?ooooo002[ooooo`?o00000_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Cooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo0_l0000dooooo`00ZOooool2o`00
02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`00Y_ooool3o`0002So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`00Y?ooool2o`0002_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`12ooooo`00XOooool3o`0002gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`12ooooo`00W_ooool3o`0000;ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo002Loooo
o`;o0000<oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo043ooooo002Iooooo`?o
0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo043ooooo002Gooooo`;o0000
>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03oooooo001eooooo`;o00007Ooo
ool3o`0003[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0nooooo`00M?ooool0
1?l0003oooooooooool0000Jooooo`;o000000?oooooo`000?ooool0>oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo03kooooo001dooooo`04o`000?ooooooooooo`0001Oooooo0ol0
0010ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?Oooool007Cooooo00Co0000
oooooooooooo00005Oooool2o`0004?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0looooo`00M?ooool01?l0003oooooooooool0000Booooo`?o0000AOooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03cooooo001dooooo`04o`000?ooooooooooo`00013ooooo0_l0
0018ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>oooool007Gooooo0_l0000>
ooooo`Co0000BOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03[ooooo0023oooo
o`;o0000COooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03[ooooo0020ooooo`?o
0000Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo001mooooo`?o0000
D_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo001kooooo`;o0000EOoo
ool00ol0003oooooooooo`0@ooooo`;o0000>Oooool007Sooooo1?l0001Fooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0=oooool007Kooooo0_l00004ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`00Loooool3o`0005co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0fooooo`00LOooool2o`0005oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0eooooo`00K_ooool3o`00067ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0eooooo`00K?ooool2o`000003ooooool0003o
oooo06;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0dooooo`00JOooool3o`00
06Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0cooooo`00Ioooool2o`0006[o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0cooooo`00I?ooool3o`0006cooooo
00?o0000ooooooooool05?ooool2o`0003Cooooo001Rooooo`;o0000Koooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo037ooooo001Oooooo`?o000000?oooooo`000?ooool0K_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo037ooooo001Looooo`?o0000M?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo033ooooo001Jooooo`;o0000Moooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02oooooo000booooo`?o00001?ooool2o`0001cooooo
0ol0001iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;oooool003?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`;o0000O?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo02kooooo000[ooooo`Go00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001Kooooo0ol00002ooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0]ooooo`00<oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001Cooooo0_l00021ooooo`03o`000?oooooooooo01[ooooo
0_l0000^ooooo`00<oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00017ooooo
0ol00023ooooo`03o`000?oooooooooo01[ooooo0_l0000^ooooo`00<_ooool2o`0000Cooooo00Co
0000oooooooooooo00003oooool2o`0008Kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0[ooooo`00<oooool00ol0003oooooooooo`03ooooo`;o00003Oooool4o`0008Oooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0[ooooo`00A_ooool2o`0008cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`06ooooo`;o00008_ooool004?ooooo0ol0002>oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Q
ooooo`00@Oooool2o`00097ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`00027ooooo000nooooo`?o0000Toooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00008Oooool003_ooooo0ol00002oooo
o`03o`000?oooooooooo097ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`00027ooooo000iooooo`;o0000Uoooool3o`00023ooooo0ol00003oooo
o`04o`000?ooooooooooo`00027ooooo000fooooo`?o0000U_ooool3o`0000;onQT000?o0000oooo
ooooool08?ooool00ol0003oooooooooo`02ooooo`;o00008_ooool003Cooooo0_l0002Fooooo`?o
00001?oj6@03o`00027ooooo00?o0000ooooooooool09_ooool0037ooooo1?l0002Dooooo`?o0000
00Con1d0o`000?oj6@3onQT00ol000001?oj6@3o0000ooXI0?l0000Qooooo`03o`000?oooooooooo
02Gooooo000`ooooo`;o0000U?ooool3o`0000Con1d00ol00005ooXI00?o00008Oooool00ol0003o
ooooooooo`0Tooooo`00<?ooool00ol0003oooooo`00002@ooooo`?o00000_of:@000ol0003on1d0
o`000002o`0000;on1d000?o0000ooXI0?oj6@000ol000000ooh7@3o0000o`00000Qooooo`03o`00
0?oooooooooo02Cooooo000`ooooo`04o`000?ooooooooooo`0008[ooooo1Ol00004ooHY00?o0000
0ooh7@05o`0000Gon1d00_l0000Qooooo`03o`000?oooooooooo02?ooooo000`ooooo`05o`000?oo
ooooooooooooool00000Poooool6o`0000GolCT02_l00004ooDZ0003o`000?oh7@3on1d000?on1d0
00?o0000ooPM0?l000008Oooool00ol0003oooooooooo`0Rooooo`00;oooool2o`0000Cooooo00?o
0000ooooooooool0Loooool=o`0000GokD`000Co0000oo4i0?oa>@3olCT01_l00004oo4l0003o`00
0?oe:P3omBX000ComBX000?o0000ooPM0?oh7@000_oh7@04o`00023ooooo0_l0000Sooooo`00;ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo1Ol00005on5c00;o00000ooW
G`0<o`0000Goje4000?o0000oo4l0?oa?0000ooa?0001?l0003omBX0ooDZ0?oe:P07o`0000;omRT0
0_l0000Qooooo`03o`000?oooooooooo027ooooo000_ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0H?oooolKo`0000GogWh01?l00002onEX0004o`000?o[D@3oje40on]A00co0000
1?oa?0000ol0003omRT0ooHY0002ooHY0003o`000?of:@3o0000027ooooo00?o0000ooooooooool0
8?ooool002oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Ioooooc3o00001OoS
K0000ol0003oje<0on]C0003on]C0003o`000?oa?03olC`000?olC`000Co0000ooHY0?of:@3omRT0
1?l0000Pooooo`03o`000?oooooooooo023ooooo000^ooooo`;o00002Oooool00ol0003ooooooooo
o`1Coooood[o00000_oa>@000ol0003olCT0o`00000Pooooo`03o`000?oooooooooo01oooooo000_
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0C?oooolEo`0000?o04]=1Ol00002
o`0mAR;o000000?ofhL0o`000?oSK0001OoSK0000ol0003oje40on]A0003on]A0007o`000?oa>@3o
lCT0oo4i0?l0003olCT0o`00000Pooooo`03o`000?oooooooooo01kooooo000^ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0AooooolEo`000003o`16Bol0003o000000Co00000_l0
=485o`0000Co02/m00Co0000o`0f@ol0=T?o03I31_l000000ol0AT_o0000o`1CC00Wo`0001oooooo
00?o0000ooooooooool07_ooool002kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`13oooooaWo00000ol0;cl5o`0000?o02@i2_l00004o`0X>`03o`000?l0=T?o000001co000000?o
g8D0o`000?oUJ0001?oUJ0001?l0003okD`0one<0?l00002one<0003o`000?oooooooooo01gooooo
00?o0000ooooooooool07Oooool002kooooo0_l0000=ooooo`03o`000?oooooooooo043ooooo0ol0
00000omf/@3o0000o`000008o`000003o`1S@?l0003o000000Ko00000ol0;Sl4o`0000?o01lf1Ol0
0004o`0H<@?o000000?o01heo`000?l000003ol00002o`1GBQoo000000?okD`0o`000?ooool07Ooo
ool2o`0001kooooo000^ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??oooolI
o`000004o`0^?ol0003o0000o`0000?o01he1?l00004o`0D;P03o`000?l0637o000000Ko00001?l0
5Rl00ol0003o01heo`0N=@02o`0N=@03o`000?l0:cgo02/m00;o02/m00?o0000o`0mA_l000001?l0
00000ol0Ed[o0000o`1S@@0>o`0000;oc;<01_l000000ooNOP3o0000onMO0004o`0001kooooo00?o
0000ooooooooool07?ooool002kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0g
oooooaWo00000ol0;cl4o`000004o`0N=Ol0003o0000o`0000?o01<]00Co0000o`0D;_l052ko01@^
1Ol00004o`0@:`04o`000?l05Roo01H_o`0F;a7o000000?o055=o`000?l000002ol000000olXV@3o
0000o`000005o`000004olbc0?l0003oei@0omND00Ko000000?oiel0o`000?ooool07Oooool00ol0
003oooooooooo`0Kooooo`00;Oooool3o`00013ooooo00?o0000ooooooooool0<_ooool:o`000003
oa>A0?l0003o000000oo000000Co02loo`000?l0003o00000ol07cH3o`0000Go01<]1?l00004o`0>
:0Wo00000ol042/00ol0003o01Pao`0H<@02o`0H<@05o`000?l093Wo02@io`0T>Ol000000ol0=486
o`0000;o05e62_l000000olXV@3o0000o`000009o`000003omND0?l0003ohG<000Co00007?ooool0
0ol0003oooooooooo`0Kooooo`00;Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02oooooo1Ol000000omf/@3o0000o`00000?o`0000;o04]=00Co0000o`0d@_l0=4;o03A21?l00000
1?l07cKo0000o`000?l00003o`0D;P03o`000?l04bgo000000?o00000_l03BL00ol0003o00hXo`00
0002o`000003o`098ol0003o00`V00Co00`V00Co0000o`0@:ol042_o010[3?l00004o`0d@P03o`00
0?l0Bdgo04]=00Go000000?o05e6o`000?l000002ol000001?nQ_03o0000o`000?l00002om2X00Ko
000000?ohG<0o`000?ooool06oooool00ol0003oooooooooo`0Jooooo`001oooool3o`0000?ooooo
0ol00003ooooo`?o00001?ooool01?l0003oooooooooooooool5o`0000?ooooo0ol00004ooooo`03
o`000?oooooooooo01;ooooo0_l0000]ooooo`Wo000000?o69<0o`000?l000003?l00002o`1;C@05
o`000?l0=4;o03A2o`0d@_l000000ol093T3o`0000Go01@^1?l00003o`0=9`?o00001Ol02B<01?l0
003o00`Vo`0<9_l032H5o`0000?o00hX00?o0000o`0D;_l052h00_l052h00ol0003o01lfo`0O=P0:
o`000003o`1;COl0003o05U900Co000000Co06Xho`000?l0003o07dI3_l000001?o@Z03o0000om^6
0?oKQP03o`0001cooooo00?o0000ooooooooool06Oooool000Sooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Xooooo`Co000000?oO;80o`000?l000002Ol000001?l0JSSo0000o`000?l0GDH2o`00
00Co055=1?l000001?l0=4;o0000o`0T>Ol093T2o`0000?o01Pa00?o0000o`0D;_l000000_l00003
o`0>:0Co00000ol022801?l0003o00TSo`098ol02B<5o`0000?o00TS00?o0000o`0>:?l03RP00ol0
3RP00ol0003o01@^o`0D;P02o`0D;P03o`000?l07cKo01lf00;o01lf00Go0000o`0_?ol0;coo02lo
o`000002o`16B`Co000000?o05U9o`000?l0IS`01_l00002o`J<00Go000000?oQ[D0o`000?l00000
2?l000000ooKQP3o0000ooooo`0Jooooo`03o`000?oooooooooo01Wooooo0008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`04o`000?oo
ooooooooooooo`Go00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo
0ol000000onh`P3o0000o`000006o`0000;o08L40ol00002o`1Z>004o`000?l0GDKo05e6o`0000Co
055=0_l00003o`0mAP?o000000?o02@io`000?l063401?l06344o`000006o`0>:?l0003o0000o`00
0?l02B?o00001Ol02284o`0000Co00LQ00?o0000o`098ol02B<00_l02B<01?l0003o00hXo`0>:?l0
3RPAo`0000?o04I;00?o0000o`1GB_l000000_l00003o`1V?0Ko000000?o1X`0o`000?l^V`001Ol0
00000on6]@3o0000o`000003o`000003omJH0?l0003o000000;o00006_ooool2o`0001Wooooo0008
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0001Sooooo00?o
0000ooooooooool08Oooool7o`000003oe2V0?l0003o000000;o00000ol0Q`@;o`0000;o055=00Co
0000o`0mA_l0?DKo03e60_l00002o`0[?@Co000000Co01Pao`000?l0003o00000ol042/2o`0000Go
00TS00?o0000o`088_l000000_l00002o`067`03o`000?l01b7o00LQ00?o00LQ2Ol00002o`0=9`03
o`000?l04bgo01<]00;o01<]00?o0000o`0N=Ol07SD00_l07SD01?l0003o02hoo`0^?ol0;Sl6o`00
00?o05M:0ol000000ol0ISco0000o`1e:006o`0000?o;Y/03?l000000ooFV03o0000ooooo`0Hoooo
o`;o00006Oooool000Sooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002?ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01kooooo0_l000000oo3a03o0000o`00000=o`000003o`1`<?l0003o
000000;o06=100?o0000o`1GB_l0EdX00_l0EdX4o`000003o`0mA_l0003o02/m00;o02/m00?o0000
o`0N=Ol07SD01?l00003o`0@:`;o00000_l032H00ol0003o00TSo`098`02o`098`?o00001Ol01Ql0
0ol0003o00LQo`000002o`000003o`067ol0003o00PR00?o00PR00?o0000o`0=9ol03BL00ol03BL0
0ol0003o01<]o`0C;@02o`0C;@03o`000?l07SGo01he00;o01he00Go0000o`0^?ol0;Soo02hoo`00
0003o`14BPCo000000?o05M:o`000?l0I3l00ol00003o`1e:0;o000000Oo08L4o`000?l0003o0000
objK0?l0003oGZX000Oo00000_o@Y`03o`0001Wooooo00?o0000ooooooooool05oooool000Oooooo
0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00004ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06oooool:o`000003objK0?l0003o000000;o1X`00ol00002o`1`<005o`000?l0Hd7o06=1o`1S
@Ol000000ol0EdX2o`0000?o04U<1?l000000ol0:cgo0000o`000003o`0000?o01H_00?o0000o`0@
:ol000001Ol032H01?l0003o00TSo`000?l00003o`078@04o`000?l01Qoo00HOo`067`?o00001Ol0
1Ql00ol0003o00PRo`088P02o`088P04o`000?l03BOo00dWo`0=9`co00001?l0;Sl00ol0003o04A:
o`14BP02o`14BP03o`000?l0ET_o000000;o00000ol0I3l8o`000004ob6G0?l0003o0000o`0000?o
GZX00ol000001_nW_@3o0000o`000?l0003od:L0o`0001[ooooo00?o0000ooooooooool05_ooool0
00Sooooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`0000Sooooo0ol00005
ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`03o`000?oooooooooo01Sooooo1?l00002
oiFi00;o000000GoGZX0o`000?l0003o;Y/0o`000002o`J<00Wo000000?o06=1o`000?l0EdX00_l0
EdX01?l0003o04U<o`19C?l0BD`2o`0000?o03I30ol000000ol07SGo0000o`0F;`04o`0F;`?o0000
1Ol032H2o`0000Go00LQ1?l00003o`057P03o`000?l01Qoo00HO00;o00HO2Ol00002o`0>:003o`00
0?l052ko01@^00;o01@^00Co0000o`0O=_l07cKo01lf2_l000000ol0A4[o0000o`1FB`02o`1FB`Go
00000_l0Lb`7o`000005ob6G0?l0003o0000o`000?mNZP001Ol000001?o;/`3o0000o`000?l0000J
ooooo`03o`000?oooooooooo01Gooooo000/ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool05Oooool2o`000003olNn0?l0003oUKT000;oUKT000?o0000oejZ0?mNZP002Ol00002o`1f
9P04o`000?l0JCWo06Tio`1Y>@So000000Co04U<o`000?l0=T?o03I30ol00002o`0X>`?o00000ol0
5Rl2o`0000?o010[00?o0000o`0<9_l000000_l00002o`098`03o`000?l01b7o000000;o00000_l0
1Ql00ol0003o00DNo`057P03o`057P06o`000?l01Qoo0000o`000?l01b7o00001Ol02B<00ol0003o
00hXo`0>:002o`0>:003o`000?l052ko01@^00;o01@^00?o0000o`0O=_l07cH00_l07cH01Ol0003o
02loo`0_?ol0;coo000000?o04I;1?l000000ol0ET_o0000o`1S@002o`1S@0Co000000?o07</o`00
0?l0PQ001_l000000om@YP3o0000o`000002o`0000;oUKT00ol000000oo;/`3o0000o`00000Hoooo
o`03o`000?oooooooooo01Gooooo000/ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool04oooool=o`000003oaFB0?l0003o000000;o08@<00Co0000o`1f9_l0MRKo00000_l0JCT2o`00
00?o05i500Co0000o`1CC?l0Ddco05=<1_l00003o`0X>`07o`000?l07SGo01heo`0N=Ol0003o01H_
o`000005o`0@:`;o00001Ol02B<2o`0000Ko00HO00Co0000o`057_l01Ako00DN0ol00004o`078@03
o`000?l02B?o00TS00?o00TS00?o0000o`0>:?l03RP00_l03RP00ol0003o01@^o`0D;P02o`0D;P03
o`000?l07cKo01lf00;o01lf00Go0000o`0_?ol0;coo02loo`000004o`16B`03o`000?l0Ed[o0000
00;o00000ol0Hd000ol0003o078]o`1b;@03o`0000?o088@0_l000001OlHT`3o0000o`000?l0003o
D:H000?o000000?oUKT0o`000?o7_P001?l0000Hooooo`03o`000?oooooooooo01Cooooo000/oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool4o`0000;oYkd00_l000001Om`
[`3o0000o`000?loX@3o000000;o5I8000Go0000o`243?l0Q0co08@<o`000002o`1f9P04o`000?l0
JCWo06Tio`0000Co05i500?o0000o`1CC?l0Dd`01?l000000ol0AT_o0000o`000002o`000003o`0X
>ol0003o01he00?o01he0ol00003o`0@:`;o00000_l03RP01Ol0003o00TSo`098ol02B?o000000;o
00PR00?o0000o`067ol01Ql00ol01Ql4o`0000;o00HO00?o0000o`078Ol01b400ol01b401?l0003o
00TSo`098ol02B<Fo`0000Co04I;00Co0000o`1GB_l0Ed[o05M:0_l00002o`1S@003o`000?l0LRgo
078]00;o078]0_l000000ol0PQ3o0000oa>A0003o`000005odJS0?l0003o0000o`000?n6]@000ol0
0003olNn00;o00006?ooool00ol0003oooooooooo`0Cooooo`00:oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00gooooo0_l000001?o;/`3o0000ojNm0?nW_@02o`0000;oL:l04ol0
0002o`1NA@03o`000?l0Ddco000000;o00000ol0AT/01?l0003o03I3o`0f@ol0=T<3o`0000?o01he
00Oo0000o`0H<Ol0637o01Pao`000?l042_o000000Go00hX00?o0000o`098ol000001?l022800ol0
003o00HOo`000002o`000003o`078Ol0003o00HO00Co00HO00Co0000o`078Ol01b7o00LQ1Ol00002
o`0<9P03o`000?l042_o010[00;o010[00?o0000o`0H<Ol063400_l063400ol0003o02@io`0T>@02
o`0T>@04o`000?l0=4;o03A2o`0d@PKo00000ol0EdX00ol0003o06@oo`000002o`0000Co078]00?o
0000o`214_l000000_l00002oa>A00;o00000om6X`03o`000006ohJe0?l0003o0000o`000?o7_P3o
00006?ooool2o`0001Cooooo000[ooooo`;o00008Oooool00ol0003oooooooooo`0;ooooo`go0000
0_lXV@001Ol0003o18/0o`B;0?l4R`3o000000;o07hG00Co0000o`1b;Ol0LRgo00001?l0IS`6o`00
00?o04I;00Go0000o`0f@ol0=T?o03I3o`000003o`0[?@03o`000?l07SGo000000Co01Pa0_l00006
o`0>:0;o00001Ol02282o`0000Go00LQ00?o0000o`067ol01Ql00_l01Ql4o`0000;o00TS00?o0000
o`0<9_l032H00ol032H00ol0003o010[o`0@:`02o`0@:`03o`000?l0637o01Pa00;o01Pa00?o0000
o`0T>Ol093T00_l093T01Ol0003o03A2o`0d@_l0=4;o000000?o04]=1_l00003o`1T?`Co000000?o
078]o`000?l0PA800_l0PA82o`0000;o4i400ol000000om6X`3o0000ogbb0003o`000004ol?40?l0
003o0000o`0001Sooooo00?o0000ooooooooool04_ooool002_ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`08ooooo`Co00000_nn``000ol0003oQ[D0ohJe0002o`0000;oE:L000Co
0000obRI0?lXV@3o00000ol4R`001?l0003o07hGo`1n5ol00002o`1b;@03o`000?l0ISco06Hl00;o
06Hl1?l00003o`1CC003o`000?l0AT_o000000?o03I300?o0000o`0[?Ol0:cd00_l0:cd2o`0000?o
01Pa0_l00002o`0D;P04o`000?l03RSo00hXo`0>:0;o000000?o00dWo`000?l022800_l02282o`00
0003o`098ol0003o00LQ00Co00LQ00?o0000o`067ol000000_l000000ol022;o0000o`098`04o`09
8`03o`000?l032Ko00`V00;o00`V00Co0000o`0@:ol042_o010[1ol00004o`0T>@03o`000?l0=4;o
03A200;o03A200Go0000o`1;COl0Bdgo04]=o`000003o`1IB@Co000000Co06@oo`000?l0Lbco07</
1?l000000ol0PA;o0000oa6A0003o`0000;o@J400ol00003ogbb00?o000000?o`l@0o`000?ooool0
5oooool00ol0003oooooooooo`05ooooo`?o00001?ooool2o`0000?ooooo000[ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool01Oooool2o`000003om2W0?l0003o000000;o_/<000Co
0000ohJe0?n6]@3o00000omDY`001?l0003o:9T0obRI0?l00003o`B;0004o`000?l0OQOo07hGo`00
00;o078]00?o0000o`1V??l0IS`00ol00002o`1LAP03o`000?l0Ddco05=<00;o05=<1?l000000ol0
=T?o0000o`0[?@03o`0[?@06o`000?l093Wo02@io`000?l0637o00001Ol052h00ol0003o00hXo`00
0004o`0=9`03o`000?l022;o000000Co00TS00?o0000o`078Ol01b400_l01b42o`0000Go00PR00?o
0000o`098ol02B<00_l02B<01?l0003o00`Vo`0<9_l032H5o`0000;o01H_00Co0000o`0N=Ol07SGo
01he2ol00004o`1;C@05o`000?l0FDWo05U9o`1IBOl000000_l0IS`3o`0000?o07</00?o0000o`22
4?l000000_l00002oa6A00;o00000om1X@04o`000003ogbb0?l0003o^<8000?o00005oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
02_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`;o00000_o@Y`001?l0
003o_/<0okk30?nn``0Ho`000005o`1V??l0003o05a6o`1LA_l000001?l0Dd`01?l0003o04U<o`19
C?l0BD`3o`0000?o02/m00?o0000o`0T>Ol093T00_l093T00ol0003o01@^o`0D;P04o`0D;P;o0000
1Ol03BL2o`0000Ko00TS00Co0000o`078Ol0003o00000_l02B<00ol0003o00PRo`088P03o`088P03
o`000?l02B?o00TS00Go00000_l042/00ol0003o01H_o`0F;`03o`0F;`05o`000?l07SGo01heo`0N
=Ol000001?l0:cd01?l0003o03e6o`0mA_l0?DH5o`000003o`1;COl0003o05U900;o05U900?o0000
o`1V??l0IS`00_l0IS`2o`0000;o07</00?o0000o`224?l0PQ000_l00003oa6A00?o000000Co@J40
o`000?mf/@3oM[400ol00003okS20003o`000?oooooooooo01Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo000[ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooool000002ol00003ofj_0004o`000?m1X@3o@J40o`0000?o6Y@0
00Co0000o`271?l0Q`Co00000_l0Nad3o`0000;o070_1_l00003o`1CC005o`000?l0BDco04U<o`19
C?l000000ol0?DH00ol0003o02/mo`000004o`0T>@03o`000?l07cKo000000?o01@^0_l00002o`0C
;@05o`000?l03BOo00dWo`0=9ol000000_l03RP00ol0003o00TSo`098`03o`098`;o00001Ol02B<0
1?l0003o00PRo`088_l02284o`0000;o00hX00?o0000o`0@:ol042/00ol042/00ol0003o01H_o`0F
;`03o`0F;`05o`000?l07SGo01heo`0N=Ol000001?l0:cd01Ol0003o03e6o`0mA_l0?DKo000000?o
055=1ol00003o`1V?003o`000?l0MBSo000000;o00001?l0PQ02o`000004oa6A0?l0003o?j40ocnQ
00?o00001?mf/@03o`000003okS20?l0003ooooo01Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo000Zooooo`03o`000?oooooooooo
02Gooooo0_l00002omJH00;o00000_o9^@02o`0000;oXK`000?o0000ofj_0?m^[`000_l00002od6Q
0005o`000?lJU03o6Y@0oaZD0?l000000_l0Q`@4o`0000Co070_00Go0000o`1V??l0ISco06Hlo`00
0002o`1NA@03o`000?l0Ddco000000?o04U<00?o0000o`0mA_l0?DH00_l0?DH3o`0000?o02@i00Oo
0000o`0O=_l07cKo01lfo`000?l052ko000000Go01<]00?o0000o`0=9ol000001?l03RP00ol0003o
00TSo`000002o`000003o`0<9_l0003o00TS00Co00TS1?l00002o`0=9`03o`000?l03RSo00hX00;o
00hX00?o0000o`0@:ol042/00ol042/00ol0003o01H_o`0F;`02o`0F;`03o`000?l07SGo01he00;o
01he00?o0000o`0[?Ol0:cd00_l0:cd01Ol0003o03e6o`0mA_l0?DKo000000Co055=00Co0000o`1M
A_l0GDKo05e60ol00002o`1V?004o`000?l0MBSo07DXo`1e:0?o000000?o088@o`000?lCT@000ol0
0003ocnQ00Co000000CoM[40o`000?nb`03o//000ol0000Fooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`00:_ooool00ol0003ooooo
ooooo`0Tooooo`05o`000?oFV03oeYP0omJH0?l000000oo9^@001Ol0003oXK`0oj6l0?nQ_03o0000
00;oKZl000Go0000od6Q0?m1X@3o@J40o`000003oaZD0003o`000?l0Q`Co000000;o000000?o07/M
o`000?l0L2l00ol0L2l01Ol0003o06Hlo`1V??l0ISco000000?o05i51?l000000ol0BDco0000o`0m
AP03o`0mAP07o`000?l0=4;o03A2o`0d@_l0003o02@io`000004o`0O=P;o00001_l04bd2o`0000Go
00hX0_l00005o`0<9P03o`000?l02B?o000000;o000000?o00hXo`000?l03BL01?l03BL00ol0003o
00hXo`0>:002o`0>:004o`000?l042_o010[o`0@:aKo00001?l0DDd01_l0003o05e6o`1MA_l0GDKo
0000o`1Z>0?o00000ol0MBP00ol0003o08@<o`243003o`0000?o4i400ol000001?loX@3o0000ogB`
0?md/003o`0000Co//0000?o0000ooooooooool04oooool2o`0000Cooooo0_l00004ooooo`04o`00
0?ooooooooooo`0000;ooooo000Zooooo`;o00008ooooolQo`0000;o070_00Go0000o`1V??l0ISco
06Hlo`000003o`1NA@04o`000?l0Ed[o05M:o`1GBP?o00000ol0?DH00ol0003o03A2o`0d@P02o`0d
@P;o00000ol07cH2o`0000;o01he00Co0000o`0C;Ol04bgo01<]0_l000000ol052ko0000o`0>:002
o`0>:0;o000000?o010[o`000?l032H01?l032H2o`0000Go00hX00?o0000o`0=9ol03BL00_l03BL0
1?l0003o00hXo`0>:?l03RP5o`0000;o01Pa00?o0000o`0N=Ol07SD00_l07SD00ol0003o02Pko`0X
>`02o`0X>`03o`000?l0=T?o03I300;o03I300Co0000o`19C?l0BDco04U<1_l00004o`1MAP04o`00
0?l0JSSo06Xho`1Z>0?o000000?o07DXo`000?l0Q0`00ol0Q0`3o`000003oa>A0?l0003o@J4000?o
00001?md/003o`000003ok;00?l0003ooooo01Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`;o00000oooool002[ooooo00?o0000ooooooooool08?ooool2o`0000?ofhH0
00Go0000om2X0?o@Z03od:P0o`000003ol740004o`000?n=]`3oSKL0o`0000?oGZX000?o0000ocFM
0?leW@000ol000000olCT@3o0000o`261`02o`261`04o`000?l0Nago07/Mo`1k7@Co000000?o06Hl
o`000?l0GTD00_l0GTD01Ol0003o05M:o`1GB_l0Ed[o000000?o055=00?o0000o`0mA_l000001?l0
=4801_l0003o02loo`0_?ol0003o01lfo`0000Go01he00?o0000o`0C;Ol000001?l052h00ol0003o
00hXo`000004o`0@:`03o`000?l032Ko00`V00;o000000?o010[o`000?l03RP01?l03RP01?l0003o
00dWo`0=9ol03BL5o`0000;o01@^00?o0000o`0H<Ol063400ol063400ol0003o01heo`0N=@02o`0N
=@03o`000?l0:3_o02Pk00;o02Pk00?o0000o`0f@ol0=T<00_l0=T<01Ol0003o04U<o`19C?l0BDco
000000?o05M:1_l00003o`1Z>003o`000?l0N2;o07PR00?o00000ol0Q0`00ol0003o69<0oaRC0003
o`0000;o@J401?l000001?md/03o0000ok2o0?n`_`03o`0001Kooooo00?o0000ooooooooool03Ooo
ool000Cooooo0ol00003ooooo`?o00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0002ooooo`?o00001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oKQP3ofhH000;ofhH000Go
0000om2X0?o@Z03od:P0o`000002ol7400;o00000_n=]`001?l0003oGZX0oejZ0?mNZP05o`0000;o
4i4000Go0000o`261ol0QPOo08H7o`000003o`1k7@04o`000?l0LRgo078]o`1b;@Co000000?o05i5
o`000?l0EdX00_l0EdX00ol0003o055=o`1AC@02o`1AC@?o00000ol0=4800ol0003o02loo`0_?`02
o`0_?`03o`000?l07SGo01he00Co01he0_l00005o`0D;P;o00001Ol042/00ol0003o00`Vo`000004
o`0@:`03o`000?l03RSo00hX00;o00hX1?l00002o`0C;@03o`000?l052ko01@^00?o01@^00?o0000
o`0H<Ol063400_l063400ol0003o01heo`0N=@02o`0N=@03o`000?l0:3_o02Pk00;o02Pk00?o0000
o`0f@ol0=T<00_l0=T<00ol0003o04U<o`19C002o`19C005o`000?l0Ed[o05M:o`1GB_l000000ol0
Hd44o`000003o`1Z>?l0003o07PR00?o07PR0_l00002o`243003o`000?lHT`3o69<000;o69<00_l0
00001?m1X@3o0000ogJa0?mf/@03o`0000Co/;l000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo1?l00002om^60005o`000?o@Z03od:P0
om2X0?l000000_o1a0001Ol0003oSKL0ohfg0?n=]`3o000000?oGZX00_l000000oleW@3o0000oa>A
0002oa>A0005o`000?l0QPOo08H7o`261ol000000ol0Nad01Ol0003o078]o`1b;Ol0LRgo000000?o
06Ti1?l000000ol0Ed[o0000o`1AC@03o`1AC@07o`000?l0Bdgo04]=o`1;COl0003o03A2o`000004
o`0_?`03o`000?l0;Soo000000?o01he0_l000000ol07cKo0000o`0D;P02o`0D;P;o000000?o01Pa
o`000?l042/01?l042/2o`0000Ko010[00Ko0000o`0>:?l0003o0000o`0D;_l00005o`0C;@03o`00
0?l052ko01@^00;o01@^00?o0000o`0H<Ol063400_l063401?l0003o01heo`0N=Ol07SD<o`0000Co
04U<00?o0000o`1GB_l0EdX00_l0EdX01Ol0003o06=1o`1S@Ol0Hd7o000000;o070`0ol00003o`1h
8P03o`000?l0Q`Co000000;o00001?lHT`000ol0003oAZ<0o`000002o`0000CoM[400_l00002ok2o
0003o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000001kooooo0_l00004on5c01[o000000?o08H7o`00
0?l0Nad00_l0Nad01Ol0003o078]o`1b;Ol0LRgo000000?o06Ti00?o0000o`1S@Ol0Hd400_l0Hd42
o`0000?o055=00?o0000o`1;COl0Bdd00_l0Bdd3o`0000?o02lo00Oo0000o`0^?ol0;Soo02hoo`00
0?l07SGo000000Co01lf00?o0000o`0D;_l000001?l063401ol0003o010[o`0@:ol042_o0000o`0F
;ol000001_l042/2o`0000Co01@^00?o0000o`0C;Ol04bd00ol04bd00ol0003o01@^o`0D;P0:o`00
00;o02/m00?o0000o`0f@ol0=T<00_l0=T<01?l0003o04I;o`16Bol0AT/;o`0000Co06=100?o0000
o`1`<?l0L3000_l0L302o`0000;o07PR00Co0000o`271?l0Q`Co08L40ol00002oaRC0003o`000?m6
X`3oAZ<000;o00000omf/@001_l0003o//00o`000?l0003o/;l0o`0001Kooooo00?o0000oooooooo
ool02oooool000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0001_o
oooo0_l00004on5c00;o00000ooGU0001?l0003oc;<0olbc0?l00003ok2o00Go00000omFZ0001Ol0
003o<Y`0oc:L0?lbW03o000000;o4i402?l000000ol0LRgo0000o`1Y>@02o`1Y>@03o`000?l0Hd7o
06=100;o06=100Ko0000o`1MA_l0GDKo0000o`1ACOl00004o`1;C@07o`000?l0AT_o04I;o`16Bol0
003o02loo`000004o`0^?`;o00001_l07cH00ol0003o01Pao`0H<@04o`0H<@03o`000?l042_o0000
00?o01H_00Co0000o`0@:ol042_o010[0_l000000ol0637o0000o`0D;P04o`0D;P03o`000?l04bgo
01<]00;o01<]0ol00002o`0O=P03o`000?l093Wo02@i00;o02@i00?o0000o`0[?Ol0:cd00ol0:cd0
0ol0003o03I3o`0f@`02o`0f@`05o`000?l0AT_o04I;o`16Bol000001?l0Dd`01?l0003o05i5o`1N
AOl0GTD4o`0000;o06=100Ko0000o`1`<?l0L33o070`o`000?l0OAT3o`0000?o08L400?o0000ob6G
0?lQU`000ol00003odJS00?o00000_mf/@000ol0003o//00ok;00002o`0001Oooooo00?o0000oooo
ooooool02_ooool000Gooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002?ooool01_l0
003ooooooooooooooooo0000ooooo`Co00001?ooool00ol0003oooooooooo`0Hooooo`Co00000_oQ
L`02o`0000?oei@00_l00002olbc0003o`000?n`_`3o/;l000?o00000_n0]0001Ol0003oEZP0oeJX
0?mFZ03o000000?o<Y`000Co0000oa>A0?lCT@3o00001?l0Q`@01?l0003o07hGo`1n5ol0OQL3o`00
0003o`1Y>Ol0003o06=100?o06=100?o0000o`1MA_l0GDH00_l0GDH2o`0000?o04]=00?o0000o`16
Bol0AT/00ol0AT/00ol0003o02hoo`0^?`02o`0^?`03o`000?l0;coo000000Go01lf0_l00006o`0H
<@;o00001Ol05Rl00ol0003o010[o`000004o`0H<@03o`000?l052ko01@^00;o01@^00?o0000o`0C
;Ol000000_l000000ol07SGo0000o`0O=P03o`0O=P03o`000?l093Wo02@i00;o02@i00?o0000o`0[
?Ol0:cd00ol0:cd00ol0003o03I3o`0f@`02o`0f@`05o`000?l0AT_o04I;o`16Bol000001?l0Dd`0
1Ol0003o05i5o`1NAOl0GTGo000000;o06Ti0ol00004o`1`<004o`000?l0OAWo07dIo`1m6@?o0000
00?o08L4o`000?lQU`000olQU`03o`000003odJS0?l0003oO;8000?o00001?nb`0000ol0003ooooo
ooooo`0Dooooo`;o00002oooool000Cooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool01ol0003ooooooooooooooooo0000ooooool000001oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oWG`3oiel000;oiel01?l00002omND0004o`000?o</`3oc;<0olbc
00Go00000on0]0001Ol0003oEZP0oeJX0?mFZ03o000000?o<Y`000Co0000oa>A0?lCT@3o00001?l0
Q`@01Ol0003o07hGo`1n5ol0OQOo000000?o07HV0_l00003o`1S@@03o`000?l0GDKo05e600;o05e6
00Ko0000o`1IBOl0FDWo0000o`1;COl00005o`16B`;o00000ol0;Sl01Ol0003o02loo`0_?ol0;coo
000000?o01lf00Co0000o`0T>Ol093Wo00000ol06342o`000003o`0N=Ol0003o01H_00Co01H_0_l0
0005o`0H<@03o`000?l052ko01@^00;o01@^0_l00005o`0N=@03o`000?l07cKo01lf00;o01lf00?o
0000o`0T>Ol093T00_l093T00ol0003o02/mo`0[?@02o`0[?@03o`000?l0=T?o03I300;o03I300?o
0000o`16Bol0AT/00_l0AT/00ol0003o05=<o`1CC002o`1CC005o`000?l0GTGo05i5o`1NAOl00000
1?l0JCT5o`0000?o07dI00?o0000o`J<0?l6S0000ol00003ob6G0003o`000?m@YP3oD:H000?o0000
0oml/P03o`000003ok;00?l0003ooooo01Kooooo00?o0000ooooooooool02Oooool000Gooooo00Co
0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`0000Sooooo0ol00002ooooo`Go0000
0oooool00ol0003oooooooooo`0Fooooo`03o`000?oWG`3oiel000;oiel000?o0000omin0?oNOP00
0_oNOP0@o`000003oeJX0?l0003o<Y`000;o<Y`000Co0000oa>A0?lCT@3o00001?l0Q`@01Ol0003o
07hGo`1n5ol0OQOo000000?o07HV00Ko0000o`1`<?l0L33o0000o`1S@Ol00004o`1MAP03o`000?l0
FDWo05U900;o05U900?o0000o`16Bol0AT/00ol0AT/01_l0003o04A:o`14B_l0003o02hoo`0000Go
02lo00?o0000o`0O=_l000001?l093T00ol0003o01Pao`000004o`0N=@03o`000?l05Roo01H_00;o
000000?o01heo`000?l063401?l063400ol0003o01@^o`000002o`000003o`0O=_l0003o01he00Co
01he00?o0000o`0O=_l07cH00_l07cH01?l0003o02@io`0T>Ol093TFo`0000Co05i500Go0000o`1Y
>Ol0JCWo06Tio`000003o`1f9PCo000000?o07dIo`000?l6S0000ol6S002o`0000;o8IL000Co0000
oe2V0?m@YP3oD:H00ol000001?ml/P3o0000okS20?nh`P03o`0001Gooooo0ol0000:ooooo`00:?oo
ool3o`0001Kooooo00?o0000onMO0?oWG`000_oWG`001?l0003ogWh0omin0?oNOP02o`000004om>M
0?l0003o0000o`0000?obKX000Go0000ojRn0?nX_P3oZ;h0o`000003ogbb00_o00000_l0Q`@01Ol0
003o07hGo`1n5ol0OQOo000000?o07HV00?o0000o`1`<?l0L3000_l0L302o`0000?o05e600?o0000
o`1IBOl0FDT00_l0FDT00ol0003o05M:o`000003o`16B`03o`000?l0A4[o04A:00;o04A:00?o0000
o`0_?ol0;cl01?l0;cl2o`0000Go02@i0_l00005o`0N=@03o`000?l05Roo000000Co01he00?o0000
o`0H<Ol063400_l06342o`0000Go01lf00?o0000o`0N=Ol07SD00_l07SD01?l0003o01lfo`0O=_l0
7cH5o`0000;o03A200?o0000o`0mA_l0?DH00_l0?DH00ol0003o04U<o`19C002o`19C003o`000?l0
Ddco05=<00;o05=<00Co0000o`1LA_l0G4Ko05a61_l00004o`1Y>@05o`000?l0MRKo07HVo`1f9_l0
00000_l0Q0`3o`0000?o1X`000?o0000objK0?l000000_l00004oe2V0003o`000?n6]@3o000000;o
00001?nh`P000ol0003oooooooooo`0?ooooo`?o00000_ooool00ol0003oooooooooo`08ooooo`00
:?ooool00ol0003oooooooooo`0Dooooo`Co00000_oWG`001?l0003ogWh0omin0?oNOP04o`000003
om>M0?l0003obKX000;obKX000Go0000ojRn0?nX_P3oZ;h0o`000003ogbb0003o`000?mFZ03oEZP0
00;oEZP000Co0000ocFM0?leW@3o00000olJU004o`000003o`1n5ol0003o07HV00;o07HV00?o0000
o`1`<?l0L3000_l0L3001_l0003o06Xho`1Z>?l0003o05e6o`0000Co05U900Oo0000o`1GB_l0Ed[o
05M:o`000?l0AT_o000000Co04A:00?o0000o`16Bol000000ol0;cl2o`000003o`0d@_l0003o02@i
00;o02@i0_l000000ol0:cgo0000o`0N=@04o`0N=@;o00001_l07SD01_l0003o01Pao`000?l0003o
02@io`0000Go01lf00?o0000o`0N=Ol07SD00_l07SD4o`0000;o02lo00?o0000o`0d@_l0=4800ol0
=4800ol0003o03e6o`0mAP02o`0mAP03o`000?l0BDco04U<00;o04U<00?o0000o`1CC?l0Dd`00_l0
Dd`01Ol0003o05a6o`1LA_l0G4Ko000000?o06Hl0ol00002o`1Y>@03o`000?l0MRKo07HV00;o07HV
00?o0000o`243?l0Q0`00_l0Q0`2o`0000;o1X`000Co0000objK0?l^V`3o;Y/00ol00002oe2V0003
o`000?n6]@3oQ[D000;o00000onh`P000ol0003oooooooooo`0<ooooo`?o00001Oooool00ol0003o
ooooooooo`08ooooo`00:?ooool00ol0003oooooooooo`0Booooo`;o00001?o]C008o`0000;odid0
00Go0000olVj0?o9^P3obKX0o`000003ojRn0005o`000?ml/P3oO;80ogbb0?l000001?mFZ0001?l0
003o=Id0ocFM0?l00004oaZD0004o`000?l4R`3o18/0o`B;00?o000000?o07HVo`000?l0L3000ol0
L3000ol0003o06Xho`1Z>002o`1Z>0;o00000ol0FDT00ol0003o05M:o`1GBP02o`1GBP?o00000ol0
A4X01ol0003o04I;o`16Bol0AT_o0000o`0_?ol000001?l0=4800ol0003o02@io`000004o`0[?@07
o`000?l07SGo01heo`0N=Ol0003o02Pko`000006o`0N=@;o00001?l093T00ol0003o01lfo`0O=P02
o`0O=P03o`000?l07SGo000000;o000000?o02hoo`000?l0;cl01?l0;cl00ol0003o03A2o`0d@P02
o`0d@P03o`000?l0?DKo03e600;o03e600?o0000o`19C?l0BD`00_l0BD`00ol0003o05=<o`1CC002
o`1CC003o`000?l0G4Ko05a600;o05a600Ko0000o`1V??l0ISco06Hlo`000?l0LRd3o`0000Co07HV
00?o0000o`243?l0Q0`00_l0Q0`00ol0003o5I80o`000002o`0000?o;Y/000?o0000oejZ0?mNZP00
1?l00003ohJe00?o000000?o^<80o`000?ooool02?ooool4o`0000Sooooo00?o0000ooooooooool0
2?ooool002Sooooo00?o0000ooooooooool04Oooool00ol0003okD`0one<0002one<00;o000000Co
iFP0o`000?l0003o00001?oLQ@08o`000003ojRn0?l0003oO;8000;oO;8000?o0000oeJX0?mFZ000
0_mFZ0001?l0003o=Id0ocFM0?l00004oaZD0005o`000?l4R`3o18/0o`B;0?l000000ol0Q0`2o`00
00?o070`00?o0000o`1Z>?l0JSP00_l0JSP01_l0003o06Hlo`1V??l0003o05U9o`0000Co05M:00Oo
0000o`1FBol0ET_o05I;o`000?l0A4[o000000Go04I;00?o0000o`0d@_l0=4801?l0=4800ol0003o
02/mo`0[?@04o`0[?@03o`000?l07SGo000000?o02Pk00Co0000o`0N=Ol07SGo01he0_l000000ol0
:cgo0000o`0T>@04o`0T>@04o`000?l07cKo01lfo`0O=P;o00001Ol0;Sl00ol0003o02loo`0_?`02
o`0_?`03o`000?l0=4;o03A200;o03A200?o0000o`0mA_l0?DH00_l0?DH00ol0003o04U<o`19C002
o`19C003o`000?l0Ddco05=<00;o05=<00?o0000o`1LA_l0G4H00_l0G4H00ol0003o06Hlo`1V?002
o`1V?004o`000?l0LRgo078]o`1b;@Go00001Ol0Q0`01?l0003o5I80oaFB0?lETP03o`000003objK
0?l0003oGZX000?oGZX00ol000001?n6]@3o0000ol?40?o3a003o`0000Gooooo0ol0000=ooooo`03
o`000?oooooooooo00Oooooo000Xooooo`;o00004?ooool4o`0000;okD`000Ko0000onEX0?l0003o
0000onEX0?l00004omb50003o`000?oBXP3odZ8000;odZ8000?o0000olRl0?o8_0002?l00002oeJX
0004o`000?leW@3o=Id0o`0000Co6Y@000Go0000o`B;0?l4R`3o18/0o`000003o`243006o`000?l0
OAWo07dIo`000?l0L33o00001?l0JSP00ol0003o06Hlo`1V?002o`1V?0;o00000ol0EdX00ol0003o
05I;o`1FB`03o`1FB`03o`000?l0AT_o04I;00?o04I;0_l00005o`0d@P;o00001_l0:cd2o`0000Go
02Pk00?o0000o`0N=Ol000001?l0:cd00ol0003o02@io`0T>@02o`0T>@06o`000?l07cKo0000o`00
0?l0;coo00001_l0;Sl01Ol0003o02loo`0_?ol0;coo000000Go03A200?o0000o`0mA_l0?DH02ol0
00000ol0Ddco0000o`1LAP02o`1LAP03o`000?l0ISco06Hl00;o06Hl00Go0000o`1b;Ol0LRgo078]
o`000003o`1n5`Co00000_l0Q0`01Ol0003o5I80oaFB0?lETP3o000000;o?j400ol00003oejZ00;o
000000CoUKT0o`000?l0003o00001?o3a0000ol0003oooooo`000002o`00013ooooo00?o0000oooo
ooooool01oooool002Sooooo00?o0000ooooooooool03?ooool3o`0000ColCT01?l00002onEX0003
o`000?oLQ@3og8D000;og8D000?o0000om:R0?oBXP000_oBXP001?l0003ob;`0olRl0?l00004ojRn
0004o`000?n0]03oP;@0oh2d00Oo00000_lJU0001Ol0003o18/0o`B;0?l4R`3o000000?o08@<00?o
0000o`1m6Ol0OAT00_l0OAT2o`0000?o06Xh00?o0000o`1V??l0IS`00_l0IS`01_l0003o06@oo`1T
?ol0003o05M:o`0000Go05I;0_l00004o`16B`04o`000?l0Bdgo04]=o`0000?o03A200Co0000o`0m
A_l0?DKo00000ol0:cd2o`000003o`0f@ol0003o02Pk00Co02Pk0_l00005o`0[?@03o`000?l093Wo
02@i00;o02@i0_l00004o`0_?`03o`000?l0;Soo02ho00?o02ho00?o0000o`0_?ol0;cl02_l00002
o`1AC@03o`000?l0Ed[o05M:00;o05M:00Co0000o`1NAOl0GTGo05i52ol00004o`1b;@05o`000?l0
OQOo07hGo`1n5ol000000_l4R`03o`0000Co5I8000?o0000ocnQ0?loX@000_loX@03o`000003oejZ
0?l0003o000000?oUKT00ol000000oo3a03o0000o`00000Cooooo`03o`000?oooooooooo00Oooooo
000Wooooo`03o`000?oooooooooo00_ooooo0ol00004oo4i00?o00000oo[D@04o`0000;og8D000?o
0000om:R0?oBXP000_oBXP001?l0003ob;`0olRl0?l00004ojRn0005o`000?n0]03oP;@0oh2d0?l0
00000omNZP001?l0003o@J40od6Q0?m1X@04o`000003o`B;0?l0003o08@<00;o08@<00?o0000o`1m
6Ol0OAT00_l0OAT01_l0003o07PRo`1h8_l0003o06Xho`0000Co06Hl00?o0000o`1T?ol0I3l00_l0
I3l00ol0003o05I;o`1FB`03o`1FB`04o`000?l0Ed[o05M:o`0000;o04I;00?o0000o`1;COl0Bdd0
0_l0Bdd00ol0003o03A2o`000004o`0mAP03o`000?l0:cgo000000Co03I300?o0000o`0X>ol0:3/0
0_l000000ol0=T?o0000o`0[?@04o`0[?@03o`000?l093Wo000000;o000000?o03A2o`000?l0;cl0
1?l0;cl00ol0003o02hoo`0^?`02o`0^?`?o00000_l0AT/00ol0003o04]=o`1;C@02o`1;C@03o`00
0?l0DDgo055=00?o055=00?o0000o`1GB_l0EdX00_l0EdX01Ol0003o05i5o`1NAOl0GTGo000000Co
06Hl00Co0000o`1`;ol0L2oo070_1?l00002o`1b;@05o`000?l0OQOo07hGo`1n5ol000001?l4R`02
o`0000;o5I8000?o0000ocnQ0?loX@000_loX@000ol0003oL:l0og2_0004o`0000;oUKT000?o0000
olNn0?o7_P000ol0000Cooooo`03o`000?oooooooooo00Oooooo000Wooooo`03o`000?oooooooooo
00Wooooo0_l00003ooHY00Co00001Oo[D@000ol0003ohf`0on=/0002on=/00Co00000_oBXP001?l0
003ob;`0olRl0?l00004ojRn0005o`000?n0]03oP;@0oh2d0?l000000omNZP000ol0003o@J40od6Q
0002od6Q0004o`000?lXV@3o:9T0obRI00?o000000?o08@<o`000?l0OAT00ol0OAT00ol0003o07PR
o`1h8P02o`1h8P;o00000ol0IS`00ol0003o06@oo`1T?`02o`1T?`03o`000?l0Hd3o000000?o05I;
00Oo0000o`1GB_l0Ed[o05M:o`000?l0AT_o000000Go04]=0_l00005o`0mAP;o00001Ol0=T<00ol0
003o02Pko`000004o`0f@`03o`000?l0:cgo02/m00;o02/m0_l00005o`0d@P03o`000?l0;coo02lo
00;o02lo00?o0000o`0^?ol000000_l000000ol0A4[o0000o`16B`03o`16B`03o`000?l0Bdgo04]=
00;o04]=00?o0000o`1ACOl0DDd00_l0DDd00ol0003o05M:o`1GBP02o`1GBP03o`000?l0GTGo05i5
00;o05i500?o0000o`1V??l0IS`00_l0IS`01Ol0003o070_o`1`;ol0L2oo000000;o07/M0ol00004
o`1n5`06o`000?l4R`3o18/0o`B;0?l0003o:9T00ol00005ocnQ0003o`000?m`[`3oL:l000;oL:l0
0_l00002oiFi0003o`000?o7_P3oakh000;oakh000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`07ooooo`009oooool00ol0003oooooooooo`08ooooo`04o`000?of:@3omRT0ooHY00Ko0000
1?o[D@000ol0003ohf`0on=/0002on=/0003o`000?oKQ`3ofhL000;ofhL01ol00002ojRn0005o`00
0?n0]03oP;@0oh2d0?l000000omNZP000ol0003o@J40od6Q0002od6Q0005o`000?lXV@3o:9T0obRI
0?l000000olETP02o`0000?o07dI00?o0000o`1h8_l0N2800_l0N2801_l0003o07DXo`1e:?l0003o
06Hlo`0000Co06@o00Oo0000o`1S@?l0Hd3o06=0o`000?l0ET_o000000Go05M:00?o0000o`1;COl0
Bdd00ol0Bdd00ol0003o055=o`000004o`0mAP03o`000?l0BDco000000Go03I30_l00005o`0f@`03
o`000?l0:cgo02/m00;o000000?o03e6o`000?l0=4801?l0=4800ol0003o02loo`0_?`02o`0_?`;o
00001Ol0A4X01Ol0003o04I;o`16Bol0AT_o000000Go04]=00?o0000o`1ACOl0DDd00_l0DDd01Ol0
003o05M:o`1GB_l0Ed[o000000Co05i500?o0000o`1V??l0IS`00_l0IS`00ol0003o070_o`1`;`02
o`1`;`03o`000?l0Nago07/M00;o07/M1Ol00004o`B;0004o`000?lXV@3o:9T0obRI00?o00000_lo
X@000ol0003oL:l0og2_0002og2_00Go00001?o7_P000ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Oooooo000Wooooo`;o00001oooool6o`000003ooHY0?l0003o000000?olC`00_l00000
0oo[D@3o0000on=/0002on=/00;o00001?oKQ`001Ol0003odZ80om:R0?oBXP3o000000?obKX02?l0
00000omNZP3o0000od6Q0003od6Q0005o`000?lXV@3o:9T0obRI0?l000000olETP001_l0003o1X`0
o`J<0?l0003o07dIo`0000Co07PR00?o0000o`1e:?l0MBP00_l0MBP2o`0000?o06@o00?o0000o`1S
@?l0Hd000ol0Hd000ol0003o05M:o`1GBP03o`1GBP03o`000?l0FDWo000000?o04]=00Go0000o`1A
COl0DDgo055=o`000002o`0mAP05o`000?l0BDco04U<o`19C?l000000ol0=T<00ol0003o04I;o`00
0005o`0f@`03o`000?l0:cgo000000Co03e600?o0000o`0d@_l0=4800_l0=4800ol0003o02loo`00
0002o`000003o`16Bol0003o04A:00Co04A:00?o0000o`16Bol0AT/00_l0AT/00ol0003o04]=o`1;
C@02o`1;C@03o`000?l0DDgo055=00;o055=00?o0000o`1GB_l0EdX00_l0EdX01Ol0003o05i5o`1N
AOl0GTGo000000Go06Hl00Go0000o`1`;ol0L2oo070_o`000004o`1k7@04o`000?l0Q`Co08L4o`27
10?o00000_l4R`001Ol0003o:9T0obRI0?lXV@3o000000;oE:L00ol00005og2_00;o00000_nW_@03
o`0000;oakh000?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`009oooool00ol0
003oooooooooo`03ooooo`So000000?omRT0o`000?oa?0001Ooa?004o`000003on=/0?l0003ofhL0
00?ofhL00_l00003om:R0005o`000?o9^P3obKX0olVj0?l000000on`_`000ol0003oSKL0ohfg0002
ohfg00?o00000_m1X@001Ol0003o:9T0obRI0?lXV@3o000000?o5I8000?o0000o`J<0?l6S0000_l6
S002o`0000?o07PR00?o0000o`1e:?l0MBP00ol0MBP01Ol0003o07</o`000?l0I3oo000000Go06=0
00?o0000o`1T?ol000000ol0EdX01ol0003o05U9o`1IBOl0FDWo0000o`1;COl000001?l0DDd00ol0
003o03e6o`000005o`19C003o`000?l0=T?o000000?o04I;00?o0000o`0f@ol0=T<00_l0=T<2o`00
00Ko03e600Co0000o`0d@_l0=4;o03A20_l00005o`16B`03o`000?l0A4[o04A:00;o04A:00?o0000
o`16Bol0AT/00_l0AT/01?l0003o04]=o`1;COl0BddDo`000003o`1V??l0003o070_00?o070_00?o
0000o`1k7Ol0Nad00_l0Nad01_l0003o08L4o`271?l0Q`Co0000oaZD00?o00001?lXV@000ol0003o
E:L0oeBW0002oeBW00?o00000_m`[`001Ol0003oYkd0o`000?nW_@3o000000;obk<00ol0000Boooo
o`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Ko00001?oh7@03o`0000Co
lC`00_l00003on]C00Co00000_oKQ`000ol0003odZ80om:R0002om:R0005o`000?o9^P3obKX0olVj
0?l000000on`_`000ol0003oSKL0ohfg0002ohfg0004o`000?m^[`3oKZl0ofj_00Co000000?o:9T0
o`000?lETP000_lETP000ol0003o1X`0o`J<0002o`J<0006o`000?l0Q`Co08L4o`000?l0N2;o0000
1Ol0MBP01Ol0003o07</o`1c;?l0Lbco000000Go06=000Oo0000o`1T?ol0I3oo06@oo`000?l0Ed[o
000000Go05U900?o0000o`1ACOl0DDd01?l0DDd00ol0003o04U<o`19C004o`19C0;o00001Ol0AT/0
1_l0003o03I3o`0f@ol0003o04U<o`0000Ko03e600Ko0000o`0d@_l0003o0000o`1;COl00005o`16
B`03o`000?l0A4[o04A:00?o04A:00?o0000o`16Bol0AT/01Ol00002o`1IB@03o`000?l0GDKo05e6
00;o05e600Go0000o`1S@Ol0Hd7o06=1o`000004o`1Y>@04o`000?l0LRgo078]o`1b;@Oo00001?l0
Nad00ol0003o08L4o`271002o`271004o`000?lJU03o6Y@0oaZD00?o00000_lXV@001Ol0003oE:L0
oeBW0?mDY`3o000000;oQ[D00ol000001OnW_@3o0000ojNm0?nW_@3o000000Cobk<000?o0000oooo
ooooool03oooool00ol0003oooooooooo`06ooooo`009_ooool8o`0000Con1d00_l00003ooDZ0004
o`000?oa?03o0000o`0000?oje<00_l00004on=/00Co00000_oBXP001Ol0003obKX0olVj0?o9^P3o
000000?o/;l000?o0000ohfg0?n=]`000_n=]`000ol0003oKZl0ofj_0002ofj_0004o`000?mDY`3o
E:L0oeBW00?o000000?o5I80o`000?l6S0000ol6S0000ol0003o08L4o`271002o`2710;o00001?l0
MBP01ol0003o07</o`1c;?l0Lbco0000o`1b;Ol000000ol0Hd000ol0003o06@oo`1T?`03o`1T?`03
o`000?l0FDWo05U900?o05U90_l00005o`1AC@;o00001Ol0BD`00ol0003o05=<o`000005o`16B`03
o`000?l0=T?o000000?o04U<00?o0000o`0mA_l0?DH00ol0?DH2o`0000Co04]=00?o0000o`16Bol0
AT/00_l0AT/01?l0003o04A:o`14B_l0A4X5o`0000;o05M:00?o0000o`1IBOl0FDT00ol0FDT00ol0
003o05e6o`1MAP02o`1MAP05o`000?l0Hd7o06=1o`1S@Ol000001?l0JCT00ol0003o078]o`1b;@02
o`1b;@04o`000?l0Nago07/Mo`1k7@Ko00001?l0Q`@01Ol0003o6Y@0oaZD0?lJU03o000000;o@J40
0ol00004oeBW0003o`000?n6]@3oQ[D000;oQ[D00ol00002ojNm0005o`000?o;/`3obk<0ol^c0?l0
00004Oooool00ol0003oooooooooo`06ooooo`009_ooool4o`0000ConQT000Co0000ooPM0?l0003o
00001Ooe:P04o`0000;oje<000?o0000on=/0?oSK0000ooSK0000ol0003og8D0omb50002omb500So
000000?o/;l0o`000?n=]`000on=]`000ol0003oKZl0ofj_0002ofj_0005o`000?mDY`3oE:L0oeBW
0?l000000oloX@02o`0000?o1X`000?o0000o`271?l0Q`@00ol0Q`@01_l0003o08@<o`000?l0003o
07DXo`0000?o07</00Oo0000o`1b;Ol0LRgo078]o`000?l0Hd3o000000Go06@o0_l00004o`1IB@04
o`000?l0GDKo05e6o`0000?o055=00Co0000o`1GB_l0Ed[o00000ol0BD`01Ol0003o05=<o`1CC?l0
Ddco000000Co04I;0_l00005o`19C003o`000?l0?DKo03e600;o000000?o055=o`000?l0Bdd01?l0
Bdd01?l0003o04I;o`16Bol0AT/4o`0000;o05I;00?o0000o`1GB_l0EdX00ol0EdX00ol0003o05U9
o`1IB@02o`1IB@03o`000?l0GDKo05e600;o05e600?o0000o`1S@Ol0Hd400_l0Hd401Ol0003o06Ti
o`1Y>Ol0JCWo000000Go078]00Go0000o`1k7Ol0Nago07/Mo`000003o`261`Ko00001?lJU0000ol0
003o@J40od6Q0002od6Q00Go00001?n6]@000ol0003o_/<0okk30003o`0000Cobk<000?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`0000Coooooo`000?l0003o00000oooool3o`00
00?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000Cooooo0_l00000
0ooooooo0000ooXI0003ooXI00?o00001?oe:P02o`0000ColC`00ol00004on=/0003o`000?oLQ@3o
g8D000;og8D000?o0000om>M0?oCW@000_oCW@001?l0003oc;<0olbc0?o</`03o`0000;oSKL000?o
0000ofj_0?m^[`000_m^[`001Ol0003oE:L0oeBW0?mDY`3o000000Co?j4000Go0000objK0?l0003o
1X`0o`000005o`271003o`000?l0Q0co08@<00;o08@<00Go0000o`1c;?l0Lbco07</o`000005o`1b
;@03o`000?l0I3oo06@o00?o06@o00Co0000o`1V??l0ISco00000_l0FDT00ol0003o05e6o`1MAP02
o`1MAP03o`000?l0DDgo000000Co05M:00?o0000o`19C?l000001?l0Dd`00ol0003o04I;o`16B`02
o`000003o`1CC?l0003o04U<00Co04U<00?o0000o`0mA_l000001?l0DDd00ol0003o04]=o`1;C@02
o`1;C@06o`000?l0AT_o0000o`000?l0Ed[o00001Ol0ET/00ol0003o05M:o`1GBP02o`1GBP03o`00
0?l0FDWo05U900;o05U900?o0000o`1MA_l0GDH00_l0GDH00ol0003o06=1o`1S@@02o`1S@@03o`00
0?l0JCWo06Ti00;o06Ti00?o0000o`1b;Ol0LRd00_l0LRd00ol0003o07/Mo`1k7@02o`1k7@05o`00
0?l0QPOo08H7o`261ol000000olCT@04o`0000;o6Y@000Go0000od6Q0?m1X@3o@J40o`000003ofj_
00Co00000_n6]@000ol0003o_/<0o`000002okk300Co000000?obk<0o`000?ooool03_ooool00ol0
003oooooooooo`06ooooo`000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000ooXI00;o00000ooh7@02o`000003ooDZ
0?l0003olC`000ColC`000Co0000on]A0?o[D@3oje400_l000000ooSK03o0000omb50003omb50003
o`000?oCW@3odid000;odid000Go0000olbc0?o</`3oc;<0o`000003ol7400Co00000_m^[`001Ol0
003oE:L0oeBW0?mDY`3o000000Co?j4000Co0000objK0?l^V`3o;Y/00_l00004o`271003o`000?l0
Q0co08@<00;o08@<00Go0000o`224?l0003o07</o`000005o`1b;@03o`000?l0Lbco000000?o06@o
00Oo0000o`1V??l0ISco06Hlo`000?l0FDWo000000Go05e60_l00005o`1GBP;o00001Ol0Dd`00ol0
003o04I;o`000004o`1CC003o`000?l0BDco04U<00;o04U<0_l00005o`1AC@03o`000?l0Bdgo04]=
00;o04]=0_l00004o`1GBP03o`000?l0ET_o05I;00;o05I;00?o0000o`1GB_l0EdX00_l0EdX00ol0
003o05U9o`1IB@03o`1IB@03o`000?l0GDKo05e600co00001?l0LRd00ol0003o07/Mo`1k7@02o`1k
7@03o`000?l0QPOo08H700;o08H700Go0000oa>A0?lCT@3o4i40o`000002ocFM00?o00001?m1X@00
1Ol0003oKZl0ofj_0?m^[`3o000000;oXK`00ol00002okk30003o`000?nn``3o000000?od:L00ol0
000>ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000o`0000Gon1d00ol00004oo4l0003o`00
0?o[D@3oje4000?oje401?l00002omb50003o`000?oCW@3odid000;odid000Go0000olbc0?o</`3o
c;<0o`000004ol740004o`000?nQ_03oXK`0oj6l00Co000000?oE:L0o`000?loX@000oloX@001Ol0
003o;Y/0objK0?l^V`3o000000;o8IL00_l000000ol0Q`Co0000o`243003o`243005o`000?l0PQ3o
088@o`224?l000001Ol0LRd01ol0003o07</o`1c;?l0Lbco0000o`1T?ol000001Ol0IS`00ol0003o
05e6o`1MAP03o`1MAP03o`000?l0Hd7o000000Co05M:00?o0000o`1NAOl000001_l0Dd`00ol0003o
05=<o`1CC003o`1CC003o`000?l0BDco04U<00;o000000?o05M:o`000?l0DDd01?l0DDd00ol0003o
04]=o`000002o`000003o`1IBOl0003o05M:00?o05M:00?o0000o`1FBol0ET/00ol0ET/01?l0003o
05M:o`1GB_l0EdX9o`0000;o06Xh00?o0000o`1`<?l0L3000_l0L3001?l0003o07HVo`1f9_l0MRH;
o`0000Co08H700?o0000oa>A0?lCT@000_lCT@000ol0003o=Id0ocFM0002ocFM00Go00001?m^[`00
0ol0003oXK`0oj6l0002oj6l00Co000000?o_/<0o`000?o@Y`000oo@Y`000ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Co00002?ooool01Ol0
003oooooooooool0003on1d000?o00000oof:@02o`000003oo4l0?l0003oje4000?oje400_l00004
onEX00Co00000_oCW@001Ol0003oc;<0olbc0?o</`3o000000Co`L@000Go0000oj6l0?nQ_03oXK`0
o`000004ohJe00;o00000oloX@001Ol0003o;Y/0objK0?l^V`3o000000Go8IL00_l00003o`243003
o`000?l0PQ3o088@00;o088@0_l00003o`1b;@03o`000?l0Lbco07</00?o07</00?o0000o`1V??l0
IS`00ol0IS`00ol0003o06Xho`000003o`1MAP05o`000?l0Hd7o06=1o`1S@Ol000000_l0EdX01Ol0
003o05i5o`1NAOl0GTGo000000Co05=<0_l00005o`1CC003o`000?l0BDco000000Co05M:00?o0000
o`1ACOl0DDd00_l0DDd2o`0000Go05U900?o0000o`1GB_l0EdX00_l0EdX00ol0003o05I;o`1FB`02
o`1FB`06o`000?l0Ed[o0000o`000?l0I3oo00001?l0IS`00ol0003o06Xho`1Z>003o`1Z>003o`00
0?l0L33o070`00;o070`00Go0000o`1f9_l0MRKo07HVo`000004o`1n5`04o`000?l0Q`Co08L4o`27
10Ko00001?lCT@000ol0003o=Id0ocFM0002ocFM0004o`000?mNZP3oGZX0oejZ00Co00000_m^[`00
1Ol0003oXK`0oj6l0?nQ_03o000000;obKT00ol00005om2W0003o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool000;ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002?oo
ool01ol0003ooooooooooooooooo0000ooooool000003?ooool2o`000003ooooool0003o000000Ko
mRT01?l00002on]A0003o`000?oUJ03oiFP000?oiFP000?o0000omin0?oNOP000_oNOP04o`000003
olbc0?l0003o`L@000?o`L@000Go0000oj6l0?nQ_03oXK`0o`000004ohJe0006o`000?m`[`3oL:l0
o`000?loX@3o00000ol^V`000ol0003o8IL0ob6G0003ob6G0006o`000?lHT`3o69<0o`000?l0Q0co
00001?l0PQ001_l0003o084Bo`214_l0003o078]o`0000Go07</00?o0000o`1e:?l000000ol0IS`0
1ol0003o06Xho`1Z>?l0JSSo0000o`1MA_l000001?l0Hd400ol0003o05M:o`000005o`1NA@04o`00
0?l0Ddco05=<o`0000;o05a600?o0000o`1CC?l0Dd`00_l0Dd`2o`0000Go05M:00?o0000o`1ACOl0
DDd00_l000000ol0GDKo0000o`1IB@04o`1IB@03o`000?l0Ed[o05M:00;o05M:00Co0000o`1FBol0
ET_o05I;0ol00004o`1T?`03o`000?l0ISco06Hl00;o06Hl00?o0000o`1Z>?l0JSP00_l0JSP00ol0
003o070`o`1`<002o`1`<003o`000?l0MRKo07HV00;o07HV00?o0000o`1n5ol0OQL00_l0OQL01Ol0
003o08L4o`271?l0Q`Co000000?o4i401?l00002oa>A0003o`000?leW@3o=Id000;o=Id000Go0000
oejZ0?mNZP3oGZX0o`000002ohfg00?o00001?nQ_0001Ol0003obKT0olVi0?l0003obKT000?o0000
0_o@Y`000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00000ooooooo0000o`00
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool00003ooHY00;o
00001?oa>@03o`0000CoiFP000?o0000omin0?oNOP000_oNOP001?l0003oei@0omND0?oGU004o`00
00;o`L@000Go0000oj6l0?nQ_03oXK`0o`000004ohJe0003o`000?m`[`3oL:l000;oL:l00ol00000
0ol^V`3o0000ob6G0004ob6G0003o`000?lHT`3o69<000;o69<00_l00003o`224003o`000?l0PA;o
084B00;o084B00?o0000o`1c;?l0Lb`00ol0Lb`01ol0003o07DXo`1e:?l0MBSo0000o`1V??l00000
1Ol0JSP00ol0003o06=1o`1S@@04o`1S@@03o`000?l0GTGo05i500Co05i500?o0000o`1CC?l00000
1?l0G4H01_l0003o05=<o`1CC?l0003o05i5o`0000Go05M:00?o0000o`1ACOl000001?l0GDH00ol0
003o05U9o`1IB@02o`1IB@03o`000?l0Ed[o05M:00;o05M:1?l00002o`1S@003o`000?l0I3oo06@o
00;o06@o00?o0000o`1V??l0IS`00_l0IS`00ol0003o06Xho`1Z>002o`1Z>003o`000?l0L33o070`
00;o070`00?o0000o`1f9_l0MRH00_l0MRH00ol0003o07hGo`1n5`02o`1n5`03o`000?l0Q`Co08L4
00;o08L400Go0000oa>A0?lCT@3o4i40o`000002oc:L00?o00001?leW@000ol0003oGZX0oejZ0002
oejZ0003o`000?n=]`3oSKL000;oSKL00ol00002oj6l0003o`000?o9^@3obKT000;o00000_oFV003
o`0000kooooo00?o0000ooooooooool01Oooool000;ooooo00Co0000oooooooooooooooo1Ol00000
0ooooooo0000o`000003o`0000Sooooo0ol00004ooooo`;o00003?ooool01_l0003oooooooooool0
003omRT0o`0000GolCT000Co0000one<0?o]C03okD`00_l000000ooUJ03o0000omin0003omin0005
o`000?oGU03oei@0omND0?l000001?o@Z004o`000003oj6l0?l0003oQ[D000?oQ[D000?o0000og2_
0?m`[`000_m`[`001?l0003oGZX0oejZ0?mNZP02o`0000Co8IL000?o0000oaRC0?lHT`000_lHT`00
1_l0003o4i40oa>A0?l0003o088@o`0000Go084B0_l00003o`1c;003o`000?l0MBSo07DX00?o07DX
00?o0000o`1Z>?l0JSP00ol0JSP2o`0000Go06=10_l00006o`1NA@;o00001Ol0G4H00ol0003o05=<
o`000003o`1NA@03o`000?l0Ed[o05M:00;o05M:0_l00005o`1MAP03o`000?l0FDWo05U900?o05U9
1?l000000ol0I3oo0000o`1S@004o`1S@003o`000?l0I3oo06@o00;o06@o00?o0000o`1V??l0IS`0
0_l0IS`00ol0003o06Xho`1Z>002o`1Z>003o`000?l0L33o070`00;o070`00Go0000o`1f9_l0MRKo
07HVo`000004o`1n5`03o`000?l0Q`Co08L400;o08L400?o0000oa>A0?lCT@000_lCT@000ol0003o
<Y`0oc:L0002oc:L00Go00001?mNZP000ol0003oSKL0ohfg0002ohfg0003o`000?o1a03o`L@000?o
00000oo9^@02o`0000CoeYP000?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`00
;oooool00ol0003oooooooooo`02o`0000ColCT000?o0000one<0?o]C0000oo]C004o`0000;ogWh0
00Go0000omND0?oGU03oei@0o`000005om2X0004o`000?o9^@3obKT0olVi00?o00000_n6]@000ol0
003oL:l0og2_0002og2_0003o`000?mNZP3oGZX000;oGZX000Ko0000oe2V0?l0003o0000ob6G0?l0
0004oaRC0003o`000?lCT@3o4i4000;o4i4000?o0000o`214_l0PA800ol0PA801_l0003o088@o`22
4?l0003o07</o`0000Go07DX0_l00004o`1Z>004o`000?l0L33o070`o`0000?o06=100Co0000o`1Y
>Ol0JCWo00001?l0GTD00ol0003o06Hlo`000005o`1LAP;o00001Ol0GTD01_l0003o05M:o`1GB_l0
003o06=1o`0000Ko05e600Co0000o`1IBOl0FDWo05U90_l00005o`1T?`03o`000?l0Hd3o06=000;o
06=000?o0000o`1T?ol0I3l00_l0I3l00ol0003o06Hlo`1V?002o`1V?003o`000?l0JSSo06Xh013o
000000?o07hGo`000?l0Q`@00ol0Q`@01Ol0003o4i40oa>A0?lCT@3o000000Co<Y`000Co0000oeJX
0?mFZ03oEZP01?l00002oejZ0003o`000?n=]`3oSKL000;oSKL000?o0000ol740?o1a0000_o1a002
o`0000;obKT000?o0000omJH0?oFV0000_oFV0000ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo000`ooooo`;o00000_ooool2o`000003oo4i0?l0003okD`000CokD`000?o0000onMO
0?oWG`000_oWG`04o`000003omND0?l0003od:P000Cod:P000Go0000olVi0?o9^@3obKT0o`000003
okk300?o00000om`[`000ol0003oGZX0oejZ0002oejZ0003o`000?m@YP3oD:H000;oD:H00_l00003
oaRC0003o`000?lCT@3o4i4000?o4i400_l00003o`214P03o`000?l0PQ3o088@00;o088@00?o0000
o`1e:?l0MBP00ol0MBP01?l0003o07PRo`1h8_l00002o`1Z>003o`000?l0L33o070`00;o070`00?o
0000o`1S@Ol000001?l0JCT01?l0003o05i5o`1NAOl00003o`1V?003o`000?l0G4Ko05a600;o0000
00?o06Hlo`000?l0GTD01?l0GTD00ol0003o05M:o`000003o`1S@@03o`000?l0GDKo05e600?o05e6
00Ko0000o`1IBOl0003o0000o`1V??l00005o`1T?`03o`000?l0Hd3o06=000;o06=000Co0000o`1T
?ol0I3oo06@o2Ol00002o`1h8P03o`000?l0OAWo07dI00;o07dI00?o0000o`243?l0Q0`00_l0Q0`0
1?l0003o18/0o`B;0?l4R`05o`000003o`271?l0003o4i4000?o4i4000?o0000oc:L0?lbW0000_lb
W0001Ol0003oEZP0oeJX0?mFZ03o000000;oP;@00ol00004ohfg0003o`000?o1a03o`L@000;o`L@0
00?o0000om2X0?l000000_l00005omJH0003o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1Oooool003;ooooo00Co0000oooooooooooooooo0_l00004one<0003o`000?oWG`3oiel000;oiel0
00?o0000on5c0?oQL`000_oQL`02o`0000Cod:P000Go0000olVi0?o9^@3obKT0o`000004okk30006
o`000?nW_@3oYkd0o`000?m`[`3o00001?mNZP000ol0003oD:H0oe2V0002oe2V0006o`000?m6X`3o
AZ<0o`000?lHT`3o00001OlCT@001_l0003o4I40oa6A0?l0003o084Bo`0000Co088@00?o0000o`24
3?l000000ol0MBP01ol0003o07PRo`1h8_l0N2;o0000o`1Z>?l000001_l0L3000ol0003o06Tio`1Y
>@03o`1Y>@03o`000?l0GTGo000000Co06Hl00?o0000o`1LA_l000001?l0IS`00ol0003o05i5o`1N
A@02o`1NA@;o00001Ol0Hd400ol0003o05e6o`1MAP02o`1MAP;o00001?l0IS`00ol0003o06@oo`1T
?`02o`1T?`03o`000?l0Hd3o06=000;o06=01?l00002o`1c;003o`000?l0MBSo07DX00;o07DX00?o
0000o`1h8_l0N2800_l0N2800ol0003o07dIo`1m6@02o`1m6@03o`000?l0Q0co08@<00;o08@<00Go
0000o`B;0?l4R`3o18/0o`000003oaZD00Oo00001?lbW0000ol0003oEZP0oeJX0002oeJX0003o`00
0?n0]03oP;@000;oP;@01Ol00005ol740004o`000?o@Z03od:P0om2X00Co000000?oeYP0o`000?oo
ool02oooool00ol0003oooooooooo`05ooooo`00<oooool00ol0003oooooooooo`02ooooo`;o0000
00?okD`0o`000?oWG`000ooWG`000ol0003ohG<0on5c0002on5c0003o`000?oKQP3ofhH000;o0000
00?od:P0o`000?o9^@000_o9^@000ol0003o_/<0okk30002okk30003o`000?nW_@3oYkd000;oYkd0
0ol00002oejZ0003o`000?m@YP3oD:H000;oD:H000?o0000odJS0?m6X`000_m6X`000ol0003o4i40
oa>A0003oa>A0003o`000?lAT@3o4I4000;o4I4000?o0000o`224?l0PQ000_l0PQ001ol0003o08@<
o`243?l0Q0co0000o`1e:?l000001Ol0N2800ol0003o070`o`1`<004o`1`<0;o00001Ol0JCT2o`00
00Ko06Hl00?o0000o`1V??l0IS`00ol0IS`00ol0003o05i5o`1NA@02o`000003o`1Y>Ol0003o06=1
00Co06=100?o0000o`1MA_l000000_l000000ol0JSSo0000o`1V?003o`1V?003o`000?l0I3oo06@o
00?o06@o1?l000000ol0LRgo0000o`1c;004o`1c;003o`000?l0MBSo07DX00;o07DX00Go0000o`1h
8_l0N2;o07PRo`000004o`1m6@03o`000?l0Q0co08@<00;o08@<00?o0000o`B;0?l4R`000_l4R`00
0ol0003o6Y@0oaZD0002oaZD0004o`000?leW@3o=Id0ocFM00Ko00001?mFZ0000ol0003oP;@0oh2d
0002oh2d0004o`000?n`_`3o/;l0ok2o00Co00000_o1a0001?l0003od:P0om2X0?o@Z002o`0000;o
fhH00ol0000<ooooo`03o`000?oooooooooo00Cooooo000dooooo`03o`000?oooooooooo00?ooooo
0ol00002onMO0003o`000?oQL`3ohG<000;ohG<000?o0000om^60?oKQP000_oKQP04o`000003olVi
0?l0003o_/<000?o_/<000?o0000ojNm0?nW_@000_nW_@001?l0003oUKT0oiFi0?nE^@03o`0000?o
D:H000?o0000odJS0?m6X`000_m6X`000ol0003o@J40o`000003oa>A0003o`000?lAT@3o4I4000;o
4I400_l00003o`224003o`000?l0Q0co08@<00?o08@<00?o0000o`1h8_l0N2801?l0N2800ol0003o
070`o`1`<003o`1`<004o`000?l0MRKo07HVo`0000?o06Ti00?o0000o`1b;Ol000001Ol0IS`2o`00
00Go06Hl00?o0000o`1NAOl000001?l0JCT00ol0003o06=1o`1S@@02o`1S@@;o00001Ol0JSP00ol0
003o06Hlo`1V?002o`1V?004o`000?l0I3oo06@oo`1T?`;o00001?l0LRd00ol0003o07</o`1c;003
o`1c;003o`000?l0MBSo07DX00;o07DX00?o0000o`1h8_l0N2800_l0N2800ol0003o07dIo`1m6@02
o`1m6@03o`000?l0Q0co08@<00;o08@<00Go0000o`B;0?l4R`3o18/0o`000005oaZD0005o`000?le
W@3o=Id0ocFM0?l000000omFZ006o`0000GoP;@000Go0000ok2o0?n`_`3o/;l0o`000002olbc00?o
00001?o@Z0000ol0003ofhH0om^60002om^60003o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01?ooool003Gooooo0_l00006ooooo`?o00000ooQL`000ol0003ofhH0om^60002om^60003o`00
0?oFV03oeYP000;oeYP00ol00002okk30003o`000?nW_@3oYkd000;oYkd000?o0000oiFi0?nE^@00
0onE^@001Ol0003oQ[D0o`000?m@YP3o000000CoAZ<000Oo0000od6Q0?m1X@3o@J40o`000?lCT@3o
000000Co4I4000Ko0000oa>A0?lCT@3o0000o`224?l00005o`2430;o00001Ol0N2800ol0003o07dI
o`000003o`1`<005o`000?l0MRKo07HVo`1f9_l000000_l0JCT01Ol0003o078]o`1b;Ol0LRgo0000
00?o06Hl00Co0000o`1`;ol0L2oo00001Ol0IS`00ol0003o06Tio`1Y>@03o`1Y>@03o`000?l0Hd7o
06=100;o000000?o070`o`000?l0JSP01?l0JSP00ol0003o06Hlo`1V?002o`1V?006o`000?l0I3oo
0000o`000?l0Lbco00001Ol0LRd00ol0003o07</o`1c;002o`1c;003o`000?l0MBSo07DX00;o07DX
00?o0000o`1h8_l0N2800_l0N2800ol0003o07dIo`1m6@02o`1m6@03o`000?l0Q0co08@<00;o08@<
00?o0000o`B;0?l4R`000_l4R`000ol0003o6Y@0oaZD0002oaZD0003o`000?leW@3o=Id000;o=Id0
00Go0000oeJX0?mFZ03oEZP0o`000003ogbb00Co00000_n0]0000ol0003o/;l0ok2o0002ok2o0003
o`000?o</`3oc;<000;oc;<01?l000000oo@Z03o0000om^60003om^60003o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool003Oooooo00?o0000ooooooooool01_ooool00ol0003ohG<0
o`000004om^60003o`000?oFV03oeYP000;oeYP000Co0000om2W0?o@Y`3od:L00ol00003ojNm0003
o`000?nE^@3oUKT000?oUKT000Co0000ohJe0?n6]@3oQ[D00_l00003odJS0003o`000?m1X@3o@J40
00?o@J400_l00003oa6A0003o`000?lCT@3o4i4000;o4i4000?o0000o`243?l0Q0`00ol0Q0`01?l0
003o08L4o`271?l00003o`1h8P07o`000?l0OAWo07dIo`1m6Ol0003o070`o`000004o`1f9P03o`00
0?l0JCWo000000Go078]00?o0000o`1V??l000000ol0L2l00ol0003o06Hlo`1V?002o`1V?0;o0000
1Ol0JCT00ol0003o06=1o`000004o`1`<003o`000?l0JSSo06Xh00;o06Xh00?o0000o`1V??l0IS`0
0_l0IS`2o`0000Co07</00?o0000o`1b;Ol0LRd00_l0LRd00ol0003o07</o`1c;003o`1c;003o`00
0?l0MBSo07DX00;o07DX00?o0000o`1h8_l0N2804Ol00004oaZD0003o`000?leW@3o=Id000;o=Id0
00?o0000oeJX0?mFZ0000_mFZ0001Ol0003oO;80ogbb0?ml/P3o000000;oZ;h00ol00005ok2o0005
o`000?o</`3oc;<0olbc0?l000000ooGU007o`0000_ooooo00?o0000ooooooooool01?ooool003So
oooo00?o0000ooooooooool01_ooool3o`0000;ofhH000?o0000omJH0?oFV0000_oFV0000ol0003o
d:L0om2W0002om2W0006o`000?o;/`3obk<0o`000?nW_@3o00001OnE^@000ol0003oQ[D0ohJe0002
ohJe0005o`000?ml/P3o0000odJS0?l000001Om1X@001_l0003o?j40ocnQ0?l0003o4I40o`0000Go
4i400_l00003o`243003o`000?l0Q`Co08L400;o08L400?o0000o`1h8_l000001Ol0OAT00ol0003o
07HVo`1f9P04o`1f9P03o`000?l0LRgo078]00Co078]0_l00005o`1`;`04o`000?l0ISco06Hlo`00
00;o078]00?o0000o`1Y>Ol0JCT00_l0JCT2o`0000Go070`00?o0000o`1Z>?l0JSP00ol0JSP4o`00
0003o`1e:?l0003o07</00?o07</00?o0000o`1b;Ol0LRd00_l0LRd00ol0003o07</o`1c;002o`1c
;0Wo00000_l0Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?lETP3o5I8000;o5I8000Co0000obRI
0?lXV@3o:9T01Ol000000olJU03o0000ocFM0002ocFM0003o`000?mFZ03oEZP000;oEZP000?o0000
ogbb0?ml/P000_ml/P000ol0003oZ;h0ojRn0002ojRn00Co000000?o/;l0o`000?o</`000oo</`00
0ol0003oei@0omND0002omND00;o00000_oQL`02o`0000[ooooo00?o0000ooooooooool01?ooool0
03Wooooo00?o0000ooooooooool02?ooool3o`0000?oeYP000?o0000om2W0?o@Y`000_o@Y`000ol0
003obk<0ol^c0002ol^c00;o00001?nE^@000ol0003oQ[D0ohJe0002ohJe0005o`000?ml/P3oO;80
ogbb0?l000001Om1X@000ol0003o?j40ocnQ0002ocnQ0003o`000?lCT@3o4i4000?o4i4000Ko0000
oaRC0?lHT`3o0000o`243?l00006o`271003o`000?l0OAWo07dI00?o07dI0_l00005o`1f9P;o0000
1Ol0LRd00ol0003o07/Mo`000005o`1`;`03o`000?l0ISco000000Co078]00Ko0000o`1Y>Ol0JCWo
0000o`1f9_l00005o`1`<003o`000?l0JSSo06Xh00;o06Xh0_l00005o`1e:003o`000?l0Lbco07</
00;o07</00?o0000o`1b;Ol0LRd00_l0LRd4o`000003o`224?l0003o08@<00?o08@<00?o0000o`27
1?l0Q`@00ol0Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?lETP3o5I8000;o5I8000Go0000obRI
0?lXV@3o:9T0o`000003od6Q00_o00001?ml/P000ol0003oZ;h0ojRn0002ojRn0004o`000?o9^P3o
bKX0olVj00Oo00001OoGU0001Ol0003ohG<0on5c0?oQL`3o000000[ooooo00?o0000ooooooooool0
1?ooool003[ooooo0_l0000;ooooo`03o`000?oFV03o000000Cod:L000?o0000ol^c0?o;/`000_o;
/`000ol0003oakh0olNn0002o`000003oiFi0?l0003oQ[D000?oQ[D000?o0000ogbb0?ml/P000_ml
/P02o`0000?o@J4000?o0000ocnQ0?loX@000oloX@02o`0000?o4i4000?o0000oaRC0?lHT`000_lH
T`000ol0003o08L4o`271004o`2710;o00001?l0OAT01?l0003o08@<o`243?l00003o`1f9P04o`00
0?l0OQOo07hGo`0000?o078]00Go0000o`1k7Ol0Nago07/Mo`000004o`1`;`;o00001Ol0LRd00ol0
003o06Tio`000003o`1f9P03o`000?l0L33o070`00?o070`1?l000000ol0N2;o0000o`1e:004o`1e
:003o`000?l0Lbco07</00;o07</00?o0000o`1b;Ol0LRd00ol00005o`224003o`000?l0Q0co08@<
00;o08@<00?o0000o`271?l0Q`@00_l0Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?lETP3o5I80
00;o5I8000?o0000obRI0?lXV@000_lXV@001Ol0003o@J40od6Q0?m1X@3o000000CoGZX000Co0000
oh2d0?n0]03oP;@01?l00002ogbb0003o`000?nX_P3oZ;h000;oZ;h000?o0000olVj0?o9^P000_o9
^P001?l0003odid0om>M0?oCW@04o`0000;oei@00_l00003on5c0003o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool003cooooo00?o0000ooooooooool02Oooool3o`0000;od:L000?o
0000ol^c0?o;/`000_o;/`000ol0003oakh0olNn0003olNn00;o00000on6]@000ol0003oO;80ogbb
0002ogbb0006o`000?mf/@3oM[40o`000?m1X@3o00001OloX@001_l0003o@J40od6Q0?l0003o4i40
o`0000Go69<000?o0000o`271?l0Q`@00ol0Q`@01?l0003o1X`0o`J<0?l00002o`1m6@03o`000?l0
Q0co08@<00;o08@<00?o0000o`1f9_l000001?l0OQL00ol0003o078]o`000004o`1k7@03o`000?l0
L2oo070_00;o000000?o07/Mo`000?l0LRd01?l0LRd2o`0000Co07HV00?o0000o`1`<?l0L3000_l0
L302o`0000Go07PR00?o0000o`1e:?l0MBP00_l0MBP00ol0003o07</o`1c;002o`1c;0?o00000_l0
PA800ol0003o088@o`224003o`224003o`000?l0Q0co08@<00;o08@<00?o0000o`271?l0Q`@00_l0
Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?lETP3o5I8000;o5I8000?o0000obRI0?lXV@000_lX
V@000ol0003o@J40od6Q0002od6Q0003o`000?mNZP3oGZX000;oGZX000Go0000oh2d0?n0]03oP;@0
o`000002ojRn00?o00001?nX_P000ol0003obKX0olVj0003olVj0005o`000?oCW@3odid0om>M0?l0
00000_oNOP03o`000003on5c0?l0003ohG<000;ohG<000?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`00?Oooool00ol0003oooooooooo`0;ooooo`?o00000oo;/`000ol0003oakh0
olNn0003olNn0006o`000?o3a03o`l@0o`000?n6]@3o00001?ml/P000ol0003oM[40ogJa0002ogJa
0003o`000?loX@3o?j4000?o?j4000?o0000od6Q0?m1X@000_m1X@000ol0003o69<0oaRC0003oaRC
0003o`000?lQU`3o000000?o08L400Oo0000o`J<0?l6S03o1X`0o`000?l0OAWo000000Ko08@<00?o
0000o`1n5ol0OQL01?l0OQL00ol0003o07/Mo`1k7@03o`1k7@03o`000?l0L2oo000000Co07/M00Oo
0000o`1b;Ol0LRgo078]o`000?l0OQOo000000Go07HV00Ko0000o`1`<?l0L33o0000o`1m6Ol00005
o`1h8P03o`000?l0MBSo07DX00?o07DX1?l000000ol0PQ3o0000o`214P03o`214P03o`000?l0PQ3o
088@00?o088@00Go0000o`243?l0Q0co08@<o`000005o`271003o`000?l6S03o1X`000;o1X`000?o
0000oaFB0?lETP000_lETP001Ol0003o:9T0obRI0?lXV@3o000000Co@J4000?o0000oejZ0?mNZP00
0_mNZP000ol0003oP;@0oh2d0002oh2d0003o`000?nX_P3oZ;h000;oZ;h01Ol00005olVj0003o`00
0?oCW@3odid000;odid000?o0000omin0?oNOP000_oNOP07o`0000Sooooo00?o0000ooooooooool0
0oooool003kooooo00?o0000ooooooooool03Oooool00ol0003obk<0o`000005olNn0003o`000?o3
a03o`l@000;o`l@00_l00003ogbb0003o`000?mf/@3oM[4000;oM[4000?o0000ogB`0?l000000olo
X@000ol0003o@J40od6Q0002od6Q0003o`000?m6X`3o000000?o69<000Oo0000ob6G0?lQU`3o8IL0
o`000?l0Q`Co000000Go1X`000?o0000o`243?l0Q0`01?l0Q0`2o`0000Go07hG0_l00006o`1k7@03
o`000?l0Nago07/M00?o07/M00Co0000o`1b;Ol0LRgo00000ol0OQL00ol0003o07HVo`1f9P02o`1f
9P03o`000?l0L33o000000?o07dI00?o0000o`1h8_l0N2800_l0N2800ol0003o07DXo`1e:002o`1e
:0;o00001Ol0PQ001Ol0003o084Bo`214_l0PA;o000000Go088@00?o0000o`243?l0Q0`00_l0Q0`0
0ol0003o08L4o`27100@o`000003obRI0?l0003o@J4000;o@J4000?o0000oejZ0?mNZP000omNZP00
1Ol0003oP;@0oh2d0?n0]03o000000CoZ;h000Co0000olRl0?o8_03ob;`01Ol000000oo9^P3o0000
om>M0003om>M0003o`000?oNOP3ogWh000;ogWh000?o0000onMO0?l000000ooWG`000ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo000oooooo`;o00003_ooool2o`0000Coakh000?o
0000ol?40?o3a0000_o3a0001_l0003o^<80okS20?l0003oO;80o`0000CoM[4000Oo0000ogB`0?md
/03oM;00o`000?loX@3o000000Co@J4000Oo0000odJS0?m6X`3oAZ<0o`000?lHT`3o000000Go8IL0
00?o0000o`J<0?l6S0001?l6S0000ol0003o08@<o`243003o`243004o`000?l4R`3o18/0o`0000?o
07hG00Co0000o`271?l0Q`Co00001?l0Nad2o`0000Go07/M00?o0000o`1b;Ol000001?l0OQL00ol0
003o07HVo`1f9P02o`1f9P;o00001?l0OAT00ol0003o07PRo`1h8P03o`1h8PCo000000?o08@<o`00
0?l0PQ001?l0PQ000ol0003o084Bo`214P02o`214P03o`000?l0PQ3o088@00;o088@00?o0000o`24
3?l0Q0`01Ol00002ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o0000ocnQ0?loX@000_loX@001?l0
003oE:L0oeBW0?mDY`0:o`000003oejZ0?l0003oP;@000?oP;@000?o0000ojRn0?nX_P000_nX_P00
1Ol0003ob;`0olRl0?o8_03o000000?odZ801ol00005omin0003o`000?oWG`3o000000?oiel000?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`00@Oooool00ol0003oooooooooo`0=
ooooo`;o000000?oakh0o`000?o3a0000oo3a0000ol0003o^<80okS20002okS200;o00000omf/@00
0ol0003oM;00ogB`0003ogB`00;o00000om1X@000ol0003oAZ<0odJS0003odJS0003o`000?lQU`3o
8IL000?o8IL00_l00005o`J<0003o`000?lETP3o000000?o08@<00Go0000o`B;0?l4R`3o18/0o`00
0002o`1n5`03o`000?l0Q`Co08L400;o08L400Co0000o`1k7Ol0Nago00000_l0QPL00ol0003o07/M
o`1k7@02o`1k7@;o00001Ol0OQL00ol0003o07HVo`1f9P02o`000003o`243?l0003o07dI00Co07dI
00Co0000o`1h8_l0N2;o07PR0_l00005o`243003o`000?l0PQ3o088@00;o088@00?o0000o`214_l0
PA800_l0PA801?l0003o088@o`224?l0PQ04o`0000;o69<000?o0000ob6G0?lQU`000olQU`000ol0
003o;Y/0objK0002objK0003o`000?loX@3o?j4000;o?j4000Go0000oeBW0?mDY`3oE:L0o`000004
ofj_0004o`000?n=]`3oSKL0ohfg00Oo00001?nX_P000ol0003ob;`0olRl0002olRl0003o`000?oB
XP3odZ8000;odZ8000Co0000omb50?oLQ@3og8D01Ol000001OoNOP3o0000onMO0?oWG`3o000000;o
iel000?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`00@_ooool00ol0003ooooo
ooooo`0>ooooo`;o00000oo3a0000ol0003o^<80okS20002okS20006o`000?nb`03o//00o`000?mf
/@3o00001Omd/0001_l0003oM[40ogJa0?l0003o@J40o`0000KoAZ<000?o0000ob6G0?lQU`000_lQ
U`001?l0003o;Y/0objK0?l00003o`J<0007o`000?lETP3o5I80oaFB0?l0003o08@<o`000004o`B;
0003o`000?l0OQOo000000Go08L400?o0000o`1k7Ol000001?l0QPL01_l0003o07/Mo`1k7Ol0003o
08L4o`0000Ko07hG0_l00004o`243003o`000?l0OAWo07dI00;o07dI00Ko0000o`1h8_l0003o0000
o`271?l00005o`243003o`000?l0PQ3o088@00?o088@00?o0000o`214_l0PA801Ol00002oa>A0003
o`000?lHT`3o69<000;o69<000?o0000ob6G0?lQU`000_lQU`000ol0003o;Y/0objK0002objK0003
o`000?loX@3o?j4000;o?j4000?o0000oeBW0?mDY`000_mDY`000ol0003oKZl0ofj_0002ofj_0003
o`000?n=]`3oSKL000;oSKL000Co0000ok2o0?n`_`3o/;l01_l00005olRl0003o`000?oBXP3odZ80
00;odZ8000Go0000omb50?oLQ@3og8D0o`000003onEX00Ko000000?oiel0o`000?ooool01_ooool0
0ol0003oooooooooo`03ooooo`00@oooool00ol0003oooooooooo`0?ooooo`03o`000?o3a03o0000
00Co^<8000?o0000ok;00?nb`0000_nb`0000ol0003oM;00ogB`0003ogB`0003o`000?mf/@3oM[40
00;oM[4000?o0000odJS0?m6X`001?m6X`000ol0003oD:H0o`000002ob6G0003o`000?l^V`3o;Y/0
00;o;Y/000?o0000o`J<0?l000001OlETP000ol0003o18/0o`B;0004o`B;0003o`000?l0Q`Co08L4
00Go08L400?o0000o`261ol0QPL00ol0QPL00ol0003o07/Mo`000003o`271003o`000?l0OQOo07hG
00;o07hG0_l00005o`243003o`000?l0OAWo07dI00;o07dI0_l00004o`271003o`000?l0Q0co08@<
00?o08@<00Co0000o`224?l0PQ3o088@1?l00002oa6A0003o`000?lCT@3o4i4000?o4i4000Go0000
oaRC0?lHT`3o69<0o`000005ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o0000ocnQ0?loX@000_lo
X@001Ol0003oE:L0oeBW0?mDY`3o000000CoKZl000?o0000ohfg0?n=]`000on=]`001Ol0003o/;l0
ok2o0?n`_`3o000000?obKX01Ol000000oo8_03o0000om:R0003om:R0003o`000?oLQ@3og8D000;o
g8D000?o0000onEX0?oUJ0000_oUJ0000ol0003okD`0one<0004o`0000Kooooo00?o0000oooooooo
ool00oooool004Cooooo0_l0000@ooooo`;o00000onh`P000ol0003o//00ok;00002ok;00003o`00
0?n`_`3o000000?oM;0000?o0000ogJa0?mf/@000omf/@000ol0003oAZ<0odJS0003odJS0006o`00
0?m@YP3oD:H0o`000?lQU`3o00001_l^V`000ol0003o5I80oaFB0003oaFB00;o00001Ol4R`02o`00
00Ko08L40_l00005o`261`;o00001Ol0Q`@01_l0003o07hGo`1n5ol0003o18/0o`0000Go08@<00?o
0000o`1m6Ol0OAT00_l000000ol6S03o0000o`271003o`271003o`000?l0Q0co08@<00?o08@<00Ko
0000o`224?l0003o0000oa>A0?l00005oa6A0003o`000?lCT@3o4i4000;o4i4000?o0000oaRC0?lH
T`000_lHT`000ol0003o8IL0ob6G0002ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o0000ocnQ0?lo
X@000_loX@000ol0003oE:L0oeBW0002oeBW0003o`000?m^[`3oKZl000;oKZl000?o0000ohfg0?n=
]`000_n=]`000ol0003o/;l0ok2o0002ok2o0005o`000?o9^P3obKX0olVj0?l000000ooBXP07o`00
00Gog8D000?o0000onEX0?oUJ0000_oUJ0001_l0003okD`0one<0?l0003okD`0o`0000Oooooo00?o
0000ooooooooool00_ooool004Kooooo00?o0000ooooooooool03oooool00ol0003o^<80o`000004
ok;00007o`000?n`_`3o/;l0ok2o0?l0003oM;00o`000005ogJa0003o`000?ml/P3o000000?oAZ<0
00?o0000oe2V0?m@YP000_m@YP000ol0003o;Y/0objK0004objK00;o00001?lETP001?l0003o:9T0
obRI0?l00003o`B;0004o`000?lJU03o6Y@0o`0000Co08L400Co0000oa>A0?lCT@3o00000ol0QPL0
0ol0003o4i40o`000005o`271003o`000?l0OQOo000000?o18/000?o0000o`243?l0Q0`00ol0Q0`2
o`0000Co1X`000?o0000o`271?l0Q`@00_l0Q`@00ol0003o08@<o`243002o`2430;o00001?lCT@00
0ol0003o4I40oa6A0002oa6A0003o`000?lCT@3o4i4000;o4i4000?o0000oaRC0?lHT`000_lHT`00
0ol0003o8IL0ob6G0002ob6G0004o`000?l^V`3o;Y/0objK00Oo00001?mDY`000ol0003oKZl0ofj_
0002ofj_0003o`000?n=]`3oSKL000;oSKL000?o0000ok2o0?n`_`000_n`_`000ol0003obKX0olVj
0002olVj0003o`000?oBXP3odZ8000;odZ8000Co0000om^70?oKQ`3ofhL01Ol000000ooLQ@3o0000
onEX0003onEX0007o`000?o]C03okD`0one<0?l0003okD`0o`000006ooooo`03o`000?oooooooooo
00;ooooo0017ooooo`03o`000?oooooooooo00oooooo0_l00003ok;00003o`000?n`_`3o/;l000?o
/;l000?o0000ogJa0?mf/@000omf/@001ol0003oO;80ogbb0?ml/P3o0000odJS0?l000001Om@YP00
0ol0003o;Y/0objK0003objK0004o`000?loX@3o?j40o`0000;o5I8000?o0000obRI0?lXV@000_lX
V@000ol0003o18/0o`000004oaZD0004o`000?l0Q`Co08L4o`0000?o4i4000Co0000o`261ol0QPOo
00000olCT@000ol0003o08L4o`271002o`2710;o00001?l4R`000ol0003o08@<o`243002o`2430;o
00001Ol6S0000ol0003o08L4o`271002o`271003o`000?l0Q0co000000;o000000?o69<0o`000?lC
T@000olCT@000ol0003o4I40oa6A0002oa6A0003o`000?lCT@3o4i4000?o4i4000?o0000oaRC0?lH
T`002_l00002oejZ0004o`000?m`[`3oL:l0og2_00oo000000?oSKL0o`000?n`_`000_n`_`000ol0
003obKX0olVj0003olVj0003o`000?oBXP3odZ8000;odZ8000Go0000om^70?oKQ`3ofhL0o`000003
on=/00ko00001Oooool00ol0003oooooooooo`02ooooo`00B?ooool00ol0003oooooooooo`0@oooo
o`03o`000?nb`03o000000Go/;l000?o0000ok;00?l000000omf/@000ol0003oO;80ogbb0003ogbb
0003o`000?m@YP3oD:H000?oD:H000?o0000oejZ0?l000000ol^V`001ol0003o?j40ocnQ0?loX@3o
0000oaFB0?l000001_lXV@000ol0003o6Y@0oaZD0003oaZD0003o`000?l0Q`Co000000Co4i4000?o
0000o`261ol000001?lCT@001ol0003o08L4o`271?l0Q`Co0000oaZD0?l000001Ol4R`001_l0003o
08@<o`243?l0003o5I80o`0000Go1X`000?o0000o`271?l0Q`@00_l0Q`@2o`0000Go69<000?o0000
oa>A0?lCT@000_lCT@000ol0003o4I40oa6A0002oa6A0003o`000?lCT@3o4i4000Go00000_m6X`00
0ol0003oD:H0oe2V0002oe2V0003o`000?mNZP3oGZX000;oGZX000?o0000og2_0?m`[`000_m`[`00
0ol0003oQ[D0ohJe0002ohJe0003o`000?nQ_03oXK`000;oXK`000Co0000ol740?o1a03o`L@01Ol0
00000on`_`3o0000olVj0003olVj0003o`000?oBXP3odZ8000;odZ8000?o0000om^70?oKQ`000_oK
Q`000ol0003ohf`0on=/0002on=/0003o`000?o[D@3oje4000;oje4000Oo0000oo4i0?oa>@3olCT0
o`000?oa>@3o000000Gooooo00?o0000ooooooooool00_ooool004Wooooo0_l0000Aooooo`03o`00
0?n`_`3o/;l000?o/;l000Oo0000ok;00?nb`03o//00o`000?mf/@3o000000GoO;8000?o0000ohJe
0?l000000om@YP001ol0003oGZX0oejZ0?mNZP3o0000objK0?l000001OloX@000ol0003o:9T0obRI
0004obRI00;o00001OlJU002o`0000Go4i400_l00005oa>A0004o`000?l0Q`Co08L4o`0000?o6Y@0
00?o0000o`B;0?l4R`000_l4R`000ol0003o08@<o`000003oaFB0003o`000?l6S03o1X`000?o1X`0
1?l000000olQU`3o0000oaRC0004oaRC0003o`000?lCT@3o4i4000;o4i4000?o0000oa6A0?lAT@00
1Ol00002od6Q0003o`000?m6X`3oAZ<000?oAZ<000?o0000oe2V0?m@YP000_m@YP000ol0003oGZX0
oejZ0002oejZ0003o`000?m`[`3oL:l000;oL:l000?o0000ohJe0?n6]@000_n6]@000ol0003oXK`0
oj6l0002oj6l0005o`000?o1a03o`L@0ol740?l000000oo</`0<o`0000CofhL000?o0000on=/0?oS
K0000ooSK0000ol0003oje40on]A0002on]A0007o`000?oa>@3olCT0oo4i0?l0003olCT0o`000004
ooooo`03o`000?oooooooooo00;ooooo001;ooooo`03o`000?oooooooooo00oooooo00Go0000ok2o
0?n`_`3o/;l0o`000005ok;00003o`000?ml/P3oO;8000?oO;8000Oo0000ohJe0?n6]@3oQ[D0o`00
0?m@YP3o000000CoGZX00_l00005ocnQ00;o00001OlXV@001?l0003o@J40od6Q0?l00003oaZD0003
o`000?leW@3o000000Co4i4000?o0000oc:L0?l000001_lCT@02o`0000Co6Y@000?o0000o`B;0?l4
R`000_l4R`02o`0000Co5I8000?o0000o`J<0?l6S0000_l6S002o`0000Go8IL000?o0000oaRC0?lH
T`000_lHT`000ol0003o4i40oa>A0002oa>A00?o00000_loX@000ol0003o@J40od6Q0003od6Q0003
o`000?m6X`3oAZ<000;oAZ<000?o0000oe2V0?m@YP000_m@YP000ol0003oGZX0oejZ0002oejZ0003
o`000?m`[`3oL:l000;oL:l000?o0000ohJe0?n6]@000_n6]@000ol0003oXK`0oj6l0002oj6l0003
o`000?o1a03o`L@000;o`L@000Go0000olbc0?o</`3oc;<0o`000005om>M0004o`000?oLQ@3og8D0
omb500Ko00001OoSK0000ol0003oje40on]A0002on]A0003o`000?oa>@3olCT000;olCT00_l00004
ooooo`03o`000?oooooooooo00;ooooo001<ooooo`03o`000?oooooooooo00oooooo00?o0000ok2o
0?l000001Onb`0000ol0003o^<80o`000003ogbb0003o`000?n6]@3oQ[D000?oQ[D000?o0000oejZ
0?mNZP000_mNZP001?l0003oL:l0og2_0?l00003ocnQ0004o`000?mDY`3oE:L0o`0000?o:9T000Go
0000od6Q0?m1X@3o@J40o`000002oaZD0005o`000?leW@3o=Id0ocFM0?l000000_lCT@001Ol0003o
<Y`0oc:L0?lbW03o000000Go4i4000?o0000oaZD0?lJU0000olJU0000ol0003o18/0o`B;0002o`00
0003obRI0?l0003o5I8000Co5I8000Ko0000o`J<0?l6S03o0000objK0?l00005ob6G0003o`000?lH
T`3o69<000?o69<01?l000000om1X@3o0000ocnQ0003ocnQ0003o`000?m1X@3o@J4000;o@J4000?o
0000odJS0?m6X`000_m6X`000ol0003oD:H0oe2V0002oe2V0003o`000?mNZP3oGZX000;oGZX000?o
0000og2_0?m`[`000_m`[`000ol0003oQ[D0ohJe0002ohJe0003o`000?nQ_03oXK`000;oXK`000?o
0000ol740?o1a0000_o1a0000ol0003oc;<0olbc0002olbc0003o`000?oCW@3odid000?odid000Go
0000omb50?oLQ@3og8D0o`000003on=/01?o00000oooool00ol0003oooooooooo`02ooooo`00COoo
ool00ol0003oooooooooo`0?ooooo`03o`000?nb`03o//0000?o//0000Oo0000okS20?nh`P3o^<80
o`000?ml/P3o000000GoQ[D00_l00003oejZ0003o`000?m`[`3oL:l000;oL:l000?o0000ocnQ0?l0
00001?mDY`000ol0003o:9T0o`000004od6Q0003o`000?lJU03o000000Co=Id000?o0000oa>A0?l0
00001?lbW0000ol0003o4i40oa>A0002oa>A00;o00001_lJU002o`0000Co:9T000?o0000oaFB0?lE
TP000_lETP000ol0003o1X`0o`000003objK0003o`000?lQU`3o8IL000;o8IL000?o0000oaRC0?lH
T`000_lHT`02o`0000Co@J4000?o0000ocnQ0?loX@000_loX@000ol0003o@J40od6Q0003od6Q0003
o`000?m6X`3oAZ<000;oAZ<000?o0000oe2V0?m@YP000_m@YP000ol0003oGZX0oejZ0002oejZ0003
o`000?m`[`3oL:l000;oL:l000?o0000ohJe0?n6]@000_n6]@000ol0003oXK`0oj6l0002oj6l0005
o`000?o1a03o`L@0ol740?l000001Oo</`000ol0003odid0om>M0002om>M0003o`000?oLQ@3og8D0
00;og8D000Go0000on=/0?oSK03ohf`0o`000005on]C0003o`000?oa?03olC`000;olC`000?o0000
ooHY0?of:@000_of:@02o`0000Cooooo00?o0000ooooooooool00Oooool004kooooo0_l0000@oooo
o`05o`000?nb`03o//00ok;00?l000001Onh`P000ol0003oQ[D0ohJe0003ohJe0006o`000?nE^@3o
UKT0o`000?mNZP3o00001_m`[`000ol0003oE:L0oeBW0004oeBW0003o`000?m1X@3o@J4000Co@J40
00?o0000ocFM0?leW@001?leW@000ol0003o<Y`0oc:L0004oc:L0004o`000?lCT@3o4i40o`0000;o
=Id000?o0000oaZD0?lJU0000_lJU002o`0000Go:9T000?o0000oaFB0?lETP000_lETP02o`0000Co
;Y/000?o0000ob6G0?lQU`000olQU`04o`000003odJS0?l0003o@J4000Co@J4000?o0000ocnQ0?lo
X@000_loX@000ol0003o@J40od6Q0002od6Q0003o`000?m6X`3oAZ<002Co000000?oc;<0o`000?oC
W@000ooCW@000ol0003og8D0omb50002omb50003o`000?oSK03ohf`000;ohf`000?o0000on]C0?o[
D`000oo[D`000ol0003olC`0oo4l0002oo4l0003o`000?of:@3omRT000;omRT00_l00003ooooo`03
o`000?oooooooooo007ooooo001@ooooo`03o`000?oooooooooo00kooooo00?o0000ok;00?l00000
1Onh`P000ol0003o`l@0o`000003ohJe0003o`000?nE^@3oUKT000;oUKT000?o0000og2_0?m`[`00
1?m`[`02o`0000KoE:L000?o0000od6Q0?m1X@000om1X@02o`0000Ko=Id000?o0000oc:L0?lbW000
1?lbW0000ol0003o4i40o`000004ocFM0006o`000?lJU03o6Y@0o`000?m1X@3o00001OlXV@000ol0
003o5I80o`000002o`000003ocnQ0?l0003o;Y/000Co;Y/000Co0000ob6G0?lQU`3o8IL00_l00005
odJS0003o`000?m1X@3o@J4000;o@J4000?o0000ocnQ0?loX@000_loX@001?l0003o@J40od6Q0?m1
X@04o`0000;oO;8000?o0000ohJe0?n6]@000_n6]@000ol0003oUKT0oiFi0002oiFi0003o`000?nW
_@3oYkd000;oYkd000?o0000okk30?nn``000_nn``000ol0003obKT0olVi0002olVi0003o`000?o@
Z03od:P000;od:P000Co0000omND0?oGU03oei@03?l00005on=/0003o`000?o[D`3oje<000;oje<0
00?o0000oo4l0?oa?0000ooa?0000ol0003omRT0ooHY0002ooHY0005o`000?ooooooooooooooool0
00000oooool0057ooooo00?o0000ooooooooool03_ooool00ol0003o^<80okS20003okS20007o`00
0?o3a03o`l@0ol?40?l0003oQ[D0o`000005oiFi0003o`000?m`[`3oL:l000?oL:l000Co0000ohJe
0?n6]@3o00001?mDY`000ol0003oKZl0o`000003od6Q0004o`000?mNZP3oGZX0o`0000Co=Id000?o
0000oeJX0?l000001OlbW002o`0000Go=Id000?o0000oaZD0?l000000om1X@000ol0003o:9T0obRI
0002obRI00;o00001OloX@000ol0003o;Y/0objK0002objK0006o`000?lQU`3o0000o`000?m@YP3o
00001Om6X`000ol0003o@J40od6Q0002od6Q0003o`000?loX@3o?j4000;o?j401?l00002ogJa0003
o`000?ml/P3oO;8000;oO;8000?o0000ohJe0?n6]@000_n6]@000ol0003oUKT0oiFi0002oiFi0003
o`000?nW_@3oYkd000;oYkd000?o0000okk30?nn``000_nn``000ol0003obKT0olVi0002olVi0003
o`000?o@Z03od:P000;od:P000?o0000omND0?oGU0000_oGU0000ol0003ogWh0omin0002omin0004
o`000?oUJ03oiFP0onEX01So00000_ooool00ol0003oooooooooo`01ooooo`00D_ooool00ol0003o
ooooooooo`0>ooooo`05o`000?nh`P3o^<80okS20?l000001Oo3a0000ol0003oUKT0oiFi0003oiFi
0003o`000?nW_@3o000000?oL:l000?o0000ohJe0?n6]@000_n6]@001?l0003oE:L0oeBW0?l00003
ofj_0003o`000?m1X@3o000000CoGZX000Co0000ocFM0?leW@3o00000omFZ0000ol0003o<Y`0oc:L
0002o`000003oeJX0?l0003o=Id000Co=Id00_l00005od6Q0006o`000?lXV@3o:9T0o`000?mDY`3o
00001OloX@000ol0003o;Y/0objK0002objK00;o00001?m@YP000ol0003oAZ<0odJS0002odJS0003
o`000?m1X@3o@J4000?o@J401?l000000omd/03o0000ogJa0004ogJa0005o`000?ml/P3oO;80ogbb
0?l000001?n6]@000ol0003oUKT0oiFi0002oiFi0003o`000?nW_@3oYkd000;oYkd000?o0000okk3
0?nn``000_nn``000ol0003obKT0olVi0002olVi0003o`000?o@Z03od:P000;od:P000?o0000omND
0?oGU0000ooGU0000ol0003ogWh0omin0002omin0005o`000?oUJ03oiFP0onEX0?l000001Oo[D@00
0ol0003olC`0oo4l0002oo4l0003o`000?oe:P3omBX000?omBX000?o0000ooPM0?oh7@000_oh7@02
o`000003ooooool0003ooooo00;ooooo001Cooooo`;o00003oooool00ol0003o^<80o`000005ol?4
0003o`000?o7_P3o000000?oUKT000Oo0000ojNm0?nW_@3oYkd0o`000?m`[`3o000000GoQ[D000?o
0000oeBW0?l000001Om^[`000ol0003oGZX0oejZ0003oejZ0003o`000?leW@3o000000CoEZP000?o
0000oc:L0?l000001?mFZ0001ol0003o=Id0ocFM0?leW@3o0000oejZ0?l000001Om1X@000ol0003o
:9T0o`000003oeBW0003o`000?loX@3o?j4000;o?j4000?o0000objK0?l^V`000_l000000omNZP3o
0000oe2V0003oe2V0003o`000?m6X`3oAZ<000?oAZ<000?o0000od6Q0?m1X@000ol00005ogB`0003
o`000?mf/@3oM[4000;oM[4000?o0000ogbb0?ml/P000_ml/P000ol0003oQ[D0ohJe0002ohJe0005
o`000?nE^@3oUKT0oiFi0?l000001?nW_@000ol0003o_/<0okk30002okk30003o`000?o9^@3obKT0
00?obKT000?o0000om2X0?o@Z0000_o@Z0000ol0003oei@0omND0002omND0003o`000?oNOP3ogWh0
00;ogWh000?o0000onEX0?oUJ0000_oUJ0000ol0003oje40on]A0003on]A0003o`000?oa?03olC`0
00;olC`000?o0000ooDZ0?oe:P000ooe:P000ol0003on1d0ooPM0002ooPM00?o00000oooool005Go
oooo00?o0000ooooooooool03Oooool00ol0003o`l@0ol?40003ol?40007o`000?o7_P3oakh0olNn
0?l0003oUKT0o`000005ojNm0003o`000?n6]@3oQ[D000CoQ[D00_l00005ofj_00;o00001OmNZP02
o`0000GoEZP00_l00005oeJX0004o`000?leW@3o=Id0o`0000?oGZX000?o0000od6Q0?m1X@000_m1
X@02o`0000CoE:L000?o0000ocnQ0?loX@000oloX@02o`0000CoGZX000?o0000oe2V0?m@YP000_m@
YP001?l0003oAZ<0odJS0?m6X`04o`0000;oM[4000?o0000ogB`0?md/0000omd/0000ol0003oM[40
ogJa0002ogJa0003o`000?ml/P3oO;8000;oO;8000?o0000ohJe0?n6]@000_n6]@000ol0003oUKT0
oiFi0002oiFi0003o`000?nW_@3oYkd000_o000000?obKT0o`000?o@Z0000oo@Z0000ol0003oei@0
omND0002omND0003o`000?oNOP3ogWh000;ogWh000?o0000onEX0?oUJ0000_oUJ0000ol0003oje40
on]A0003on]A0003o`000?oa?03olC`000;olC`000?o0000ooDZ0?oe:P000ooe:P000ol0003on1d0
o`000005o`0000?ooooo001Fooooo`03o`000?oooooooooo00gooooo00Go0000ol?40?o3a03o`l@0
o`000005olNn0003o`000?nW_@3oYkd000CoYkd000?o0000ohJe0?n6]@000on6]@000ol0003oXK`0
o`000004ofj_0004o`000?n=]`3oSKL0o`0000?oGZX000?o0000oh2d0?l000001?mFZ0000ol0003o
O;80o`000005oeJX0003o`000?leW@3o000000CoGZX000Oo0000od6Q0?m1X@3o@J40o`000?m^[`3o
000000GoE:L000Co0000ocnQ0?loX@3o?j400_l00005oejZ0003o`000?m@YP3oD:H000;oD:H000Ko
0000odJS0?l0003o0000ogbb0?l00005ogJa0003o`000?md/03oM;0000;oM;0000?o0000ogJa0?mf
/@000omf/@001Ol0003oO;80ogbb0?ml/P3o000000?oQ[D02Ol00002ol^c0003o`000?o@Y`3od:L0
00;od:L000Co0000omJH0?oFV03oeYP0:?l00004ooXI00?o00000_ooool005Oooooo0_l0000>oooo
o`03o`000?o3a03o000000Goakh00_l00005ojNm0003o`000?nn``3o000000?oQ[D000Go0000oj6l
0?nQ_03oXK`0o`000002ofj_0005o`000?n=]`3oSKL0ohfg0?l000000_mNZP001Ol0003oP;@0oh2d
0?n0]03o000000;oEZP000Go0000ogbb0?ml/P3oO;80o`000005oeJX0003o`000?mNZP3oGZX000?o
GZX000Co0000od6Q0?m1X@3o00000om^[`000ol0003oE:L0oeBW0002oeBW0006o`000?loX@3o0000
o`000?m`[`3o00001OmNZP000ol0003oD:H0oe2V0002oe2V00;o00001?ml/P000ol0003oM[40ogJa
0002ogJa0003o`000?md/03oM;0000?oM;0000?o0000ogJa0?mf/@002_l00002ol?40005o`000?o7
_P3oakh0olNn0?l000001Oo;/`000ol0003od:L0om2W0002om2W0003o`000?oFV03oeYP000;oeYP0
00?o0000om^60?oKQP000_oKQP000ol0003ohG<0on5c0002on5c0003o`000?oWG`3oiel000;oiel0
00?o0000one<0?o]C0000_o]C0000ol0003olCT0oo4i0003oo4i0003o`000?of:@3omRT000;omRT0
00?o0000ooPM0?oh7@001?oh7@001?l0003onQT0ooXI0?oj6@03o`0000;ooooo001Iooooo`03o`00
0?oooooooooo00cooooo00?o0000olNn0?o7_P000oo7_P001?l0003obk<0ol^c0?l00003ojNm0007
o`000?nn``3o_/<0okk30?l0003oQ[D0o`000004oj6l0003o`000?m^[`3o000000CoSKL000?o0000
oejZ0?l000001?n0]0000ol0003oEZP0o`000004ogbb0003o`000?mFZ03oEZP000;oEZP00_l00006
oejZ00;o00001?m^[`000ol0003oE:L0oeBW0002oeBW00;o00001?m`[`000ol0003oGZX0oejZ0003
oejZ00Co000000?oQ[D0o`000?ml/P000oml/P000ol0003oM[40ogJa0002ogJa0003o`000?md/03o
M;0000;oM;001?l00002ok;00003o`000?nh`P3o^<8000;o^<8000?o0000ol?40?o3a0000oo3a000
1Ol0003oakh0olNn0?o7_P3o000000Cobk<000?o0000om2W0?o@Y`000_o@Y`000ol0003oeYP0omJH
0003omJH0003o`000?oKQP3ofhH000;ofhH000?o0000on5c0?oQL`000_oQL`000ol0003oiel0onMO
0002onMO0003o`000?o]C03okD`000;okD`000?o0000oo4i0?oa>@000ooa>@000ol0003omRT0ooHY
0002ooHY0003o`000?oh7@3on1d000?on1d01ol00002ooooo`00F_ooool00ol0003oooooooooo`0<
ooooo`05o`000?o7_P3oakh0olNn0?l000001?o;/`000ol0003oYkd0o`000005okk30003o`000?nQ
_03oXK`000CoXK`000?o0000ohfg0?n=]`001?n=]`000ol0003oP;@0oh2d0004oh2d0003o`000?ml
/P3oO;8000CoO;8000Co0000oeJX0?mFZ03o00000_n0]0000ol0003oGZX0oejZ0002oejZ00;o0000
1Om^[`000ol0003oE:L0oeBW0002o`000003ohJe0?l0003oL:l000CoL:l000Co0000oejZ0?mNZP3o
GZX00_l00005ohJe0003o`000?ml/P3oO;8000;oO;8000?o0000ogJa0?mf/@000_mf/@04o`000003
ok2o0?l0003o//0000Co//0000?o0000okS20?nh`P000_nh`P000ol0003o`l@0ol?40002ol?40003
o`000?o7_P3oakh000;oakh000?o0000ol^c0?o;/`000_o;/`000ol0003od:L0om2W0002om2W0003
o`000?oFV03oeYP000;oeYP000?o0000om^60?oKQP000_oKQP000ol0003ohG<0on5c0002on5c0003
o`000?oWG`3oiel000;oiel000?o0000one<0?o]C0000oo]C0000ol0003olCT0oo4i0002oo4i0003
o`000?of:@3omRT000;omRT000?o0000ooPM0?oh7@001ol00005ooooo`00Foooool00ol0003ooooo
ooooo`0<ooooo`03o`000?o7_P3o000000Gobk<00_l00005okk300;o00001OnQ_002o`0000GoSKL0
0_l00006oh2d0003o`000?ml/P3oO;8000CoO;8000?o0000oeJX0?l000001?n0]0001_l0003oGZX0
oejZ0?l0003oSKL0o`0000KoKZl00_l00004ohJe0003o`000?m`[`3oL:l000;oL:l000Ko0000oejZ
0?l0003o0000oiFi0?l00005ohJe0003o`000?ml/P3oO;8000;oO;8000?o0000ogJa0?mf/@000ol0
0005ok2o0003o`000?nb`03o//0000;o//0000?o0000okS20?nh`P000_nh`P000ol0003o`l@0ol?4
0002ol?40003o`000?o7_P3oakh000;oakh000?o0000ol^c0?o;/`000_o;/`000ol0003od:L0om2W
0002om2W0003o`000?oFV03oeYP000;oeYP000?o0000om^60?oKQP000_oKQP000ol0003ohG<0on5c
0002on5c0003o`000?oWG`3oiel000;oiel000?o0000one<0?o]C0000oo]C0001?l0003olCT0oo4i
0?oa>@0<o`0000Wooooo001Looooo`;o00003Oooool00ol0003obk<0ol^c0003ol^c0003o`000?o@
Y`3o000000Co_/<000Co0000olVi0?o9^@3o00000onQ_0001?l0003o`L@0ol740?l00003ohfg0004
o`000?n`_`3o/;l0o`0000CoP;@000?o0000ojRn0?l000001Oml/P02o`0000GoP;@000?o0000oejZ
0?l000000on=]`000ol0003oKZl0ofj_0002ofj_00;o00001On6]@000ol0003oL:l0og2_0002og2_
00;o00001?nE^@000ol0003oQ[D0ohJe0002ohJe0003o`000?ml/P3oO;8000;oO;800ol00002ok;0
0003o`000?n`_`3o/;l000?o/;l000?o0000ok;00?nb`0000_nb`0000ol0003o^<80okS20002okS2
0003o`000?o3a03o`l@000?o`l@000?o0000olNn0?o7_P00:Ol00005ooooo`Co00003?ooool005ko
oooo00?o0000ooooooooool02oooool01Ol0003obk<0ol^c0?o;/`3o000000?od:L000Co0000okk3
0?nn``3o00001?o9^@000ol0003oXK`0o`000004ol740003o`000?n=]`3o000000Co/;l000Co0000
oh2d0?n0]03o00000onX_P000ol0003oO;80ogbb0002o`000003ojRn0?l0003oP;@000CoP;@00_l0
0005ohfg0006o`000?m^[`3oKZl0o`000?nQ_03o00001On6]@000ol0003oL:l0og2_0002o`000003
ojNm0?l0003oUKT000?oUKT000?o0000ohJe0?n6]@000on6]@04o`000003okS20?l0003o//0000?o
//0000?o0000ok2o0?n`_`000on`_`000ol0003o//00ok;00002ok;00003o`000?nh`P3o^<8000;o
^<8000?o0000ol?40?o3a0001Ol0000Zooooo`Co00004?ooool005oooooo00?o0000ooooooooool0
2oooool00ol0003obk<0o`000004om2W0003o`000?nn``3o000000KobKT000?o0000ol740?o1a000
0oo1a002o`0000Go/;l000?o0000oh2d0?l000001?nX_P000ol0003oO;80o`000004ojRn0007o`00
0?n0]03oP;@0oh2d0?l0003o/;l0o`000005ohfg0003o`000?m^[`3o000000?oXK`000?o0000ohJe
0?n6]@000on6]@02o`0000CoYkd000?o0000oiFi0?nE^@000_nE^@001?l0003oQ[D0ohJe0?n6]@02
o`0000Go^<8000Go0000ok;00?nb`03o//00o`000005ok2o0003o`000?nb`03o//0000[o0000:ooo
ool4o`0001Cooooo001Pooooo`03o`000?oooooooooo00_ooooo00?o0000om2W0?o@Y`001?o@Y`00
0ol0003obKT0olVi0004olVi00;o00001?o1a0000ol0003oc;<0o`000005ok2o00;o00001OnX_P02
o`0000GoZ;h000Co0000oh2d0?n0]03o00000on`_`000ol0003oSKL0ohfg0002ohfg00;o00001?nQ
_0000ol0003oQ[D0ohJe0002ohJe00;o00001OnW_@000ol0003oUKT0oiFi0002oiFi0006o`000?n6
]@3o0000o`000?o3a03o00001Onh`P000ol0003o//00ok;00002ok;00003o`000?n`_`3o/;l000;o
/;l00ol0000aooooo`Co00006?ooool0067ooooo0_l0000;ooooo`03o`000?o@Y`3od:L000?od:L0
0_l00005olVi0004o`000?o@Z03od:P0o`0000;o`L@000Go0000olbc0?o</`3oc;<0o`000003ok2o
0003o`000?o9^P3o000000CoZ;h000?o0000olRl0?l000001OnX_P000ol0003oP;@0o`000004ok2o
0003o`000?n=]`3oSKL000;o000000?o`L@0o`000?nQ_0001?nQ_0001_l0003oQ[D0ohJe0?l0003o
_/<0o`0000GoYkd000?o0000oiFi0?nE^@000_nE^@02o`0000Co`l@000?o0000okS20?nh`P000_nh
`P000ol0003o//00ok;00002ok;00003o`000?n`_`3o000000;o0000<Oooool3o`0001cooooo001S
ooooo`03o`000?oooooooooo00Wooooo00Go0000om2W0?o@Y`3od:L0o`000002omJH0005o`000?o9
^@3obKT0olVi0?l000000oo@Z0000ol0003o`L@0o`000004olbc0004o`000?n`_`3o/;l0o`0000?o
bKX000Co0000ojRn0?nX_P3o00000oo8_0000ol0003oZ;h0ojRn0002ojRn00;o00001On`_`000ol0
003oSKL0o`000004ol740003o`000?nQ_03oXK`000;oXK`000?o0000ohJe0?l000000onn``000ol0
003oYkd0ojNm0003ojNm00Co000000?oakh0o`000?o3a0000oo3a0000ol0003o^<80okS20003okS2
0003o`000?nb`03o//0000?o0000<?ooool4o`0001oooooo001Tooooo`03o`000?oooooooooo00Wo
oooo00?o0000om2W0?l000001?oFV0000ol0003obKT0o`000005om2X0003o`000?o</`3oc;<000?o
c;<000?o0000ok2o0?l000001?o9^P000ol0003oZ;h0o`000005olRl0006o`000?nX_P3oZ;h0o`00
0?o9^P3o00001_n`_`000ol0003o`L@0ol740003ol740003o`000?nQ_03oXK`000;oXK`00_l00004
okk30003o`000?nW_@3oYkd000;oYkd00_l00005olNn0003o`000?o3a03o`l@000;o`l@000Co0000
okS20?nh`P3o^<801?l0000_ooooo`Co00008oooool006Gooooo00?o0000ooooooooool02Oooool0
0ol0003oeYP0omJH0003omJH00;o00001Oo@Z002o`0000Goc;<00_l00006olVj0003o`000?o8_03o
b;`000Cob;`000?o0000ojRn0?l000000oo9^P000ol0003o/;l0ok2o0002ok2o00;o00001Oo1a000
0ol0003oXK`0oj6l0002o`000003olVi0?l0003o_/<000?o_/<000?o0000ojNm0?nW_@000_l00000
0oo;/`3o0000olNn0004olNn0003o`000?o3a03o`l@000;o`l@000Co0000okS20?l0003o0000;ooo
ool4o`0002Oooooo001Vooooo`;o00002Oooool00ol0003oeYP0omJH0002omJH0004o`000?oKQP3o
fhH0o`0000?od:P000Co0000omND0?oGU03o00000oo</`000ol0003odid0o`000005olVj00;o0000
1_o8_002o`0000GobKX000Co0000ok2o0?n`_`3o00000_o</`000ol0003o`L@0ol740003ol7400;o
00001?o9^@000ol0003o_/<0okk30002okk300;o00001?o;/`000ol0003oakh0olNn0002olNn0003
o`000?o3a03o`l@000;o`l@00_l0000]ooooo`Co0000:oooool006Sooooo00?o0000ooooooooool0
1oooool01?l0003oeYP0omJH0?l00004om^60003o`000?o@Z03o000000Coei@000?o0000olbc0?l0
00000ooCW@001Ol0003obKX0olVj0?o9^P3o000000;odZ8000?o0000olRl0?o8_0000_o8_0000ol0
003odZ80o`000005olVj0003o`000?n`_`3o000000?oc;<000?o0000ol740?o1a0000_o1a002o`00
00GobKT000Co0000okk30?nn``3o_/<00_l00005ol^c0003o`000?o7_P3oakh000?oakh01?l0000/
ooooo`?o0000;oooool006Wooooo00?o0000ooooooooool01_ooool00ol0003oeYP0o`000005om^6
00;o00001OoGU002o`0000Godid000?o0000olVj0?l000001?oBXP001?l0003ob;`0olRl0?l00003
om:R0003o`000?o9^P3obKX000;obKX00_l00005olbc0006o`000?o1a03o`L@0o`000?o@Z03o0000
1Oo9^@001_l0003o_/<0o`000?l0003od:L0o`0000Gobk<000?o0000olNn0?o7_P000_o7_P02o`00
02_ooooo1?l0000booooo`00J_ooool00ol0003oooooooooo`06ooooo`03o`000?oKQP3ofhH000?o
fhH000?o0000on5c0?l000001?oGU0000ol0003ogWh0o`000005om>M00;o00001OoBXP000ol0003o
b;`0o`000004om:R0003o`000?o9^P3obKX000;o000000?odid0o`000?o</`001?o</`000ol0003o
`L@0o`000003om2X0003o`000?o9^@3obKT000;obKT00_l00004om2W0003o`000?o;/`3obk<000?o
bk<01?l0000Yooooo`Co0000=_ooool006_ooooo0_l00007ooooo`05o`000?oKQP3ofhH0om^60?l0
00000ooQL`001?l0003oei@0omND0?l00003omin0007o`000?oCW@3odid0om>M0?l0003og8D0o`00
0005om:R00;o00001OoBXP000ol0003obKX0o`000004om>M0003o`000?o</`3oc;<000;oc;<00_l0
0004om2X0003o`000?o9^@3obKT000;o000000?oeYP0o`000?o@Y`001?o@Y`001?l0003obk<0ol^c
0?o;/`02o`0002Sooooo1?l0000jooooo`00KOooool00ol0003oooooooooo`05ooooo`03o`000?oK
QP3o000000CohG<000?o0000omND0?l000001?oNOP001?l0003odid0om>M0?l00003omb50007o`00
0?oBXP3odZ80om:R0?l0003ofhL0o`000005om:R00;o00001OoCW@000ol0003oc;<0olbc0002o`00
0003omND0?l0003od:P000?od:P000?o0000olVi0?l000001?oFV0000ol0003od:L0om2W0002om2W
0004o`000?o;/`3o0000o`0002Kooooo1?l0000nooooo`00K_ooool00ol0003oooooooooo`05oooo
o`03o`000?oQL`3ohG<000CohG<000?o0000omin0?oNOP000ooNOP000ol0003odid0o`000005omb5
0003o`000?oBXP3o000000?ofhL000Oo0000om:R0?oBXP3odZ80o`000?oLQ@3o000000Godid000?o
0000olbc0?l000001?oGU0001?l0003od:P0om2X0?o@Z002o`0000GoeYP000?o0000om2W0?o@Y`00
0_o@Y`02o`0002Gooooo0ol00012ooooo`00Koooool00ol0003oooooooooo`04ooooo`03o`000?oQ
L`3ohG<000?ohG<00_l00005omin00;o00001_oLQ@02o`0000GofhL000?o0000om:R0?l000000ooL
Q@000ol0003odid0om>M0002om>M00;o00001OoGU0001_l0003od:P0om2X0?l0003ofhH0o`0000Go
eYP000?o0000om2W0?l000000_l0000Sooooo`Co0000AOooool0073ooooo0_l00005ooooo`05o`00
0?oQL`3ohG<0on5c0?l000000_oWG`001ol0003ogWh0omin0?oNOP3o0000onEX0?l000001OoLQ@00
0ol0003ohf`0o`000005om^700;o00001OoLQ@001_l0003odid0om>M0?l0003ogWh0o`0000Goei@0
00?o0000om2X0?l000000ooKQP000ol0003oeYP0omJH0002omJH00;o00008_ooool4o`0004Wooooo
001booooo`03o`000?oooooooooo00?ooooo00?o0000on5c0?l000001?oWG`000ol0003ogWh0o`00
0003onEX0005o`000?oLQ@3og8D0omb50?l000000ooSK0001ol0003ofhL0om^70?oKQ`3o0000on=/
0?l000001OoLQ@000ol0003odid0o`000003omin0003o`000?oGU03oei@000;oei@00_l00005om^6
0004o`000?oFV03oeYP0o`00023ooooo1?l0001=ooooo`00Loooool00ol0003oooooooooo`03oooo
o`03o`000?oWG`3oiel000?oiel00_l00005onEX0003o`000?oLQ@3o000000Cohf`000Co0000om^7
0?oKQ`3o00000ooSK0000ol0003og8D0omb50002omb500;o00001?oNOP000ol0003oei@0o`000002
o`000003on5c0?l0003ofhH000CofhH000?o0000omJH0?l000007Oooool4o`00057ooooo001doooo
o`03o`000?oooooooooo00;ooooo00Co0000onMO0?oWG`3oiel00_l000000oo]C03o0000onEX0004
onEX00;o00001OoSK0000ol0003ofhL0o`000004on=/0003o`000?oLQ@3og8D000;o000000?oiFP0
o`000?oNOP000ooNOP02o`0000GohG<000?o0000om^60?oKQP000_oKQP02o`0001_ooooo0ol0001E
ooooo`00MOooool2o`0000?ooooo00?o0000onMO0?l000001?o]C0001ol0003oiFP0onEX0?oUJ03o
0000on]A0?l000001OoSK002o`0000Gohf`000?o0000omb50?l000001?oUJ0001_l0003ogWh0omin
0?l0003oiel0o`0000GohG<000?o0000om^60?l000000_l0000Iooooo`Co0000F?ooool007Oooooo
00Go0000ooooooooooooooooo`000006one<0003o`000?oUJ03o000000?oje4000Oo0000on=/0?oS
K03ohf`0o`000?o[D`3o000000Gohf`00_l00005onEX0003o`000?oNOP3o000000?oiel000?o0000
on5c0?oQL`000_oQL`02o`0001Sooooo1?l0001Looooo`00N?ooool01?l0003oooooooooool00006
one<00;o00001Oo[D@000ol0003ohf`0o`000003on]C0007o`000?oSK03ohf`0on=/0?l0003oje40
o`000005onEX00;o00001OoWG`001?l0003ohG<0on5c0?l0000Fooooo`Co0000H?ooool007Wooooo
00Co0000oooooooooooo00000oo]C002o`000003oo4i0?l0003oje4000Coje400_l00005on]C0003
o`000?oSK03o000000?oje4000Oo0000onEX0?oUJ03oiFP0o`000?o]C03o000000Goiel000?o0000
on5c0?l000004oooool4o`0006Cooooo001jooooo`;o000000Coooooo`000?o]C03o00001?oa>@00
0ol0003oje40o`000002o`000003oo4l0?l0003oje<000Coje<00_l00005on]A0003o`000?oUJ03o
000000?okD`000?o0000onMO0?oWG`000_oWG`02o`00017ooooo0ol0001Xooooo`00O?ooool00ol0
003oooooo`000005oo4i00;o00001Ooa?0000ol0003oje<0o`000002o`000003oo4l0?l0003oje40
00Coje400_l00004one<0003o`000?oWG`3o000000;o00003oooool4o`0006_ooooo001mooooo`03
o`000?oooooo000000?olCT000?o0000ooHY0?l000001Ooa?002o`0000GolC`000?o0000on]A0?l0
00000_l000000ooa>@3o0000one<0003one<00;o00003_ooool4o`0006oooooo001nooooo`05o`00
0?oooooo0000oo4i0?l000000oof:@001ol0003olC`0oo4l0?oa?03o0000ooDZ0?l000001Ooa?002
o`0000GolCT000Co0000one<0?o]C03o00003?ooool4o`0007?ooooo001oooooo`?o00001Oof:@00
0ol0003olC`0o`000003ooDZ0007o`000?oa?03olC`0oo4l0?l0003omRT0o`000005oo4i0003o`00
0?o]C03o000000Wooooo1?l0001gooooo`00POooool2o`0000?omRT00ol00005ooDZ0003o`000?oa
?03o000000?omRT000?o0000oo4i0?oa>@000_oa>@02o`0000Oooooo0ol0001kooooo`00P_ooool4
o`0000?on1d000Co0000ooDZ0?oe:P3omBX00ol00005ooHY0004o`000?oa>@3o0000o`0000Gooooo
1?l0001nooooo`00Poooool2o`0000Con1d01?l00003ooPM0004o`000?of:@3omRT0ooHY00?o0000
0oooool4o`0008;ooooo0024ooooo`;o000000?on1d0o`000?l000000_oj6@000ol0003on1d0ooPM
0002ooPM00Co00000_ooool4o`0008Kooooo0026ooooo`;o00001?oj6@001?l0003on1d0o`000?l0
0002ooooo`Co0000R_ooool008Oooooo0_l00002ooXI00?o000000Coooooo`000?l0003o0000S_oo
ool008Sooooo1ol0002Aooooo`00ROooool2o`0009Gooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo000cooooo`?o0000F?ooool3o`0001Oooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`0;ooooo`00=?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0:ooooo`00;_ooool3o`0000?o
oooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l0
00000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_ooool5o`0000;o
oooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool6o`00
00Oooooo00?o0000ooooooooool00oooool4o`000003ooooool0003o000000;o00000_ooool4o`00
00?ooooo0ol00002ooooo`Go00000oooool2o`000004ooooool0003oooooooooo`;o00000oooool3
o`0000Wooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00001?ooool2
o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o0000
0oooool3o`0000Gooooo00?o0000ooooooooool02Oooool002gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0000;ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`09ooooo`00;Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`03ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`?o00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00007ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00?o0000ooooooooool00oooool3o`00
00?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go00001?ooool00ol0003ooooooooo
o`09ooooo`00;Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Ko
0000oooooooooooo0000ooooool00005ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool002gooooo00Ko0000ooooooooooooooooo`00
0?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o
00002Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o
00002Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`0000?ooooo1?l00002ooooo`?o
00001?ooool01?l0003oooooooooooooool2o`000004ooooool0003o0000ooooo`Co00000oooool3
o`0000Wooooo0ol00002ooooo`?o00001?ooool4o`000003ooooool0003o000000;o00000oooool2
o`0000?ooooo1?l00003ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool02Oooool0
02gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`00;_ooool3o`0000Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000
ooooooooool00_ooool2o`0000[ooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000=
ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`?o00002_ooool00ol0003oooooooooo`0@
ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.150433, 0.0170257, \
0.00386341, 0.00386341}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.02269 .27405 -24 -2.74987 ]
[.02269 .27405 0 6.25013 ]
[.01481 .32345 -30 -2.79165 ]
[.01481 .32345 0 6.20835 ]
[.00667 .37445 -18 -2.83493 ]
[.00667 .37445 0 6.16507 ]
[-0.00174 .42714 -30 -2.8798 ]
[-0.00174 .42714 0 6.1202 ]
[-0.01043 .4816 -24 -2.92632 ]
[-0.01043 .4816 0 6.07368 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03492 .26929 m
.04103 .26691 L
s
[(0.05)] .02269 .27405 1 -0.38892 Mshowa
.02707 .31879 m
.03321 .31646 L
s
[(0.075)] .01481 .32345 1 -0.37963 Mshowa
.01897 .3699 m
.02513 .36762 L
s
[(0.1)] .00667 .37445 1 -0.37001 Mshowa
.01061 .4227 m
.01678 .42047 L
s
[(0.125)] -0.00174 .42714 1 -0.36005 Mshowa
.00196 .47727 m
.00815 .47511 L
s
[(0.15)] -0.01043 .4816 1 -0.34971 Mshowa
.125 Mabswid
.03337 .27907 m
.03704 .27765 L
s
.03181 .2889 m
.03548 .28749 L
s
.03024 .2988 m
.03392 .29739 L
s
.02866 .30876 m
.03234 .30736 L
s
.02547 .32888 m
.02916 .32749 L
s
.02386 .33904 m
.02755 .33765 L
s
.02224 .34926 m
.02593 .34788 L
s
.02061 .35954 m
.0243 .35817 L
s
.01732 .38032 m
.02102 .37896 L
s
.01566 .39081 m
.01936 .38946 L
s
.01399 .40137 m
.01769 .40002 L
s
.0123 .412 m
.016 .41066 L
s
.0089 .43347 m
.01261 .43214 L
s
.00718 .44431 m
.01089 .44299 L
s
.00545 .45522 m
.00916 .45391 L
s
.00371 .46621 m
.00742 .4649 L
s
.03646 .25958 m
.04012 .25815 L
s
.00019 .48841 m
.00391 .48711 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .454 .167 r
.39279 .65964 .40417 .63098 .41929 .67752 .40743 .72342 Metetra
.301 .646 0 r
.40743 .72342 .41929 .67752 .43562 .69986 .42381 .7529 Metetra
.6 .729 0 r
.42381 .7529 .43562 .69986 .45269 .70404 .44123 .75704 Metetra
.693 .751 0 r
.44123 .75704 .45269 .70404 .47006 .70227 .45901 .75322 Metetra
.718 .757 0 r
.45901 .75322 .47006 .70227 .48758 .69934 .47692 .74814 Metetra
.731 .76 0 r
.47692 .74814 .48758 .69934 .50524 .69606 .49495 .74291 Metetra
.741 .763 0 r
.49495 .74291 .50524 .69606 .52303 .69253 .5131 .73764 Metetra
.749 .765 0 r
.5131 .73764 .52303 .69253 .54094 .68877 .53137 .73234 Metetra
.756 .766 0 r
.53137 .73234 .54094 .68877 .55899 .68479 .54975 .72703 Metetra
.762 .767 0 r
.54975 .72703 .55899 .68479 .57716 .68061 .56826 .72172 Metetra
.766 .768 0 r
.56826 .72172 .57716 .68061 .59545 .67623 .58688 .71641 Metetra
.769 .769 0 r
.58688 .71641 .59545 .67623 .61388 .67168 .60563 .71111 Metetra
.77 .768 0 r
.60563 .71111 .61388 .67168 .63242 .66697 .62451 .70583 Metetra
.77 .767 0 r
.62451 .70583 .63242 .66697 .65109 .66209 .64351 .70057 Metetra
.77 .767 0 r
.64351 .70057 .65109 .66209 .66988 .65705 .66265 .69533 Metetra
.77 .766 0 r
.66265 .69533 .66988 .65705 .68879 .65186 .68191 .69011 Metetra
.77 .766 0 r
.68191 .69011 .68879 .65186 .70782 .64651 .70131 .68491 Metetra
.77 .767 0 r
.70131 .68491 .70782 .64651 .72697 .641 .72085 .67974 Metetra
.77 .767 0 r
.72085 .67974 .72697 .641 .74625 .63532 .74053 .67458 Metetra
.77 .769 0 r
.74053 .67458 .74625 .63532 .76564 .62947 .76035 .66945 Metetra
.768 .769 0 r
.76035 .66945 .76564 .62947 .78514 .62344 .78031 .66433 Metetra
.764 .768 0 r
.78031 .66433 .78514 .62344 .80476 .61722 .80042 .65921 Metetra
.759 .767 0 r
.80042 .65921 .80476 .61722 .82449 .61078 .82068 .65409 Metetra
.753 .766 0 r
.82068 .65409 .82449 .61078 .84433 .60413 .84108 .64896 Metetra
.746 .764 0 r
.84108 .64896 .84433 .60413 .86427 .59723 .86164 .64382 Metetra
.737 .762 0 r
.86164 .64382 .86427 .59723 .88431 .59006 .88235 .63864 Metetra
.725 .759 0 r
.88235 .63864 .88431 .59006 .90444 .58258 .9032 .63339 Metetra
.709 .755 0 r
.9032 .63339 .90444 .58258 .92463 .57455 .92417 .62774 Metetra
.666 .745 0 r
.92417 .62774 .92463 .57455 .94461 .56387 .94489 .6188 Metetra
.499 .703 0 r
.94489 .6188 .94461 .56387 .9632 .54189 .96372 .5943 Metetra
.089 .574 0 r
.96372 .5943 .9632 .54189 .97837 .49525 .97779 .53506 Metetra
.14 .593 0 r
.38194 .66675 .39279 .65964 .40743 .72342 .39629 .73684 Metetra
.815 .654 0 r
.39629 .73684 .40743 .72342 .42381 .7529 .41269 .76806 Metetra
.903 .379 0 r
.41269 .76806 .42381 .7529 .44123 .75704 .4303 .7712 Metetra
.92 .318 0 r
.4303 .7712 .44123 .75704 .45901 .75322 .4483 .76581 Metetra
.919 .323 0 r
.4483 .76581 .45901 .75322 .47692 .74814 .46642 .75927 Metetra
.915 .337 0 r
.46642 .75927 .47692 .74814 .49495 .74291 .48465 .75277 Metetra
.911 .351 0 r
.48465 .75277 .49495 .74291 .5131 .73764 .50298 .7464 Metetra
.908 .363 0 r
.50298 .7464 .5131 .73764 .53137 .73234 .52142 .74016 Metetra
.905 .374 0 r
.52142 .74016 .53137 .73234 .54975 .72703 .53997 .73405 Metetra
.902 .383 0 r
.53997 .73405 .54975 .72703 .56826 .72172 .55864 .72806 Metetra
.9 .392 0 r
.55864 .72806 .56826 .72172 .58688 .71641 .57742 .72218 Metetra
.898 .398 0 r
.57742 .72218 .58688 .71641 .60563 .71111 .59633 .71644 Metetra
.896 .404 0 r
.59633 .71644 .60563 .71111 .62451 .70583 .61536 .71081 Metetra
.895 .408 0 r
.61536 .71081 .62451 .70583 .64351 .70057 .63453 .70529 Metetra
.894 .41 0 r
.63453 .70529 .64351 .70057 .66265 .69533 .65383 .69989 Metetra
.894 .411 0 r
.65383 .69989 .66265 .69533 .68191 .69011 .67326 .69461 Metetra
.894 .411 0 r
.67326 .69461 .68191 .69011 .70131 .68491 .69284 .68944 Metetra
.894 .409 0 r
.69284 .68944 .70131 .68491 .72085 .67974 .71256 .68439 Metetra
.895 .406 0 r
.71256 .68439 .72085 .67974 .74053 .67458 .73244 .67946 Metetra
.897 .401 0 r
.73244 .67946 .74053 .67458 .76035 .66945 .75246 .67465 Metetra
.898 .395 0 r
.75246 .67465 .76035 .66945 .78031 .66433 .77265 .66996 Metetra
.901 .388 0 r
.77265 .66996 .78031 .66433 .80042 .65921 .793 .6654 Metetra
.903 .379 0 r
.793 .6654 .80042 .65921 .82068 .65409 .81351 .66096 Metetra
.906 .369 0 r
.81351 .66096 .82068 .65409 .84108 .64896 .8342 .65666 Metetra
.909 .358 0 r
.8342 .65666 .84108 .64896 .86164 .64382 .85507 .6525 Metetra
.913 .345 0 r
.85507 .6525 .86164 .64382 .88235 .63864 .87613 .64848 Metetra
.917 .331 0 r
.87613 .64848 .88235 .63864 .9032 .63339 .89737 .64459 Metetra
.92 .318 0 r
.89737 .64459 .9032 .63339 .92417 .62774 .91877 .64049 Metetra
.917 .33 0 r
.91877 .64049 .92417 .62774 .94489 .6188 .93994 .63305 Metetra
.877 .469 0 r
.93994 .63305 .94489 .6188 .96372 .5943 .95911 .60862 Metetra
.618 .733 0 r
.95911 .60862 .96372 .5943 .97779 .53506 .97301 .54526 Metetra
.288 .642 0 r
.3714 .66177 .38194 .66675 .39629 .73684 .38558 .73239 Metetra
.87 .49 0 r
.38558 .73239 .39629 .73684 .41269 .76806 .40199 .76308 Metetra
.957 .178 0 r
.40199 .76308 .41269 .76806 .4303 .7712 .41969 .76553 Metetra
.971 .124 0 r
.41969 .76553 .4303 .7712 .4483 .76581 .43779 .75961 Metetra
.965 .145 0 r
.43779 .75961 .4483 .76581 .46642 .75927 .45601 .75264 Metetra
.958 .174 0 r
.45601 .75264 .46642 .75927 .48465 .75277 .47434 .74577 Metetra
.951 .2 0 r
.47434 .74577 .48465 .75277 .50298 .7464 .49277 .73908 Metetra
.946 .223 0 r
.49277 .73908 .50298 .7464 .52142 .74016 .5113 .73257 Metetra
.941 .242 0 r
.5113 .73257 .52142 .74016 .53997 .73405 .52995 .72622 Metetra
.936 .259 0 r
.52995 .72622 .53997 .73405 .55864 .72806 .54871 .72003 Metetra
.932 .273 0 r
.54871 .72003 .55864 .72806 .57742 .72218 .56759 .71398 Metetra
.929 .285 0 r
.56759 .71398 .57742 .72218 .59633 .71644 .58659 .70808 Metetra
.927 .294 0 r
.58659 .70808 .59633 .71644 .61536 .71081 .60572 .70232 Metetra
.925 .3 0 r
.60572 .70232 .61536 .71081 .63453 .70529 .62497 .6967 Metetra
.924 .304 0 r
.62497 .6967 .63453 .70529 .65383 .69989 .64437 .69121 Metetra
.924 .306 0 r
.64437 .69121 .65383 .69989 .67326 .69461 .6639 .68586 Metetra
.924 .305 0 r
.6639 .68586 .67326 .69461 .69284 .68944 .68358 .68064 Metetra
.924 .303 0 r
.68358 .68064 .69284 .68944 .71256 .68439 .7034 .67556 Metetra
.926 .297 0 r
.7034 .67556 .71256 .68439 .73244 .67946 .72338 .67061 Metetra
.928 .29 0 r
.72338 .67061 .73244 .67946 .75246 .67465 .74352 .66581 Metetra
.931 .28 0 r
.74352 .66581 .75246 .67465 .77265 .66996 .76381 .66115 Metetra
.934 .267 0 r
.76381 .66115 .77265 .66996 .793 .6654 .78428 .65665 Metetra
.938 .252 0 r
.78428 .65665 .793 .6654 .81351 .66096 .80492 .65231 Metetra
.943 .234 0 r
.80492 .65231 .81351 .66096 .8342 .65666 .82574 .64813 Metetra
.948 .213 0 r
.82574 .64813 .8342 .65666 .85507 .6525 .84674 .64414 Metetra
.954 .189 0 r
.84674 .64414 .85507 .6525 .87613 .64848 .86795 .64034 Metetra
.961 .161 0 r
.86795 .64034 .87613 .64848 .89737 .64459 .88935 .63673 Metetra
.968 .133 0 r
.88935 .63673 .89737 .64459 .91877 .64049 .91092 .633 Metetra
.969 .13 0 r
.91092 .633 .91877 .64049 .93994 .63305 .9323 .62606 Metetra
.932 .275 0 r
.9323 .62606 .93994 .63305 .95911 .60862 .95173 .60224 Metetra
.787 .727 0 r
.95173 .60224 .95911 .60862 .97301 .54526 .9659 .53893 Metetra
.322 .652 0 r
.36086 .65359 .3714 .66177 .38558 .73239 .37491 .72346 Metetra
.878 .465 0 r
.37491 .72346 .38558 .73239 .40199 .76308 .39131 .75326 Metetra
.962 .158 0 r
.39131 .75326 .40199 .76308 .41969 .76553 .40907 .7553 Metetra
.974 .11 0 r
.40907 .7553 .41969 .76553 .43779 .75961 .42724 .74923 Metetra
.968 .135 0 r
.42724 .74923 .43779 .75961 .45601 .75264 .44555 .74218 Metetra
.96 .167 0 r
.44555 .74218 .45601 .75264 .47434 .74577 .46395 .73525 Metetra
.953 .195 0 r
.46395 .73525 .47434 .74577 .49277 .73908 .48246 .72849 Metetra
.946 .219 0 r
.48246 .72849 .49277 .73908 .5113 .73257 .50107 .72192 Metetra
.941 .24 0 r
.50107 .72192 .5113 .73257 .52995 .72622 .5198 .71551 Metetra
.936 .258 0 r
.5198 .71551 .52995 .72622 .54871 .72003 .53864 .70925 Metetra
.932 .273 0 r
.53864 .70925 .54871 .72003 .56759 .71398 .5576 .70313 Metetra
.929 .285 0 r
.5576 .70313 .56759 .71398 .58659 .70808 .57668 .69717 Metetra
.927 .295 0 r
.57668 .69717 .58659 .70808 .60572 .70232 .59589 .69134 Metetra
.925 .302 0 r
.59589 .69134 .60572 .70232 .62497 .6967 .61523 .68565 Metetra
.924 .306 0 r
.61523 .68565 .62497 .6967 .64437 .69121 .63471 .68009 Metetra
.923 .308 0 r
.63471 .68009 .64437 .69121 .6639 .68586 .65433 .67467 Metetra
.923 .307 0 r
.65433 .67467 .6639 .68586 .68358 .68064 .67409 .66938 Metetra
.924 .304 0 r
.67409 .66938 .68358 .68064 .7034 .67556 .694 .66422 Metetra
.925 .299 0 r
.694 .66422 .7034 .67556 .72338 .67061 .71407 .6592 Metetra
.928 .291 0 r
.71407 .6592 .72338 .67061 .74352 .66581 .73429 .65432 Metetra
.93 .28 0 r
.73429 .65432 .74352 .66581 .76381 .66115 .75468 .64958 Metetra
.934 .267 0 r
.75468 .64958 .76381 .66115 .78428 .65665 .77524 .645 Metetra
.938 .251 0 r
.77524 .645 .78428 .65665 .80492 .65231 .79597 .64059 Metetra
.943 .231 0 r
.79597 .64059 .80492 .65231 .82574 .64813 .81688 .63633 Metetra
.949 .209 0 r
.81688 .63633 .82574 .64813 .84674 .64414 .83799 .63226 Metetra
.956 .183 0 r
.83799 .63226 .84674 .64414 .86795 .64034 .85928 .62839 Metetra
.963 .153 0 r
.85928 .62839 .86795 .64034 .88935 .63673 .88078 .6247 Metetra
.971 .121 0 r
.88078 .6247 .88935 .63673 .91092 .633 .90246 .62092 Metetra
.973 .114 0 r
.90246 .62092 .91092 .633 .9323 .62606 .92397 .61408 Metetra
.938 .252 0 r
.92397 .61408 .9323 .62606 .95173 .60224 .94361 .59077 Metetra
.796 .704 0 r
.94361 .59077 .95173 .60224 .9659 .53893 .95813 .52833 Metetra
.326 .654 0 r
.35021 .64486 .36086 .65359 .37491 .72346 .36413 .7139 Metetra
.875 .472 0 r
.36413 .7139 .37491 .72346 .39131 .75326 .38052 .74289 Metetra
.957 .177 0 r
.38052 .74289 .39131 .75326 .40907 .7553 .39834 .7446 Metetra
.968 .132 0 r
.39834 .7446 .40907 .7553 .42724 .74923 .41658 .73846 Metetra
.962 .158 0 r
.41658 .73846 .42724 .74923 .44555 .74218 .43496 .73138 Metetra
.954 .189 0 r
.43496 .73138 .44555 .74218 .46395 .73525 .45344 .72441 Metetra
.947 .216 0 r
.45344 .72441 .46395 .73525 .48246 .72849 .47203 .71762 Metetra
.941 .24 0 r
.47203 .71762 .48246 .72849 .50107 .72192 .49072 .711 Metetra
.936 .261 0 r
.49072 .711 .50107 .72192 .5198 .71551 .50952 .70455 Metetra
.931 .278 0 r
.50952 .70455 .5198 .71551 .53864 .70925 .52844 .69824 Metetra
.927 .293 0 r
.52844 .69824 .53864 .70925 .5576 .70313 .54748 .69207 Metetra
.924 .305 0 r
.54748 .69207 .5576 .70313 .57668 .69717 .56665 .68604 Metetra
.921 .314 0 r
.56665 .68604 .57668 .69717 .59589 .69134 .58594 .68016 Metetra
.92 .32 0 r
.58594 .68016 .59589 .69134 .61523 .68565 .60537 .6744 Metetra
.918 .325 0 r
.60537 .6744 .61523 .68565 .63471 .68009 .62493 .66877 Metetra
.918 .326 0 r
.62493 .66877 .63471 .68009 .65433 .67467 .64464 .66327 Metetra
.918 .326 0 r
.64464 .66327 .65433 .67467 .67409 .66938 .66448 .65791 Metetra
.919 .323 0 r
.66448 .65791 .67409 .66938 .694 .66422 .68448 .65267 Metetra
.92 .318 0 r
.68448 .65267 .694 .66422 .71407 .6592 .70464 .64757 Metetra
.922 .31 0 r
.70464 .64757 .71407 .6592 .73429 .65432 .72495 .6426 Metetra
.925 .3 0 r
.72495 .6426 .73429 .65432 .75468 .64958 .74543 .63778 Metetra
.929 .287 0 r
.74543 .63778 .75468 .64958 .77524 .645 .76608 .6331 Metetra
.933 .271 0 r
.76608 .6331 .77524 .645 .79597 .64059 .7869 .62858 Metetra
.938 .252 0 r
.7869 .62858 .79597 .64059 .81688 .63633 .80791 .62423 Metetra
.944 .23 0 r
.80791 .62423 .81688 .63633 .83799 .63226 .8291 .62005 Metetra
.95 .204 0 r
.8291 .62005 .83799 .63226 .85928 .62839 .85049 .61606 Metetra
.958 .175 0 r
.85049 .61606 .85928 .62839 .88078 .6247 .87209 .61226 Metetra
.966 .144 0 r
.87209 .61226 .88078 .6247 .90246 .62092 .89386 .60837 Metetra
.968 .136 0 r
.89386 .60837 .90246 .62092 .92397 .61408 .91549 .60153 Metetra
.934 .268 0 r
.91549 .60153 .92397 .61408 .94361 .59077 .93533 .57865 Metetra
.795 .706 0 r
.93533 .57865 .94361 .59077 .95813 .52833 .95019 .51705 Metetra
.328 .654 0 r
.33943 .63591 .35021 .64486 .36413 .7139 .35322 .70423 Metetra
.872 .483 0 r
.35322 .70423 .36413 .7139 .38052 .74289 .3696 .73251 Metetra
.952 .198 0 r
.3696 .73251 .38052 .74289 .39834 .7446 .38747 .73393 Metetra
.963 .156 0 r
.38747 .73393 .39834 .7446 .41658 .73846 .40579 .72772 Metetra
.956 .181 0 r
.40579 .72772 .41658 .73846 .43496 .73138 .42425 .7206 Metetra
.949 .211 0 r
.42425 .7206 .43496 .73138 .45344 .72441 .44281 .7136 Metetra
.942 .238 0 r
.44281 .7136 .45344 .72441 .47203 .71762 .46147 .70677 Metetra
.936 .261 0 r
.46147 .70677 .47203 .71762 .49072 .711 .48024 .70011 Metetra
.93 .281 0 r
.48024 .70011 .49072 .711 .50952 .70455 .49913 .6936 Metetra
.926 .297 0 r
.49913 .6936 .50952 .70455 .52844 .69824 .51813 .68724 Metetra
.922 .312 0 r
.51813 .68724 .52844 .69824 .54748 .69207 .53725 .68101 Metetra
.919 .323 0 r
.53725 .68101 .54748 .69207 .56665 .68604 .5565 .67493 Metetra
.916 .332 0 r
.5565 .67493 .56665 .68604 .58594 .68016 .57588 .66898 Metetra
.915 .338 0 r
.57588 .66898 .58594 .68016 .60537 .6744 .59539 .66315 Metetra
.913 .343 0 r
.59539 .66315 .60537 .6744 .62493 .66877 .61504 .65746 Metetra
.913 .344 0 r
.61504 .65746 .62493 .66877 .64464 .66327 .63483 .65189 Metetra
.913 .344 0 r
.63483 .65189 .64464 .66327 .66448 .65791 .65477 .64644 Metetra
.914 .341 0 r
.65477 .64644 .66448 .65791 .68448 .65267 .67485 .64113 Metetra
.915 .336 0 r
.67485 .64113 .68448 .65267 .70464 .64757 .6951 .63594 Metetra
.917 .328 0 r
.6951 .63594 .70464 .64757 .72495 .6426 .7155 .63089 Metetra
.92 .318 0 r
.7155 .63089 .72495 .6426 .74543 .63778 .73607 .62598 Metetra
.924 .306 0 r
.73607 .62598 .74543 .63778 .76608 .6331 .75681 .62121 Metetra
.928 .29 0 r
.75681 .62121 .76608 .6331 .7869 .62858 .77773 .61659 Metetra
.933 .272 0 r
.77773 .61659 .7869 .62858 .80791 .62423 .79883 .61213 Metetra
.938 .251 0 r
.79883 .61213 .80791 .62423 .8291 .62005 .82012 .60785 Metetra
.945 .226 0 r
.82012 .60785 .8291 .62005 .85049 .61606 .8416 .60375 Metetra
.952 .198 0 r
.8416 .60375 .85049 .61606 .87209 .61226 .86329 .59983 Metetra
.96 .168 0 r
.86329 .59983 .87209 .61226 .89386 .60837 .88517 .59583 Metetra
.962 .159 0 r
.88517 .59583 .89386 .60837 .91549 .60153 .90691 .58898 Metetra
.929 .285 0 r
.90691 .58898 .91549 .60153 .93533 .57865 .92695 .56644 Metetra
.793 .71 0 r
.92695 .56644 .93533 .57865 .95019 .51705 .94214 .50556 Metetra
.328 .654 0 r
.32852 .62679 .33943 .63591 .35322 .70423 .34217 .69449 Metetra
.869 .492 0 r
.34217 .69449 .35322 .70423 .3696 .73251 .35854 .72214 Metetra
.947 .217 0 r
.35854 .72214 .3696 .73251 .38747 .73393 .37647 .72331 Metetra
.957 .177 0 r
.37647 .72331 .38747 .73393 .40579 .72772 .39487 .71703 Metetra
.951 .201 0 r
.39487 .71703 .40579 .72772 .42425 .7206 .4134 .70987 Metetra
.944 .23 0 r
.4134 .70987 .42425 .7206 .44281 .7136 .43204 .70283 Metetra
.937 .256 0 r
.43204 .70283 .44281 .7136 .46147 .70677 .45078 .69595 Metetra
.931 .279 0 r
.45078 .69595 .46147 .70677 .48024 .70011 .46964 .68924 Metetra
.926 .298 0 r
.46964 .68924 .48024 .70011 .49913 .6936 .4886 .68268 Metetra
.921 .314 0 r
.4886 .68268 .49913 .6936 .51813 .68724 .50769 .67627 Metetra
.917 .328 0 r
.50769 .67627 .51813 .68724 .53725 .68101 .52689 .66998 Metetra
.914 .339 0 r
.52689 .66998 .53725 .68101 .5565 .67493 .54623 .66383 Metetra
.912 .348 0 r
.54623 .66383 .5565 .67493 .57588 .66898 .56569 .65781 Metetra
.91 .354 0 r
.56569 .65781 .57588 .66898 .59539 .66315 .58529 .65192 Metetra
.909 .358 0 r
.58529 .65192 .59539 .66315 .61504 .65746 .60502 .64615 Metetra
.909 .36 0 r
.60502 .64615 .61504 .65746 .63483 .65189 .6249 .64051 Metetra
.909 .359 0 r
.6249 .64051 .63483 .65189 .65477 .64644 .64493 .63499 Metetra
.909 .357 0 r
.64493 .63499 .65477 .64644 .67485 .64113 .66511 .62959 Metetra
.911 .352 0 r
.66511 .62959 .67485 .64113 .6951 .63594 .68544 .62432 Metetra
.913 .344 0 r
.68544 .62432 .6951 .63594 .7155 .63089 .70594 .61918 Metetra
.916 .335 0 r
.70594 .61918 .7155 .63089 .73607 .62598 .7266 .61418 Metetra
.919 .322 0 r
.7266 .61418 .73607 .62598 .75681 .62121 .74744 .60932 Metetra
.923 .308 0 r
.74744 .60932 .75681 .62121 .77773 .61659 .76845 .6046 Metetra
.928 .29 0 r
.76845 .6046 .77773 .61659 .79883 .61213 .78965 .60004 Metetra
.933 .269 0 r
.78965 .60004 .79883 .61213 .82012 .60785 .81103 .59566 Metetra
.94 .245 0 r
.81103 .59566 .82012 .60785 .8416 .60375 .83262 .59145 Metetra
.947 .218 0 r
.83262 .59145 .8416 .60375 .86329 .59983 .85441 .58741 Metetra
.954 .188 0 r
.85441 .58741 .86329 .59983 .88517 .59583 .87638 .58331 Metetra
.957 .179 0 r
.87638 .58331 .88517 .59583 .90691 .58898 .89824 .57643 Metetra
.925 .3 0 r
.89824 .57643 .90691 .58898 .92695 .56644 .91848 .55418 Metetra
.792 .714 0 r
.91848 .55418 .92695 .56644 .94214 .50556 .93397 .4939 Metetra
.329 .654 0 r
.31748 .6175 .32852 .62679 .34217 .69449 .33098 .68467 Metetra
.867 .501 0 r
.33098 .68467 .34217 .69449 .35854 .72214 .34734 .71179 Metetra
.943 .233 0 r
.34734 .71179 .35854 .72214 .37647 .72331 .36533 .71273 Metetra
.953 .195 0 r
.36533 .71273 .37647 .72331 .39487 .71703 .38381 .70638 Metetra
.947 .219 0 r
.38381 .70638 .39487 .71703 .4134 .70987 .40242 .69918 Metetra
.939 .247 0 r
.40242 .69918 .4134 .70987 .43204 .70283 .42114 .69208 Metetra
.933 .272 0 r
.42114 .69208 .43204 .70283 .45078 .69595 .43996 .68516 Metetra
.927 .294 0 r
.43996 .68516 .45078 .69595 .46964 .68924 .4589 .67839 Metetra
.922 .313 0 r
.4589 .67839 .46964 .68924 .4886 .68268 .47795 .67178 Metetra
.917 .329 0 r
.47795 .67178 .4886 .68268 .50769 .67627 .49712 .6653 Metetra
.913 .343 0 r
.49712 .6653 .50769 .67627 .52689 .66998 .51641 .65895 Metetra
.91 .353 0 r
.51641 .65895 .52689 .66998 .54623 .66383 .53583 .65274 Metetra
.908 .362 0 r
.53583 .65274 .54623 .66383 .56569 .65781 .55538 .64665 Metetra
.906 .368 0 r
.55538 .64665 .56569 .65781 .58529 .65192 .57506 .64069 Metetra
.905 .372 0 r
.57506 .64069 .58529 .65192 .60502 .64615 .59489 .63485 Metetra
.905 .374 0 r
.59489 .63485 .60502 .64615 .6249 .64051 .61486 .62913 Metetra
.905 .373 0 r
.61486 .62913 .6249 .64051 .64493 .63499 .63497 .62353 Metetra
.906 .37 0 r
.63497 .62353 .64493 .63499 .66511 .62959 .65525 .61806 Metetra
.907 .365 0 r
.65525 .61806 .66511 .62959 .68544 .62432 .67567 .6127 Metetra
.909 .358 0 r
.67567 .6127 .68544 .62432 .70594 .61918 .69626 .60748 Metetra
.912 .349 0 r
.69626 .60748 .70594 .61918 .7266 .61418 .71702 .60238 Metetra
.915 .337 0 r
.71702 .60238 .7266 .61418 .74744 .60932 .73795 .59743 Metetra
.919 .322 0 r
.73795 .59743 .74744 .60932 .76845 .6046 .75906 .59262 Metetra
.924 .305 0 r
.75906 .59262 .76845 .6046 .78965 .60004 .78036 .58796 Metetra
.929 .285 0 r
.78036 .58796 .78965 .60004 .81103 .59566 .80184 .58347 Metetra
.936 .261 0 r
.80184 .58347 .81103 .59566 .83262 .59145 .82353 .57915 Metetra
.943 .235 0 r
.82353 .57915 .83262 .59145 .85441 .58741 .84542 .57501 Metetra
.95 .206 0 r
.84542 .57501 .85441 .58741 .87638 .58331 .8675 .5708 Metetra
.952 .197 0 r
.8675 .5708 .87638 .58331 .89824 .57643 .88948 .56389 Metetra
.921 .314 0 r
.88948 .56389 .89824 .57643 .91848 .55418 .9099 .54187 Metetra
.79 .718 0 r
.9099 .54187 .91848 .55418 .93397 .4939 .92569 .48207 Metetra
.33 .655 0 r
.30631 .60803 .31748 .6175 .33098 .68467 .31966 .67477 Metetra
.864 .508 0 r
.31966 .67477 .33098 .68467 .34734 .71179 .336 .70144 Metetra
.939 .247 0 r
.336 .70144 .34734 .71179 .36533 .71273 .35405 .70218 Metetra
.949 .21 0 r
.35405 .70218 .36533 .71273 .38381 .70638 .3726 .69575 Metetra
.943 .234 0 r
.3726 .69575 .38381 .70638 .40242 .69918 .3913 .6885 Metetra
.936 .261 0 r
.3913 .6885 .40242 .69918 .42114 .69208 .4101 .68136 Metetra
.929 .286 0 r
.4101 .68136 .42114 .69208 .43996 .68516 .429 .67438 Metetra
.923 .308 0 r
.429 .67438 .43996 .68516 .4589 .67839 .44802 .66755 Metetra
.918 .326 0 r
.44802 .66755 .4589 .67839 .47795 .67178 .46716 .66087 Metetra
.914 .342 0 r
.46716 .66087 .47795 .67178 .49712 .6653 .48641 .65433 Metetra
.91 .355 0 r
.48641 .65433 .49712 .6653 .51641 .65895 .50579 .64792 Metetra
.907 .365 0 r
.50579 .64792 .51641 .65895 .53583 .65274 .52529 .64164 Metetra
.905 .374 0 r
.52529 .64164 .53583 .65274 .55538 .64665 .54493 .63549 Metetra
.903 .38 0 r
.54493 .63549 .55538 .64665 .57506 .64069 .56471 .62946 Metetra
.902 .383 0 r
.56471 .62946 .57506 .64069 .59489 .63485 .58462 .62354 Metetra
.901 .385 0 r
.58462 .62354 .59489 .63485 .61486 .62913 .60469 .61774 Metetra
.902 .385 0 r
.60469 .61774 .61486 .62913 .63497 .62353 .6249 .61207 Metetra
.902 .382 0 r
.6249 .61207 .63497 .62353 .65525 .61806 .64526 .60651 Metetra
.904 .377 0 r
.64526 .60651 .65525 .61806 .67567 .6127 .66578 .60107 Metetra
.906 .37 0 r
.66578 .60107 .67567 .6127 .69626 .60748 .68647 .59576 Metetra
.908 .361 0 r
.68647 .59576 .69626 .60748 .71702 .60238 .70732 .59057 Metetra
.912 .349 0 r
.70732 .59057 .71702 .60238 .73795 .59743 .72835 .58552 Metetra
.916 .335 0 r
.72835 .58552 .73795 .59743 .75906 .59262 .74956 .58062 Metetra
.92 .318 0 r
.74956 .58062 .75906 .59262 .78036 .58796 .77096 .57587 Metetra
.926 .298 0 r
.77096 .57587 .78036 .58796 .80184 .58347 .79255 .57128 Metetra
.932 .275 0 r
.79255 .57128 .80184 .58347 .82353 .57915 .81433 .56686 Metetra
.939 .249 0 r
.81433 .56686 .82353 .57915 .84542 .57501 .83633 .56261 Metetra
.946 .221 0 r
.83633 .56261 .84542 .57501 .8675 .5708 .85851 .55829 Metetra
.948 .212 0 r
.85851 .55829 .8675 .5708 .88948 .56389 .88061 .55134 Metetra
.918 .325 0 r
.88061 .55134 .88948 .56389 .9099 .54187 .90121 .52948 Metetra
.789 .721 0 r
.90121 .52948 .9099 .54187 .92569 .48207 .91729 .47007 Metetra
.33 .655 0 r
.295 .59839 .30631 .60803 .31966 .67477 .30819 .66478 Metetra
.863 .514 0 r
.30819 .66478 .31966 .67477 .336 .70144 .32451 .69109 Metetra
.936 .258 0 r
.32451 .69109 .336 .70144 .35405 .70218 .34262 .69165 Metetra
.946 .223 0 r
.34262 .69165 .35405 .70218 .3726 .69575 .36125 .68515 Metetra
.94 .246 0 r
.36125 .68515 .3726 .69575 .3913 .6885 .38003 .67784 Metetra
.932 .273 0 r
.38003 .67784 .3913 .6885 .4101 .68136 .39891 .67064 Metetra
.926 .298 0 r
.39891 .67064 .4101 .68136 .429 .67438 .4179 .6636 Metetra
.92 .319 0 r
.4179 .6636 .429 .67438 .44802 .66755 .43701 .65671 Metetra
.915 .337 0 r
.43701 .65671 .44802 .66755 .46716 .66087 .45623 .64997 Metetra
.911 .352 0 r
.45623 .64997 .46716 .66087 .48641 .65433 .47557 .64337 Metetra
.907 .365 0 r
.47557 .64337 .48641 .65433 .50579 .64792 .49503 .63688 Metetra
.904 .376 0 r
.49503 .63688 .50579 .64792 .52529 .64164 .51463 .63054 Metetra
.902 .384 0 r
.51463 .63054 .52529 .64164 .54493 .63549 .53436 .62431 Metetra
.9 .389 0 r
.53436 .62431 .54493 .63549 .56471 .62946 .55422 .6182 Metetra
.899 .393 0 r
.55422 .6182 .56471 .62946 .58462 .62354 .57423 .61221 Metetra
.899 .395 0 r
.57423 .61221 .58462 .62354 .60469 .61774 .59438 .60634 Metetra
.899 .394 0 r
.59438 .60634 .60469 .61774 .6249 .61207 .61469 .60058 Metetra
.899 .392 0 r
.61469 .60058 .6249 .61207 .64526 .60651 .63515 .59494 Metetra
.901 .387 0 r
.63515 .59494 .64526 .60651 .66578 .60107 .65577 .58942 Metetra
.903 .38 0 r
.65577 .58942 .66578 .60107 .68647 .59576 .67655 .58402 Metetra
.905 .371 0 r
.67655 .58402 .68647 .59576 .70732 .59057 .69751 .57874 Metetra
.909 .36 0 r
.69751 .57874 .70732 .59057 .72835 .58552 .71864 .5736 Metetra
.913 .346 0 r
.71864 .5736 .72835 .58552 .74956 .58062 .73995 .5686 Metetra
.917 .329 0 r
.73995 .5686 .74956 .58062 .77096 .57587 .76144 .56375 Metetra
.922 .31 0 r
.76144 .56375 .77096 .57587 .79255 .57128 .78313 .55906 Metetra
.929 .287 0 r
.78313 .55906 .79255 .57128 .81433 .56686 .80503 .55455 Metetra
.935 .262 0 r
.80503 .55455 .81433 .56686 .83633 .56261 .82713 .5502 Metetra
.943 .234 0 r
.82713 .5502 .83633 .56261 .85851 .55829 .84942 .54578 Metetra
.945 .225 0 r
.84942 .54578 .85851 .55829 .88061 .55134 .87164 .53877 Metetra
.916 .335 0 r
.87164 .53877 .88061 .55134 .90121 .52948 .89242 .51703 Metetra
.788 .724 0 r
.89242 .51703 .90121 .52948 .91729 .47007 .90878 .45789 Metetra
.33 .655 0 r
.28355 .58857 .295 .59839 .30819 .66478 .29657 .65472 Metetra
.861 .519 0 r
.29657 .65472 .30819 .66478 .32451 .69109 .31287 .68073 Metetra
.934 .268 0 r
.31287 .68073 .32451 .69109 .34262 .69165 .33104 .68114 Metetra
.943 .234 0 r
.33104 .68114 .34262 .69165 .36125 .68515 .34975 .67456 Metetra
.937 .257 0 r
.34975 .67456 .36125 .68515 .38003 .67784 .36861 .66719 Metetra
.93 .283 0 r
.36861 .66719 .38003 .67784 .39891 .67064 .38758 .65993 Metetra
.923 .307 0 r
.38758 .65993 .39891 .67064 .4179 .6636 .40666 .65282 Metetra
.918 .328 0 r
.40666 .65282 .4179 .6636 .43701 .65671 .42585 .64587 Metetra
.913 .346 0 r
.42585 .64587 .43701 .65671 .45623 .64997 .44516 .63906 Metetra
.908 .361 0 r
.44516 .63906 .45623 .64997 .47557 .64337 .46458 .63239 Metetra
.905 .374 0 r
.46458 .63239 .47557 .64337 .49503 .63688 .48414 .62583 Metetra
.902 .384 0 r
.48414 .62583 .49503 .63688 .51463 .63054 .50382 .61941 Metetra
.899 .392 0 r
.50382 .61941 .51463 .63054 .53436 .62431 .52364 .61311 Metetra
.898 .398 0 r
.52364 .61311 .53436 .62431 .55422 .6182 .5436 .60693 Metetra
.897 .401 0 r
.5436 .60693 .55422 .6182 .57423 .61221 .5637 .60086 Metetra
.896 .403 0 r
.5637 .60086 .57423 .61221 .59438 .60634 .58395 .5949 Metetra
.896 .402 0 r
.58395 .5949 .59438 .60634 .61469 .60058 .60435 .58907 Metetra
.897 .4 0 r
.60435 .58907 .61469 .60058 .63515 .59494 .62491 .58334 Metetra
.898 .395 0 r
.62491 .58334 .63515 .59494 .65577 .58942 .64563 .57773 Metetra
.9 .388 0 r
.64563 .57773 .65577 .58942 .67655 .58402 .66651 .57225 Metetra
.903 .38 0 r
.66651 .57225 .67655 .58402 .69751 .57874 .68756 .56689 Metetra
.906 .368 0 r
.68756 .56689 .69751 .57874 .71864 .5736 .70879 .56166 Metetra
.91 .355 0 r
.70879 .56166 .71864 .5736 .73995 .5686 .73021 .55656 Metetra
.915 .338 0 r
.73021 .55656 .73995 .5686 .76144 .56375 .75181 .55162 Metetra
.92 .319 0 r
.75181 .55162 .76144 .56375 .78313 .55906 .77361 .54683 Metetra
.926 .297 0 r
.77361 .54683 .78313 .55906 .80503 .55455 .79561 .54222 Metetra
.933 .272 0 r
.79561 .54222 .80503 .55455 .82713 .5502 .81782 .53776 Metetra
.94 .245 0 r
.81782 .53776 .82713 .5502 .84942 .54578 .84022 .53325 Metetra
.942 .235 0 r
.84022 .53325 .84942 .54578 .87164 .53877 .86257 .52617 Metetra
.913 .343 0 r
.86257 .52617 .87164 .53877 .89242 .51703 .88351 .5045 Metetra
.787 .726 0 r
.88351 .5045 .89242 .51703 .90878 .45789 .90014 .44554 Metetra
.33 .655 0 r
.27196 .57858 .28355 .58857 .29657 .65472 .2848 .64457 Metetra
.86 .523 0 r
.2848 .64457 .29657 .65472 .31287 .68073 .30108 .67035 Metetra
.932 .276 0 r
.30108 .67035 .31287 .68073 .33104 .68114 .31931 .67063 Metetra
.941 .242 0 r
.31931 .67063 .33104 .68114 .34975 .67456 .3381 .66398 Metetra
.935 .265 0 r
.3381 .66398 .34975 .67456 .36861 .66719 .35705 .65655 Metetra
.928 .291 0 r
.35705 .65655 .36861 .66719 .38758 .65993 .3761 .64921 Metetra
.921 .315 0 r
.3761 .64921 .38758 .65993 .40666 .65282 .39527 .64204 Metetra
.915 .335 0 r
.39527 .64204 .40666 .65282 .42585 .64587 .41454 .63502 Metetra
.911 .353 0 r
.41454 .63502 .42585 .64587 .44516 .63906 .43394 .62814 Metetra
.906 .368 0 r
.43394 .62814 .44516 .63906 .46458 .63239 .45346 .62139 Metetra
.903 .38 0 r
.45346 .62139 .46458 .63239 .48414 .62583 .4731 .61476 Metetra
.9 .39 0 r
.4731 .61476 .48414 .62583 .50382 .61941 .49288 .60827 Metetra
.898 .398 0 r
.49288 .60827 .50382 .61941 .52364 .61311 .51279 .60189 Metetra
.896 .404 0 r
.51279 .60189 .52364 .61311 .5436 .60693 .53284 .59563 Metetra
.895 .408 0 r
.53284 .59563 .5436 .60693 .5637 .60086 .55304 .58948 Metetra
.894 .409 0 r
.55304 .58948 .5637 .60086 .58395 .5949 .57338 .58344 Metetra
.895 .409 0 r
.57338 .58344 .58395 .5949 .60435 .58907 .59388 .57752 Metetra
.895 .406 0 r
.59388 .57752 .60435 .58907 .62491 .58334 .61453 .57171 Metetra
.897 .402 0 r
.61453 .57171 .62491 .58334 .64563 .57773 .63535 .56602 Metetra
.899 .395 0 r
.63535 .56602 .64563 .57773 .66651 .57225 .65633 .56045 Metetra
.901 .386 0 r
.65633 .56045 .66651 .57225 .68756 .56689 .67749 .555 Metetra
.904 .375 0 r
.67749 .555 .68756 .56689 .70879 .56166 .69883 .54968 Metetra
.908 .362 0 r
.69883 .54968 .70879 .56166 .73021 .55656 .72034 .54449 Metetra
.913 .345 0 r
.72034 .54449 .73021 .55656 .75181 .55162 .74205 .53945 Metetra
.918 .327 0 r
.74205 .53945 .75181 .55162 .77361 .54683 .76396 .53457 Metetra
.924 .305 0 r
.76396 .53457 .77361 .54683 .79561 .54222 .78607 .52986 Metetra
.931 .28 0 r
.78607 .52986 .79561 .54222 .81782 .53776 .80839 .52531 Metetra
.938 .253 0 r
.80839 .52531 .81782 .53776 .84022 .53325 .8309 .52069 Metetra
.94 .244 0 r
.8309 .52069 .84022 .53325 .86257 .52617 .85338 .51355 Metetra
.912 .349 0 r
.85338 .51355 .86257 .52617 .88351 .5045 .87449 .49189 Metetra
.787 .728 0 r
.87449 .49189 .88351 .5045 .90014 .44554 .89138 .43301 Metetra
.331 .655 0 r
.26023 .56841 .27196 .57858 .2848 .64457 .27288 .63433 Metetra
.859 .526 0 r
.27288 .63433 .2848 .64457 .30108 .67035 .28913 .65996 Metetra
.93 .281 0 r
.28913 .65996 .30108 .67035 .31931 .67063 .30742 .66013 Metetra
.939 .249 0 r
.30742 .66013 .31931 .67063 .3381 .66398 .32629 .6534 Metetra
.933 .271 0 r
.32629 .6534 .3381 .66398 .35705 .65655 .34532 .64589 Metetra
.926 .297 0 r
.34532 .64589 .35705 .65655 .3761 .64921 .36447 .63849 Metetra
.92 .321 0 r
.36447 .63849 .3761 .64921 .39527 .64204 .38372 .63124 Metetra
.914 .341 0 r
.38372 .63124 .39527 .64204 .41454 .63502 .40308 .62415 Metetra
.909 .358 0 r
.40308 .62415 .41454 .63502 .43394 .62814 .42257 .6172 Metetra
.905 .373 0 r
.42257 .6172 .43394 .62814 .45346 .62139 .44218 .61038 Metetra
.901 .385 0 r
.44218 .61038 .45346 .62139 .4731 .61476 .46192 .60367 Metetra
.898 .395 0 r
.46192 .60367 .4731 .61476 .49288 .60827 .48178 .5971 Metetra
.896 .403 0 r
.48178 .5971 .49288 .60827 .51279 .60189 .50179 .59064 Metetra
.895 .409 0 r
.50179 .59064 .51279 .60189 .53284 .59563 .52194 .5843 Metetra
.893 .412 0 r
.52194 .5843 .53284 .59563 .55304 .58948 .54223 .57806 Metetra
.893 .414 0 r
.54223 .57806 .55304 .58948 .57338 .58344 .56267 .57195 Metetra
.893 .414 0 r
.56267 .57195 .57338 .58344 .59388 .57752 .58327 .56594 Metetra
.894 .411 0 r
.58327 .56594 .59388 .57752 .61453 .57171 .60402 .56005 Metetra
.895 .407 0 r
.60402 .56005 .61453 .57171 .63535 .56602 .62494 .55427 Metetra
.897 .4 0 r
.62494 .55427 .63535 .56602 .65633 .56045 .64603 .54861 Metetra
.9 .391 0 r
.64603 .54861 .65633 .56045 .67749 .555 .66729 .54307 Metetra
.903 .38 0 r
.66729 .54307 .67749 .555 .69883 .54968 .68873 .53766 Metetra
.907 .367 0 r
.68873 .53766 .69883 .54968 .72034 .54449 .71035 .53238 Metetra
.911 .351 0 r
.71035 .53238 .72034 .54449 .74205 .53945 .73217 .52725 Metetra
.916 .332 0 r
.73217 .52725 .74205 .53945 .76396 .53457 .75418 .52227 Metetra
.922 .311 0 r
.75418 .52227 .76396 .53457 .78607 .52986 .77641 .51746 Metetra
.929 .286 0 r
.77641 .51746 .78607 .52986 .80839 .52531 .79884 .51282 Metetra
.936 .259 0 r
.79884 .51282 .80839 .52531 .8309 .52069 .82147 .5081 Metetra
.939 .25 0 r
.82147 .5081 .8309 .52069 .85338 .51355 .84407 .50088 Metetra
.91 .354 0 r
.84407 .50088 .85338 .51355 .87449 .49189 .86535 .47919 Metetra
.786 .729 0 r
.86535 .47919 .87449 .49189 .89138 .43301 .8825 .4203 Metetra
.331 .655 0 r
.24835 .55807 .26023 .56841 .27288 .63433 .2608 .624 Metetra
.858 .528 0 r
.2608 .624 .27288 .63433 .28913 .65996 .27701 .64955 Metetra
.929 .285 0 r
.27701 .64955 .28913 .65996 .30742 .66013 .29536 .64963 Metetra
.938 .253 0 r
.29536 .64963 .30742 .66013 .32629 .6534 .31432 .64282 Metetra
.932 .275 0 r
.31432 .64282 .32629 .6534 .34532 .64589 .33344 .63524 Metetra
.925 .301 0 r
.33344 .63524 .34532 .64589 .36447 .63849 .35267 .62776 Metetra
.918 .324 0 r
.35267 .62776 .36447 .63849 .38372 .63124 .37201 .62044 Metetra
.913 .345 0 r
.37201 .62044 .38372 .63124 .40308 .62415 .39147 .61327 Metetra
.908 .362 0 r
.39147 .61327 .40308 .62415 .42257 .6172 .41105 .60623 Metetra
.904 .377 0 r
.41105 .60623 .42257 .6172 .44218 .61038 .43075 .59933 Metetra
.9 .389 0 r
.43075 .59933 .44218 .61038 .46192 .60367 .45058 .59255 Metetra
.897 .399 0 r
.45058 .59255 .46192 .60367 .48178 .5971 .47054 .58589 Metetra
.895 .407 0 r
.47054 .58589 .48178 .5971 .50179 .59064 .49064 .57935 Metetra
.894 .412 0 r
.49064 .57935 .50179 .59064 .52194 .5843 .51089 .57293 Metetra
.892 .416 0 r
.51089 .57293 .52194 .5843 .54223 .57806 .53127 .56661 Metetra
.892 .417 0 r
.53127 .56661 .54223 .57806 .56267 .57195 .55182 .56041 Metetra
.892 .417 0 r
.55182 .56041 .56267 .57195 .58327 .56594 .57251 .55432 Metetra
.893 .414 0 r
.57251 .55432 .58327 .56594 .60402 .56005 .59337 .54834 Metetra
.894 .41 0 r
.59337 .54834 .60402 .56005 .62494 .55427 .61439 .54248 Metetra
.896 .403 0 r
.61439 .54248 .62494 .55427 .64603 .54861 .63558 .53673 Metetra
.899 .395 0 r
.63558 .53673 .64603 .54861 .66729 .54307 .65695 .5311 Metetra
.902 .384 0 r
.65695 .5311 .66729 .54307 .68873 .53766 .67849 .5256 Metetra
.906 .37 0 r
.67849 .5256 .68873 .53766 .71035 .53238 .70023 .52023 Metetra
.91 .355 0 r
.70023 .52023 .71035 .53238 .73217 .52725 .72216 .51501 Metetra
.915 .336 0 r
.72216 .51501 .73217 .52725 .75418 .52227 .74428 .50993 Metetra
.921 .315 0 r
.74428 .50993 .75418 .52227 .77641 .51746 .76662 .50503 Metetra
.928 .29 0 r
.76662 .50503 .77641 .51746 .79884 .51282 .78917 .50029 Metetra
.935 .264 0 r
.78917 .50029 .79884 .51282 .82147 .5081 .81192 .49548 Metetra
.937 .254 0 r
.81192 .49548 .82147 .5081 .84407 .50088 .83464 .48817 Metetra
.909 .357 0 r
.83464 .48817 .84407 .50088 .86535 .47919 .85609 .46641 Metetra
.786 .73 0 r
.85609 .46641 .86535 .47919 .8825 .4203 .87349 .40741 Metetra
.331 .655 0 r
.23632 .54755 .24835 .55807 .2608 .624 .24856 .61358 Metetra
.858 .529 0 r
.24856 .61358 .2608 .624 .27701 .64955 .26473 .63911 Metetra
.929 .287 0 r
.26473 .63911 .27701 .64955 .29536 .64963 .28313 .63913 Metetra
.937 .255 0 r
.28313 .63913 .29536 .64963 .31432 .64282 .30218 .63224 Metetra
.931 .278 0 r
.30218 .63224 .31432 .64282 .33344 .63524 .32139 .62458 Metetra
.924 .304 0 r
.32139 .62458 .33344 .63524 .35267 .62776 .34071 .61701 Metetra
.918 .327 0 r
.34071 .61701 .35267 .62776 .37201 .62044 .36015 .60961 Metetra
.912 .347 0 r
.36015 .60961 .37201 .62044 .39147 .61327 .3797 .60236 Metetra
.907 .364 0 r
.3797 .60236 .39147 .61327 .41105 .60623 .39936 .59524 Metetra
.903 .379 0 r
.39936 .59524 .41105 .60623 .43075 .59933 .41916 .58826 Metetra
.9 .391 0 r
.41916 .58826 .43075 .59933 .45058 .59255 .43908 .58139 Metetra
.897 .401 0 r
.43908 .58139 .45058 .59255 .47054 .58589 .45914 .57465 Metetra
.895 .408 0 r
.45914 .57465 .47054 .58589 .49064 .57935 .47934 .56803 Metetra
.893 .414 0 r
.47934 .56803 .49064 .57935 .51089 .57293 .49968 .56152 Metetra
.892 .418 0 r
.49968 .56152 .51089 .57293 .53127 .56661 .52017 .55512 Metetra
.892 .419 0 r
.52017 .55512 .53127 .56661 .55182 .56041 .54081 .54883 Metetra
.892 .419 0 r
.54081 .54883 .55182 .56041 .57251 .55432 .56161 .54266 Metetra
.892 .416 0 r
.56161 .54266 .57251 .55432 .59337 .54834 .58257 .53659 Metetra
.894 .412 0 r
.58257 .53659 .59337 .54834 .61439 .54248 .60369 .53064 Metetra
.896 .405 0 r
.60369 .53064 .61439 .54248 .63558 .53673 .62499 .5248 Metetra
.898 .397 0 r
.62499 .5248 .63558 .53673 .65695 .5311 .64647 .51908 Metetra
.901 .386 0 r
.64647 .51908 .65695 .5311 .67849 .5256 .66812 .51349 Metetra
.905 .372 0 r
.66812 .51349 .67849 .5256 .70023 .52023 .68997 .50804 Metetra
.91 .357 0 r
.68997 .50804 .70023 .52023 .72216 .51501 .71201 .50272 Metetra
.915 .338 0 r
.71201 .50272 .72216 .51501 .74428 .50993 .73425 .49755 Metetra
.921 .317 0 r
.73425 .49755 .74428 .50993 .76662 .50503 .7567 .49256 Metetra
.927 .292 0 r
.7567 .49256 .76662 .50503 .78917 .50029 .77937 .48772 Metetra
.934 .266 0 r
.77937 .48772 .78917 .50029 .81192 .49548 .80224 .48282 Metetra
.937 .257 0 r
.80224 .48282 .81192 .49548 .83464 .48817 .82509 .47542 Metetra
.909 .359 0 r
.82509 .47542 .83464 .48817 .85609 .46641 .8467 .45353 Metetra
.785 .73 0 r
.8467 .45353 .85609 .46641 .87349 .40741 .86435 .39433 Metetra
.331 .655 0 r
.22415 .53684 .23632 .54755 .24856 .61358 .23616 .60306 Metetra
.858 .529 0 r
.23616 .60306 .24856 .61358 .26473 .63911 .25227 .62865 Metetra
.928 .288 0 r
.25227 .62865 .26473 .63911 .28313 .63913 .27074 .62862 Metetra
.937 .256 0 r
.27074 .62862 .28313 .63913 .30218 .63224 .28987 .62165 Metetra
.931 .278 0 r
.28987 .62165 .30218 .63224 .32139 .62458 .30917 .6139 Metetra
.924 .304 0 r
.30917 .6139 .32139 .62458 .34071 .61701 .32859 .60625 Metetra
.918 .327 0 r
.32859 .60625 .34071 .61701 .36015 .60961 .34811 .59877 Metetra
.912 .347 0 r
.34811 .59877 .36015 .60961 .3797 .60236 .36776 .59143 Metetra
.907 .364 0 r
.36776 .59143 .3797 .60236 .39936 .59524 .38752 .58423 Metetra
.903 .379 0 r
.38752 .58423 .39936 .59524 .41916 .58826 .40741 .57716 Metetra
.9 .391 0 r
.40741 .57716 .41916 .58826 .43908 .58139 .42743 .5702 Metetra
.897 .401 0 r
.42743 .5702 .43908 .58139 .45914 .57465 .44759 .56338 Metetra
.895 .409 0 r
.44759 .56338 .45914 .57465 .47934 .56803 .46788 .55667 Metetra
.893 .414 0 r
.46788 .55667 .47934 .56803 .49968 .56152 .48832 .55007 Metetra
.892 .418 0 r
.48832 .55007 .49968 .56152 .52017 .55512 .50891 .54359 Metetra
.891 .419 0 r
.50891 .54359 .52017 .55512 .54081 .54883 .52965 .53721 Metetra
.892 .419 0 r
.52965 .53721 .54081 .54883 .56161 .54266 .55056 .53095 Metetra
.892 .417 0 r
.55056 .53095 .56161 .54266 .58257 .53659 .57162 .52479 Metetra
.894 .412 0 r
.57162 .52479 .58257 .53659 .60369 .53064 .59285 .51875 Metetra
.895 .406 0 r
.59285 .51875 .60369 .53064 .62499 .5248 .61426 .51282 Metetra
.898 .397 0 r
.61426 .51282 .62499 .5248 .64647 .51908 .63584 .50702 Metetra
.901 .386 0 r
.63584 .50702 .64647 .51908 .66812 .51349 .65761 .50134 Metetra
.905 .373 0 r
.65761 .50134 .66812 .51349 .68997 .50804 .67956 .49579 Metetra
.909 .357 0 r
.67956 .49579 .68997 .50804 .71201 .50272 .70172 .49038 Metetra
.915 .339 0 r
.70172 .49038 .71201 .50272 .73425 .49755 .72408 .48513 Metetra
.92 .317 0 r
.72408 .48513 .73425 .49755 .7567 .49256 .74665 .48004 Metetra
.927 .293 0 r
.74665 .48004 .7567 .49256 .77937 .48772 .76943 .47512 Metetra
.934 .266 0 r
.76943 .47512 .77937 .48772 .80224 .48282 .79243 .47012 Metetra
.937 .257 0 r
.79243 .47012 .80224 .48282 .82509 .47542 .81541 .46261 Metetra
.909 .36 0 r
.81541 .46261 .82509 .47542 .8467 .45353 .83719 .44056 Metetra
.785 .73 0 r
.83719 .44056 .8467 .45353 .86435 .39433 .85508 .38106 Metetra
.331 .655 0 r
.21182 .52595 .22415 .53684 .23616 .60306 .22359 .59245 Metetra
.858 .528 0 r
.22359 .59245 .23616 .60306 .25227 .62865 .23964 .61817 Metetra
.929 .286 0 r
.23964 .61817 .25227 .62865 .27074 .62862 .25816 .6181 Metetra
.937 .254 0 r
.25816 .6181 .27074 .62862 .28987 .62165 .27738 .61105 Metetra
.931 .277 0 r
.27738 .61105 .28987 .62165 .30917 .6139 .29678 .60321 Metetra
.924 .303 0 r
.29678 .60321 .30917 .6139 .32859 .60625 .31629 .59548 Metetra
.918 .326 0 r
.31629 .59548 .32859 .60625 .34811 .59877 .33591 .5879 Metetra
.913 .346 0 r
.33591 .5879 .34811 .59877 .36776 .59143 .35565 .58047 Metetra
.908 .363 0 r
.35565 .58047 .36776 .59143 .38752 .58423 .37551 .57318 Metetra
.904 .378 0 r
.37551 .57318 .38752 .58423 .40741 .57716 .39549 .56603 Metetra
.9 .39 0 r
.39549 .56603 .40741 .57716 .42743 .5702 .41561 .55898 Metetra
.897 .4 0 r
.41561 .55898 .42743 .5702 .44759 .56338 .43587 .55207 Metetra
.895 .408 0 r
.43587 .55207 .44759 .56338 .46788 .55667 .45626 .54527 Metetra
.893 .413 0 r
.45626 .54527 .46788 .55667 .48832 .55007 .4768 .53858 Metetra
.892 .417 0 r
.4768 .53858 .48832 .55007 .50891 .54359 .49749 .53201 Metetra
.892 .418 0 r
.49749 .53201 .50891 .54359 .52965 .53721 .51834 .52554 Metetra
.892 .418 0 r
.51834 .52554 .52965 .53721 .55056 .53095 .53935 .51919 Metetra
.893 .415 0 r
.53935 .51919 .55056 .53095 .57162 .52479 .56052 .51295 Metetra
.894 .411 0 r
.56052 .51295 .57162 .52479 .59285 .51875 .58186 .50681 Metetra
.896 .404 0 r
.58186 .50681 .59285 .51875 .61426 .51282 .60337 .5008 Metetra
.898 .396 0 r
.60337 .5008 .61426 .51282 .63584 .50702 .62506 .4949 Metetra
.902 .385 0 r
.62506 .4949 .63584 .50702 .65761 .50134 .64694 .48913 Metetra
.905 .372 0 r
.64694 .48913 .65761 .50134 .67956 .49579 .66902 .4835 Metetra
.91 .356 0 r
.66902 .4835 .67956 .49579 .70172 .49038 .69129 .478 Metetra
.915 .337 0 r
.69129 .478 .70172 .49038 .72408 .48513 .71376 .47265 Metetra
.921 .316 0 r
.71376 .47265 .72408 .48513 .74665 .48004 .73645 .46748 Metetra
.928 .291 0 r
.73645 .46748 .74665 .48004 .76943 .47512 .75936 .46246 Metetra
.935 .265 0 r
.75936 .46246 .76943 .47512 .79243 .47012 .78248 .45738 Metetra
.937 .255 0 r
.78248 .45738 .79243 .47012 .81541 .46261 .8056 .44975 Metetra
.909 .358 0 r
.8056 .44975 .81541 .46261 .83719 .44056 .82754 .42749 Metetra
.786 .73 0 r
.82754 .42749 .83719 .44056 .85508 .38106 .84567 .36759 Metetra
.331 .655 0 r
.19934 .51488 .21182 .52595 .22359 .59245 .21085 .58175 Metetra
.858 .527 0 r
.21085 .58175 .22359 .59245 .23964 .61817 .22683 .60766 Metetra
.93 .283 0 r
.22683 .60766 .23964 .61817 .25816 .6181 .2454 .60758 Metetra
.938 .251 0 r
.2454 .60758 .25816 .6181 .27738 .61105 .26471 .60045 Metetra
.932 .273 0 r
.26471 .60045 .27738 .61105 .29678 .60321 .28421 .59251 Metetra
.925 .299 0 r
.28421 .59251 .29678 .60321 .31629 .59548 .30381 .58468 Metetra
.919 .323 0 r
.30381 .58468 .31629 .59548 .33591 .5879 .32353 .57701 Metetra
.913 .343 0 r
.32353 .57701 .33591 .5879 .35565 .58047 .34336 .56949 Metetra
.909 .36 0 r
.34336 .56949 .35565 .58047 .37551 .57318 .36332 .56211 Metetra
.904 .375 0 r
.36332 .56211 .37551 .57318 .39549 .56603 .3834 .55486 Metetra
.901 .387 0 r
.3834 .55486 .39549 .56603 .41561 .55898 .40362 .54772 Metetra
.898 .397 0 r
.40362 .54772 .41561 .55898 .43587 .55207 .42398 .54072 Metetra
.896 .405 0 r
.42398 .54072 .43587 .55207 .45626 .54527 .44447 .53383 Metetra
.894 .411 0 r
.44447 .53383 .45626 .54527 .4768 .53858 .46512 .52705 Metetra
.893 .414 0 r
.46512 .52705 .4768 .53858 .49749 .53201 .48591 .52038 Metetra
.893 .416 0 r
.48591 .52038 .49749 .53201 .51834 .52554 .50686 .51383 Metetra
.893 .415 0 r
.50686 .51383 .51834 .52554 .53935 .51919 .52798 .50738 Metetra
.893 .413 0 r
.52798 .50738 .53935 .51919 .56052 .51295 .54925 .50105 Metetra
.895 .408 0 r
.54925 .50105 .56052 .51295 .58186 .50681 .5707 .49483 Metetra
.897 .402 0 r
.5707 .49483 .58186 .50681 .60337 .5008 .59233 .48872 Metetra
.899 .393 0 r
.59233 .48872 .60337 .5008 .62506 .4949 .61414 .48274 Metetra
.902 .382 0 r
.61414 .48274 .62506 .4949 .64694 .48913 .63613 .47688 Metetra
.906 .369 0 r
.63613 .47688 .64694 .48913 .66902 .4835 .65832 .47115 Metetra
.911 .353 0 r
.65832 .47115 .66902 .4835 .69129 .478 .68071 .46556 Metetra
.916 .334 0 r
.68071 .46556 .69129 .478 .71376 .47265 .70331 .46013 Metetra
.922 .313 0 r
.70331 .46013 .71376 .47265 .73645 .46748 .72612 .45486 Metetra
.928 .288 0 r
.72612 .45486 .73645 .46748 .75936 .46246 .74915 .44976 Metetra
.935 .262 0 r
.74915 .44976 .75936 .46246 .78248 .45738 .7724 .44459 Metetra
.938 .252 0 r
.7724 .44459 .78248 .45738 .8056 .44975 .79565 .43684 Metetra
.91 .356 0 r
.79565 .43684 .8056 .44975 .82754 .42749 .81776 .41432 Metetra
.786 .729 0 r
.81776 .41432 .82754 .42749 .84567 .36759 .83612 .35393 Metetra
.33 .655 0 r
.1867 .50361 .19934 .51488 .21085 .58175 .19794 .57094 Metetra
.859 .524 0 r
.19794 .57094 .21085 .58175 .22683 .60766 .21383 .59712 Metetra
.931 .278 0 r
.21383 .59712 .22683 .60766 .2454 .60758 .23246 .59706 Metetra
.94 .245 0 r
.23246 .59706 .2454 .60758 .26471 .60045 .25186 .58984 Metetra
.934 .268 0 r
.25186 .58984 .26471 .60045 .28421 .59251 .27145 .5818 Metetra
.927 .294 0 r
.27145 .5818 .28421 .59251 .30381 .58468 .29115 .57387 Metetra
.92 .318 0 r
.29115 .57387 .30381 .58468 .32353 .57701 .31097 .5661 Metetra
.915 .338 0 r
.31097 .5661 .32353 .57701 .34336 .56949 .3309 .55848 Metetra
.91 .356 0 r
.3309 .55848 .34336 .56949 .36332 .56211 .35095 .55101 Metetra
.906 .37 0 r
.35095 .55101 .36332 .56211 .3834 .55486 .37114 .54366 Metetra
.902 .383 0 r
.37114 .54366 .3834 .55486 .40362 .54772 .39146 .53643 Metetra
.899 .393 0 r
.39146 .53643 .40362 .54772 .42398 .54072 .41192 .52933 Metetra
.897 .401 0 r
.41192 .52933 .42398 .54072 .44447 .53383 .43251 .52234 Metetra
.895 .406 0 r
.43251 .52234 .44447 .53383 .46512 .52705 .45326 .51547 Metetra
.894 .41 0 r
.45326 .51547 .46512 .52705 .48591 .52038 .47416 .50871 Metetra
.894 .412 0 r
.47416 .50871 .48591 .52038 .50686 .51383 .49522 .50206 Metetra
.894 .411 0 r
.49522 .50206 .50686 .51383 .52798 .50738 .51644 .49553 Metetra
.895 .409 0 r
.51644 .49553 .52798 .50738 .54925 .50105 .53783 .4891 Metetra
.896 .404 0 r
.53783 .4891 .54925 .50105 .5707 .49483 .55939 .48279 Metetra
.898 .397 0 r
.55939 .48279 .5707 .49483 .59233 .48872 .58113 .47659 Metetra
.9 .389 0 r
.58113 .47659 .59233 .48872 .61414 .48274 .60305 .47051 Metetra
.904 .378 0 r
.60305 .47051 .61414 .48274 .63613 .47688 .62516 .46456 Metetra
.907 .364 0 r
.62516 .46456 .63613 .47688 .65832 .47115 .64747 .45875 Metetra
.912 .348 0 r
.64747 .45875 .65832 .47115 .68071 .46556 .66998 .45307 Metetra
.917 .329 0 r
.66998 .45307 .68071 .46556 .70331 .46013 .6927 .44755 Metetra
.923 .308 0 r
.6927 .44755 .70331 .46013 .72612 .45486 .71564 .4422 Metetra
.93 .283 0 r
.71564 .4422 .72612 .45486 .74915 .44976 .7388 .43701 Metetra
.937 .256 0 r
.7388 .43701 .74915 .44976 .7724 .44459 .76217 .43175 Metetra
.939 .247 0 r
.76217 .43175 .7724 .44459 .79565 .43684 .78557 .42387 Metetra
.911 .352 0 r
.78557 .42387 .79565 .43684 .81776 .41432 .80783 .40104 Metetra
.786 .728 0 r
.80783 .40104 .81776 .41432 .83612 .35393 .82643 .34006 Metetra
.33 .655 0 r
.1739 .49214 .1867 .50361 .19794 .57094 .18484 .56003 Metetra
.86 .521 0 r
.18484 .56003 .19794 .57094 .21383 .59712 .20064 .58656 Metetra
.933 .272 0 r
.20064 .58656 .21383 .59712 .23246 .59706 .21932 .58653 Metetra
.942 .238 0 r
.21932 .58653 .23246 .59706 .25186 .58984 .23881 .57923 Metetra
.936 .261 0 r
.23881 .57923 .25186 .58984 .27145 .5818 .2585 .57108 Metetra
.929 .287 0 r
.2585 .57108 .27145 .5818 .29115 .57387 .2783 .56305 Metetra
.922 .311 0 r
.2783 .56305 .29115 .57387 .31097 .5661 .29822 .55517 Metetra
.917 .332 0 r
.29822 .55517 .31097 .5661 .3309 .55848 .31825 .54745 Metetra
.912 .349 0 r
.31825 .54745 .3309 .55848 .35095 .55101 .33841 .53987 Metetra
.907 .364 0 r
.33841 .53987 .35095 .55101 .37114 .54366 .35869 .53242 Metetra
.904 .377 0 r
.35869 .53242 .37114 .54366 .39146 .53643 .37911 .52509 Metetra
.901 .387 0 r
.37911 .52509 .39146 .53643 .41192 .52933 .39967 .5179 Metetra
.899 .395 0 r
.39967 .5179 .41192 .52933 .43251 .52234 .42038 .51082 Metetra
.897 .401 0 r
.42038 .51082 .43251 .52234 .45326 .51547 .44123 .50385 Metetra
.896 .404 0 r
.44123 .50385 .45326 .51547 .47416 .50871 .46224 .49699 Metetra
.895 .406 0 r
.46224 .49699 .47416 .50871 .49522 .50206 .48341 .49025 Metetra
.896 .405 0 r
.48341 .49025 .49522 .50206 .51644 .49553 .50474 .48362 Metetra
.896 .403 0 r
.50474 .48362 .51644 .49553 .53783 .4891 .52624 .4771 Metetra
.898 .398 0 r
.52624 .4771 .53783 .4891 .55939 .48279 .54791 .47069 Metetra
.9 .392 0 r
.54791 .47069 .55939 .48279 .58113 .47659 .56976 .46441 Metetra
.902 .383 0 r
.56976 .46441 .58113 .47659 .60305 .47051 .5918 .45824 Metetra
.905 .372 0 r
.5918 .45824 .60305 .47051 .62516 .46456 .61403 .4522 Metetra
.909 .358 0 r
.61403 .4522 .62516 .46456 .64747 .45875 .63646 .44629 Metetra
.914 .342 0 r
.63646 .44629 .64747 .45875 .66998 .45307 .65909 .44053 Metetra
.919 .323 0 r
.65909 .44053 .66998 .45307 .6927 .44755 .68194 .43492 Metetra
.925 .301 0 r
.68194 .43492 .6927 .44755 .71564 .4422 .705 .42949 Metetra
.932 .276 0 r
.705 .42949 .71564 .4422 .7388 .43701 .72829 .42422 Metetra
.939 .249 0 r
.72829 .42422 .7388 .43701 .76217 .43175 .7518 .41886 Metetra
.941 .239 0 r
.7518 .41886 .76217 .43175 .78557 .42387 .77533 .41084 Metetra
.912 .346 0 r
.77533 .41084 .78557 .42387 .80783 .40104 .79776 .38766 Metetra
.787 .727 0 r
.79776 .38766 .80783 .40104 .82643 .34006 .81659 .32598 Metetra
.33 .655 0 r
.16094 .48046 .1739 .49214 .18484 .56003 .17156 .549 Metetra
.862 .516 0 r
.17156 .549 .18484 .56003 .20064 .58656 .18726 .57596 Metetra
.935 .263 0 r
.18726 .57596 .20064 .58656 .21932 .58653 .20598 .576 Metetra
.944 .228 0 r
.20598 .576 .21932 .58653 .23881 .57923 .22557 .56861 Metetra
.938 .251 0 r
.22557 .56861 .23881 .57923 .2585 .57108 .24536 .56036 Metetra
.931 .278 0 r
.24536 .56036 .2585 .57108 .2783 .56305 .26526 .55222 Metetra
.925 .302 0 r
.26526 .55222 .2783 .56305 .29822 .55517 .28527 .54424 Metetra
.919 .323 0 r
.28527 .54424 .29822 .55517 .31825 .54745 .30541 .53641 Metetra
.914 .341 0 r
.30541 .53641 .31825 .54745 .33841 .53987 .32567 .52872 Metetra
.91 .356 0 r
.32567 .52872 .33841 .53987 .35869 .53242 .34606 .52117 Metetra
.906 .369 0 r
.34606 .52117 .35869 .53242 .37911 .52509 .36659 .51374 Metetra
.903 .379 0 r
.36659 .51374 .37911 .52509 .39967 .5179 .38725 .50644 Metetra
.901 .387 0 r
.38725 .50644 .39967 .5179 .42038 .51082 .40806 .49926 Metetra
.899 .393 0 r
.40806 .49926 .42038 .51082 .44123 .50385 .42902 .49219 Metetra
.898 .397 0 r
.42902 .49219 .44123 .50385 .46224 .49699 .45014 .48524 Metetra
.898 .399 0 r
.45014 .48524 .46224 .49699 .48341 .49025 .47141 .4784 Metetra
.898 .398 0 r
.47141 .4784 .48341 .49025 .50474 .48362 .49286 .47167 Metetra
.898 .396 0 r
.49286 .47167 .50474 .48362 .52624 .4771 .51447 .46506 Metetra
.9 .391 0 r
.51447 .46506 .52624 .4771 .54791 .47069 .53626 .45856 Metetra
.902 .384 0 r
.53626 .45856 .54791 .47069 .56976 .46441 .55823 .45218 Metetra
.904 .375 0 r
.55823 .45218 .56976 .46441 .5918 .45824 .58038 .44592 Metetra
.908 .364 0 r
.58038 .44592 .5918 .45824 .61403 .4522 .60273 .4398 Metetra
.911 .35 0 r
.60273 .4398 .61403 .4522 .63646 .44629 .62529 .4338 Metetra
.916 .334 0 r
.62529 .4338 .63646 .44629 .65909 .44053 .64804 .42795 Metetra
.921 .314 0 r
.64804 .42795 .65909 .44053 .68194 .43492 .67101 .42226 Metetra
.927 .292 0 r
.67101 .42226 .68194 .43492 .705 .42949 .69421 .41674 Metetra
.934 .266 0 r
.69421 .41674 .705 .42949 .72829 .42422 .71763 .41137 Metetra
.941 .239 0 r
.71763 .41137 .72829 .42422 .7518 .41886 .74128 .40593 Metetra
.944 .23 0 r
.74128 .40593 .7518 .41886 .77533 .41084 .76495 .39776 Metetra
.915 .339 0 r
.76495 .39776 .77533 .41084 .79776 .38766 .78755 .37415 Metetra
.788 .725 0 r
.78755 .37415 .79776 .38766 .81659 .32598 .80661 .31167 Metetra
.33 .655 0 r
.14782 .46858 .16094 .48046 .17156 .549 .15809 .53787 Metetra
.864 .511 0 r
.15809 .53787 .17156 .549 .18726 .57596 .17366 .56534 Metetra
.938 .252 0 r
.17366 .56534 .18726 .57596 .20598 .576 .19243 .56547 Metetra
.947 .217 0 r
.19243 .56547 .20598 .576 .22557 .56861 .21212 .55799 Metetra
.941 .24 0 r
.21212 .55799 .22557 .56861 .24536 .56036 .23201 .54963 Metetra
.934 .267 0 r
.23201 .54963 .24536 .56036 .26526 .55222 .25201 .54137 Metetra
.927 .292 0 r
.25201 .54137 .26526 .55222 .28527 .54424 .27213 .53328 Metetra
.922 .313 0 r
.27213 .53328 .28527 .54424 .30541 .53641 .29237 .52534 Metetra
.917 .331 0 r
.29237 .52534 .30541 .53641 .32567 .52872 .31274 .51754 Metetra
.912 .347 0 r
.31274 .51754 .32567 .52872 .34606 .52117 .33323 .50988 Metetra
.909 .36 0 r
.33323 .50988 .34606 .52117 .36659 .51374 .35386 .50234 Metetra
.906 .37 0 r
.35386 .50234 .36659 .51374 .38725 .50644 .37464 .49494 Metetra
.903 .378 0 r
.37464 .49494 .38725 .50644 .40806 .49926 .39556 .48766 Metetra
.902 .384 0 r
.39556 .48766 .40806 .49926 .42902 .49219 .41663 .48049 Metetra
.901 .388 0 r
.41663 .48049 .42902 .49219 .45014 .48524 .43785 .47344 Metetra
.9 .39 0 r
.43785 .47344 .45014 .48524 .47141 .4784 .45924 .4665 Metetra
.9 .389 0 r
.45924 .4665 .47141 .4784 .49286 .47167 .4808 .45967 Metetra
.901 .386 0 r
.4808 .45967 .49286 .47167 .51447 .46506 .50252 .45296 Metetra
.902 .382 0 r
.50252 .45296 .51447 .46506 .53626 .45856 .52443 .44637 Metetra
.904 .375 0 r
.52443 .44637 .53626 .45856 .55823 .45218 .54652 .4399 Metetra
.907 .366 0 r
.54652 .4399 .55823 .45218 .58038 .44592 .56879 .43355 Metetra
.91 .354 0 r
.56879 .43355 .58038 .44592 .60273 .4398 .59127 .42733 Metetra
.914 .34 0 r
.59127 .42733 .60273 .4398 .62529 .4338 .61394 .42125 Metetra
.919 .323 0 r
.61394 .42125 .62529 .4338 .64804 .42795 .63683 .41531 Metetra
.924 .304 0 r
.63683 .41531 .64804 .42795 .67101 .42226 .65993 .40954 Metetra
.93 .281 0 r
.65993 .40954 .67101 .42226 .69421 .41674 .68325 .40393 Metetra
.937 .255 0 r
.68325 .40393 .69421 .41674 .71763 .41137 .70681 .39849 Metetra
.944 .228 0 r
.70681 .39849 .71763 .41137 .74128 .40593 .7306 .39296 Metetra
.947 .218 0 r
.7306 .39296 .74128 .40593 .76495 .39776 .75441 .38462 Metetra
.917 .33 0 r
.75441 .38462 .76495 .39776 .78755 .37415 .77718 .36055 Metetra
.789 .722 0 r
.77718 .36055 .78755 .37415 .80661 .31167 .79647 .29715 Metetra
.329 .655 0 r
.13452 .45648 .14782 .46858 .15809 .53787 .14443 .52663 Metetra
.866 .504 0 r
.14443 .52663 .15809 .53787 .17366 .56534 .15986 .55471 Metetra
.941 .24 0 r
.15986 .55471 .17366 .56534 .19243 .56547 .17867 .55496 Metetra
.951 .202 0 r
.17867 .55496 .19243 .56547 .21212 .55799 .19845 .54739 Metetra
.945 .226 0 r
.19845 .54739 .21212 .55799 .23201 .54963 .21845 .5389 Metetra
.938 .254 0 r
.21845 .5389 .23201 .54963 .25201 .54137 .23856 .53052 Metetra
.931 .279 0 r
.23856 .53052 .25201 .54137 .27213 .53328 .25879 .5223 Metetra
.925 .3 0 r
.25879 .5223 .27213 .53328 .29237 .52534 .27913 .51425 Metetra
.92 .319 0 r
.27913 .51425 .29237 .52534 .31274 .51754 .2996 .50634 Metetra
.916 .335 0 r
.2996 .50634 .31274 .51754 .33323 .50988 .32021 .49857 Metetra
.912 .348 0 r
.32021 .49857 .33323 .50988 .35386 .50234 .34095 .49092 Metetra
.909 .359 0 r
.34095 .49092 .35386 .50234 .37464 .49494 .36183 .48341 Metetra
.907 .367 0 r
.36183 .48341 .37464 .49494 .39556 .48766 .38286 .47602 Metetra
.905 .373 0 r
.38286 .47602 .39556 .48766 .41663 .48049 .40404 .46875 Metetra
.904 .377 0 r
.40404 .46875 .41663 .48049 .43785 .47344 .42538 .46159 Metetra
.903 .379 0 r
.42538 .46159 .43785 .47344 .45924 .4665 .44688 .45455 Metetra
.903 .378 0 r
.44688 .45455 .45924 .4665 .4808 .45967 .46855 .44763 Metetra
.904 .376 0 r
.46855 .44763 .4808 .45967 .50252 .45296 .49039 .44082 Metetra
.905 .371 0 r
.49039 .44082 .50252 .45296 .52443 .44637 .51242 .43413 Metetra
.907 .364 0 r
.51242 .43413 .52443 .44637 .54652 .4399 .53463 .42757 Metetra
.91 .354 0 r
.53463 .42757 .54652 .4399 .56879 .43355 .55703 .42113 Metetra
.913 .343 0 r
.55703 .42113 .56879 .43355 .59127 .42733 .57962 .41482 Metetra
.917 .328 0 r
.57962 .41482 .59127 .42733 .61394 .42125 .60243 .40865 Metetra
.922 .311 0 r
.60243 .40865 .61394 .42125 .63683 .41531 .62544 .40263 Metetra
.928 .291 0 r
.62544 .40263 .63683 .41531 .65993 .40954 .64867 .39678 Metetra
.934 .268 0 r
.64867 .39678 .65993 .40954 .68325 .40393 .67213 .39109 Metetra
.941 .242 0 r
.67213 .39109 .68325 .40393 .70681 .39849 .69583 .38557 Metetra
.948 .213 0 r
.69583 .38557 .70681 .39849 .7306 .39296 .71975 .37995 Metetra
.95 .204 0 r
.71975 .37995 .7306 .39296 .75441 .38462 .74372 .37144 Metetra
.92 .319 0 r
.74372 .37144 .75441 .38462 .77718 .36055 .76665 .34684 Metetra
.79 .719 0 r
.76665 .34684 .77718 .36055 .79647 .29715 .78617 .2824 Metetra
.329 .654 0 r
.12107 .44416 .13452 .45648 .14443 .52663 .13057 .51528 Metetra
.868 .496 0 r
.13057 .51528 .14443 .52663 .15986 .55471 .14584 .54407 Metetra
.945 .225 0 r
.14584 .54407 .15986 .55471 .17867 .55496 .16469 .54446 Metetra
.955 .186 0 r
.16469 .54446 .17867 .55496 .19845 .54739 .18457 .5368 Metetra
.949 .209 0 r
.18457 .5368 .19845 .54739 .21845 .5389 .20467 .52818 Metetra
.942 .238 0 r
.20467 .52818 .21845 .5389 .23856 .53052 .22489 .51967 Metetra
.935 .264 0 r
.22489 .51967 .23856 .53052 .25879 .5223 .24523 .51133 Metetra
.929 .286 0 r
.24523 .51133 .25879 .5223 .27913 .51425 .26568 .50315 Metetra
.924 .305 0 r
.26568 .50315 .27913 .51425 .2996 .50634 .28626 .49512 Metetra
.919 .321 0 r
.28626 .49512 .2996 .50634 .32021 .49857 .30697 .48723 Metetra
.916 .335 0 r
.30697 .48723 .32021 .49857 .34095 .49092 .32782 .47947 Metetra
.913 .346 0 r
.32782 .47947 .34095 .49092 .36183 .48341 .34882 .47184 Metetra
.91 .354 0 r
.34882 .47184 .36183 .48341 .38286 .47602 .36996 .46435 Metetra
.908 .361 0 r
.36996 .46435 .38286 .47602 .40404 .46875 .39125 .45697 Metetra
.907 .364 0 r
.39125 .45697 .40404 .46875 .42538 .46159 .41271 .44971 Metetra
.907 .366 0 r
.41271 .44971 .42538 .46159 .44688 .45455 .43432 .44257 Metetra
.907 .366 0 r
.43432 .44257 .44688 .45455 .46855 .44763 .45611 .43554 Metetra
.908 .363 0 r
.45611 .43554 .46855 .44763 .49039 .44082 .47807 .42864 Metetra
.909 .358 0 r
.47807 .42864 .49039 .44082 .51242 .43413 .50022 .42185 Metetra
.911 .351 0 r
.50022 .42185 .51242 .43413 .53463 .42757 .52255 .41519 Metetra
.914 .341 0 r
.52255 .41519 .53463 .42757 .55703 .42113 .54507 .40866 Metetra
.917 .329 0 r
.54507 .40866 .55703 .42113 .57962 .41482 .5678 .40226 Metetra
.921 .314 0 r
.5678 .40226 .57962 .41482 .60243 .40865 .59073 .39601 Metetra
.926 .297 0 r
.59073 .39601 .60243 .40865 .62544 .40263 .61388 .38991 Metetra
.931 .277 0 r
.61388 .38991 .62544 .40263 .64867 .39678 .63724 .38397 Metetra
.938 .253 0 r
.63724 .38397 .64867 .39678 .67213 .39109 .66084 .37821 Metetra
.945 .226 0 r
.66084 .37821 .67213 .39109 .69583 .38557 .68468 .37261 Metetra
.952 .197 0 r
.68468 .37261 .69583 .38557 .71975 .37995 .70875 .36692 Metetra
.955 .188 0 r
.70875 .36692 .71975 .37995 .74372 .37144 .73286 .35822 Metetra
.923 .307 0 r
.73286 .35822 .74372 .37144 .76665 .34684 .75596 .33301 Metetra
.791 .716 0 r
.75596 .33301 .76665 .34684 .78617 .2824 .77572 .26741 Metetra
.328 .654 0 r
.10744 .43161 .12107 .44416 .13057 .51528 .11652 .50381 Metetra
.871 .487 0 r
.11652 .50381 .13057 .51528 .14584 .54407 .1316 .53341 Metetra
.95 .207 0 r
.1316 .53341 .14584 .54407 .16469 .54446 .15047 .53399 Metetra
.96 .166 0 r
.15047 .53399 .16469 .54446 .18457 .5368 .17045 .52623 Metetra
.954 .19 0 r
.17045 .52623 .18457 .5368 .20467 .52818 .19067 .51747 Metetra
.946 .22 0 r
.19067 .51747 .20467 .52818 .22489 .51967 .211 .50882 Metetra
.939 .246 0 r
.211 .50882 .22489 .51967 .24523 .51133 .23145 .50035 Metetra
.933 .269 0 r
.23145 .50035 .24523 .51133 .26568 .50315 .25201 .49204 Metetra
.928 .289 0 r
.25201 .49204 .26568 .50315 .28626 .49512 .27271 .48389 Metetra
.924 .305 0 r
.27271 .48389 .28626 .49512 .30697 .48723 .29353 .47588 Metetra
.92 .319 0 r
.29353 .47588 .30697 .48723 .32782 .47947 .31449 .468 Metetra
.917 .331 0 r
.31449 .468 .32782 .47947 .34882 .47184 .3356 .46026 Metetra
.914 .339 0 r
.3356 .46026 .34882 .47184 .36996 .46435 .35685 .45265 Metetra
.913 .346 0 r
.35685 .45265 .36996 .46435 .39125 .45697 .37826 .44516 Metetra
.911 .35 0 r
.37826 .44516 .39125 .45697 .41271 .44971 .39983 .4378 Metetra
.911 .351 0 r
.39983 .4378 .41271 .44971 .43432 .44257 .42157 .43055 Metetra
.911 .351 0 r
.42157 .43055 .43432 .44257 .45611 .43554 .44347 .42342 Metetra
.912 .348 0 r
.44347 .42342 .45611 .43554 .47807 .42864 .46556 .41642 Metetra
.913 .343 0 r
.46556 .41642 .47807 .42864 .50022 .42185 .48782 .40954 Metetra
.915 .336 0 r
.48782 .40954 .50022 .42185 .52255 .41519 .51028 .40278 Metetra
.918 .326 0 r
.51028 .40278 .52255 .41519 .54507 .40866 .53293 .39616 Metetra
.921 .313 0 r
.53293 .39616 .54507 .40866 .5678 .40226 .55579 .38967 Metetra
.926 .298 0 r
.55579 .38967 .5678 .40226 .59073 .39601 .57885 .38333 Metetra
.93 .28 0 r
.57885 .38333 .59073 .39601 .61388 .38991 .60213 .37715 Metetra
.936 .259 0 r
.60213 .37715 .61388 .38991 .63724 .38397 .62563 .37113 Metetra
.942 .235 0 r
.62563 .37113 .63724 .38397 .66084 .37821 .64937 .36529 Metetra
.95 .207 0 r
.64937 .36529 .66084 .37821 .68468 .37261 .67335 .35963 Metetra
.957 .178 0 r
.67335 .35963 .68468 .37261 .70875 .36692 .69756 .35386 Metetra
.959 .169 0 r
.69756 .35386 .70875 .36692 .73286 .35822 .72183 .34496 Metetra
.927 .292 0 r
.72183 .34496 .73286 .35822 .75596 .33301 .7451 .31908 Metetra
.793 .712 0 r
.7451 .31908 .75596 .33301 .77572 .26741 .7651 .25218 Metetra
.327 .654 0 r
.09363 .41881 .10744 .43161 .11652 .50381 .10225 .49223 Metetra
.874 .477 0 r
.10225 .49223 .11652 .50381 .1316 .53341 .11713 .52275 Metetra
.955 .187 0 r
.11713 .52275 .1316 .53341 .15047 .53399 .13602 .52355 Metetra
.966 .144 0 r
.13602 .52355 .15047 .53399 .17045 .52623 .1561 .5157 Metetra
.959 .169 0 r
.1561 .5157 .17045 .52623 .19067 .51747 .17643 .5068 Metetra
.952 .199 0 r
.17643 .5068 .19067 .51747 .211 .50882 .19688 .498 Metetra
.945 .226 0 r
.19688 .498 .211 .50882 .23145 .50035 .21744 .48939 Metetra
.939 .25 0 r
.21744 .48939 .23145 .50035 .25201 .49204 .23812 .48095 Metetra
.933 .27 0 r
.23812 .48095 .25201 .49204 .27271 .48389 .25893 .47266 Metetra
.929 .287 0 r
.25893 .47266 .27271 .48389 .29353 .47588 .27986 .46453 Metetra
.925 .301 0 r
.27986 .46453 .29353 .47588 .31449 .468 .30094 .45652 Metetra
.922 .313 0 r
.30094 .45652 .31449 .468 .3356 .46026 .32216 .44867 Metetra
.919 .322 0 r
.32216 .44867 .3356 .46026 .35685 .45265 .34353 .44094 Metetra
.917 .329 0 r
.34353 .44094 .35685 .45265 .37826 .44516 .36506 .43334 Metetra
.916 .333 0 r
.36506 .43334 .37826 .44516 .39983 .4378 .38675 .42586 Metetra
.916 .335 0 r
.38675 .42586 .39983 .4378 .42157 .43055 .4086 .41851 Metetra
.916 .334 0 r
.4086 .41851 .42157 .43055 .44347 .42342 .43063 .41128 Metetra
.917 .331 0 r
.43063 .41128 .44347 .42342 .46556 .41642 .45284 .40417 Metetra
.918 .326 0 r
.45284 .40417 .46556 .41642 .48782 .40954 .47523 .39719 Metetra
.92 .318 0 r
.47523 .39719 .48782 .40954 .51028 .40278 .49781 .39034 Metetra
.923 .308 0 r
.49781 .39034 .51028 .40278 .53293 .39616 .52059 .38362 Metetra
.926 .295 0 r
.52059 .38362 .53293 .39616 .55579 .38967 .54358 .37705 Metetra
.931 .28 0 r
.54358 .37705 .55579 .38967 .57885 .38333 .56677 .37063 Metetra
.936 .261 0 r
.56677 .37063 .57885 .38333 .60213 .37715 .59019 .36437 Metetra
.941 .24 0 r
.59019 .36437 .60213 .37715 .62563 .37113 .61383 .35827 Metetra
.948 .215 0 r
.61383 .35827 .62563 .37113 .64937 .36529 .63771 .35236 Metetra
.955 .186 0 r
.63771 .35236 .64937 .36529 .67335 .35963 .66184 .34663 Metetra
.963 .155 0 r
.66184 .34663 .67335 .35963 .69756 .35386 .6862 .34078 Metetra
.965 .147 0 r
.6862 .34078 .69756 .35386 .72183 .34496 .71063 .33167 Metetra
.932 .276 0 r
.71063 .33167 .72183 .34496 .7451 .31908 .73408 .30503 Metetra
.794 .708 0 r
.73408 .30503 .7451 .31908 .7651 .25218 .75432 .23668 Metetra
.325 .653 0 r
.07968 .40564 .09363 .41881 .10225 .49223 .0878 .48032 Metetra
.877 .467 0 r
.0878 .48032 .10225 .49223 .11713 .52275 .10244 .51189 Metetra
.96 .166 0 r
.10244 .51189 .11713 .52275 .13602 .52355 .12134 .51298 Metetra
.972 .119 0 r
.12134 .51298 .13602 .52355 .1561 .5157 .14153 .50506 Metetra
.965 .145 0 r
.14153 .50506 .1561 .5157 .17643 .5068 .16197 .49602 Metetra
.958 .176 0 r
.16197 .49602 .17643 .5068 .19688 .498 .18253 .48709 Metetra
.95 .204 0 r
.18253 .48709 .19688 .498 .21744 .48939 .20321 .47834 Metetra
.944 .228 0 r
.20321 .47834 .21744 .48939 .23812 .48095 .224 .46977 Metetra
.939 .249 0 r
.224 .46977 .23812 .48095 .25893 .47266 .24492 .46135 Metetra
.934 .267 0 r
.24492 .46135 .25893 .47266 .27986 .46453 .26597 .45309 Metetra
.93 .282 0 r
.26597 .45309 .27986 .46453 .30094 .45652 .28717 .44497 Metetra
.927 .294 0 r
.28717 .44497 .30094 .45652 .32216 .44867 .30851 .43699 Metetra
.924 .303 0 r
.30851 .43699 .32216 .44867 .34353 .44094 .33 .42915 Metetra
.923 .31 0 r
.33 .42915 .34353 .44094 .36506 .43334 .35164 .42143 Metetra
.921 .314 0 r
.35164 .42143 .36506 .43334 .38675 .42586 .37345 .41384 Metetra
.921 .316 0 r
.37345 .41384 .38675 .42586 .4086 .41851 .39543 .40638 Metetra
.921 .315 0 r
.39543 .40638 .4086 .41851 .43063 .41128 .41758 .39904 Metetra
.922 .312 0 r
.41758 .39904 .43063 .41128 .45284 .40417 .43991 .39183 Metetra
.923 .307 0 r
.43991 .39183 .45284 .40417 .47523 .39719 .46243 .38475 Metetra
.925 .299 0 r
.46243 .38475 .47523 .39719 .49781 .39034 .48514 .3778 Metetra
.928 .289 0 r
.48514 .3778 .49781 .39034 .52059 .38362 .50805 .37099 Metetra
.932 .275 0 r
.50805 .37099 .52059 .38362 .54358 .37705 .53117 .36432 Metetra
.936 .259 0 r
.53117 .36432 .54358 .37705 .56677 .37063 .5545 .35781 Metetra
.941 .24 0 r
.5545 .35781 .56677 .37063 .59019 .36437 .57806 .35146 Metetra
.947 .218 0 r
.57806 .35146 .59019 .36437 .61383 .35827 .60184 .34528 Metetra
.954 .192 0 r
.60184 .34528 .61383 .35827 .63771 .35236 .62586 .33929 Metetra
.961 .162 0 r
.62586 .33929 .63771 .35236 .66184 .34663 .65014 .33348 Metetra
.969 .131 0 r
.65014 .33348 .66184 .34663 .6862 .34078 .67465 .32753 Metetra
.971 .123 0 r
.67465 .32753 .6862 .34078 .71063 .33167 .69923 .31815 Metetra
.936 .258 0 r
.69923 .31815 .71063 .33167 .73408 .30503 .72286 .29066 Metetra
.796 .704 0 r
.72286 .29066 .73408 .30503 .75432 .23668 .74335 .22075 Metetra
.31 .649 0 r
.06575 .3908 .07968 .40564 .0878 .48032 .07341 .46625 Metetra
.876 .47 0 r
.07341 .46625 .0878 .48032 .10244 .51189 .08779 .4988 Metetra
.962 .158 0 r
.08779 .4988 .10244 .51189 .12134 .51298 .10667 .50036 Metetra
.975 .107 0 r
.10667 .50036 .12134 .51298 .14153 .50506 .12692 .49259 Metetra
.969 .131 0 r
.12692 .49259 .14153 .50506 .16197 .49602 .14745 .48359 Metetra
.961 .162 0 r
.14745 .48359 .16197 .49602 .18253 .48709 .1681 .47466 Metetra
.954 .19 0 r
.1681 .47466 .18253 .48709 .20321 .47834 .18887 .4659 Metetra
.948 .214 0 r
.18887 .4659 .20321 .47834 .224 .46977 .20977 .45729 Metetra
.943 .235 0 r
.20977 .45729 .224 .46977 .24492 .46135 .23079 .44883 Metetra
.938 .252 0 r
.23079 .44883 .24492 .46135 .26597 .45309 .25195 .4405 Metetra
.934 .267 0 r
.25195 .4405 .26597 .45309 .28717 .44497 .27325 .4323 Metetra
.931 .279 0 r
.27325 .4323 .28717 .44497 .30851 .43699 .2947 .42424 Metetra
.928 .289 0 r
.2947 .42424 .30851 .43699 .33 .42915 .3163 .41631 Metetra
.926 .295 0 r
.3163 .41631 .33 .42915 .35164 .42143 .33805 .4085 Metetra
.925 .3 0 r
.33805 .4085 .35164 .42143 .37345 .41384 .35998 .4008 Metetra
.925 .301 0 r
.35998 .4008 .37345 .41384 .39543 .40638 .38207 .39323 Metetra
.925 .301 0 r
.38207 .39323 .39543 .40638 .41758 .39904 .40434 .38578 Metetra
.926 .298 0 r
.40434 .38578 .41758 .39904 .43991 .39183 .4268 .37844 Metetra
.927 .293 0 r
.4268 .37844 .43991 .39183 .46243 .38475 .44944 .37123 Metetra
.929 .285 0 r
.44944 .37123 .46243 .38475 .48514 .3778 .47227 .36414 Metetra
.932 .274 0 r
.47227 .36414 .48514 .3778 .50805 .37099 .49531 .35718 Metetra
.936 .261 0 r
.49531 .35718 .50805 .37099 .53117 .36432 .51855 .35036 Metetra
.94 .245 0 r
.51855 .35036 .53117 .36432 .5545 .35781 .54202 .34367 Metetra
.945 .226 0 r
.54202 .34367 .5545 .35781 .57806 .35146 .5657 .33713 Metetra
.951 .204 0 r
.5657 .33713 .57806 .35146 .60184 .34528 .58962 .33075 Metetra
.957 .178 0 r
.58962 .33075 .60184 .34528 .62586 .33929 .61377 .32453 Metetra
.964 .149 0 r
.61377 .32453 .62586 .33929 .65014 .33348 .63817 .31847 Metetra
.972 .118 0 r
.63817 .31847 .65014 .33348 .67465 .32753 .66282 .31221 Metetra
.973 .112 0 r
.66282 .31221 .67465 .32753 .69923 .31815 .68753 .30234 Metetra
.937 .255 0 r
.68753 .30234 .69923 .31815 .72286 .29066 .71132 .27385 Metetra
.793 .71 0 r
.71132 .27385 .72286 .29066 .74335 .22075 .73208 .20265 Metetra
.228 .623 0 r
.05279 .36803 .06575 .3908 .07341 .46625 .06046 .44057 Metetra
.85 .553 0 r
.06046 .44057 .07341 .46625 .08779 .4988 .07468 .47282 Metetra
.938 .253 0 r
.07468 .47282 .08779 .4988 .10667 .50036 .09339 .47528 Metetra
.953 .194 0 r
.09339 .47528 .10667 .50036 .12692 .49259 .11353 .46848 Metetra
.949 .209 0 r
.11353 .46848 .12692 .49259 .14745 .48359 .13398 .46032 Metetra
.943 .231 0 r
.13398 .46032 .14745 .48359 .1681 .47466 .15458 .45209 Metetra
.938 .252 0 r
.15458 .45209 .1681 .47466 .18887 .4659 .17532 .44389 Metetra
.933 .27 0 r
.17532 .44389 .18887 .4659 .20977 .45729 .19621 .43575 Metetra
.929 .286 0 r
.19621 .43575 .20977 .45729 .23079 .44883 .21724 .42765 Metetra
.925 .3 0 r
.21724 .42765 .23079 .44883 .25195 .4405 .23842 .41961 Metetra
.922 .312 0 r
.23842 .41961 .25195 .4405 .27325 .4323 .25975 .41161 Metetra
.919 .322 0 r
.25975 .41161 .27325 .4323 .2947 .42424 .28124 .40368 Metetra
.917 .329 0 r
.28124 .40368 .2947 .42424 .3163 .41631 .3029 .39581 Metetra
.916 .335 0 r
.3029 .39581 .3163 .41631 .33805 .4085 .32471 .388 Metetra
.915 .338 0 r
.32471 .388 .33805 .4085 .35998 .4008 .3467 .38026 Metetra
.914 .34 0 r
.3467 .38026 .35998 .4008 .38207 .39323 .36886 .37257 Metetra
.914 .339 0 r
.36886 .37257 .38207 .39323 .40434 .38578 .39121 .36494 Metetra
.915 .337 0 r
.39121 .36494 .40434 .38578 .4268 .37844 .41373 .35738 Metetra
.916 .332 0 r
.41373 .35738 .4268 .37844 .44944 .37123 .43645 .34988 Metetra
.918 .326 0 r
.43645 .34988 .44944 .37123 .47227 .36414 .45936 .34244 Metetra
.92 .318 0 r
.45936 .34244 .47227 .36414 .49531 .35718 .48247 .33505 Metetra
.923 .307 0 r
.48247 .33505 .49531 .35718 .51855 .35036 .50579 .32772 Metetra
.927 .294 0 r
.50579 .32772 .51855 .35036 .54202 .34367 .52931 .32045 Metetra
.931 .28 0 r
.52931 .32045 .54202 .34367 .5657 .33713 .55306 .31322 Metetra
.935 .262 0 r
.55306 .31322 .5657 .33713 .58962 .33075 .57703 .30604 Metetra
.94 .243 0 r
.57703 .30604 .58962 .33075 .61377 .32453 .60122 .2989 Metetra
.946 .221 0 r
.60122 .2989 .61377 .32453 .63817 .31847 .62565 .29177 Metetra
.952 .199 0 r
.62565 .29177 .63817 .31847 .66282 .31221 .6503 .28429 Metetra
.951 .203 0 r
.6503 .28429 .66282 .31221 .68753 .30234 .675 .27307 Metetra
.912 .348 0 r
.675 .27307 .68753 .30234 .71132 .27385 .69886 .24374 Metetra
.758 .767 0 r
.69886 .24374 .71132 .27385 .73208 .20265 .71996 .1738 Metetra
0 .53 .02 r
.04284 .32478 .05279 .36803 .06046 .44057 .05194 .38408 Metetra
.643 .739 0 r
.05194 .38408 .06046 .44057 .07468 .47282 .06649 .41135 Metetra
.826 .623 0 r
.06649 .41135 .07468 .47282 .09339 .47528 .08485 .41448 Metetra
.846 .564 0 r
.08485 .41448 .09339 .47528 .11353 .46848 .1045 .40981 Metetra
.848 .557 0 r
.1045 .40981 .11353 .46848 .13398 .46032 .12451 .40373 Metetra
.848 .558 0 r
.12451 .40373 .13398 .46032 .15458 .45209 .14472 .39733 Metetra
.847 .56 0 r
.14472 .39733 .15458 .45209 .17532 .44389 .16512 .39073 Metetra
.847 .563 0 r
.16512 .39073 .17532 .44389 .19621 .43575 .1857 .38393 Metetra
.846 .565 0 r
.1857 .38393 .19621 .43575 .21724 .42765 .20647 .37697 Metetra
.845 .567 0 r
.20647 .37697 .21724 .42765 .23842 .41961 .22742 .36986 Metetra
.844 .569 0 r
.22742 .36986 .23842 .41961 .25975 .41161 .24855 .3626 Metetra
.844 .571 0 r
.24855 .3626 .25975 .41161 .28124 .40368 .26987 .35523 Metetra
.843 .573 0 r
.26987 .35523 .28124 .40368 .3029 .39581 .29136 .34774 Metetra
.843 .574 0 r
.29136 .34774 .3029 .39581 .32471 .388 .31304 .34014 Metetra
.843 .575 0 r
.31304 .34014 .32471 .388 .3467 .38026 .3349 .33243 Metetra
.842 .575 0 r
.3349 .33243 .3467 .38026 .36886 .37257 .35695 .32461 Metetra
.842 .575 0 r
.35695 .32461 .36886 .37257 .39121 .36494 .37918 .31669 Metetra
.843 .575 0 r
.37918 .31669 .39121 .36494 .41373 .35738 .4016 .30866 Metetra
.843 .574 0 r
.4016 .30866 .41373 .35738 .43645 .34988 .42421 .30051 Metetra
.843 .572 0 r
.42421 .30051 .43645 .34988 .45936 .34244 .44701 .29225 Metetra
.844 .571 0 r
.44701 .29225 .45936 .34244 .48247 .33505 .47 .28385 Metetra
.845 .569 0 r
.47 .28385 .48247 .33505 .50579 .32772 .49318 .27532 Metetra
.845 .566 0 r
.49318 .27532 .50579 .32772 .52931 .32045 .51656 .26662 Metetra
.846 .564 0 r
.51656 .26662 .52931 .32045 .55306 .31322 .54013 .25775 Metetra
.847 .562 0 r
.54013 .25775 .55306 .31322 .57703 .30604 .5639 .24869 Metetra
.848 .559 0 r
.5639 .24869 .57703 .30604 .60122 .2989 .58786 .2394 Metetra
.848 .558 0 r
.58786 .2394 .60122 .2989 .62565 .29177 .61201 .22986 Metetra
.848 .558 0 r
.61201 .22986 .62565 .29177 .6503 .28429 .63633 .21972 Metetra
.841 .579 0 r
.63633 .21972 .6503 .28429 .675 .27307 .6607 .20622 Metetra
.799 .696 0 r
.6607 .20622 .675 .27307 .69886 .24374 .68442 .17785 Metetra
.353 .662 0 r
.68442 .17785 .69886 .24374 .71996 .1738 .70603 .11699 Metetra
0 .333 .297 r
.03634 .26033 .04284 .32478 .05194 .38408 .04859 .2952 Metetra
0 .496 .092 r
.04859 .2952 .05194 .38408 .06649 .41135 .06425 .31112 Metetra
.076 .569 0 r
.06425 .31112 .06649 .41135 .08485 .41448 .08236 .31262 Metetra
.142 .594 0 r
.08236 .31262 .08485 .41448 .1045 .40981 .10136 .30927 Metetra
.171 .604 0 r
.10136 .30927 .1045 .40981 .12451 .40373 .1207 .30485 Metetra
.192 .611 0 r
.1207 .30485 .12451 .40373 .14472 .39733 .14027 .3 Metetra
.211 .617 0 r
.14027 .3 .14472 .39733 .16512 .39073 .16007 .29479 Metetra
.227 .622 0 r
.16007 .29479 .16512 .39073 .1857 .38393 .18008 .28924 Metetra
.241 .627 0 r
.18008 .28924 .1857 .38393 .20647 .37697 .20031 .28336 Metetra
.253 .631 0 r
.20031 .28336 .20647 .37697 .22742 .36986 .22075 .27715 Metetra
.262 .634 0 r
.22075 .27715 .22742 .36986 .24855 .3626 .2414 .27062 Metetra
.27 .637 0 r
.2414 .27062 .24855 .3626 .26987 .35523 .26225 .2638 Metetra
.277 .638 0 r
.26225 .2638 .26987 .35523 .29136 .34774 .2833 .25667 Metetra
.281 .64 0 r
.2833 .25667 .29136 .34774 .31304 .34014 .30455 .24925 Metetra
.284 .641 0 r
.30455 .24925 .31304 .34014 .3349 .33243 .32599 .24154 Metetra
.285 .641 0 r
.32599 .24154 .3349 .33243 .35695 .32461 .34762 .23354 Metetra
.285 .641 0 r
.34762 .23354 .35695 .32461 .37918 .31669 .36945 .22524 Metetra
.283 .64 0 r
.36945 .22524 .37918 .31669 .4016 .30866 .39146 .21665 Metetra
.279 .639 0 r
.39146 .21665 .4016 .30866 .42421 .30051 .41365 .20775 Metetra
.274 .638 0 r
.41365 .20775 .42421 .30051 .44701 .29225 .43603 .19855 Metetra
.267 .635 0 r
.43603 .19855 .44701 .29225 .47 .28385 .45859 .18904 Metetra
.258 .633 0 r
.45859 .18904 .47 .28385 .49318 .27532 .48132 .17919 Metetra
.247 .629 0 r
.48132 .17919 .49318 .27532 .51656 .26662 .50423 .169 Metetra
.235 .625 0 r
.50423 .169 .51656 .26662 .54013 .25775 .5273 .15846 Metetra
.22 .62 0 r
.5273 .15846 .54013 .25775 .5639 .24869 .55053 .14755 Metetra
.203 .615 0 r
.55053 .14755 .5639 .24869 .58786 .2394 .57392 .13625 Metetra
.183 .608 0 r
.57392 .13625 .58786 .2394 .61201 .22986 .59747 .12454 Metetra
.16 .6 0 r
.59747 .12454 .61201 .22986 .63633 .21972 .62115 .11221 Metetra
.121 .586 0 r
.62115 .11221 .63633 .21972 .6607 .20622 .64488 .09765 Metetra
.016 .545 0 r
.64488 .09765 .6607 .20622 .68442 .17785 .6683 .07412 Metetra
0 .434 .196 r
.6683 .07412 .68442 .17785 .70603 .11699 .69056 .0314 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00[oooool3
o`0000Cooooo0_l0001Xooooo`00/?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0006Oooooo002`ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000Ioooool0
0;3ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001Wooooo`00/?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Cooooo0_l0001Aooooo`00[oooool2o`00
00Cooooo00Co0000oooooooooooo00004Oooool3o`000003ooooool0003ooooo053ooooo002`oooo
o`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o00001?ooool2o`00053ooooo0035ooooo`?o
00001_ooool00ol0003oooooo`00001?ooooo`00`_ooool3o`0000Wooooo0ol0001?ooooo`00`?oo
ool2o`0000cooooo00Co0000oooooooooooo0000C_ooool00;gooooo0ol0000>ooooo`05o`000?oo
ooooooooooooool00000COooool00;[ooooo0ol0000Aooooo`05o`000?ooooooooooooooool00000
COooool00;Sooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02ooo
ool3o`0000Cooooo0_l0000fooooo`00]_ooool2o`0000?ooooo00?o0000ooooooooool04?ooool2
o`0000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0003Gooooo002cooooo`?o00005oooool3o`0000Cooooo00?o0000ooooooooool00oooool5
o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000eooooo`00/?ooool3
o`0001[ooooo0ol00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000eooooo`00[_ooool2o`0001cooooo00Co0000o`1_<_l0Kc;o00001_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
=Oooool00:_ooooo0ol0000Nooooo`04o`000?l0Kc;o06lbo`0000Kooooo00?o0000ooooooooool0
2?ooool2o`0000Cooooo00Co0000oooooooooooo0000=Oooool00:Wooooo0_l00002ooooo`03o`00
0?oooooooooo01_ooooo00Go0000o`1_<_l0Kc;o06lbo`000005ooooo`?o00002_ooool00ol0003o
ooooooooo`03ooooo`;o0000=_ooool00:Kooooo0ol0000Rooooo`05o`000?l0Kc;o06lbo`1_<_l0
00002?ooool00ol0003oooooooooo`15ooooo`00Y?ooool2o`0002Cooooo00?o0000o`1_<_l0Kc80
0_l0Kc800ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Gooooo002Qooooo`?o00009_oo
ool00ol0003o06lbo`1_<P02o`1_<P;o00002?ooool00ol0003oooooooooo`14ooooo`00W_ooool3
o`0002Sooooo00?o0000o`1_<_l0Kc800ol0Kc82o`0000Wooooo00?o0000ooooooooool0@oooool0
09cooooo0_l000000ooooooo0000ooooo`0Wooooo`;o00001Ol0Kc82o`0000Wooooo00?o0000oooo
ooooool0@oooool009Wooooo0ol0000[ooooo`03o`000?l4R`3o000000Go06lb0_l0000:ooooo`03
o`000?oooooooooo04;ooooo002Gooooo`;o0000;Oooool01?l0003o18/0o`B;0?l00005o`1_<P;o
00002oooool00ol0003oooooooooo`11ooooo`00U?ooool3o`0002kooooo00?o0000o`B;0?l4R`00
0_l4R`000ol0003o06lbo`1_<P02o`1_<P03o`000?l0Kc;o000000[ooooo00?o0000ooooooooool0
@Oooool009;ooooo0_l0000`ooooo`03o`000?l4R`3o18/000?o18/000?o0000o`1_<_l0Kc800_l0
Kc800ol0003o06lbo`00000;ooooo`03o`000?oooooooooo043ooooo001`ooooo`;o00007Oooool3
o`00033ooooo0_l00006o`B;0003o`000?l0Kc;o06lb00?o06lb0_l0000;ooooo`;o0000@Oooool0
06oooooo00Co0000oooooooooooo00006Oooool3o`0003;ooooo00?o0000oajF0?l000001_l4R`00
0ol0003o06lbo`1_<P03o`1_<P;o00003?ooool00ol0003oooooooooo`0oooooo`00Koooool01?l0
003oooooooooool0000Gooooo`;o0000<oooool2o`0000;o7YH000?o0000o`B;0?l4R`001?l4R`00
0ol0003o06lbo`1_<P03o`1_<P;o00003Oooool00ol0003oooooooooo`0nooooo`00Koooool01?l0
003oooooooooool0000Dooooo`?o0000=?ooool00ol0003o7YH0oajF0002oajF0003o`000?l4R`3o
18/000Co18/000?o0000o`1_<_l0Kc800ol0Kc800ol0003o06lbo`00000=ooooo`03o`000?oooooo
oooo03gooooo001_ooooo`04o`000?ooooooooooo`0001;ooooo0_l0000eooooo`;o00001_lNUP00
0ol0003o18/0o`B;0003o`B;0003o`000?l0Kc;o06lb00?o06lb00?o0000o`1_<_l000003Oooool0
0ol0003oooooooooo`0mooooo`00Koooool01?l0003oooooooooool0000?ooooo`?o0000=Oooool2
o`000003obRI0?l0003o7YH000Go7YH000?o0000o`B;0?l4R`001?l4R`000ol0003o06lbo`1_<P02
o`1_<P03o`000?l0Kc;o000000kooooo00?o0000ooooooooool0??ooool0073ooooo0_l0000>oooo
o`;o000000?oooooo`000?ooool0<oooool2o`0000?o:9T000?o0000oajF0?lNUP001?lNUP000ol0
003o18/0o`B;0004o`B;0003o`000?l0Kc;o06lb00;o06lb00?o0000o`1_<_l000003_ooool00ol0
003oooooooooo`0looooo`00OOooool3o`0003Kooooo0_l00005obRI0003o`000?lNUP3o7YH000Co
7YH000?o0000o`B;0?l4R`001?l4R`000ol0003o06lbo`1_<P02o`1_<P03o`000?l0Kc;o000000oo
oooo00?o0000ooooooooool0>oooool007[ooooo0ol0000gooooo`;o000000?o;Y/0o`000?lXV@00
1?lXV@000ol0003o7YH0oajF0004oajF0003o`000?l4R`3o18/000Co18/000?o0000o`1_<_l0Kc80
0_l0Kc82o`000003oeZY0?l0003ooooo00kooooo00?o0000ooooooooool0>_ooool007Sooooo0_l0
000hooooo`;o00000ol^V`000ol0003o:9T0obRI0003obRI0003o`000?lNUP3o7YH000Co7YH000?o
0000o`B;0?l4R`001?l4R`000ol0003o06lbo`1_<P02o`1_<P;o000000?oFZT0o`000?ooool03_oo
ool2o`0003_ooooo001eooooo`?o0000>?ooool2o`0000Go;Y/000?o0000obRI0?lXV@001?lXV@00
0ol0003o7YH0oajF0003oajF0003o`000?l4R`3o18/000Co18/000?o0000o`1_<_l0Kc800_l0Kc82
o`000003oeZY0?l0003ooooo00kooooo0_l0000kooooo`00Loooool2o`0000;ooooo00?o0000oooo
ooooool0=?ooool2o`000003oc>M0?l0003o;Y/000Co;Y/000?o0000obRI0?lXV@001?lXV@000ol0
003o7YH0oajF0004oajF0003o`000?l4R`3o18/000?o18/000?o0000o`1_<_l0Kc800_l0Kc801?l0
003oFZT0oeZY0?l0000Aooooo`03o`000?oooooooooo03Sooooo001`ooooo`?o0000>Oooool2o`00
00?o<id000?o0000objK0?l^V`001?l^V`000ol0003o:9T0obRI0003obRI0003o`000?lNUP3o7YH0
00Co7YH000?o0000o`B;0?l4R`001?l4R`001Ol0003o06lbo`1_<_l0Kc;o000000?oFZT000?o0000
ooooooooool03_ooool00ol0003oooooooooo`0hooooo`00K_ooool2o`0003[ooooo0_l00005oc>M
0003o`000?l^V`3o;Y/000Co;Y/000?o0000obRI0?lXV@000olXV@000ol0003o7YH0oajF0004oajF
0003o`000?l4R`3o18/000Co18/000Go0000o`1_<_l0Kc;o06lbo`000003oeZY0003o`000?oooooo
oooo00oooooo00?o0000ooooooooool0=oooool006_ooooo0ol0000jooooo`;o000000?o>9h0o`00
0?lcW@001?lcW@000ol0003o;Y/0objK0004objK0003o`000?lXV@3o:9T000?o:9T000?o0000oajF
0?lNUP001?lNUP000ol0003o18/0o`B;0004o`B;0003o`000?l0Kc;o06lb00;o00000omJZ@000ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03Kooooo001Yooooo`;o0000>oooool2o`0000?o
>9h000?o0000oc>M0?lcW@001?lcW@000ol0003o;Y/0objK0003objK0003o`000?lXV@3o:9T000?o
:9T000?o0000oajF0?lNUP001?lNUP000ol0003o18/0o`B;0004o`B;0003o`000?l0Kc;o06lb00;o
00001?mJZ@000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Kooooo001Vooooo`Co0000
>_ooool2o`0000Go>9h000?o0000oc>M0?lcW@001?lcW@000ol0003o;Y/0objK0003objK0003o`00
0?lXV@3o:9T000?o:9T000?o0000oajF0?lNUP001?lNUP000ol0003o18/0o`B;0004o`B;0006o`00
0?l0Kc;o06lbo`000?mJZ@3o00000omJZ@000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03Gooooo001Sooooo`?o0000??ooool2o`000003ocbO0?l0003o>9h000Co>9h000?o0000oc>M0?lc
W@001?lcW@000ol0003o;Y/0objK0003objK0003o`000?lXV@3o:9T000?o:9T000?o0000oajF0?lN
UP001?lNUP000ol0003o18/0o`B;0004o`B;0003o`000?l0Kc;o000000;oFZT000Go0000oeZY0?mJ
Z@3oFZT0o`00000Cooooo`03o`000?oooooooooo03Cooooo001Qooooo`;o0000?Oooool2o`0000?o
?9l000?o0000ocRN0?lhWP001?lhWP000ol0003o<id0oc>M0003oc>M0003o`000?l^V`3o;Y/000?o
;Y/000?o0000obRI0?lXV@000olXV@000ol0003o7YH0oajF0005oajF0003o`000?l4R`3o18/000?o
18/000?o0000o`1_<_l000000_mJZ@001Ol0003oFZT0oeZY0?mJZ@3o000001?ooooo00?o0000oooo
ooooool0=?ooool005kooooo0ol0000mooooo`;o00001OllW`000ol0003o>9h0ocRN0004ocRN0003
o`000?lcW@3o<id000?o<id000?o0000objK0?l^V`000ol^V`000ol0003o:9T0obRI0004obRI0003
o`000?lNUP3o7YH000Co7YH000?o0000o`B;0?l4R`001?l4R`02o`0000;oFZT000?o0000oeZY0?mJ
Z@000_mJZ@000ol0003oooooooooo`0@ooooo`;o0000=Oooool005cooooo0_l0000mooooo`?o0000
00?o?j40o`000?llW`001?llW`000ol0003o>9h0ocRN0004ocRN0003o`000?lcW@3o<id000?o<id0
00?o0000objK0?l^V`000ol^V`000ol0003o:9T0obRI0004obRI0003o`000?lNUP3o7YH000Co7YH0
00?o0000o`B;0?l4R`001?l4R`001Ol0003oFZT0oeZY0?mJZ@3o000000CoFZT000?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0booooo`00FOooool3o`000003ooooool0003ooooo03Wooooo
0ol00004ocnQ0003o`000?llW`3o?9l000Co?9l000?o0000ocRN0?lhWP000olhWP000ol0003o<id0
oc>M0003oc>M0003o`000?l^V`3o;Y/000Co;Y/000?o0000obRI0?lXV@000olXV@000ol0003o7YH0
oajF0004oajF0003o`000?l4R`3o18/000Co18/000Go0000oeZY0?mJZ@3oFZT0o`000004oeZY0003
o`000?oooooooooo01;ooooo00?o0000ooooooooool0<_ooool005Oooooo0_l0000mooooo`;o0000
00?o@Z80o`000?loX@001?loX@000ol0003o?9l0ocbO0004ocbO0003o`000?lhWP3o>9h000?o>9h0
00?o0000oc>M0?lcW@000olcW@000ol0003o;Y/0objK0004objK0003o`000?lXV@3o:9T000?o:9T0
00?o0000oajF0?lNUP001?lNUP000ol0003o18/0o`B;0004o`B;0005o`000?mJZ@3oFZT0oeZY0?l0
00000omJZ@000ol0003o`/@0o`00000Dooooo`03o`000?oooooooooo037ooooo001Dooooo`?o0000
?Oooool2o`0000?o@Z8000?o0000ocnQ0?loX@000oloX@000ol0003o?9l0ocbO0004ocbO0003o`00
0?lhWP3o>9h000?o>9h000?o0000oc>M0?lcW@000olcW@000ol0003o;Y/0objK0004objK0003o`00
0?lXV@3o:9T000?o:9T000?o0000oajF0?lNUP001?lNUP000ol0003o18/0o`B;0003o`B;00;o0000
0omJZ@001ol0003oFZT0oeZY0?mJZ@3o0000ol;40?l000005Oooool00ol0003oooooooooo`0`oooo
o`00:_ooool3o`0000Cooooo0_l0000Nooooo`?o0000?_ooool2o`0000Go@Z8000?o0000ocnQ0?lo
X@001?loX@000ol0003o?9l0ocbO0003ocbO0003o`000?lhWP3o>9h000?o>9h000?o0000oc>M0?lc
W@001?lcW@000ol0003o;Y/0objK0003objK0003o`000?lXV@3o:9T000?o:9T000?o0000oajF0?lN
UP001?lNUP000ol0003o18/0o`B;0002o`B;0003o`000?o</P3o000000?oFZT000Go0000oeZY0?mJ
Z@3oFZT0o`000002ol;40003o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool002_o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Kooooo`;o0000?_ooool3o`00
0003odBR0?l0003o@Z8000Co@Z8000?o0000ocnQ0?loX@001?loX@000ol0003o?9l0ocbO0003ocbO
0003o`000?lhWP3o>9h000?o>9h000?o0000oc>M0?lcW@001?lcW@000ol0003o;Y/0objK0003objK
0003o`000?lXV@3o:9T000?o:9T000?o0000oajF0?lNUP001OlNUP001?l0003o18/0o`B;0?l00003
olbb0004o`000?mJZ@3oFZT0o`0000;oFZT000Go0000ol;40?o2a03o`/@0o`00000Eooooo`03o`00
0?oooooooooo02oooooo000Sooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001Sooooo0ol000000ooooooo0000ooooo`0jooooo`?o00001?m4XP000ol0003o@Z80
od:R0004od:R0003o`000?loX@3o?j4000?o?j4000?o0000ocbO0?llW`000ollW`000ol0003o>9h0
ocRN0003ocRN0003o`000?lcW@3o<id000Co<id000?o0000objK0?l^V`000ol^V`000ol0003o:9T0
obRI0003obRI0003o`000?lNUP3o7YH000Go7YH000?o0000o`B;0?l000001?o</P001?l0003oFZT0
oeZY0?l00002oeZY0005o`000?o2a03o`/@0ol;40?l000005_ooool00ol0003oooooooooo`0^oooo
o`00:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Kooooo0_l0000noooo
o`;o000000?oAZ<0o`000?m4XP001?m4XP000ol0003o@Z80od:R0004od:R0003o`000?loX@3o?j40
00?o?j4000?o0000ocbO0?llW`000ollW`000ol0003o>9h0ocRN0004ocRN0003o`000?lcW@3o<id0
00?o<id000?o0000objK0?l^V`000ol^V`000ol0003o:9T0obRI0003obRI0003o`000?lNUP3o7YH0
00Go7YH00_l00005olbb0004o`000?mJZ@3oFZT0o`0000;oFZT000?o0000ol;40?o2a0000_o2a000
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02kooooo000[ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00004oooool3o`0003oooooo00Go0000odJS0?m6X`3oAZ<0o`00
0005odBR0003o`000?m2XP3o@Z8000Co@Z8000?o0000ocnQ0?loX@000oloX@000ol0003o?9l0ocbO
0003ocbO0003o`000?lhWP3o>9h000Co>9h000?o0000oc>M0?lcW@000olcW@000ol0003o;Y/0objK
0003objK0003o`000?lXV@3o:9T000Co:9T000?o0000oajF0?lNUP000olNUP02o`0000Koc;8000Ko
0000oeZY0?mJZ@3o0000oeZY0?l00005ol;40003o`000?oooooooooo01?ooooo0_l0000_ooooo`00
:_ooool2o`0000Cooooo00Co0000oooooooooooo00004Oooool2o`00043ooooo0_l00004odJS0003
o`000?m4XP3oA:8000CoA:8000?o0000od:R0?m2XP000om2XP000ol0003o?j40ocnQ0003ocnQ0003
o`000?llW`3o?9l000Co?9l000?o0000ocRN0?lhWP000olhWP000ol0003o<id0oc>M0003oc>M0003
o`000?l^V`3o;Y/000?o;Y/000?o0000obRI0?lXV@001?lXV@001?l0003o7YH0oajF0?lNUP02o`00
0003omND0?l0003oc;8000Goc;8000Ko0000oeZY0?mJZ@3o0000oeZY0?l00005ol;400;o00005_oo
ool00ol0003oooooooooo`0/ooooo`00:oooool00ol0003oooooooooo`03ooooo`;o00003oooool3
o`0003oooooo0ol000000om7X`3o0000odJS0003odJS0003o`000?m4XP3oA:8000CoA:8000?o0000
od:R0?m2XP000om2XP000ol0003o?j40ocnQ0003ocnQ0003o`000?llW`3o?9l000Co?9l000?o0000
ocRN0?lhWP000olhWP000ol0003o<id0oc>M0003oc>M0003o`000?l^V`3o;Y/000Co;Y/000?o0000
obRI0?lXV@000olXV@001?l0003o7YH0oajF0?l00003omND0003o`000?o</P3oc;8000Goc;8000Go
0000oeZY0?l0003oFZT0o`000004ol;40004o`000?o;]@3obkD0o`0001Gooooo00?o0000oooooooo
ool0;?ooool003oooooo0ol00002ooooo`03o`000?oooooooooo03[ooooo0ol00004odNS0003o`00
0?m6X`3oAZ<000?oAZ<000?o0000odBR0?m4XP000om4XP000ol0003o@Z80od:R0003od:R0003o`00
0?loX@3o?j4000?o?j4000?o0000ocbO0?llW`001?llW`000ol0003o>9h0ocRN0003ocRN0003o`00
0?lcW@3o<id000?o<id000?o0000objK0?l^V`001?l^V`000ol0003o:9T0obRI0003obRI00?o0000
1?oGU0000ol0003oc;80olbb0005olbb0004o`000?mJZ@3oFZT0o`0000Go`/@000Co0000ol^e0?o;
]@3o00005_ooool00ol0003oooooooooo`06ooooo`;o00008oooool003gooooo0_l0000oooooo`?o
000000?oB:<0o`000?m7X`001?m7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4XP3oA:8000?o
A:8000?o0000od:R0?m2XP000om2XP000ol0003o?j40ocnQ0004ocnQ0003o`000?llW`3o?9l000?o
?9l000?o0000ocRN0?lhWP000olhWP000ol0003o<id0oc>M0003oc>M0003o`000?l^V`3o;Y/000Co
;Y/000?o0000obRI0?lXV@000_lXV@02o`0000Ooei@000?o0000olbb0?o</P001?o</P001?l0003o
FZT0oeZY0?l00005ol;40005o`000?o;]@3obkD0ol^e0?l000005_ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`0002;ooooo000jooooo`?o0000?_ooool3o`0000CoB:<000?o0000
odNS0?m7X`000om7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4XP3oA:8000?oA:8000?o0000
od:R0?m2XP000om2XP000ol0003o?j40ocnQ0004ocnQ0003o`000?llW`3o?9l000?o?9l000?o0000
ocRN0?lhWP000olhWP000ol0003o<id0oc>M0004oc>M0003o`000?l^V`3o;Y/000?o;Y/000?o0000
obRI0?l000000_l000000ooISP3o0000omND0006omND0003o`000?o</P3oc;8000Coc;8000Co0000
oeZY0?mJZ@3o00001?o2a0000ol0003obkD0ol^e0002ol^e0003o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000Rooooo`00>?ooool2o`0003kooooo0ol0
00000om8Y03o0000odRS0004odRS0003o`000?m7X`3oAj<000?oAj<000?o0000odJS0?m6X`000om6
X`000ol0003oA:80odBR0003odBR0003o`000?m2XP3o@Z8000Co@Z8000?o0000ocnQ0?loX@000olo
X@000ol0003o?9l0ocbO0003ocbO0003o`000?lhWP3o>9h000?o>9h000?o0000oc>M0?lcW@001?lc
W@000ol0003o;Y/0objK0002objK00?o00001?oISP000ol0003oei@0omND0005omND0003o`000?o<
/P3oc;8000Coc;8000Co0000oeZY0?l0003o00001?o2a0000ol0003obkD0ol^e0002ol^e00;o0000
5_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0002;ooooo000eooooo`?o0000
?_ooool2o`0000CoB:@000?o0000odRS0?m8X`000om8X`000ol0003oAj<0odNS0003odNS0003o`00
0?m6X`3oAZ<000?oAZ<000?o0000odBR0?m4XP000om4XP000ol0003o@Z80od:R0004od:R0003o`00
0?loX@3o?j4000?o?j4000?o0000ocbO0?llW`000ollW`000ol0003o>9h0ocRN0003ocRN0003o`00
0?lcW@3o<id000Co<id000?o0000objK0?l^V`000_l000000ooISP3o0000omV>0005omV>0003o`00
0?oGU03oei@000Coei@000?o0000olbb0?o</P001?o</P001?l0003oFZT0o`000?l00004ol;40005
o`000?o;]@3obkD0ol^e0?l000000_o;]0000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00008_ooool003?ooooo0_l00003ooooo`03o`000?oooooooooo
03Sooooo0ol000000om8Y03o0000odRT0003odRT0003o`000?m8X`3oB:<000CoB:<000?o0000odNS
0?m7X`000om7X`000ol0003oAZ<0odJS0002odJS0003o`000?m4XP3oA:8000?oA:8000?o0000od:R
0?m2XP001?m2XP000ol0003o?j40ocnQ0003ocnQ0003o`000?llW`3o?9l000?o?9l000?o0000ocRN
0?lhWP001?lhWP000ol0003o<id0oc>M0003oc>M00?o00000ooISP000ol0003ofHh0omV>0004omV>
0003o`000?oGU03oei@000Coei@000?o0000olbb0?o</P001Oo</P03o`0000Co`/@000Go0000ol^e
0?o;]@3obkD0o`000003ol^d0003o`000?oooooooooo01?ooooo0_l00003ooooo`04o`000?oooooo
ooooo`0002;ooooo000`ooooo`?o0000?Oooool3o`0000CoB:@000?o0000odRT0?m8Y0000_m8Y000
0ol0003oB:<0odRS0004odRS0003o`000?m7X`3oAj<000?oAj<000?o0000odJS0?m6X`000_m6X`00
0ol0003oA:80odBR0004odBR0003o`000?m2XP3o@Z8000?o@Z8000?o0000ocnQ0?loX@000oloX@00
0ol0003o?9l0ocbO0003ocbO0003o`000?lhWP3o>9h000Co>9h000?o0000oc>M0?lcW@000_lcW@02
o`0000KofHh000?o0000omV>0?oISP000ooISP000ol0003oei@0omND0005omND0003o`000?o</P3o
c;8000Coc;8000?o0000ol;40?l000000oo2a0000ol0003obkD0ol^e0002ol^e0005o`000?o;]03o
bk@0ol^d0?l000005?ooool00ol0003oooooo`000004ooooo`;o00008oooool002gooooo0ol0000m
ooooo`?o000000?oB:@0o`000?m8Y0001?m8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8X`3o
B:<000?oB:<000?o0000odNS0?m7X`000om7X`000ol0003oAZ<0odJS0002odJS0003o`000?m4XP3o
A:8000CoA:8000?o0000od:R0?m2XP000om2XP000ol0003o?j40ocnQ0003ocnQ0003o`000?llW`3o
?9l000Co?9l000?o0000ocRN0?lhWP000olhWP000ol0003o<id0o`000002o`000003omV?0?l0003o
fHh000GofHh000?o0000omV>0?oISP000ooISP000ol0003oei@0omND0005omND0003o`000?o</P3o
c;8000Coc;800ol00003ol;40005o`000?o;]@3obkD0ol^e0?l000000oo;]0000ol0003obkD0o`00
000Fooooo`03o`000?oooooooooo02Kooooo000[ooooo`;o0000?_ooool2o`0000CoB:@000?o0000
odRT0?m8Y0000om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8X`3oB:<000?oB:<000?o0000
odNS0?m7X`000om7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4XP3oA:8000?oA:8000?o0000
od:R0?m2XP000om2XP000ol0003o?j40ocnQ0003ocnQ0003o`000?llW`3o?9l000Co?9l000?o0000
ocRN0?lhWP000_lhWP03o`0000CofHl000?o0000omV>0?oISP001?oISP000ol0003ofHh0omV>0004
omV>0003o`000?oGU03oei@000Coei@000?o0000olbb0?o</P000_o</P03o`000003ol;40?l0003o
`/@000;o`/@000Go0000ol^e0?o;]@3obkD0o`000003ol^d0003o`000?o;]@3o000001Kooooo00?o
0000ooooooooool09_ooool002Sooooo0ol000000ooooooo0000ooooo`0jooooo`?o000000?oAj<0
o`000?m8Y0000om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000?oB:@000?o0000
odRS0?m8X`000om8X`000ol0003oAj<0odNS0003odNS0003o`000?m6X`3oAZ<000?oAZ<000?o0000
odBR0?m4XP000om4XP000ol0003o@Z80od:R0003od:R0003o`000?loX@3o?j4000?o?j4000?o0000
ocbO0?llW`001?llW`000ol0003o>9h0o`000002o`000003omR?0?l0003ofHl000GofHl000?o0000
omV>0?oISP000ooISP000ol0003ofHh0omV>0004omV>0003o`000?oGU03oei@000Coei@000?o0000
olbb0?l000000_l000001_o</P3o0000onUI0?l0003o`/@0o`0000;o`/@000Go0000ol^e0?o;]@3o
bkD0o`000003ol^d0004o`000?o;]@3obkD0o`0001Kooooo00?o0000ooooooooool09Oooool002Oo
oooo0_l0000looooo`?o00001?m7X`000ol0003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?o
B:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0odRS0003odRS0003o`000?m7X`3oAj<000?o
Aj<000?o0000odJS0?m6X`000om6X`000ol0003oA:80odBR0003odBR0003o`000?m2XP3o@Z8000?o
@Z8000?o0000ocnQ0?loX@001?loX@000ol0003o?9l0ocbO0002ocbO00?o00001?oHS`000ol0003o
fHl0omV?0004omV?0003o`000?oISP3ofHh000CofHh000?o0000omV>0?oISP000ooISP000ol0003o
ei@0omND0003omND00?o00000oo</P001?l0003ojET0onUI0?l00002ol;400;o00001?o;]@001?l0
003obk@0ol^d0?l00003ol^e0003o`000?oooooooooo01Gooooo00?o0000ooooooooool09?ooool0
02Oooooo00?o0000ooooool00000>?ooool3o`000003odJS0?l0003oAj<000CoAj<000?o0000odRT
0?m8Y0000_m8Y0000ol0003oB:@0odRT0004odRT0003o`000?m8Y03oB:@000;oB:@000?o0000odRS
0?m8X`000om8X`000ol0003oAj<0odNS0003odNS0003o`000?m6X`3oAZ<000?oAZ<000?o0000odBR
0?m4XP000om4XP000ol0003o@Z80od:R0003od:R0003o`000?loX@3o?j4000Co?j4000?o0000ocbO
0?llW`000_l000000ooHT03o0000omR?0005omR?0003o`000?oIS`3ofHl000?ofHl000?o0000omV>
0?oISP001?oISP000ol0003ofHh0omV>0003omV>0003o`000?oGU03oei@000?o000000?oei@0o`00
0?o</P000_o</P000ol0003ojET0onUI0002onUI0004o`000?o2a03o`/@0o`0000?obkD000Go0000
ol^d0?o;]03obk@0o`000003ol^e00;o00005_ooool00ol0003oooooooooo`0Tooooo`009oooool0
1?l0003oooooooooool0000eooooo`;o00001?m6X`000ol0003oAj<0odNS0003odNS0003o`000?m8
Y03oB:@000;oB:@000?o0000odRT0?m8Y0001?m8Y0000ol0003oB:@0odRT0002odRT0003o`000?m8
X`3oB:<000CoB:<000?o0000odNS0?m7X`000_m7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4
XP3oA:8000?oA:8000?o0000od:R0?m2XP001?m2XP000ol0003o?j40ocnQ0003ocnQ00?o00000ooH
T0000ol0003of8l0omR?0004omR?0003o`000?oIS`3ofHl000?ofHl000?o0000omV>0?oISP001?oI
SP000ol0003ofHh0omV>0003omV>00?o00001OoGU0000ol0003oc;80o`000006onUI0003o`000?o2
a03o000000?obkD000Go0000ol^d0?o;]03obk@0o`000002ol^e0004o`000?o;]P3obkH0o`0001Ko
oooo00?o0000ooooooooool08oooool002Oooooo0_l00002ooooo`03o`000?oooooooooo02oooooo
0ol000000om5X`3o0000odJS0003odJS0003o`000?m7X`3oAj<000?oAj<000?o0000odRT0?m8Y000
0om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000;oB:@000?o0000odRS0?m8X`00
1?m8X`000ol0003oAj<0odNS0002odNS0003o`000?m6X`3oAZ<000?oAZ<000?o0000odBR0?m4XP00
0om4XP000ol0003o@Z80od:R0004od:R0003o`000?loX@3o?j4000;o?j400_l00006omR@0003o`00
0?oHS`3of8l000?of8l000?o0000omV?0?oIS`001?oIS`000ol0003ofHh0omV>0003omV>0003o`00
0?oISP3ofHh000?o000000?ofHh0o`000?oGU0001OoGU002o`0000OojET00_l000001Oo;]@3o0000
ol^e0?o;]@3o000000;obk@000Go0000ol^e0?o;]@3obkD0o`000003ol^f0003o`000?oooooooooo
01Cooooo00?o0000ooooooooool08_ooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`?o00001?ooool3o`0000?ooooo00?o0000ooooooooool0:_ooool4o`0000Co
AJ<000?o0000odJS0?m6X`000_m6X`000ol0003oAj<0odNS0003odNS0003o`000?m8Y03oB:@000?o
B:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8X`3oB:<000?o
B:<000?o0000odNS0?m7X`000_m7X`000ol0003oAZ<0odJS0003odJS0003o`000?m4XP3oA:8000Co
A:8000?o0000od:R0?m2XP000om2XP000ol0003o?j40o`000002o`000003omR@0?l0003of90000Go
f90000?o0000omR?0?oHS`000ooHS`000ol0003ofHl0omV?0004omV?0003o`000?oISP3ofHh000Co
fHh00_l00004omV>0003o`000?oGU03oei@000?oei@00_l00009onUI0006o`000?o;]@3obkD0o`00
0?o;]@3o00000_o;]0001Ol0003obkD0ol^e0?o;]@3o000000?obkH000?o0000ooooooooool04ooo
ool2o`0002Cooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`0Uoooo
o`Co00000om3XP000ol0003oAJ<0odFS0002odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS
0?m7X`001?m7X`000ol0003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT
0?m8Y0000om8Y0000ol0003oB:<0odRS0003odRS0003o`000?m7X`3oAj<000;oAj<000?o0000odJS
0?m6X`000om6X`000ol0003oA:80odBR0004odBR0003o`000?m2XP3o@Z8000;o@Z800ol00004omR@
0003o`000?oHT03of90000Cof90000?o0000omR?0?oHS`000ooHS`000ol0003ofHl0omV?0004omV?
0004o`000?oISP3ofHh0omV>00Co00001OoISP001?l0003oei@0omND0?oGU002o`000003oo<c0?l0
003ojET000SojET000?o0000ol^e0?o;]@000_l00003ol^d0004o`000?o;]@3obkD0o`0000CobkH0
0_l0000Fooooo`03o`000?oooooooooo027ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001Oooool01_l0003ooooooooooooooooo0000ooooo`;o00001?ooool0
0ol0003oooooooooo`0Qooooo`?o000000?o@:40o`000?m3XP001?m3XP000ol0003oAJ<0odFS0002
odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`001?m7X`000ol0003oB:@0odRT0002
odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0odRS0003
odRS0003o`000?m7X`3oAj<000?oAj<000?o0000odJS0?m6X`000om6X`000ol0003oA:80odBR0003
odBR0003o`000?m2XP3o000000;o000000?of940o`000?oHT0001OoHT0000ol0003of900omR@0003
omR@0003o`000?oHS`3of8l000Cof8l000?o0000omV?0?oIS`001?oIS`03o`0000?ofHh000?o0000
omV>0?oISP001?oISP03o`0000Colc<000?o0000onUI0?oYF@001OoYF@000ol0003okd40o`000002
ol^e0004o`000?o;]03obk@0o`0000?obkD000Go0000ol^f0?o;]P3obkH0o`000002olZg0003o`00
0?oooooooooo01Cooooo00?o0000ooooooooool08?ooool000gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00005ooooo`06o`000?ooooooooooooooool0003ooooo0_l00005
ooooo`03o`000?oooooooooo01gooooo0ol00004od2Q0003o`000?m3XP3o@j8000?o@j8000?o0000
odFS0?m5X`000_m5X`000ol0003oAZ<0odJS0003odJS0003o`000?m7X`3oAj<000?oAj<000?o0000
odRT0?m8Y0000_m8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000?oB:@000?o0000
odRS0?m8X`000om8X`000ol0003oAj<0odNS0003odNS0003o`000?m6X`3oAZ<000?oAZ<000?o0000
odBR0?m4XP000_m4XP03o`0000Cof94000?o0000omR@0?oHT0001?oHT0000ol0003of900omR@0003
omR@0003o`000?oHS`3of8l000Cof8l000Co0000omV?0?oIS`3ofHl01?l00005omV>0003o`000?oI
SP3ofHh000?ofHh00_l00006oo<c0003o`000?oYF@3ojET000CojET000Ko0000onm10?o_@@3okd40
o`000?o;]@02o`000003ol^d0?l0003obkD000;obkD000Go0000ol^f0?o;]P3obkH0o`000003olZg
0003o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool000gooooo00Co0000oooooooo
oooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00001?ooool4o`0000Kooooo00?o0000
ooooooooool06?ooool4o`0000;o?J0000?o0000od2Q0?m0X@000_m0X@000ol0003o@j80od>R0003
od>R0003o`000?m5X`3oAJ<000;oAJ<000?o0000odJS0?m6X`000om6X`000ol0003oAj<0odNS0003
odNS0003o`000?m8Y03oB:@000;oB:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:@0odRT0003
odRT0003o`000?m8X`3oB:<000?oB:<000?o0000odNS0?m7X`000om7X`000ol0003oAZ<0odJS0003
odJS0003o`000?m4XP3o000000;o000000?of980o`000?oHT@001OoHT@000ol0003of900omR@0003
omR@0003o`000?oHT03of90000Cof90000?o0000omR?0?oHS`000ooHS`04o`0000?ofHl000?o0000
omV>0?oISP001?oISP000ol0003ofHh0o`000002o`000003oo<b0?l0003olc<000Kolc<000?o0000
onUI0?oYF@000_oYF@000ol0003okd40onm10002onm100;o00000_o;]002o`0000;obkD000?o0000
ol^f0?o;]P000_o;]P001Ol0003ob[L0olZg0?o:]`3o000001Kooooo00?o0000ooooooooool07ooo
ool000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Oo
oooo00Go0000ooooool0003o05E<o`000006ooooo`03o`000?oooooooooo01Cooooo0ol000000olj
W`3o0000ocfP0003ocfP0003o`000?m0X@3o@:4000;o@:4000?o0000od>R0?m3XP000om3XP000ol0
003oAJ<0odFS0003odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`000om7X`000ol0
003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT0?m8Y0000om8Y0000ol0
003oB:<0odRS0003odRS0003o`000?m7X`3oAj<000?oAj<000?o0000odJS0?m6X`000_m6X`03o`00
00Cof98000?o0000omRA0?oHT@001?oHT@000ol0003of900omR@0003omR@0003o`000?oHT03of900
00Cof90000Co0000omR?0?oHS`3of8l00ol00006omV?0003o`000?oISP3ofHh000?ofHh00ol00005
oo<b0003o`000?oc<`3olc<000Colc<000?o0000onUI0?oYF@000_oYF@000ol0003okd40onm10003
onm10004o`000?o;]03obk@0o`0000?obkD000Go0000ol^f0?o;]P3obkH0o`000004olZg00;o0000
5_ooool00ol0003oooooooooo`0Nooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go00000ooo
ool01Ol0003oooooo`000?l0EDco000000Oooooo00?o0000ooooooooool04?ooool3o`0000Co>Yl0
00?o0000ocfP0?lmX0000_lmX0000ol0003o@:40od2Q0002od2Q0003o`000?m3XP3o@j8000?o@j80
00?o0000odFS0?m5X`000om5X`000ol0003oAZ<0odJS0002odJS0003o`000?m7X`3oAj<000?oAj<0
00?o0000odRT0?m8Y0000_m8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000?oB:@0
00?o0000odRS0?m8X`001?m8X`000ol0003oAj<0odNS0002odNS0003o`000?m6X`3o000000;o0000
00?oei80o`000?oHTP001OoHTP000ol0003of940omRA0003omRA0003o`000?oHT03of90000Cof900
00?o0000omR@0?oHT0000ooHT004o`0000;of8l000?o0000omV?0?oIS`001OoIS`000ol0003ofHh0
o`000002o`000003oo8h0?l0003olc8000Golc8000?o0000oo<c0?oc<`001Ooc<`001?l0003ojET0
onUI0?l00006onm10003o`000?o;]03obk@000;o00000_o;]@001Ol0003obkH0ol^f0?o;]P3o0000
00?ob[L000Co0000olZh0?o:^03o00005Oooool00ol0003oooooooooo`0Nooooo`009Oooool4o`00
0003o`1EC?l0003o000000Oooooo00?o0000ooooooooool02_ooool5o`0000;o=Yd000?o0000ocZO
0?ljW`000_ljW`000ol0003o?J00ocfP0002ocfP0003o`000?m0X@3o@:4000;o@:4000?o0000od>R
0?m3XP000om3XP000ol0003oAJ<0odFS0003odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS
0?m7X`000om7X`000ol0003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT
0?m8Y0000om8Y0000ol0003oB:<0odRS0004odRS0004o`000?m7X`3oAj<0odNS00?o00001?oGTP00
0ol0003of980omRB0004omRB0003o`000?oHT@3of94000?of94000?o0000omR@0?oHT0001?oHT000
0ol0003of900omR@0002omR@00;o00001_oHS`000ol0003ofHl0omV?0002omV?00Co00001Oob>000
0ol0003olc80oo<b0004oo<b0003o`000?oc<`3olc<000Colc<000?o0000onUI0?l000001_o_@@00
2Ol0003okd80o`000?o;]03o0000ol^e0?l0003obkD0o`000003ol^f0005o`000?o:]`3ob[L0olZg
0?l000000_o:^0000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo000Uooooo`08
o`000?ooooooooooo`000?l0EDco0000o`1n5ol00007ooooo`03o`000?oooooooooo00Gooooo1?l0
0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP
0002ocfP0003o`000?m0X@3o@:4000?o@:4000?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0odFS
0003odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`000om7X`000ol0003oB:@0odRT
0002odRT0003o`000?m8Y03oB:@000CoB:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0odRS
0003odRS00Co000000?oei80o`000?oGTP001OoGTP000ol0003of980omRB0003omRB0003o`000?oH
T@3of94000Cof94000?o0000omR@0?oHT0000ooHT0000ol0003of900o`000002o`000003omR@0?l0
003of8l000Gof8l000?o0000omV?0?l000000_l00002oo0n0003o`000?ob>03olSP000ColSP000?o
0000oo<b0?oc<P001?oc<P000ol0003olc<0oo<c0003oo<c00?o00001_o_@@001Ol0003okd80onm2
0?o_@P3o000000;obkD00_l00003ol^f0003o`000?o:]`3ob[L000;ob[L000?o0000olZh0?o:^000
0_l0000Dooooo`?o00007_ooool002Gooooo0_l000001?oooooo0000o`1EC?l00002o`1n5`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol000000ol[VP3o0000oc6L0003oc6L0003
o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP0002ocfP0003
o`000?m0X@3o@:4000?o@:4000?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0odFS0003odFS0003
o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`000om7X`000ol0003oB:@0odRT0002odRT0003
o`000?m8Y03oB:@000CoB:@000?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0odRS0002odRS00;o
00001?oGTP000ol0003oei80omNB0004omNB0003o`000?oHTP3of98000?of98000?o0000omRA0?oH
T@001?oHT@000ol0003of900omR@0002omR@00?o00001OoHT0000ol0003of8l0omR?0002omR?00?o
00001_o`?P000ol0003olSP0oo8h0004oo8h0003o`000?oc<P3olc8000?olc8000?o0000oo<c0?oc
<`000ol00002ooTL0003o`000?o_@@3okd4000?okd4000?o0000onm20?o_@P000_o_@P001Ol0003o
bkD0ol^e0?o;]@3o000000?obkH000Go0000olZg0?o:]`3ob[L0o`000002olZh0004o`000?o9^03o
bKP0o`0001Gooooo00?o0000ooooooooool07?ooool002Gooooo00Ko0000oooooooooooo0000o`1E
C?l00003o`1n5`_o00001?l[VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd0
00?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP0003ocfP0003o`000?m0X@3o@:4000;o@:40
00?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0odFS0003odFS0003o`000?m6X`3oAZ<000;oAZ<0
00?o0000odNS0?m7X`000om7X`000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000?oB:@0
00?o0000odRT0?m8Y0000om8Y0000ol0003oB:<0o`000002o`000003omNC0?l0003oei8000Coei80
00?o0000omNB0?oGTP000ooGTP000ol0003of980omRB0004omRB0003o`000?oHT@3of94000?of940
00?o0000omR@0?l000000_l000000ooHT03o0000omR@0005omR@0003o`000?oHS`3o000000;o0000
00?okd<0o`000?o`?P001_o`?P000ol0003olSP0oo8h0004oo8h0003o`000?oc<P3olc8000?olc80
0ol00006ooTL0005o`000?o_@@3okd40onm10?l000001?o_@P000ol0003okTH0o`000002ol^e00;o
00000_o;]P001Ol0003ob[L0olZg0?o:]`3o000000;ob[P000Go0000olVh0?o9^03obKP0o`00000E
ooooo`03o`000?oooooooooo01_ooooo000Uooooo`;o00000_ooool2o`0000?o07hG00?o0000oa>A
0?lCT@000_lCT@000ol0003o99P0obBH0002obBH0003o`000?l[VP3o:iX000;o:iX000?o0000oc6L
0?laW0000_laW0000ol0003o=Yd0ocJM0002ocJM0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocfP
0?lmX0000olmX0000ol0003o@:40od2Q0002od2Q0003o`000?m3XP3o@j8000;o@j8000?o0000odFS
0?m5X`000om5X`000ol0003oAZ<0odJS0002odJS0003o`000?m7X`3oAj<000?oAj<000?o0000odRT
0?m8Y0000om8Y0000ol0003oB:@0odRT0003odRT0003o`000?m8Y03oB:@000;oB:@00ol00004omNC
0003o`000?oGTP3oei8000?oei8000?o0000omNB0?oGTP000ooGTP000ol0003of980omRB0004omRB
0003o`000?oHT@3of94000;of9400ol00005omR@0003o`000?oHT03of90000Go00001Oo_@`000ol0
003ol3h0oo0n0005oo0n0003o`000?ob>03olSP000?olSP000?o0000oo<b0?oc<P000ol000000ooh
7P3o0000ooTL0007ooTL0003o`000?o_@@3o000000Cokd8000Co0000oni60?o^AP3okTH00_l00002
ol^f0003o`000?o;]P3o000000?ob[L000Co0000olZh0?o:^03o00000oo9^0000ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01[ooooo000Uooooo`04o`000?ooooooooooooooo`;o00000ol0
OQL00ol0003o4i40oa>A0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[
VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_lj
W`000ol0003o?J00ocfP0003ocfP0003o`000?m0X@3o@:4000;o@:4000?o0000od>R0?m3XP000om3
XP000ol0003oAJ<0odFS0002odFS0003o`000?m6X`3oAZ<000;oAZ<000?o0000odNS0?m7X`001?m7
X`000ol0003oB:@0odRT0002odRT0003o`000?m8Y03oB:@000?oB:@000?o0000odRT0?l000000_l0
00000ooGT`3o0000omNC0005omNC0003o`000?oGTP3oei8000;oei8000?o0000omNB0?oGTP001?oG
TP000ol0003of980omRB0003omRB0003o`000?oHT@3o000000;o000000?of940o`000?oHT0001?oH
T004o`0000?okTL000?o0000onm30?o_@`001Oo_@`000ol0003ol3h0oo0n0004oo0n0004o`000?ob
>03olSP0oo8h00Go00001Ooh7P000ol0003onA`0ooTL0004ooTL00?o00001?o_@P000ol0003okTH0
oni60003oni60003o`000?o;]P3obkH000;o00000oo:]`001?l0003ob[P0olZh0?l00004olVh00;o
00005Oooool00ol0003oooooooooo`0Jooooo`001_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00Co0000oooooooooooo
oooo0_l00003o`1n5`03o`000?lCT@3o4i4000;o4i4000?o0000obBH0?lTV0000_lTV0000ol0003o
:iX0ob^J0002ob^J0003o`000?laW03o<I`000;o<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o
>Yl0ocZO0002ocZO0003o`000?lmX03o?J0000?o?J0000?o0000od2Q0?m0X@000_m0X@000ol0003o
@j80od>R0003od>R0003o`000?m5X`3oAJ<000;oAJ<000?o0000odJS0?m6X`000_m6X`000ol0003o
Aj<0odNS0004odNS0003o`000?m8Y03oB:@000;oB:@000?o0000odRT0?m8Y0000_m8Y003o`0000Co
ei<000?o0000omNC0?oGT`001?oGT`000ol0003oei80omNB0002omNB0003o`000?oGTP3oei8000Co
ei8000?o0000omRB0?oHTP000_oHTP03o`0000Gof94000?o0000omR@0?l000000_l000000oo]B`3o
0000oni70005oni70003o`000?o_@`3okd<000Cokd<000?o0000oo0n0?o`?P001?o`?P04o`0000?o
mRH000?o0000ooPN0?oh7P001Ooh7P000ol0003onA`0ooTL0003o`0000;on1l000Go0000onm20?o_
@P3okd80o`000006oni60005o`000?o;]P3obkH0ol^f0?l000000oo:]`001?l0003ob[P0olZh0?l0
0003olVh0004o`000?o9^@3obKT0o`0001Gooooo00?o0000ooooooooool06Oooool000Gooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooooooool2o`0000?ooooo0_l00003o`1n5`03o`000?lCT@3o
4i4000;o4i4000?o0000obBH0?lTV0000_lTV0000ol0003o:iX0ob^J0002ob^J0003o`000?laW03o
<I`000;o<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o>Yl0ocZO0002ocZO0003o`000?lmX03o
?J0000?o?J0000?o0000od2Q0?m0X@000_m0X@000ol0003o@j80od>R0003od>R0003o`000?m5X`3o
AJ<000;oAJ<000?o0000odJS0?m6X`000om6X`000ol0003oAj<0odNS0003odNS0003o`000?m8Y03o
B:@000;oB:@000?o0000odRT0?l000000_l000000ooGT`3o0000omNC0005omNC0003o`000?oGT`3o
ei<000?oei<000?o0000omNB0?oGTP000ooGTP000ol0003oei80omNB0003omNB0003o`000?oHTP3o
f98000;o000000?of980o`000?oHT@001?oHT@03o`0000GokD/000?o0000oni70?o^A`000oo^A`00
0ol0003okd<0onm30005onm30003o`000?o`?P3ol3h000?o000000?om2d0o`000?of9P001Oof9P00
0ol0003on1h0ooPN0004ooPN00?o00001_oh7`000ol0003okd80o`000006oni60003o`000?o]BP3o
000000;obkH00_l00002olZg0004o`000?o:^03ob[P0o`0000?obKP000Go0000olVi0?o9^@3obKT0
o`00000Dooooo`03o`000?oooooooooo01Wooooo0005ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001?ooool2o`0000?o07hG00?o0000oa>A0?lCT@000_lCT@000ol0003o99P0obBH0002obBH
0003o`000?l[VP3o:iX000;o:iX000?o0000oc6L0?laW0000_laW0000ol0003o=Yd0ocJM0002ocJM
0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocfP0?lmX0000olmX0000ol0003o@:40od2Q0002od2Q
0003o`000?m3XP3o@j8000?o@j8000?o0000odFS0?m5X`000_m5X`000ol0003oAZ<0odJS0003odJS
0003o`000?m7X`3oAj<000?oAj<000Co0000odRT0?m8Y03oB:@00ol00004omNC0003o`000?oGT`3o
ei<000Coei<000?o0000omNC0?oGT`000ooGT`000ol0003oei80omNB0003omNB0003o`000?oGTP3o
ei8000?oei800ol00004omRB0003o`000?oHT@3o000000;o000000?ok4h0o`000?o]B`001Oo]B`00
0ol0003okTL0oni70004oni70003o`000?o_@`3okd<000?okd<01?l00005oo@]0003o`000?of9P3o
mRH000ComRH000?o0000ooPN0?oh7P000ol000000ooh8@3o0000ooPO0006ooPO00;o00001_o^AP00
1?l0003okDX0one:0?o]BP02o`0000;ob[L00_l00002olZh0003o`000?o9^03obKP000;obKP000Go
0000olVi0?o9^@3obKT0o`00000Eooooo`03o`000?oooooooooo01Sooooo0005ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001?ooool2o`0000?o07hG00?o0000oa>A0?lCT@000_lCT@000ol0
003o99P0obBH0002obBH0003o`000?l[VP3o:iX000;o:iX000?o0000oc6L0?laW0000_laW0000ol0
003o=Yd0ocJM0002ocJM0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocfP0?lmX0000olmX0000ol0
003o@:40od2Q0002od2Q0003o`000?m3XP3o@j8000?o@j8000?o0000odFS0?m5X`000om5X`000ol0
003oAZ<0odJS0002odJS0003o`000?m7X`3oAj<000?oAj<01?l000000ooGT`3o0000omNC0005omNC
0003o`000?oGT`3oei<000?oei<000?o0000omNC0?oGT`001?oGT`000ol0003oei80omNB0002omNB
0003o`000?oGTP3oei8000Co00001OoHTP03o`0000Gok4h000?o0000one;0?o]B`001?o]B`000ol0
003okTL0oni70003oni70003o`000?o_@`3okd<000?o00000_oc=0000ol0003om2d0oo@]0005oo@]
0004o`000?of9P3omRH0ooHV00Go00001Ooh8@000ol0003on1l0ooPO0002ooPO00;o000000?ombD0
o`000?o^AP001?o^AP000ol0003okDX0one:0003one:0003o`000?o:]`3ob[L000;o00000_o:^000
1Ol0003obKP0olVh0?o9^03o000000CobKT00_l0000Dooooo`;o00006Oooool000Gooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o0000
1?ooool2o`0000?ooooo0_l00003o`1n5`03o`000?lCT@3o4i4000;o4i4000?o0000obBH0?lTV000
0_lTV0000ol0003o:iX0ob^J0002ob^J0003o`000?laW03o<I`000;o<I`000?o0000ocJM0?lfW@00
0_lfW@000ol0003o>Yl0ocZO0003ocZO0003o`000?lmX03o?J0000;o?J0000?o0000od2Q0?m0X@00
0_m0X@000ol0003o@j80od>R0003od>R0003o`000?m5X`3oAJ<000?oAJ<000?o0000odJS0?m6X`00
0_m6X`000ol0003oAj<0odNS0002odNS00;o00001?oGT`000ol0003oei<0omNC0004omNC0003o`00
0?oGT`3oei<000?oei<000?o0000omNC0?oGT`001?oGT`000ol0003oei80omNB0002omNB00?o0000
1?oGTP000ol0003of980o`000002o`000003on]A0?l0003ok4h000Gok4h000?o0000one;0?o]B`00
1?o]B`001?l0003okTL0oni70?o^A`05o`0000Kolc@000?o0000oo@]0?od;@001?od;@04o`0000Co
mRT000?o0000ooPQ0?oh8@001?oh8@001?l0003on1l0o`000?l00004ooLU0005o`000?o^AP3okTH0
oni60?l000001Oo]BP000ol0003ok4h0o`000002olZg0004o`000?o:^03ob[P0o`0000?obKP000Go
0000olVi0?o9^@3obKT0o`000002olVj0003o`000?oooooooooo01;ooooo00?o0000ooooooooool0
5oooool000Gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?l0EDco0000
00;o07hG00?o0000oa>A0?lCT@000_lCT@000ol0003o99P0obBH0002obBH0003o`000?l[VP3o:iX0
00;o:iX000?o0000oc6L0?laW0000_laW0000ol0003o=Yd0ocJM0002ocJM0003o`000?ljW`3o>Yl0
00?o>Yl000?o0000ocfP0?lmX0000_lmX0000ol0003o@:40od2Q0002od2Q0003o`000?m3XP3o@j80
00?o@j8000?o0000odFS0?m5X`000om5X`000ol0003oAZ<0odJS0002odJS0003o`000?m7X`3o0000
00;o000000?oei80o`000?oGT`001?oGT`000ol0003oei<0omNC0003omNC0003o`000?oGT`3oei<0
00Coei<000?o0000omNC0?oGT`000ooGT`000ol0003oei80o`000003o`0000Goei800ol00005on]A
0003o`000?o/CP3ok4h000Cok4h000?o0000one;0?o]B`000oo]B`04o`0000GolCT000?o0000oo<d
0?oc=0001?oc=0000ol0003om2d0oo@]0003o`000003oo@a0?l0003omRT000KomRT000Co0000ooPQ
0?oh8@3on2401?l00007ooLU0003o`000?o^AP3o000000GokDX000Co0000ona>0?o/CP3ok4h00_l0
00001?o:^03o0000olZh0?l00003olVh0005o`000?o9^@3obKT0olVi0?l000000_o9^P000ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo0006ooooo`;o00002_ooool2o`0000;ooooo
1Ol000000ooooooo0000o`000003o`0000?ooooo0_l00004ooooo`;o00000_l0OQL00ol0003o4i40
oa>A0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0
oc6L0002oc6L0003o`000?lfW@3o=Yd000?o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00
ocfP0002ocfP0003o`000?m0X@3o@:4000;o@:4000?o0000od>R0?m3XP000om3XP000ol0003oAJ<0
odFS0003odFS0004o`000?m6X`3oAZ<0odJS00?o00001?oGTP000ol0003oei<0omNC0003omNC0003
o`000?oGT`3oei<000?oei<000?o0000omNC0?oGT`001?oGT`000ol0003oei<0omNC0002omNC00?o
00001?oGTP000ol0003oei80o`000002o`000003on]C0?l0003oje4000Goje4000?o0000ona>0?o/
CP001?o/CP000ol0003okD/0one;0003o`0000;ol3h000?o0000oo4i0?oa>@001Ooa>@001?l0003o
lc@0oo<d0?oc=005o`0000Gom34000?o0000ooHY0?of:@001?of:@04o`0000ComRL000?o0000ooLU
0?og9@001?og9@02o`0000GokDX000?o0000ona>0?o/CP000oo/CP001?l0003ob[P0o`000?l00003
olVh0003o`000?o9^@3obKT000;obKT000?o0000olVj0?o9^P000_l0000Eooooo`03o`000?oooooo
oooo01Gooooo000Sooooo`;o00001Oooool2o`0000;o07hG00?o0000oa>A0?lCT@000_lCT@000ol0
003o99P0obBH0002obBH0003o`000?l[VP3o:iX000;o:iX000?o0000oc6L0?laW0000olaW0000ol0
003o=Yd0ocJM0002ocJM0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocfP0?lmX0000_lmX0000ol0
003o@:40od2Q0003od2Q0003o`000?m3XP3o@j8000;o@j8000?o0000odFS0?m5X`000om5X`04o`00
0003omNB0?l0003oei8000Goei8000?o0000omNC0?oGT`000_oGT`000ol0003oei<0omNC0004omNC
0003o`000?oGT`3oei<000?oei<000?o0000omNC0?l000000_l000000ooGT`3o0000omNB0003omNB
00?o00001Oo[D`000ol0003oje40on]A0004on]A0003o`000?o/CP3ok4h000?ok4h00ol00006oo0n
0003o`000?oa>@3olCT000ColCT01?l00004oo8g0003o`000?od<@3om34000Com34000?o0000ooHY
0?of:@000ol00002oo@_0003o`000?of9`3omRL000ComRL000?o0000ooLU0?og9@000ol00002ooD[
0005o`000?o]BP3okDX0one:0?l000001Oo/CP02o`0000;ob[P000Go0000olVh0?o9^03obKP0o`00
0003olVi0004o`000?o9^P3obKX0o`0000;obKX000?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Eooooo`008oooool00ol0003oooooooooo`04ooooo`;o00000_l0OQL00ol0003o4i40oa>A
0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0oc6L
0003oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP
0002ocfP0003o`000?m0X@3o@:4000?o@:4000?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0odFS
0002odFS00;o00001?oGTP000ol0003oei80omNB0004omNB0003o`000?oGT`3oei<000?oei<000?o
0000omNC0?oGT`000ooGT`000ol0003oei<0omNC0003omNC00;o00001OoGT`04o`000003onYD0?l0
003oje<000Koje<000?o0000on]A0?o[D@000oo[D@000ol0003ok4h0ona>0003o`0000;okd8000?o
0000oo0n0?o`?P001Oo`?P000ol0003olCT0oo4i0003o`000003oo0m0?l0003olSL000KolSL000Co
0000oo@a0?od<@3om3401Ol00006oo@_0004o`000?of9`3omRL0ooHW00Go00001_oe:`000ol0003o
kDX0o`000005ona>0005o`000?o[D@3oje40o`000?o:^0000_l00002olVh0005o`000?o9^@3obKT0
olVi0?l000000_o9^P001Ol0003obKX0olVj0?o9^P3o000001Cooooo00?o0000ooooooooool05?oo
ool002?ooooo0_l00005ooooo`;o00000_l0OQL00ol0003o4i40oa>A0002oa>A0003o`000?lTV03o
99P000;o99P000?o0000ob^J0?l[VP000ol[VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o
=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP0003ocfP0003o`000?m0X@3o
@:4000;o@:4000?o0000od>R0?m3XP000_m3XP000ol0003oAJ<0o`000002o`000003omRB0?l0003o
ei8000Coei8000?o0000omNB0?oGTP000ooGTP000ol0003oei<0omNC0003omNC0003o`000?oGT`3o
ei<000?oei<000?o0000omNC0?oGT`001?l00005omNC00;o00001OoZE0000ol0003oje<0on]C0004
on]C0003o`000?o[D@3oje4000?oje400ol00006onm20003o`000?o`?P3ol3h000Col3h00ol00005
oo0m0003o`000?ob=`3olSL000ColSL01?l00004oo8g0003o`000?od;`3om2l000Com2l01?l00004
oo@]0003o`000?oe:`3omB/000ComB/00_l00005ona>0004o`000?o[D@3oje40on]A00;o00000_o9
^002o`0000CobKT000Co0000olVj0?o9^P3o00000oo9^P000ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo00Cooooo0_l00002o`1n5`03o`000?lC
T@3o4i4000;o4i4000?o0000obBH0?lTV0000olTV0000ol0003o:iX0ob^J0002ob^J0003o`000?la
W03o<I`000;o<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o>Yl0ocZO0002ocZO0003o`000?lm
X03o?J0000?o?J0000?o0000od2Q0?m0X@000_m0X@001?l0003o@j80od>R0?m3XP03o`0000Cof980
00?o0000omNB0?oGTP000ooGTP000ol0003oei80omNB0003omNB0003o`000?oGT`3oei<000?oei<0
00?o0000omNC0?oGT`000ooGT`03o`0000Coei<000?o0000omNC0?l000000_l000000ooZEP3o0000
onYD0005onYD0003o`000?o[D`3oje<000Coje<000?o0000on]A0?l000000_l00003oni60003o`00
0?o_@P3okd8000Cokd8000?o0000oo0n0?o`?P000ol00002onm20003o`000?o`?@3ol3d000Col3d0
00?o0000oo8g0?ob=`000ol00002oo0m0003o`000?ob=`3olSL000ColSL000?o0000oo@_0?od;`00
0ol000000ooc=03o0000oo@]0006oo@]0003o`000?oe:`3omB/000?o00000_od<0001Ol0003ok4h0
ona>0?o/CP3o000000Goje4000?o0000olVh0?o9^0000_l00003olVi0004o`000?o9^P3obKX0o`00
00?obKX000?o0000olVj0?l000005?ooool00ol0003oooooooooo`0Cooooo`008oooool2o`0000Go
oooo0_l00003o`1n5`03o`000?lCT@3o4i4000;o4i4000?o0000obBH0?lTV0000_lTV0000ol0003o
:iX0ob^J0002ob^J0003o`000?laW03o<I`000;o<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o
>Yl0ocZO0002ocZO0003o`000?lmX03o?J0000?o?J0000?o0000od2Q0?m0X@000_m0X@04o`000003
omRA0?l0003of98000Gof98000?o0000omNB0?oGTP000_oGTP000ol0003oei80omNB0004omNB0003
o`000?oGT`3oei<000?oei<000?o0000omNC0?l000000ol00005omNC00?o00001OoZEP000ol0003o
jU@0onYD0004onYD0004o`000?o[D`3oje<0on]C00Co00001oo^AP001?l0003okd80onm20?o_@P05
o`0000Kokd8000Co0000oo0m0?o`?@3ol3d01Ol00006oo0m0004o`000?ob=`3olSL0oo8g00Go0000
1Ooc=0000ol0003om2d0oo@]0004oo@]00?o00001_od<0000ol0003ok4h0o`000006on]A00;o0000
0_o9^0001Ol0003obKT0olVi0?o9^@3o000000;obKX000Go0000olVj0?o9^P3obKX0o`000002olVj
0003o`000?oooooooooo017ooooo0_l0000Dooooo`008oooool00ol0003oooooooooo`04ooooo`;o
00000ol0OQL00ol0003o4i40oa>A0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[
VP000_l[VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?lj
W`000_ljW`000ol0003o?J00ocfP0003ocfP0004o`000?m0X@3o@:40od2Q00;o00001?oHT@000ol0
003of980omRB0004omRB0003o`000?oGTP3oei8000;oei8000?o0000omNB0?oGTP001?oGTP000ol0
003oei<0omNC0002omNC00?o00001?oGT`000ol0003oei<0o`000002o`000003onUF0?l0003ojUH0
00KojUH000?o0000onYD0?oZE0000ooZE004o`0000CokDP000?o0000oni60?o^AP001?o^AP04o`00
00CokTH000?o0000onm20?o_@P001?o_@P04o`0000Cokd8000?o0000oo0m0?o`?@001?o`?@04o`00
00ColC`000?o0000oo<d0?oc=0001?oc=0000ol0003om2d0oo@]0003o`000003oo<b0?l0003om300
00Kom3000_l00006on]A0003o`000?oZE03ojU@000;o000000GobKT0o`000?o9^@3obKT0o`000002
olVj0005o`000?o9^P3obKX0olVj0?l000000_o9^P000ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Gooooo0ol00004ooooo`;o00000oooool0013ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00Go0000o`1n5ol0OQOo07hGo`00
0004oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0oc6L
0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP
0003ocfP00Co000000?of940o`000?oHT@001?oHT@000ol0003of980omRB0003omRB0003o`000?oG
TP3oei8000?oei8000?o0000omNB0?oGTP000ooGTP000ol0003oei<0o`000002o`000003omNC0?l0
003oei<000?oei<00ol00005onUF0003o`000?oZEP3ojUH000CojUH000?o0000onYD0?oZE0000ol0
00000oo]B`3o0000one80006one80003o`000?o^AP3okTH000?o000000?okDT0o`000?o^AP001_o^
AP000ol0003okd80onm20003o`0000;okTL000?o0000onm20?o_@P001?o_@P000ol0003ol3d0oo0m
0003o`000003onm20?l0003olC`000KolC`000Co0000oo<d0?oc=03olc@01Ol00005oo<b0003o`00
0?od<03om30000;om3000_l000000ooc=03o0000on]A0004on]A0003o`000?oZE03ojU@000;ojU@0
00Go0000olVi0?l0003obKT0o`000002olVj0005o`000?o9^P3obKX0olVj0?l000000oo9^P02o`00
01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo000?ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool2
o`0000Oooooo00Go0000o`1n5ol0OQOo07hGo`000004oa>A0003o`000?lTV03o99P000;o99P000?o
0000ob^J0?l[VP000_l[VP000ol0003o<I`0oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o
0000ocZO0?ljW`000_ljW`000ol0003o?J00ocfP0002ocfP00;o00001?oHT@000ol0003of940omRA
0003omRA0003o`000?oHTP3of98000?of98000?o0000omNB0?oGTP000ooGTP000ol0003oei80omNB
0002omNB00?o00001OoGT`04o`000003onUG0?l0003ojEH000KojEH000?o0000onYF0?oZEP000ooZ
EP03o`0000GokD/000?o0000one80?o]B0001?o]B003o`0000GokDT000?o0000oni60?o^AP001?o^
AP03o`0000KokTL000Co0000onm20?o_@P3okd801Ol00005onm20003o`000?oa?03olC`000ColC`0
1?l00004oo4i0003o`000?oc<P3olc8000Colc8000Co0000oo@`0?l0003o00001?oc=0001Ol0003o
je40on]A0?o[D@3o000000CojU@00_l00002olVi00;o00000_o9^P001Ol0003obKX0olVj0?o9^P3o
000000;obKX000?o0000olVj0?l000005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool000oooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Go0000o`1n5ol0OQOo07hG
o`000004oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0
oc6L0002oc6L0003o`000?lfW@3o=Yd000;o=Yd000?o0000ocZO0?ljW`000_ljW`000ol0003o?J00
o`000002o`000003omR@0?l0003of94000Cof94000?o0000omRA0?oHT@000_oHT@000ol0003of980
omRB0004omRB0003o`000?oGTP3oei8000;oei8000?o0000omNB0?oGTP000_l000000ooGTP3o0000
omNC0004omNC00;o00001OoYE`000ol0003ojEH0onUF0004onUF0003o`000?oZEP3ojUH000?o0000
00?okD`0o`000?o]B`001_o]B`000ol0003okDP0one80003o`0000;ok4`000?o0000one90?o]B@00
1?o]B@000ol0003okTH0oni60003o`0000;okD/000?o0000oni70?o^A`001?o^A`04o`0000CokTL0
00?o0000onm20?o_@P001?o_@P000ol0003olC`0oo4l0003o`0000;ol40000?o0000oo4i0?oa>@00
1?oa>@001?l0003olc80oo<b0?oc<P04o`0000Oolc@000?o0000on]A0?l000001?oZE0001?l0003o
jUH0onYF0?l00002olVi0004o`000?o9^P3obKX0o`0000?obKX000Co0000olVj0?o9^P3o00000_o9
^P000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`003oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01Ol0003o07hGo`1n5ol0OQOo000000Co
4i4000?o0000obBH0?lTV0000_lTV0000ol0003o:iX0ob^J0002ob^J0003o`000?laW03o<I`000;o
<I`000?o0000ocJM0?lfW@000_lfW@000ol0003o>Yl0ocZO0004o`0000Cof90000?o0000omRA0?oH
T@000ooHT@000ol0003of940omRA0002omRA0003o`000?oHTP3of98000Cof98000?o0000omNB0?oG
TP000_oGTP03o`0000Coei8000?o0000omNC0?l000000_l000000ooZEP3o0000onUG0005onUG0003
o`000?oYEP3ojEH000?ojEH00ol00005one<0003o`000?o]B`3okD/000CokD/00ol00006ona<0004
o`000?o]B@3okDT0one900Go00001_o]B`000ol0003okTL0oni70003o`000003one<0?l0003okTL0
00KokTL000Co0000onm20?o_@P3okd801Ol00006oo100004o`000?oa>@3olCT0oo4i00Ko00001?ob
=P000ol0003olc@0oo<d0004oo<d00;o00001?oZE0000ol0003ojUH0onYF0002onYF00;o000000?o
bKX0o`000?l000000oo9^P001Ol0003obKX0olVj0?o9^P3o000000;obKX00_l0000Dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`00
3oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`05
o`000?l0OQOo07hGo`1n5ol000001?lCT@000ol0003o99P0obBH0002obBH0003o`000?l[VP3o:iX0
00;o:iX000?o0000oc6L0?laW0000_laW0001?l0003o=Yd0ocJM0?lfW@04o`0000;of90000?o0000
omR@0?oHT0000ooHT0000ol0003of940omRA0003omRA0003o`000?oHT@3of94000?of94000?o0000
omRB0?oHTP000ooHTP000ol0003oei80o`000003o`0000Goei800ol00005onYF0003o`000?oYE`3o
jEL000CojEL000?o0000onUF0?l000000_l00003ona=0003o`000?o]C03okD`000?okD`000?o0000
one;0?o]B`000ol00002ona>0003o`000?o/C03ok4`000Cok4`01?l00004ona>0003o`000?o]B`3o
kD/000CokD/00ol00005one<0003o`000?o^A`3okTL000CokTL01?l00004oni60003o`000?o`@03o
l40000Col4001?l00003oo0m0003o`000?ob=P3olSH000GolSH000?o0000oo<d0?oc=0000ol00000
0oob=`3o0000onYD0002onYD0003o`000?oZEP3ojUH000?ojUH00_l000000oo9^P3o0000o`000003
olVj0004o`000?o9^P3obKX0o`0000?obKX000?o0000olRj0?l000005?ooool00ol0003ooooooooo
o`02ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`003oooool01?l0003ooooooooo
ool00008ooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`;o00000_l0OQL00ol0003o4i40
oa>A0002oa>A0003o`000?lTV03o99P000;o99P000?o0000ob^J0?l[VP000_l[VP000ol0003o<I`0
oc6L0002oc6L00Co000000?of8l0o`000?oHT0000ooHT0000ol0003of900omR@0004omR@0003o`00
0?oHT@3of94000;of94000?o0000omRA0?oHT@000ooHT@000ol0003of980omRB0002omRB00?o0000
1?oGTP000ol0003oei80o`000002o`000003onYE0?l0003ojUH000KojUH000?o0000onUG0?oYE`00
0ooYE`02o`0000Ook4d000Co0000one<0?o]C03okD`01?l00006ona>0003o`000?o/C03ok4`000?o
00000_o[D@000ol0003ok4h0ona>0004ona>0003o`000?o]B`3okD/000?o00000_o[D0000ol0003o
kD`0one<0004one<0003o`000?o^A`3okTL000?o00000_o]C0000ol0003okTH0oni60004oni60003
o`000?o`@03ol40000?o000000?okd@0o`000?o`?@001Oo`?@000ol0003olSH0oo8f0002oo8f00Go
00001Oob=`000ol0003ojU@0o`000005onYF0003o`000?oYF03o000000;obKX000Go0000olVj0?o9
^P3obKX0o`000002olVj0004o`000?o9^P3obKX0o`0000?ob;X000?o0000ooooooooool04?ooool3
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo000@ooooo`;o00002_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo0_l00002o`1n5`03o`000?lCT@3o4i40
00;o4i4000?o0000obBH0?lTV0000_lTV0000ol0003o:iX0ob^J0002ob^J0004o`000?laW03o<I`0
oc6L00;o00001?oHS`000ol0003of900omR@0003omR@0003o`000?oHT03of90000?of90000?o0000
omRA0?oHT@000ooHT@000ol0003of940omRA0002omRA0003o`000?oHTP3o000000;o000000?of980
o`000?oGTP000ooGTP03o`0000GojUD000?o0000onYF0?oZEP001?oZEP000ol0003ojEL0onUG0003
o`0000;ok4d000?o0000ona=0?o/C@001?o/C@04o`0000Cok4l000?o0000ona>0?o/CP000oo/CP03
o`0000Koje4000Co0000ona>0?o/CP3ok4h01Ol00006on]@0004o`000?o]C03okD`0one<00Go0000
1_o]C0001?l0003okTH0oni60?o^AP05o`0000Gokd@000?o0000oo0m0?o`?@000oo`?@05o`0000?o
lCX000?o0000oo8g0?ob=`001?ob=`02o`0000GojUH000Co0000onUH0?oYF03ojEP00_l000001?o9
^P3o0000olVj0?l00003olVj0004o`000?o9^P3obKX0o`0000?ob;X000?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0=ooooo`008_ooool00ol0003oooooooooo`07ooooo`;o000000?o07hG
o`000?lCT@000olCT@000ol0003o99P0obBH0002obBH0003o`000?l[VP3o:iX000;o:iX01?l00000
0ooISP3o0000omR?0004omR?0003o`000?oHT03of90000;of90000?o0000omR@0?oHT0000ooHT000
0ol0003of940omRA0003omRA0004o`000?oHT@3of940omRA00?o00001OoHTP04o`000003onYD0?l0
003ojUD000KojUD000?o0000onYF0?oZEP000ooZEP03o`0000Kok4d000?o0000ona=0?o/C@000ol0
00000oo[D03o0000ona?0006ona?0003o`000?o/CP3o000000;o00000oo[D`000ol0003oje40on]A
0003on]A00Co00001?o[D`000ol0003oje00on]@0004on]@00Co00001?o[D0000ol0003okD`0one<
0004one<00Co00001?o]BP000ol0003okd@0onm40003onm40003o`000?o`?@3ol3d000?o000000?o
kd40o`000?oa>P001_oa>P000ol0003olSL0oo8g0003o`0000;olCX000Go0000onYF0?oZEP3ojUH0
o`000005onUH0005o`000?o9^P3o0000olVj0?l000000_o9^P001Ol0003obKX0olVj0?o9^P3o0000
00;ob;X000?o0000olRj0?l000005?ooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`04o`000?nT_@3o0000o`0000Co4i4000?o0000obBH0?lTV0000_lTV0000ol0
003o:iX0ob^J0003o`0000CofHh000?o0000omR?0?oHS`000ooHS`000ol0003of900omR@0002omR@
0003o`000?oHT03of90000?of90000?o0000omRA0?oHT@000ooHT@04o`000003omRA0?l0003of980
00Cof9800_l00005onYD0003o`000?oZE@3ojUD000CojUD000?o0000onYF0?oZEP000ol00002ona<
0003o`000?o/C@3ok4d000Cok4d00ol00005on]@0003o`000?o/C`3ok4l000Cok4l00_l00007on]C
0003o`000?o[D@3o000000;o000000?ojUH0o`000?o[D`001_o[D`000ol0003oje00on]@0003o`00
0003onYD0?l0003oje0000Koje0000?o0000one<0?o]C0000ol000000oo/C`3o0000one:0006one:
0004o`000?o_A03okd@0onm400Co00001Oo_@@000ol0003olCX0oo4j0004oo4j00?o00001_oa>P00
0ol0003ojUH0o`000006onUH00;o000000?obKX0o`000?l000000_o9^P001Ol0003obKX0olVj0?o9
^P3o000000;ob;X000?o0000olRj0?l000005Oooool00ol0003oooooooooo`0;ooooo`008Oooool2
o`0000Wooooo00Co0000ojBm0?l0003o00001?lCT@000ol0003o99P0obBH0005o`0000;ofHh000?o
0000omV>0?oISP000_oISP000ol0003of8l0omR?0003omR?0003o`000?oHT03of90000;of90000?o
0000omR@0?oHT0000ooHT0000ol0003of940omRA0002omRA00;o00001OoHT@000ol0003of980o`00
0002o`000003on]B0?l0003ojU@000GojU@000?o0000onYE0?oZE@000ooZE@03o`0000Kok4`000?o
0000ona=0?o/C@000ol00002on]@0003o`000?o[D03oje0000Coje0000?o0000ona?0?o/C`000ol0
0002onYD0003o`000?o[D`3oje<000Coje<00_l00005onYF0003o`000?o[D`3oje<000Coje<00ol0
0005onYD0003o`000?o[D03oje0000Coje000ol00005ona?0003o`000?o]BP3okDX000CokDX01?l0
0003oni70003o`000?o_@@3okd4000Cokd4000?o0000oo4j0?oa>P000ol000000oo`?@3o0000oo4j
0006oo4j00;o00001_oYF0000ol0003ojEX0onUJ0003o`0000;obKX000Co0000olVj0?o9^P3o0000
0oo8^P001?l0003ob;X0olRj0?l0000Dooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ojBm0?nT_@002?l00002omR@0003o`000?oISP3ofHh000;ofHh0
00?o0000omV>0?oISP000ooISP000ol0003of8l0omR?0002omR?0003o`000?oHT03of90000?of900
00?o0000omR@0?oHT0000_oHT0000ol0003of940o`000002o`000003omRA0?l0003of94000?of940
0ol00005on]B0003o`000?oZE03ojU@000CojU@000?o0000onYE0?l000000_l00003one;0003o`00
0?o/C03ok4`000?ok4`00ol00006on]@0004o`000?o[D03oje00on]@00Go00001_oZE0000ol0003o
je<0on]C0003o`0000;ojEL000?o0000onYF0?oZEP000ooZEP000ol0003oje<0on]C0003o`0000;o
jEL000?o0000onYD0?oZE0001?oZE0000ol0003oje00on]@0003o`0000;ojU<000?o0000ona?0?o/
C`001?o/C`000ol0003okDX0one:0003o`000003ona=0?l0003okTL000GokTL000Co0000onm10?o_
@@3okd401Ol00005oo0m0003o`000?oa>P3olCX000;olCX00_l000000oo`?@3o0000onUH0004onUH
0003o`000?oYFP3ojEX000;ojEX000Co0000olVj0?l0003o00000oo9^P001?l0003ob;X0olRj0?l0
0003olRj0003o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool0027ooooo00?o0000
ooooooooool02?ooool01?l0003oY;d0ojBm0?l00004om>O0003o`000?oHT03of90000;of90000?o
0000omV>0?oISP000_oISP000ol0003ofHh0omV>0003omV>0003o`000?oHS`3of8l000;of8l000?o
0000omR@0?oHT0000ooHT0001?l0003of900omR@0?oHT003o`0000Gof9401?l000000oo/C`3o0000
on]B0006on]B0003o`000?oZE03ojU@000?ojU@00_l00007one;0003o`000?o/C03o000000;o0000
0oo[D0000ol0003oje00on]@0003on]@00Co00001?oZE@000ol0003ojU@0onYD0004onYD00?o0000
1_oYE`001?l0003ojUH0onYF0?oZEP04o`0000KojEL000Co0000onYD0?oZE03ojU@01Ol00006onYC
0004o`000?o/C`3ok4l0ona?00Go00001Oo/C@001?l0003okTL0oni70?o^A`06o`0000Cokd@000?o
0000oo0m0?o`?@001?o`?@001?l0003olCX0o`000?l00004oo0m0005o`000?oYF03ojEP0onUH0?l0
00001?oYFP02o`000003olVj0?l0003o000000?obKX000Co0000olRj0?o8^P3o00000oo8^P02o`00
01Gooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`04o`000?nT_@3oY;d0o`00
00Codil000?o0000omR@0?oHT0000_oHT0000ol0003ofHh0omV>0003omV>0003o`000?oISP3ofHh0
00;ofHh000?o0000omR?0?oHS`000ooHS`000ol0003of900omR@0002omR@00Co00000_oHT0000ol0
003of940omRA0002omRA00;o00001Oo/C`000ol0003oje80on]B0004on]B0003o`000?oZE03ojU@0
00?o00000_o]B@000ol0003okD/0one;0004one;00;o00001oo[D0000ol0003oje00o`000002o`00
00;ojUD000?o0000onYE0?oZE@001?oZE@000ol0003ojU@0onYD0003o`0000;ojET000?o0000onUG
0?oYE`001?oYE`04o`0000CojET000?o0000onUG0?oYE`000ooYE`04o`0000CojEL000?o0000onYC
0?oZD`001?oZD`04o`0000?oje8000?o0000ona=0?o/C@001?o/C@04o`0000CokDX000?o0000onm4
0?o_A0001?o_A0001?l0003ol3d0oo0m0?o`?@04o`0000Ool3d000?o0000onUH0?l000001?oYFP00
1_l0003oj5/0onQK0?l0003obKX0o`0000;obKX000Go0000olRj0?o8^P3ob;X0o`000002olRj0004
o`000?o9^P3obKX0o`0001?ooooo0_l0000;ooooo`000_ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`04
o`000?nT_@3oY;d0o`0000Codil000?o0000omR@0?oHT0000_oHT0000ol0003ofHh0omV>0003omV>
0003o`000?oISP3ofHh000;ofHh000?o0000omR?0?oHS`000ooHS`000ol0003of900omR@0003o`00
00Gof90000?o0000omRA0?l000000_l000000oo/C03o0000ona?0005ona?0003o`000?o[DP3oje80
00?oje800ol00006one90003o`000?o]B`3okD/000?o00000_o/C`000ol0003oje00on]@0004on]@
00;o00001_oZE@000ol0003ojUD0onYE0003onYE00?o00001_oYF@000ol0003ojEL0onUG0003o`00
00;oj5/000?o0000onUI0?oYF@001?oYF@000ol0003ojEL0o`000002o`0000;oj5X000?o0000onUG
0?oYE`001?oYE`000ol0003ojU<0onYC0003o`0000;ojEL000?o0000on]B0?o[DP000oo[DP000ol0
003ok4d0ona=0003o`000003on]@0?l0003okDX000KokDX000Co0000onm40?o_A03okd@01_l00004
oo0o0003o`000?o`?@3ol3d000Col3d00_l00004onUJ0004o`000?oXF`3oj5/0onQK00;o000000Co
bKX0o`000?o9^P3o00000_o8^P001Ol0003ob;X0olRj0?o8^P3o000000;obKX00_l0000Dooooo`03
o`000?oooooooooo00Sooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000oooooooo
ool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000ooooooooooooooooo`00
000<ooooo`03o`000?nT_@3o000000Codil000?o0000omR@0?oHT0000ooHT0000ol0003ofHh0omV>
0002omV>0003o`000?oISP3ofHh000;ofHh000?o0000omR?0?oHS`000ooHS`03o`0000;of90000?o
0000omR@0?oHT0000_oHT003o`0000Gok4`000?o0000ona?0?o/C`001?o/C`000ol0003oje80o`00
0002o`0000?okTL000?o0000one90?o]B@000oo]B@03o`0000Kok4l000?o0000on]@0?o[D0000ol0
0002onYE0003o`000?oZE@3ojUD000CojUD000?o0000onYE0?l000000_l00002onUI0003o`000?oY
F@3ojET000CojET00ol00006onQK0004o`000?oYF@3ojET0onUI00Co00001_oXFP001?l0003ojEL0
onUG0?oYE`05o`0000KojEL000Co0000on]B0?o[DP3oje801?l00005on]@0003o`000?o]BP3okDX0
00CokDX01?l00004oni60003o`000?o`?`3ol3l000Col3l000?o0000oo0m0?o`?@000ol000000oo`
?`3o0000onUJ0002onUJ0003o`000?oXF`3oj5/000?oj5/000?o0000olVj0?o9^P000_l00002olRj
0005o`000?o8^P3ob;X0olRj0?l000000_o9^P000ol0003obKX0o`00000Booooo`?o00002Oooool0
0005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooooooo0_l0000;ooooo`04o`000?nT_@3oY;d0o`0000Codil0
00?o0000omR@0?oHT0000_oHT0000ol0003ofHh0omV>0002omV>0003o`000?oISP3ofHh000;ofHh0
00?o0000omR?0?oHS`001?l00005omR@00Co000000?okDT0o`000?o/C0001_o/C0000ol0003ok4l0
ona?0003ona?00;o00001oo^A`000ol0003okDT0o`000002o`0000?ok4d000?o0000ona?0?o/C`00
0oo/C`03o`0000KojUD000Co0000onYE0?oZE@3ojUD01?l00006onUI0003o`000?oYF@3ojET000?o
00000_oXG0000ol0003oj5/0onQK0004onQK00Co00001?oXG@000ol0003oj5X0onQJ0003onQJ00Co
00001?oXFP000ol0003ojEL0onUG0004onUG00Co00000ooZE@000ol0003oje00on]@0004on]@0003
o`000?o]BP3okDX000?o000000?ok4d0o`000?o^AP001_o^AP001?l0003ol3l0oo0o0?o`?`05o`00
00Gol3l000?o0000onUJ0?l000001OoXF`001?l0003oj5/0o`000?o9^P02o`0000;ob;X000Oo0000
olRj0?o8^P3ob;X0o`000?o9^P3o000000?obKX000?o0000ooooooooool03?ooool3o`0000;ooooo
00?o0000ooooooooool01oooool00005ooooool0003oooooooooool000002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<ooooo`04
o`000?nT_@3oY;d0o`0000Codil000?o0000omR@0?oHT0000_oHT0000ol0003ofHh0omV>0002omV>
0003o`000?oISP3ofHh000;ofHh00ol00003omR?0003o`000?oHT03of90000;of9000_l00005one9
0003o`000?o/C03ok4`000Cok4`000?o0000ona?0?o/C`000ol00002onm40003o`000?o^A`3okTL0
00CokTL00_l00007ona=0003o`000?o/C`3o000000;o00000ooZE0000ol0003ojUD0onYE0003onYE
00Co00001?oYF@000ol0003ojET0onUI0003onUI00?o00001_oXG0000ol0003oj5/0onQK0003o`00
0003onMN0?l0003oj5d000Koj5d000?o0000onQJ0?l000000_l00002onQM0003o`000?oXFP3oj5X0
00Coj5X000?o0000onUG0?oYE`000ol000000ooYF@3o0000onYE0005onYE0004o`000?o[D03oje00
on]@00Go00001Oo/C@000ol0003okTH0oni60004oni600Co00000oo_@@000ol0003ol3l0oo0o0004
oo0o00;o00001OoXF`001?l0003oj5/0onQK0?oXF`03o`000003olRj0?l0003ob;X000;ob;X000Co
0000olVj0?o9^P3o00000oo9^P000ol0003oooooooooo`09ooooo`?o00001Oooool00ol0003ooooo
ooooo`07ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000003o`0000Cooooo00?o0000ooooooooool02_ooool01?l0003o
Y;d0ojBm0?l00004om>O0003o`000?oHT03of90000;of90000?o0000omV>0?oISP000_oISP000ol0
003ofHh0omV>0004o`0000Gof8l01?l000000oo^A@3o0000one90005one90003o`000?o/C03ok4`0
00?ok4`00ol00006onm40003o`000?o^A`3okTL000?o00000_o]B`000ol0003ok4d0ona=0004ona=
00;o00001ooZE0000ol0003ojUD0o`000002o`0000;ojET000?o0000onUI0?oYF@001?oYF@000ol0
003ojET0o`000002o`0000?oj5d000?o0000onQL0?oXG0000ooXG003o`0000Goieh000?o0000onQM
0?oXG@001?oXG@02o`0000Koj5d000Co0000onQJ0?oXFP3oj5X01Ol00005onUI0003o`000?oZE@3o
jUD000?ojUD01?l00004on]B0003o`000?o/C@3ok4d000Cok4d000?o0000oni60?o^AP000ol00000
0oo^B03o0000onm10005onm10003o`000?o`?`3ol3l000?o00000_o`@0001Ol0003oj5/0onQK0?oX
F`3o000000Goj5/000Co0000olRj0?l0003o00000oo8^P001?l0003obKX0olVj0?l00002olVj0003
o`000?o9^P3o000000Kooooo1?l00008ooooo`03o`000?oooooooooo00Oooooo00001Ooooooo0000
oooooooooooo000000Sooooo0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000007
ooooo`;o00002oooool01?l0003oY;d0ojBm0?l00004om>O0003o`000?oHT03of90000;of90000?o
0000omV>0?oISP000_oISP03o`0000?ofHh000?o0000omR?0?oHS`000_oHS`02o`0000GokTD000?o
0000one90?o]B@001?o]B@000ol0003ok4`0o`000002o`0000?ol40000?o0000onm40?o_A0000oo_
A003o`0000KokD/000?o0000ona=0?o/C@000ol00002on]B0003o`000?oZE03ojU@000CojU@00_l0
0006onUI0004o`000?oYF@3ojET0onUI00Co00001ooXG@000ol0003oj5`0o`000002o`0000;oif00
00?o0000onMN0?oWGP001?oWGP000ol0003oj5d0onQM0003o`0000;oiel000?o0000onQM0?oXG@00
0ooXG@04o`0000Coj5d000?o0000onUI0?oYF@001?oYF@000ol0003ojUD0o`000002o`0000;ojEL0
00?o0000on]B0?o[DP001?o[DP001?l0003ok4d0ona=0?o/C@05o`0000GokTP000Co0000onm10?o_
@@3okd401Ol00006oo100003o`000?oXF`3o000000Goj5/00_l000000oo8^P3o0000o`000003olRj
0004o`000?o9^P3obKX0o`0000;obKX000Co0000olVj0?o9^P3o00000_ooool3o`0000cooooo00?o
0000ooooooooool01oooool000;ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo0ol00002
ooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?nT_@3o000000Codil000?o0000
omR@0?oHT0000_oHT0000ol0003ofHh0o`000002o`000003omV>0?l0003ofHh000?ofHh000?o0000
omR?0?l000000_l000000oo`@03o0000oni50005oni50003o`000?o]B@3okDT000?okDT00ol00006
oo100003o`000?o_A03o000000;o00000oo^B0000ol0003okD/0one;0003one;00?o00001_o[DP00
0ol0003ojU@0onYD0003o`0000;ojEP000?o0000onUI0?oYF@000ooYF@04o`0000Coj5d000?o0000
onQM0?oXG@001?oXG@02o`0000Koif0000Co0000onMN0?oWGP3oieh01Ol00006onMO0003o`000?oX
G@3o000000;o000000?oiel0o`000?oXG@001_oXG@001?l0003ojET0onUI0?oYF@04o`0000KojEL0
00Co0000on]B0?o[DP3oje801_l00003ona>0003o`000?o^B03okTP000CokTP01?l00004onm30003
o`000?o`@03ol40000Col4000_l00005onQK0003o`000?oXG03oj5`000?o00000_o8^P001?l0003o
bKX0olVj0?l00003olVj0003o`000?o9^P3obKX000?o00004?ooool00ol0003oooooooooo`06oooo
o`008?ooool00ol0003oooooooooo`0;ooooo`03o`000?nT_@3o000000Codil000Co0000omR@0?oH
T03of9000ol00004omV>0004o`000?oISP3ofHh0omV>00?o00001Oo`@0000ol0003okTD0oni50004
oni50003o`000?o]B@3o000000;o00000ooa?0000ol0003ol400oo100003oo1000;o00001oo^B000
0ol0003okD/0o`000002o`0000?ok50000?o0000on]B0?o[DP000oo[DP03o`0000KojEP000?o0000
onUI0?l000000_l00003onQM0003o`000?oXG@3oj5d000?oj5d000?o0000onQM0?oXG@000ol00002
onMP0003o`000?oWH03oif0000?oif001?l00004onIQ0003o`000?oWG`3oiel000Coiel00_l00005
onMO0003o`000?oXG@3oj5d000Coj5d01?l00003onQK0003o`000?oYE`3ojEL000CojEL01?l00004
onYD0003o`000?o/CP3ok4h000?ok4h000?o0000oni80?o^B0000ol000000oo]B@3o0000onm30006
onm30003o`000?o`@03ol40000?o000000?okd40o`000?oXF`000ooXF`000ol0003oj5`0onQL0002
onQL0005o`000?o8^P3o0000olRj0?l000000_o9^P001?l0003obKX0olVj0?l00003olVj00;o0000
4Oooool00ol0003oooooooooo`06ooooo`007oooool00ol0003oooooooooo`0=ooooo`;o00001?oC
W`04o`0000;of90000?o0000omV>0?oISP000_oISP04o`000003oo4k0?l0003ol40000Gol40000?o
0000oni50?o^A@001?o^A@02o`0000OolC`000?o0000oo100?l000000_l00002onm40003o`000?o^
B03okTP000CokTP00_l00007ona@0003o`000?o[DP3o000000;o00000_oYEP000ol0003ojEP0onUH
0004onUH00;o00001ooXG@001?l0003oj5d0onQM0?oXG@04o`0000Koif0000?o0000onMP0?l00000
0_l00002onIR0003o`000?oVH@3oiV4000CoiV4000?o0000onMO0?oWG`000ol000000ooVHP3o0000
onMO0005onMO0003o`000?oXG@3oj5d000?o00000_oWG`000ol0003oj5/0onQK0003onQK0003o`00
0?oYE`3ojEL000?o00000_oYF@000ol0003ojU@0onYD0004onYD0004o`000?o/CP3ok4h0ona>00Co
00001Oo]B@000ol0003okd<0onm30004onm300?o00001Oo_@@001?l0003oj5/0onQK0?l00005onQL
0003o`000?o8^P3ob;X000;o00000_o9^P001?l0003obKX0olVj0?l00002olVj0003o`000?o9^@3o
0000017ooooo00?o0000ooooooooool01_ooool001oooooo00?o0000ooooooooool03Oooool01?l0
003oY;d0o`000?oCW`03o`0000Gof90000Co0000omV>0?oISP3ofHh00_l00005oo4k0003o`000?o`
@03ol40000Col40000Co0000oni50?o^A@3okTD00_l000000oob=P3o0000oo4l0006oo4l00;o0000
1_o_A0000ol0003okTP0oni80003o`0000;ok4d000?o0000ona@0?o/D0001?o/D002o`0000KojEH0
00?o0000onUH0?oYF0000ol00002onQL0003o`000?oXG@3oj5d000Coj5d01?l00003onMQ0003o`00
0?oWH03oif0000Coif000_l00006onIR0004o`000?oVH@3oiV40onIQ00Go00001OoVHP001?l0003o
iel0onMO0?oWG`05o`0000Koiel000Co0000onQK0?oXF`3oj5/01?l00006onUI0004o`000?oZE03o
jU@0onYD00Ko00000oo/D0000ol0003okDT0one90004one90003o`000?o_@`3okd<000?o000000?o
kd<0o`000?o_@@001Oo_@@000ol0003oj5/0o`000005onQL0004o`000?oXF`3o0000olRj00;o0000
00?obKX0o`000?o9^P000_o9^P001?l0003obKX0olVj0?l00002olVi0003o`000?oooooooooo00ko
oooo00?o0000ooooooooool01_ooool001oooooo0_l0000?ooooo`?o00000ooCW`000ol0003of900
omR@0002omR@00Co000000?olSD0o`000?oa>`001Ooa>`000ol0003ol400oo100003oo100004o`00
0?o^A@3o0000o`0000ColSH000?o0000oo4l0?oa?0000_oa?002o`0000;ol3l000?o0000onm40?o_
A0000oo_A003o`0000Kok4d000?o0000ona@0?o/D0000ol00002onYD0003o`000?oYEP3ojEH000?o
jEH00ol00006onQL0003o`000?oXG@3oj5d000?o00000_oWH0000ol0003oif40onMQ0003onMQ0003
o`000?oWH03oif0000?o00000_oVH`000ol0003oiV80onIR0003onIR00Co00001?oVI0000ol0003o
iV80onIR0003onIR00Co00001?oVHP000ol0003oiel0onMO0004onMO00Co00000ooXG@000ol0003o
jET0onUI0004onUI00Co00000ooZE@000ol0003ok500ona@0004ona@0004o`000?o]B@3okDT0one9
00Go00001Oo_@`000ol0003okd40onm10003onm100;o00001OoXG0001?l0003oj5/0onQK0?oXF`03
o`000005olVj0?l0003obKX0olVj0?l000000oo9^P001?l0003obKT0olVi0?l0000@ooooo`03o`00
0?oooooooooo00Kooooo000Oooooo`03o`000?oooooooooo00cooooo1?l00004om>O0004o`000?oH
T03of900omR@00;o00001Oob=@000ol0003olC/0oo4k0003oo4k0003o`000?o`@03ol40000?ol400
0ol00006oo8f0004o`000?oa?03o0000o`0000Gol3l000?o0000onm40?l000000_l00003one90003
o`000?o/C@3ok4d000?ok4d00ol00006onYD0003o`000?oYEP3o000000;o00000ooXFP000ol0003o
j5`0onQL0003onQL00?o00001_oWH0001?l0003oif40onMQ0?oWH@04o`0000KoiV<000?o0000onIR
0?l000000_l00002onEU0003o`000?oVI03oiV@000CoiV@000?o0000onIR0?l000000_l00002onIT
0003o`000?oVHP3oiV8000CoiV8000?o0000onMO0?oWG`000ol000000ooWH03o0000onQM0005onQM
0003o`000?oYF@3ojET000?o000000?ojEX0o`000?oZE@001OoZE@001?l0003ok500ona@0?o/D006
o`0000?okDX000?o0000onm30?o_@`001?o_@`000ol0003okd40onm10003o`0000;okd4000Go0000
onQL0?oXG03oj5`0o`000004onQK00;o000000?obKX0o`000?l000000_o9^P001Ol0003obKX0olVj
0?o9^P3o000000;obKT00_l0000?ooooo`03o`000?oooooooooo00Kooooo000Oooooo`03o`000?oo
oooooooo00Wooooo0ol00003ooooo`Co000000?odil0o`000?l000000_l000000ooc<@3o0000oo8e
0005oo8e0003o`000?oa>`3olC/000?olC/000?o0000oo100?l000000_l00003oo@`0003o`000?ob
=P3olSH000?olSH00ol00006oo0o00?o00001_o]B@000ol0003ok4d0o`000002o`0000?oje4000?o
0000onYD0?oZE0000ooZE002o`0000Ooj5X000?o0000onQL0?l000000_l00002onMO0003o`000?oW
H03oif0000Coif001?l00003onIS0003o`000?oVH`3oiV<000CoiV<00_l00006onEU0004o`000?oV
I03oiV@0onIT00Co00001_oVI0001?l0003oiV80onIR0?oVHP05o`0000Goif0000Co0000onQM0?oX
G@3oj5d01Ol00005onUJ0003o`000?oZE@3ojUD000?ojUD01?l00004on]@0003o`000?o]BP3okDX0
00?okDX000Co0000onm30?o_@`3okd<01Ol00006onm10003o`000?oXG03o000000Coj5/000Co0000
onQK0?l0003obKX00_l00002olVj0004o`000?o9^P3obKX0o`0000;obKT000Co0000olVi0?o9^@3o
00003_ooool00ol0003oooooooooo`06ooooo`007_ooool3o`0000Oooooo0ol00006ooooo`04o`00
0?o`@03ol400oo1000;o00001Ooc<@000ol0003olSD0oo8e0003oo8e0003o`000?oa>`3olC/000?o
lC/00ol00006oo@`0003o`000?ob=P3o000000;o00000ooa>P02o`000004oo0o0?l0003o0000o`00
00?okTD000?o0000one90?o]B@000oo]B@02o`0000Ooje4000?o0000onYD0?l000000_l00002onUH
0003o`000?oXFP3oj5X000Coj5X00_l00006onMO0003o`000?oWH03oif0000?o00000_oVH`000ol0
003oiV<0onIS0003onIS0003o`000?oVH`3oiV<000?o00000_oUI@000ol0003oiFD0onEU0003onEU
00Co00001?oUI@000ol0003oiV@0onIT0003onIT00Co00001?oVH`000ol0003oif00onMP0003onMP
00Co00001?oWGP000ol0003ojEX0onUJ0004onUJ0003o`000?oZE@3o000000;o00000_oZEP000ol0
003oje00on]@0004on]@0004o`000?o]BP3okDX0one:00Go00001?o_A0000ol0003okd40onm10004
onm100;o00001?oXF`001?l0003oj5/0onQK0?oXF`03o`000003olVj0?l0003obKX000;obKX000Co
0000olVi0?o9^@3o00000_o9^@000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo
0005ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Kooooo00?o
0000ooooooooool00oooool3o`0000[ooooo00Go0000oo100?o`@03ol400o`000005oo<a0003o`00
0?ob=@3olSD000ColSD000?o0000oo4k0?l000000_l00003ooHY0003o`000?od<03om30000?om300
0_l00007oo4j00;o00001oo^A@000ol0003okDT0o`000002o`0000;ok4h000?o0000on]A0?o[D@00
1?o[D@02o`0000KojEP000?o0000onQJ0?oXFP000ol00002onQM0003o`000?oWG`3oiel000?oiel0
0ol00006onIS0004o`000?oVH`3oiV<0onIS00Co00001_oUI@000ol0003oiFD0o`000002o`0000;o
iFL000?o0000onEU0?oUI@001?oUI@000ol0003oiV@0o`000002o`0000;oiFD000?o0000onIS0?oV
H`001?oVH`000ol0003oif00o`000002o`0000;oiV4000?o0000onMN0?oWGP001?oWGP001?l0003o
jEX0onUJ0?oYFP04o`0000KojUH000Co0000on]@0?o[D03oje001_l00003one;0003o`000?o_A03o
kd@000Cokd@000?o0000onm10?o_@@000ol000000oo_@@3o0000onQK0002onQK0003o`000?oXF`3o
j5/000?oj5/000Co0000olVj0?l0003o00000oo9^P001?l0003obKT0olVi0?l00002olVi00;o0000
3_ooool00ol0003oooooooooo`05ooooo`001?ooool01?l0003oooooooooool00009ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`?o00003Oooool00ol0003ol400oo100002oo100003o`000?oc<@3olc4000?olc4000?o0000oo8e
0?ob=@000oob=@02o`0000OomRT000?o0000oo@`0?l000000_l00002oo<d0003o`000?oa>P3olCX0
00;olCX00_l00002oo0o0003o`000?o^A@3okTD000CokTD00_l00006ona>0003o`000?o[D@3oje40
00?o00000_oZE@000ol0003ojEP0onUH0003onUH00?o00001_oXG@000ol0003oiel0o`000002o`00
00?oiV8000?o0000onIS0?oVH`000ooVH`04o`0000?oiFH000?o0000onEU0?oUI@001?oUI@02o`00
00KoiFL000Co0000onEU0?oUI@3oiFD01?l00006onEU0004o`000?oVH`3oiV<0onIS00Co00001_oV
H@001?l0003oieh0onMN0?oWGP06o`0000?oj5/000?o0000onYF0?oZEP001?oZEP04o`0000?oje40
00?o0000one;0?o]B`001?o]B`001?l0003okd@0onm40?o_A005o`0000Gokd4000?o0000onQK0?l0
00001OoXF`02o`0000;obKX000Co0000olVj0?o9^P3o00000oo9^@000ol0003obKT0o`000002olVh
0003o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool000Cooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1?l0000Aoooo
o`05o`000?o`@03ol400oo100?l000001Ooc<@000ol0003olSD0oo8e0003o`0000;on24000?o0000
ooHY0?of:@001?of:@02o`0000Kolc@000Co0000oo4j0?l0003o00001Oo`?`000ol0003okTD0oni5
0003o`0000;okDT000?o0000ona>0?o/CP000oo/CP03o`0000KojUD000?o0000onUH0?l000000_l0
0003onQK0003o`000?oXG@3oj5d000?oj5d00_l00007onIR0003o`000?oVH`3o000000;o00000_oU
I@000ol0003oiFH0onEV0003onEV0003o`000?oUI@3oiFD000?o00000_oUI`000ol0003oiFL0onEW
0003onEW00Co00001?oUI`000ol0003oiFD0onEU0003onEU00Co00001?oVI0000ol0003oiV40onIQ
0003onIQ00Co00001?oWG`000ol0003oj5/0onQK0003onQK0003o`000?oZEP3ojUH000?o000000?o
jUH0o`000?o[D@001Oo[D@001?l0003okD/0one;0?o]B`06o`0000?okd@000?o0000onm10?o_@@00
1?o_@@02o`0000Goj5/000?o0000onQJ0?oXFP000ol00002olVj0004o`000?o9^@3obKT0o`0000;o
bKT000?o0000olVh0?o9^0000_l0000<ooooo`03o`000?oooooooooo00Gooooo0004ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o
00004oooool00ol0003ol400oo100002oo100003o`000?oc<@3olc4000;olc400ol00006ooPQ0003
o`000?of:@3omRT000?o00000_oe;@000ol0003olc@0oo<d0003oo<d00?o00001_o`?`03o`0000Ko
kDT000?o0000ona>0?l000000_l00003on]B0003o`000?oZE@3ojUD000?ojUD00_l00007onQK0003
o`000?oXG@3o000000;o00000_oWH0000ol0003oiV80onIR0004onIR00;o00001_oUI@001?l0003o
iFH0onEV0?oUIP04o`0000KoiFL000?o0000onEW0?l000000_l000000ooUJ03o0000onEW0006onEW
0003o`000?oUI@3o000000;o00000_oUIP000ol0003oiV@0onIT0004onIT0003o`000?oVH@3o0000
00;o000000?oiV80o`000?oWG`001_oWG`001?l0003oj5/0onQK0?oXF`04o`0000GojUH000?o0000
on]A0?o[D@000oo[D@04o`0000CokDX000?o0000onm40?o_A0000oo_A0000ol0003okd40onm10003
o`0000;okd4000Go0000onQK0?oXF`3oj5/0o`000004onQJ0005o`000?o9^P3o0000olVj0?l00000
0_o9^@001?l0003obKT0olVi0?l00002olVh0003o`000?o:]`3o000000_ooooo00?o0000oooooooo
ool01Oooool000Cooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooooooool4o`00
00Oooooo00?o0000ooooooooool04?ooool00ol0003ol400oo100002oo100003o`000?oc<@3o0000
00;o00000_oi6`000ol0003on240ooPQ0004ooPQ00?o00001_oe;@000ol0003olc@0o`000002o`00
00?olCT00_l000001?o`?`3o0000o`000?l00003oni40003o`000?o]B@3okDT000?okDT00_l00007
on]B0003o`000?oZE@3o000000;o00000_oYF@000ol0003oj5/0onQK0004onQK00;o00001_oWH000
0ol0003oiV80onIR0003o`0000;oiV@000?o0000onEU0?oUI@000ooUI@04o`0000?oiFL000?o0000
onEW0?oUI`001?oUI`02o`0000GoiFP000?o0000onEW0?oUI`001?oUI`02o`0000KoiFH000Co0000
onIT0?oVI03oiV@01?l00005onIR0003o`000?oWG`3oiel000Coiel01?l00003onQK0003o`000?oZ
EP3ojUH000CojUH000?o0000on]A0?l000000_l000000oo[D@3o0000one:0006one:0004o`000?o_
A03okd@0onm400Co00001_o_@@000ol0003oj5/0o`000005onQJ00;o000000?obKX0o`000?l00000
0_o9^@001_l0003obKT0olVi0?l0003obKP0o`0000?ob[L000?o0000ooooooooool02?ooool00ol0
003oooooooooo`05ooooo`001?ooool01?l0003oooooooooool00008ooooo`;o00000oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo1_l00006ooTK0004o`000?oh8@3on240
ooPQ00;o00000oog9@000ol0003omBd0ooD]0003ooD]00?o00001_oa>@03o`0000KokT@000?o0000
one90?l000000_l00002ona>0003o`000?o[DP3oje8000Coje800_l00006onUI0003o`000?oXF`3o
j5/000?o00000_oWGP000ol0003oif00onMP0003onMP00?o00001_oVI0000ol0003oiFD0o`000002
o`0000;oiFL000?o0000onEW0?oUI`000ooUI`000ol0003oiFL0onEW0003o`0000;oi6T000?o0000
onEX0?oUJ0000ooUJ0000ol0003oiFL0onEW0003o`0000;oiFP000?o0000onEV0?oUIP000ooUIP04
o`0000?oiFD000?o0000onIR0?oVHP001?oVHP000ol0003oiel0onMO0003o`000003onMO0?l0003o
j5/000Goj5/000Co0000onYF0?oZEP3ojUH01?l00005on]A0003o`000?o]BP3okDX000CokDX01?l0
0003onm30003o`000?o_@@3okd4000Cokd400_l00005onQJ0003o`000?oYF@3ojET000?o000000Go
bKT0o`000?o9^@3obKT0o`000002olVh0005o`000?o:]`3ob[L0olZg0?l000002_ooool00ol0003o
ooooooooo`05ooooo`001Oooool2o`0000[ooooo00Co0000oooooooooooooooo1Ol00008ooooo`03
o`000?oooooooooo017ooooo00Go0000ooHX0?of:03omRP0o`000006ooTK0003o`000?oh8@3o0000
00KombD000?o0000ooD]0?l000000_l00003oo<b0004o`000?oa>@3olCT0oo4i00;o00000oo`?P00
0ol0003okT@0oni40003oni400;o00001_o/CP000ol0003oje80on]B0003o`0000;ojUD000?o0000
onUI0?oYF@000ooYF@03o`0000Koieh000?o0000onMP0?l000000_l00002onIS0003o`000?oVI03o
iV@000CoiV@00_l00006onEW0004o`000?oUI`3oiFL0onEW00Co00001_oTJ@001?l0003oiFP0onEX
0?oUJ004o`0000KoiFP000?o0000onEV0?l000000_l000000ooUI`3o0000onEU0005onEU0004o`00
0?oVHP3oiV80onIR00Go00001OoWG`001?l0003oj5/0onQK0?oXF`06o`0000?ojUH000?o0000on]A
0?o[D@001?o[D@000ol0003okDX0one:0003o`000003one:0?l0003okd<000Gokd<000?o0000onm1
0?o_@@000ol000000oo`?`3o0000onQJ0003onQJ0003o`000?oYF@3ojET000;ojET00_l000001Oo9
^@3o0000olVi0?o9^@3o000000;obKP000Co0000olZg0?o:]`3ob[L00_l00008ooooo`;o00001ooo
ool002?ooooo0_l0000Booooo`05o`000?of:03omRP0ooHX0?l000001Ooi6`03o`0000KombD00ol0
0006oo<b0003o`000?oa>@3o000000Kol3h000?o0000oni40?l000000_l00002one90003o`000?o/
CP3ok4h000?ok4h00ol00006onYE0003o`000?oYF@3o000000;o00000ooXG0000ol0003oieh0onMN
0003onMN00;o00001_oVH`000ol0003oiV@0onIT0003o`0000;oiFH000?o0000onEW0?oUI`000ooU
I`04o`0000?oi6T000?o0000onAY0?oTJ@001?oTJ@04o`0000?oi6T000?o0000onEX0?oUJ0001?oU
J002o`0000GoiFL000?o0000onEU0?oUI@000ooUI@04o`0000CoiV8000?o0000onMO0?oWG`000ooW
G`04o`0000?oj5/000?o0000onYF0?oZEP001?oZEP001?l0003oje40on]A0?o[D@05o`0000GokDX0
00?o0000onm30?o_@`000oo_@`03o`0000Gol3l000Co0000onQJ0?oXFP3o00001?oYF@02o`000003
olVi0?l0003o000000;obKT000Co0000olVh0?o9^03o00000_o:]`001?l0003ob[H0olZf0?l00007
ooooo`;o00001oooool002Gooooo00?o0000ooooooooool04?ooool5o`000004ooTK0?l0003o0000
o`0000?on1h00_l000001?og9@3o0000o`000?l00003ooD[0003o`000?oc<P3olc8000?olc800ol0
0006oo0n00;o00001_o]B@000ol0003ok4h0o`000002o`0000?oje4000?o0000onYE0?oZE@000ooZ
E@02o`0000Ooj5`000?o0000onMN0?l000000_l00002onMQ0003o`000?oVH`3oiV<000?oiV<00ol0
0006onEV0003o`000?oUI`3o000000;o00000_oTJ0000ol0003oi6T0onAY0003onAY0003o`000?oT
J@3oi6T000?o00000_oTJP000ol0003oi6T0onAY0003onAY0003o`000?oUJ03oiFP000?o000000?o
i6T0o`000?oUI`001OoUI`000ol0003oiFD0o`000002o`0000;oiFD000?o0000onIR0?oVHP001?oV
HP000ol0003oiel0o`000002o`0000;oiel000?o0000onQK0?oXF`000ooXF`001?l0003ojUH0onYF
0?oZEP06o`0000?oje0000?o0000one:0?o]BP001?o]BP000ol0003okd<0onm30003o`000003onm2
0?l0003ol3l000Gol3l000?o0000onQJ0?l000001?oYF@002?l0003ojEL0onUG0?l0003obKT0o`00
0?o9^@3o00000_o9^0001Ol0003ob[L0olZg0?o:]`3o000000;ob[H000?o0000ooooooooool01Ooo
ool3o`0000Kooooo000Vooooo`03o`000?oooooooooo017ooooo00?o0000ooDZ0?l000000_l00006
ooPN00;o00001ooe:`000ol0003olc80o`000002o`0000?olSP000?o0000oo0n0?o`?P000ol00002
onm30003o`000?o]B@3okDT000?okDT00ol00006on]A0003o`000?oZE@3o000000;o00000_oYF000
0ol0003oj5`0onQL0004onQL00;o00001_oWH@000ol0003oiV<0o`000002o`0000;oiVD000?o0000
onEV0?oUIP001?oUIP02o`0000Koi6P000Co0000onAY0?oTJ@3oi6T01?l00006onAZ0004o`000?oT
J@3oi6T0onAY00Co00001OoTJ@001?l0003oiFL0onEW0?oUI`04o`0000KoiFD000Co0000onIR0?oV
HP3oiV801?l00006onMO0004o`000?oXF`3oj5/0onQK00Go00001?oZEP000ol0003oje00on]@0003
on]@0004o`000?o]BP3okDX0one:00Go00001Oo_@P000ol0003ol3l0oo0o0003oo0o00;o00001?oY
F@001?l0003ojEL0onUG0?oYE`03o`000005olVi0?l0003obKP0olVh0?l000000oo:]`000ol0003o
b[H0olZf0002o`0000Gooooo00Co0000oaJB0?l0003o00001_ooool002Oooooo00?o0000oooooooo
ool04Oooool01?l0003omBX0ooDZ0?oe:P02o`000004ooPN0?l0003o0000o`0000;omb@000?o0000
ooD[0?oe:`001?oe:`03o`0000GolSP00ol00006onm30003o`000?o]B@3o000000;o00000oo/C000
0ol0003oje40on]A0003on]A00;o00001_oYF0000ol0003oj5`0onQL0003o`0000;oieh000?o0000
onMQ0?oWH@000ooWH@02o`0000KoiVD000?o0000onEV0?oUIP000ol00002onEW0003o`000?oTJ03o
i6P000?oi6P01?l00003onAZ0003o`000?oTJP3oi6X000Coi6X01?l00003onAZ0003o`000?oTJ@3o
i6T000?oi6T01?l00004onEW0003o`000?oUI@3oiFD000?oiFD01?l00003onIR0003o`000?oWG`3o
iel000Coiel01?l00003onQJ0003o`000?oZEP3ojUH000CojUH000Co0000on]@0?o[D03oje001Ol0
0003one90003o`000?o_@P3okd8000Cokd8000?o0000oo0o0?o`?`000ol000000oo`?P3o0000onUI
0002onUI0003o`000?oYE`3ojEL000?ojEL000Co0000olVi0?l0003o00000_o9^0001ol0003ob[L0
olZg0?o:]`3o0000olZf0?l000000_o;]@000ol0003oooooooooo`02ooooo`04o`000?lFTP3o0000
o`0000Kooooo000Xooooo`;o00004_ooool6o`0000Komb@000?o0000ooD[0?oe:`000ol00003oo@`
0003o`000?ob>03o000000;o00000ooa?0000ol0003okd<0onm30003onm300;o00001oo/C0000ol0
003oje40o`000002o`0000;ojU@000?o0000onUH0?oYF0000ooYF003o`0000Koieh000?o0000onMQ
0?l000000_l00002onIS0003o`000?oVI@3oiVD000?oiVD00ol00006onEW0003o`000?oTJ03o0000
00;o00000_oTJ@000ol0003oi6X0onAZ0003onAZ0003o`000?oTJP3oi6X000?o00000_oTJ`000ol0
003oi6X0onAZ0003onAZ0003o`000?oTJ@3o000000;o00000_oTJ@000ol0003oiFL0onEW0004onEW
0003o`000?oUI@3o000000;o00000_oUI@000ol0003oiV80onIR0003onIR0003o`000?oWG`3oiel0
00?o000000?oieh0o`000?oXFP001OoXFP001?l0003ojUH0onYF0?oZEP06o`0000?ok4l000?o0000
one90?o]B@000oo]B@001?l0003okd80onm20?o_@P05o`0000Gol3h000?o0000onUI0?l000001OoY
E`02o`0000;obKT000?o0000olVh0?l000000oo:]`001?l0003ob[H0olZf0?l00002ol^e0003o`00
0?oooooooooo00;ooooo00Co0000oaJB0?l0003o00001_ooool002[ooooo00?o0000ooooooooool0
4Oooool01Ol0003om2l0oo@_0?od;`3o000000Gomb@00ol00006oo@`00?o00001_oa?0000ol0003o
kd<0o`000002o`0000;okTL000?o0000ona<0?o/C0001?o/C002o`0000KojU@000?o0000onUH0?l0
00000_l00003onQK0003o`000?oWGP3oieh000?oieh00_l00006onIS0003o`000?oVI@3o000000;o
00000_oUIP000ol0003oiFL0onEW0004onEW00;o00001_oTJ@001?l0003oi6X0onAZ0?oTJP04o`00
00Koi6/000Co0000onAZ0?oTJP3oi6X00ol00006onAY0004o`000?oUI`3oiFL0onEW00Co00001_oU
I@001?l0003oiV80onIR0?oVHP04o`0000Goieh000?o0000onQJ0?oXFP000ooXFP04o`0000?ojU@0
00?o0000ona?0?o/C`001?o/C`001?l0003okDT0one90?o]B@05o`0000Col40000?o0000oo0n0?o`
?P000oo`?P02o`0000GojEL000?o0000onYE0?oZE@000_l000000oo9^03o0000o`000003olZg0004
o`000?o:]P3ob[H0o`0000;obkD00_l00002ooooo`03o`000?lFTP3o5Y8000;o00001_ooool002_o
oooo00?o0000ooooooooool04Oooool01_l0003om2l0oo@_0?od;`3o0000ooLT00?o00000ooe:P00
1?l0003om300oo@`0?od<002o`0000?olSD000?o0000oo4l0?oa?0000ooa?002o`0000KokTL000?o
0000ona<0?o/C0000ol00002ona@0003o`000?oZE03ojU@000?ojU@00ol00006onQK0003o`000?oW
GP3o000000;o00000_oWH0000ol0003oiV<0onIS0003onIS00;o00001_oUIP000ol0003oiFL0onEW
0003o`0000;oi6T000?o0000onAY0?oTJ@000ooTJ@04o`0000?oi6/000?o0000onA[0?oTJ`001?oT
J`04o`0000?oi6X000?o0000onAY0?oTJ@000ooTJ@04o`0000?oiFL000?o0000onEU0?oUI@001?oU
I@04o`0000?oiV8000?o0000onMN0?oWGP000ooWGP000ol0003oj5X0onQJ0003o`000003onUI0?l0
003ojU@000GojU@000Co0000ona?0?o/C`3ok4l01_l00003oni70003o`000?o`@03ol40000Col400
00?o0000oo0n0?l000000_l00002oo4l0005o`000?oYE`3ojEL0onUG0?l000001?oZE@001?l0003o
bKP0o`000?l00003olZg0006o`000?o:]P3ob[H0o`000?o;]@3o00000_o;]0000ol0003oooooo`00
0002oaJB00;o00001_ooool002cooooo00?o0000ooooooooool04Oooool6o`0000KomBX000?o0000
oo@`0?l000001_ob=@000ol0003olC`0o`000002o`0000;ol44000?o0000oni70?o^A`000oo^A`03
o`0000Kok50000?o0000onYD0?l000000_l00003onUG0004o`000?oXF`3oj5/0onQK00Go00001OoW
H0000ol0003oiV<0o`000002o`0000;oiV@000?o0000onEV0?oUIP000ooUIP03o`0000Koi6T000?o
0000onAY0?l000000_l00002onAZ0003o`000?oTJ`3oi6/000?oi6/000?o0000onA[0?oTJ`000ol0
00000ooTJ`3o0000onAZ0005onAZ0003o`000?oTJ@3o000000;o00000_oTJ@000ol0003oiFL0onEW
0003onEW0003o`000?oUI@3oiFD000?o000000?oiVD0o`000?oVHP001OoVHP001?l0003oieh0onMN
0?oWGP04o`0000GojET000Co0000onYD0?oZE03ojU@01_l00003ona>0003o`000?o^A`3okTL000Co
kTL000Co0000oo100?o`@03ol4001?l00006oo4l0003o`000?oYE`3o000000CojUD00_l00002olVh
0004o`000?o:]`3ob[L0o`0000;ob[H000Co0000ol^e0?o;]@3o00000_o;]003o`0000;o5Y800_l0
0006ooooo`00;Oooool2o`0001;ooooo00?o0000oo<d0?oc=0000_oc=0000ol0003omBX0ooDZ0003
ooDZ00?o00001_ob=@02o`0000Kol44000?o0000oni70?l000000_l00003one:0003o`000?o/D03o
k50000?ok5000ol00005onUG00Co00001OoXG@001?l0003oif00onMP0?oWH004o`0000GoiV@000?o
0000onEV0?l000000_l00002onEW0003o`000?oTJ@3oi6T000Coi6T00_l00006onAZ0004o`000?oT
J`3oi6/0onA[00Co00001OoTJ`001?l0003oi6X0onAZ0?oTJP04o`0000Koi6T000Co0000onEW0?oU
I`3oiFL01?l00005onIU0004o`000?oVHP3oiV80onIR00Ko00000ooXG@000ol0003ojET0onUI0003
onUI00Co00001?o[D`000ol0003ok4h0ona>0003ona>0004o`000?o^A`3okTL0oni700Ko00000oo`
?P000ol0003olC`0oo4l0004oo4l00;o00001?oZE@000ol0003oje<0on]C0002o`000004olZg0?l0
003ob[L0o`0000;ob[H000Co0000ol^e0?o;]@3o00000_o;]0000ol0003obk@0o`000002oaJB00;o
00001_ooool002oooooo00?o0000ooooooooool04?ooool00ol0003olc@0oo<d0002oo<d0003o`00
0?oe:P3o000000;o00000ood;`02o`000004oo8e0?l0003o0000o`0000;olCT000?o0000oo110?o`
@@000oo`@@03o`0000KokDX000?o0000ona@0?l000000_l00003on]B0003o`000?oYE`3o000000;o
00000ooYF@000ol0003oj5d0onQM0003onQM00Co00001?oVHP001?l0003oiV@0onIT0?oVI003o`00
00KoiFL000?o0000onAY0?oTJ@000ol00002onAY0003o`000?oTJP3oi6X000?oi6X01?l00003onA[
0003o`000?oTJ`3oi6/000?oi6/01?l00004onAZ0003o`000?oTJ@3oi6T000?oi6T01?l00003onEW
0003o`000?oVI@3oiVD000?oiVD01?l00003onMQ0003o`000?oXG@3oj5d000Coj5d000?o0000onUI
0?l000000_l00002onUH0003o`000?o[D`3oje<000Coje<000Co0000ona>0?o/CP3ok4h01Ol00003
oni50003o`000?o`?P3ol3h000Col3h000?o0000oo4l0?oa?0000ol000000ooa>@3o0000onYE0002
onYE0003o`000?o[D`3oje<000;oje<000Go0000olZg0?l0003ob[L0o`000002olZf0006o`000?o;
]@3obkD0o`000?o;]03o00000_o;]0001_l0003o5Y80o`000?l0003oooooo`0000Gooooo000`oooo
o`03o`000?oooooooooo013ooooo1ol00006oo@_00;o00001_oa>@000ol0003ol440o`000002o`00
00?okd@000?o0000one:0?o]BP000oo]BP03o`0000Goje800_l00007onUI0003o`000?oXG@3o0000
00;o00000_oWGP000ol0003oiV80onIR0003onIR00Co00000ooUI@000ol0003oiFL0onEW0003onEW
00?o00001_oTJ@000ol0003oi6X0o`000002o`0000;oi6/000?o0000onA[0?oTJ`000ooTJ`000ol0
003oi6/0o`000002o`0000;oi6/000?o0000onAZ0?oTJP001?oTJP000ol0003oi6T0o`000002o`00
00;oi6P000?o0000onEW0?oUI`000ooUI`000ol0003oiVD0o`000002o`0000;oiV@000?o0000onMQ
0?oWH@000ooWH@001?l0003oj5d0onQM0?oXG@04o`0000KojEP000Co0000on]C0?o[D`3oje<01_l0
0003one<0003o`000?o^A@3okTD000?okTD000Co0000oo0n0?o`?P3ol3h01Ol00005oo4i0003o`00
0?oZE@3o000000Goje<00_l000001Oo:]`3o0000o`000?o:]P3o000000;obkD000Co0000ol^d0?o;
]03o00000_o;]003o`0000;ooooo00?o0000ooooooooool00oooool0037ooooo00?o0000oooooooo
ool04Oooool2o`0000?olCT00_l000001?od;`3o0000o`000?l00002oo<c0003o`000?oa>@3olCT0
00?olCT00ol00006onm40003o`000?o]BP3o000000;o00000oo/C@000ol0003oje80o`000002o`00
00;ojU@000?o0000onUI0?oYF@001?oYF@02o`0000Koieh000?o0000onIR0?l000000_l00002onIS
0003o`000?oUI@3oiFD000?oiFD000?o0000onEW0?l000000_l00002onEX0003o`000?oTJ@3oi6T0
00Coi6T00_l00006onA[0004o`000?oTJ`3oi6/0onA[00?o00001_oTJ`001?l0003oi6X0onAZ0?oT
JP04o`0000Koi6P000Co0000onEW0?oUI`3oiFL00ol00006onIT0004o`000?oWH@3oif40onMQ00Go
00000ooXG0000ol0003ojEP0onUH0004onUH00Co00000oo[D@000ol0003okD`0one<0004one<0004
o`000?o^A@3okTD0oni500Go00000ooa>`000ol0003olCT0oo4i0004oo4i00;o00001Oo[D`000ol0
003oje00on]@0003o`000005olZf0?l0003obkD0ol^e0?l000000_o;]0001?l0003obk@0o`000?o9
^P02o`0000;ooooo00?o0000ooooooooool00oooool003;ooooo0_l0000Cooooo`Ko00001_oc<`00
0ol0003olCT0o`000002o`0000?ol3d000?o0000onm40?o_A0000oo_A003o`0000Gok4d00_l00006
onYD0003o`000?oYF@3ojET000?o00000_oXF`000ol0003oieh0onMN0003onMN00;o00001_oVH`00
1?l0003oiFD0onEU0?oUI@04o`0000GoiFP000?o0000onAY0?oTJ@000ol00002onAY0003o`000?oT
J`3oi6/000?oi6/01?l00003onA[0003o`000?oTJ`3oi6/000?oi6/01?l00003onAY0003o`000?oT
J03oi6P000Coi6P01?l00003onEV0003o`000?oVI03oiV@000?oiV@01?l00003onMO0003o`000?oX
G03oj5`000?oj5`000?o0000onUH0?oYF0000ol000000ooZEP3o0000on]A0005on]A0004o`000?o]
C03okD`0one<00Ko00000oo_@`000ol0003olC/0oo4k0003oo4k0003o`000?oa>@3olCT000?o0000
00?olSH0o`000?o[D`000oo[D`000ol0003oje00on]@0002on]@0004o`000?o:]P3o0000o`0000;o
bkD000Oo0000ol^d0?o;]03o0000ol^d0?l0003obKX000;o00000_ooool00ol0003oooooooooo`03
ooooo`00=?ooool00ol0003oooooooooo`0Aooooo`03o`000?o`?@3ol3d000;ol3d000?o0000oo<c
0?oc<`000ooc<`03o`0000Kol3d000?o0000onm40?l000000_l00003oni70003o`000?o/C@3o0000
00;o00000_o/C`000ol0003ojU@0onYD0003onYD00?o00001_oXF`000ol0003oieh0o`000002o`00
00;oiel000?o0000onIS0?oVH`000ooVH`04o`0000CoiFH000Co0000onEX0?oUJ03oiFP01?l00006
onAY0003o`000?oTJ`3o000000;o00000_oTJ`000ol0003oi6/0onA[0003onA[0003o`000?oTJ`3o
000000;o00000_oTJP000ol0003oi6T0onAY0003onAY0003o`000?oTJ03oi6P000?o000000?oiFP0
o`000?oUIP001OoUIP000ol0003oiV@0o`000002o`0000;oiV8000?o0000onMO0?oWG`000ooWG`00
1?l0003oj5`0onQL0?oXG004o`0000GojUH000?o0000on]A0?o[D@000oo[D@04o`0000?okDT000?o
0000onm30?o_@`001?o_@`001?l0003olC/0oo4k0?oa>`04o`0000GolSH000Co0000on]C0?o[D`3o
00001?o[D002o`000005olZf0?l0003o0000ol^e0?l000000_o;]0001Ol0003obk@0ol^d0?l0003o
bKX000;o00000_ooool00ol0003oooooooooo`03ooooo`00=Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?o`?@3ol3d000;ol3d000?o0000oo<c0?l000000_l00003oo8g0003o`000?o`?@3ol3d0
00?ol3d00ol00005oni700;o00001_o/C`000ol0003ojU@0o`000002o`0000?ojUH000?o0000onQK
0?oXF`000ooXF`02o`0000Koiel000?o0000onIS0?l000000_l00002onIS0003o`000?oUIP3oiFH0
00?oiFH01?l00003onEX0003o`000?oTJ@3oi6T000Coi6T00_l00006onA[0004o`000?oTJ`3oi6/0
onA[00?o00001_oTJP001?l0003oi6T0onAY0?oTJ@04o`0000GoiFP000Co0000onEV0?oUIP3oiFH0
1?l00006onIR0004o`000?oWG`3oiel0onMO00Go00000ooXFP000ol0003ojUH0onYF0003onYF0003
o`000?o[D@3oje4000?o000000?ok4l0o`000?o]B@001Oo]B@001?l0003okd<0onm30?o_@`06o`00
00?olSP000?o0000oo8f0?ob=P000oob=P000ol0003oje<0o`000004on]@0003o`000?o/C03ok4`0
00?o000000GobkD0o`000?o;]03obk@0o`000002ol^d00?o00000oooool00ol0003oooooooooo`03
ooooo`00=_ooool00ol0003oooooooooo`0Aooooo`Oo00001_ob=`000ol0003ol3d0o`000002o`00
00?ol40000?o0000oni70?l000000_l00002one90003o`000?o/C`3ok4l000?ok4l00ol00006onYF
0003o`000?oXF`3o000000;o00000_oXG0000ol0003oiel0onMO0003onMO00;o00001_oVH`000ol0
003oiFH0o`000002o`0000;oiFH000?o0000onEX0?oUJ0000ooUJ0000ol0003oi6T0onAY0003o`00
0003onAY0?l0003oi6/000Goi6/01?l00003onAZ0003o`000?oTJP3oi6X000?oi6X01?l00003onAY
0003o`000?oUJ03oiFP000?oiFP01?l00003onIU0003o`000?oVHP3oiV8000CoiV801?l00003onMN
0003o`000?oXFP3oj5X000?oj5X000Co0000onYF0?oZEP3ojUH01?l00005ona?0004o`000?o]B@3o
kDT0one900Ko00000oo`?`000ol0003olSP0oo8h0004oo8h0004o`000?ob=P3olSH0oo8f00?o0000
1?o[D0000ol0003ok4`0ona<0002ona<0004o`000?o;]@3o0000o`0000;obk@000Co0000ol^d0?l0
003obKX00_l00003ooooo`03o`000?oooooooooo00?ooooo000gooooo`;o00004oooool00ol0003o
l400oo100002oo100003o`000?ob=`3olSL000?olSL00_l00006oo1000;o00001_o]B@000ol0003o
k4l0o`000002o`0000?oje4000?o0000onYF0?oZEP000ooZEP02o`0000Koj5`000?o0000onMO0?l0
00000_l00002onMP0003o`000?oVH`3oiV<000?oiV<00_l00006onEV0004o`000?oUJ03oiFP0onEX
00Co00001OoTJ@000ol0003oi6/0onA[0003o`000003onAZ0?l0003oi6X000Goi6X000?o0000onAZ
0?l000000_l00002onAY0003o`000?oTJ@3oi6T000?oi6T000?o0000onEX0?l000000_l00002onEV
0003o`000?oVI@3oiVD000?oiVD000?o0000onIR0?oVHP000ol000000ooWH@3o0000onMN0005onMN
0004o`000?oXFP3oj5X0onQJ00Go00000ooZE0000ol0003ok4l0ona?0003ona?00Co00000oo^AP00
0ol0003ol3l0oo0o0004oo0o0004o`000?ob>03olSP0oo8h00Ko00000_oc<P001Ol0003oje00on]@
0?o[D03o000000Gok4`000Ko0000ol^e0?l0003o0000ol^d0?l00002ol^d0004o`000?o9^P3o0000
o`0000?ooooo00?o0000ooooooooool00oooool003Wooooo00?o0000ooooooooool04Oooool00ol0
003ol400oo100002oo100003o`000?ob=`3o000000;o00000_oa>P001?l0003ol400oo100?o`@002
o`0000;okd8000?o0000one90?o]B@000oo]B@03o`0000Koje4000?o0000onYF0?l000000_l00002
onUG0003o`000?oXG03oj5`000?oj5`00_l00006onMP0003o`000?oVH`3o000000;o00000_oVI000
0ol0003oiFH0onEV0003onEV00Co00000ooUJ0000ol0003oi6T0onAY0003onAY00?o00001OoTJP00
1?l0003oi6X0onAZ0?oTJP04o`0000Koi6T000Co0000onAY0?oTJ@3oi6T00ol00006onEV0004o`00
0?oVI@3oiVD0onIU00Co00001OoWH@001?l0003oieh0onMN0?oWGP06o`0000;ojEP000?o0000onYD
0?oZE0001?oZE0000ol0003ok4l0o`000002o`000003one<0?l0003okTH000GokTH000Co0000oo0o
0?o`?`3ol3l01_l00003oo<d0003o`000?oc<P3olc8000?olc8000?o0000on]@0?l000001Oo/C000
0ol0003okDP0o`000002o`000007ol^d0?l0003obk@0ol^d0?l0003obKX0o`000004ooooo`03o`00
0?oooooooooo00?ooooo000jooooo`03o`000?oooooooooo017ooooo1ol00005oo4j0003o`000?o`
@03o000000Gokd8000?o0000one90?l000000_l00003one;0003o`000?o[D@3oje4000?oje400_l0
0006onUG0003o`000?oXG03o000000;o00000_oXG0000ol0003oif00onMP0003onMP00;o00001_oV
I0000ol0003oiFH0o`000002o`0000;oiFH000?o0000onEX0?oUJ0000ooUJ0000ol0003oi6T0o`00
0002o`0000;oi6T000?o0000onAZ0?oTJP000ooTJP04o`0000?oi6T000?o0000onAY0?oTJ@001?oT
J@04o`0000?oiFL000?o0000onEV0?oUIP000ooUIP04o`0000?oiV<000?o0000onMQ0?oWH@000ooW
H@04o`0000?oj5`000?o0000onUH0?oYF0000ooYF0001?l0003ojU@0onYD0?oZE004o`0000GokD`0
00?o0000oni60?o^AP000oo^AP04o`0000?olC`000?o0000oo<d0?oc=0001?oc=0000ol0003olc80
oo<b0002oo<b00;o00001Oo/C0001_l0003okDP0one80?o]B03o0000ol^d00;o00000_o;]0000ol0
003obKX0o`000005ooooo`03o`000?oooooooooo00;ooooo000kooooo`03o`000?oooooooooo01;o
oooo00?o0000onm30?o_@`000_o_@`001?l0003olCX0oo4j0?oa>P04o`0000Gokd800ol00006one;
0003o`000?o[D@3o000000;o00000_o[DP000ol0003ojEL0onUG0003onUG00;o00001_oXG0000ol0
003oif00o`000002o`0000;oif4000?o0000onIT0?oVI0000ooVI002o`0000KoiFH000Co0000onEX
0?oUJ03oiFP01?l00005onAY0003o`000?oTJP3o000000;o00000_oTJ@000ol0003oi6T0onAY0003
onAY0003o`000?oTJ@3oi6T000?o000000?oiFP0o`000?oUI`001OoUI`000ol0003oiFH0o`000002
o`000003onEU0?l0003oiV<000GoiV<000?o0000onMQ0?l000000_l00002onMN0003o`000?oXG03o
j5`000?oj5`000Co0000onUH0?oYF03ojEP01Ol00003on]A0003o`000?o]C03okD`000CokD`000?o
0000oni60?l000000_l000000oo_@P3o0000oo4l0005oo4l0003o`000?oc=03olc@000?olc@000?o
0000oo<b0?l000000_l00002oo@]0005o`000?o/C03ok4`0ona<0?l000001?o]B0001ol0003obk@0
ol^d0?l0003obk@0o`000?o9^P000_l00005ooooo`03o`000?oooooooooo00;ooooo000looooo`03
o`000?oooooooooo01;ooooo2?l00004oo4l0003o`000?o_@P3o000000;o00000oo_A0000ol0003o
kD/0one;0003one;00;o00001_o[DP000ol0003ojEL0o`000002o`0000;ojEP000?o0000onQL0?oX
G0000ooXG002o`0000Koif4000?o0000onIT0?l000000_l00002onIT0003o`000?oUIP3oiFH000?o
iFH01?l00004onEX0004o`000?oTJ@3oi6T0onAY00?o00001_oTJ@001?l0003oi6T0onAY0?oTJ@04
o`0000GoiFP000Co0000onEW0?oUI`3oiFL01?l00005onEU0004o`000?oVH`3oiV<0onIS00Co0000
1_oWGP001?l0003oj5`0onQL0?oXG005o`0000?ojUD000?o0000on]A0?o[D@000oo[D@001?l0003o
kD`0one<0?o]C004o`0000Gokd8000?o0000oo4l0?oa?0000ooa?0001?l0003olc@0oo<d0?oc=004
o`0000Kom2d000?o0000ona<0?l000001?o]B0000ol0003okd@0o`000002o`000003ol^d0?l0003o
bKX000;o00001Oooool00ol0003oooooooooo`02ooooo`00?Oooool2o`0001Cooooo00Go0000oni5
0?o^A@3okTD0o`000005oo4l00?o00001_o_A0000ol0003okD/0o`000002o`0000;ok4`000?o0000
on]B0?o[DP000oo[DP03o`0000GojEP000?o0000onQL0?l000000_l00002onQM0003o`000?oWH@3o
if4000?oif400_l00006onIT0003o`000?oUIP3o000000;o00000_oUIP000ol0003oiFP0onEX0003
onEX00Co00000ooUJ0000ol0003oi6T0onAY0003onAY00Co00000ooTJ0000ol0003oiFP0onEX0003
onEX00Co00000ooUIP000ol0003oiFD0onEU0003onEU00Co00000ooWH@000ol0003oieh0onMN0004
onMN00Co00000_oYF@000ol0003ojUD0onYE0004onYE0004o`000?o[D@3oje40on]A00Go00000oo]
B0000ol0003okd80onm20004onm20004o`000?oa?03olC`0oo4l00Go00000ood<0000ol0003om2d0
oo@]0004oo@]00;o00001?o]B0001_l0003okd@0onm40?o_A03o0000ol^d00;o000000?obKX0o`00
0?ooool01Oooool00ol0003oooooooooo`02ooooo`00?oooool00ol0003oooooooooo`0Booooo`06
o`000?o^A@3okTD0oni50?l0003olC`00ol00003oo0n0003o`000?o_A03okd@000?okd@00_l00006
ona<0003o`000?o[DP3o000000;o00000oo[D`001?l0003ojEP0onUH0?oYF004o`0000Goj5d000?o
0000onMQ0?l000000_l00002onMQ0003o`000?oVI03oiV@000?oiV@00_l00006onEV0003o`000?oU
J03o000000;o00000_oUI`000ol0003oiFP0onEX0003onEX0003o`000?oTJ@3o000000;o00000_oU
J0000ol0003oi6P0onAX0003onAX0003o`000?oUJ03o000000;o00000_oUIP000ol0003oiFH0onEV
0003onEV0003o`000?oUI@3o000000;o00000_oVH`000ol0003oif40onMQ0003onMQ0003o`000?oW
GP3oieh000?o000000?oj5`0o`000?oYF@001?oYF@001?l0003ojUD0onYE0?oZE@06o`0000?ok4h0
00?o0000one80?o]B0000oo]B0001?l0003okd80onm20?o_@P06o`0000;olSL000?o0000oo@`0?od
<0001?od<0000ol0003om2d0oo@]0003o`000003ooHX0?l0003okDP000;okDP000?o0000onm40?o_
A0000_o_A0001_l0003obk@0ol^d0?l0003obKX0o`0000Kooooo00?o0000ooooooooool00_ooool0
043ooooo00?o0000ooooooooool04_ooool6o`0000Kol3h000?o0000onm40?l000000_l00002oni5
0003o`000?o/C03ok4`000?ok4`00ol00005on]C00Co00001?oYF0001?l0003oj5d0onQM0?oXG@04
o`0000Goif4000?o0000onIT0?l000000_l00002onIS0003o`000?oUIP3oiFH000?oiFH00_l00006
onEW0004o`000?oUJ03oiFP0onEX00?o00001_oUJ0001?l0003oi6P0onAX0?oTJ004o`0000GoiFH0
00Co0000onEV0?oUIP3oiFH01?l00005onIS0004o`000?oWH@3oif40onMQ00Co00001OoXG0001?l0
003ojET0onUI0?oYF@05o`0000?oje8000?o0000ona>0?o/CP001?o/CP001?l0003okDP0one80?o]
B005o`0000?ol3h000?o0000oo8g0?ob=`000oob=`001?l0003om300oo@`0?od<005o`0000GomRP0
00?o0000one80?l000001?o_A0001Ol0003ol400o`000?l0003obKX000;o00001_ooool00ol0003o
ooooooooo`02ooooo`00@Oooool00ol0003oooooooooo`0Booooo`03o`000?o^A`3okTL000;okTL0
00?o0000oo0n0?o`?P000oo`?P02o`0000KokTD000?o0000ona<0?l000000_l00003ona=0003o`00
0?o[D`3o000000;o00000_o[D`000ol0003ojEP0onUH0003onUH00Co00001?oXG@001?l0003oif40
onMQ0?oWH@04o`0000GoiV<000?o0000onEV0?l000000_l00002onEU0003o`000?oUI`3oiFL000?o
iFL01?l00003onEW0003o`000?oUJ03oiFP000?oiFP01?l00004onEW0004o`000?oUIP3oiFH0onEV
00Go00001?oVI0001?l0003oiV<0onIS0?oVH`05o`0000?oieh000?o0000onQL0?oXG0000ooXG004
o`0000?ojUH000?o0000on]B0?o[DP000oo[DP001?l0003ok4h0ona>0?o/CP06o`0000;okT@000?o
0000oo0n0?o`?P001?o`?P001?l0003olSL0oo8g0?ob=`05o`0000?omB/000?o0000ooHX0?of:000
1?of:002o`0000Cokd@000Ko0000oo100?o`@03ol400o`000?o9^P02o`0000Kooooo00?o0000oooo
ooooool00_ooool004;ooooo0_l0000Cooooo`03o`000?o^A`3okTL000;okTL000?o0000oo0n0?l0
00000_l00002oo100003o`000?o^A@3okTD000?okTD00ol00005ona=00;o00001_o[D`000ol0003o
jEP0o`000002o`0000;ojEP000?o0000onQM0?oXG@000ooXG@04o`0000Coif0000Co0000onIS0?oV
H`3oiV<00ol00006onEU0003o`000?oUI`3o000000;o00000_oUI@000ol0003oiFL0onEW0003onEW
0003o`000?oUJ03o000000;o00000_oUIP000ol0003oiFL0onEW0003onEW00Co00000ooVI0000ol0
003oiV@0onIT0003onIT00Co00000ooWH0000ol0003oieh0onMN0003onMN0003o`000?oXG03o0000
00;o00000_oYF@000ol0003ojUH0onYF0003onYF0004o`000?o[DP3oje80on]B00Go00000oo]BP00
0ol0003okT@0oni40003oni40004o`000?o`?P3ol3h0oo0n00Ko00000ooc<P000ol0003omB/0ooD[
0003ooD[0003o`000?of:03omRP000?o000000?omb80o`000?o_A0000_o_A0000ol0003ol400oo10
0002oo1000Co00001_ooool00ol0003oooooooooo`02ooooo`00A?ooool00ol0003oooooooooo`0A
ooooo`Oo00001Oo`@0000ol0003okTD0o`000002o`0000?okTH000?o0000ona=0?l000000_l00002
ona=0003o`000?o[D`3oje<000?oje<00_l00006onUH0003o`000?oXG@3o000000;o00000_oXG000
0ol0003oif00onMP0003onMP00Co00000ooVHP000ol0003oiFD0onEU0003onEU00;o00001_oUI@00
1?l0003oiFL0onEW0?oUI`04o`0000GoiFH000?o0000onEW0?l000000_l000000ooVI@3o0000onIT
0005onIT0003o`000?oVI03o000000;o000000?oiV40o`000?oWH0001OoWH0001?l0003oieh0onMN
0?oWGP03o`0000KojET000Co0000onYF0?oZEP3ojUH01Ol00003ona>0003o`000?o]BP3okDX000?o
kDX000Co0000oni40?o^A03okT@01Ol00003oo4i0003o`000?oc<P3olc8000Colc8000Co0000ooD[
0?oe:`3omB/01?l00005ooLR0003o`000?o_A03o000000Col40000Ko0000oni60?o^AP3o0000oooo
ool00006ooooo`03o`000?oooooooooo007ooooo0015ooooo`03o`000?oooooooooo01;ooooo00?o
0000oni80?o^B0000_o^B0001?l0003ol400oo100?o`@004o`0000GokTH00_l00006ona=0003o`00
0?o[D`3o000000;o00000_o[D`000ol0003ojEP0onUH0003onUH00;o00001_oXG0000ol0003oif00
o`000002o`0000;oiel000?o0000onIR0?oVHP000ooVHP000ol0003oiFD0o`000002o`0000;oiV<0
00?o0000onEU0?oUI@000ooUI@04o`0000CoiFD000Co0000onEV0?oUIP3oiFH00ol00005onIU0004
o`000?oVI03oiV@0onIT00Co00001OoVH@001?l0003oif00onMP0?oWH006o`0000;oj5/000?o0000
onUI0?oYF@001?oYF@04o`0000;oje8000?o0000ona>0?o/CP001?o/CP001?l0003okDX0one:0?o]
BP05o`0000?ol40000?o0000oo4i0?oa>@000ooa>@001?l0003olc80oo<b0?oc<P06o`0000;omb@0
00?o0000ooLR0?og8P001?og8P02o`0000Col40000Oo0000oni60?o^AP3okTH0o`000?oooooo0000
00Kooooo00?o0000ooooooooool00Oooool004Kooooo00?o0000ooooooooool04_ooool8o`0000Co
kd4000?o0000oni60?l000000_l00002oni70003o`000?o/C@3ok4d000?ok4d00_l00006on]C0003
o`000?oYF03o000000;o00000_oYF0000ol0003oj5`0onQL0003onQL00;o00001_oWG`001?l0003o
iV80onIR0?oVHP04o`0000GoiV<000?o0000onEU0?l000000_l000000ooVI03o0000onEU0005onEU
00Co00000_oVI0000ol0003oiVD0onIU0003onIU00Co00000ooVHP000ol0003oiV40onIQ0003onIQ
00Co00000ooXG@000ol0003oj5/0onQK0003onQK0003o`000?oYF@3ojET000?o000000?ojUD0o`00
0?o[DP001?o[DP001?l0003ok4h0ona>0?o/CP06o`0000;okTD000?o0000oo100?o`@0001?o`@000
1?l0003olCT0oo4i0?oa>@05o`0000?omB`000?o0000ooLT0?og90000oog90000ol0003omb80ooLR
0003o`000003ooTM0?l0003ol40000;ol40000Go0000oni60?o^AP3okTH0o`000003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00Oooool004Oooooo0_l0000Cooooo`03o`000?o]
B@3okDT000;okDT000?o0000onm10?o_@@000oo_@@02o`0000KokTL000?o0000ona=0?l000000_l0
0002ona=0003o`000?o[D`3oje<000?oje<00_l00006onUH0003o`000?oXG03o000000;o00000_oX
F`000ol0003oiel0onMO0003onMO00Co00001?oWH@001?l0003oiV<0onIS0?oVH`03o`0000GoiV@0
00?o0000onEU0?oUI@000ol000000ooVH`3o0000onIT0004onIT0003o`000?oVI@3o000000;o0000
0_oVHP000ol0003oiV80onIR0003onIR0003o`000?oVH@3o000000;o00000_oWGP000ol0003oj5d0
onQM0003onQM0004o`000?oXF`3oj5/0onQK00Co00001OoZE@001?l0003oje80on]B0?o[DP05o`00
00?okDX000?o0000oni50?o^A@000oo^A@001?l0003ol400oo100?o`@006o`0000;olc@000?o0000
ooD/0?oe;0001?oe;0001?l0003omb@0ooLT0?og9004o`0000GonAd000?o0000oo100?l000000oo^
AP000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00Ooo
ool004Wooooo00?o0000ooooooooool04Oooool00ol0003okDT0one90002one90003o`000?o_@@3o
000000;o00000_o_@@000ol0003okTL0oni70003oni700;o00001_o/C@000ol0003oje<0o`000002
o`0000;oje8000?o0000onUH0?oYF0000ooYF002o`0000Koj5/000?o0000onMO0?l000000_l00002
onMN0003o`000?oWH@3oif4000?oif401?l00002onIR0003o`000?oVI03oiV@000?oiV@00ol00005
onIS0004o`000?oVI03oiV@0onIT00?o00001_oVHP001?l0003oiV80onIR0?oVHP03o`0000Koieh0
00Co0000onQM0?oXG@3oj5d01Ol00003onUH0003o`000?oZE@3ojUD000?ojUD01?l00003ona>0003
o`000?o]BP3okDX000?okDX000Co0000oni50?o^A@3okTD01Ol00003oo4j0003o`000?oc=03olc@0
00?olc@000Co0000ooD/0?oe;03omB`01_l00003ooPN0003o`000?oi7@3onAd000?onAd00_l00003
oni60003o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`00B_ooool0
0ol0003oooooooooo`0Aooooo`Ko00001_o_@@000ol0003okTL0o`000002o`0000;okTL000?o0000
ona=0?o/C@000oo/C@02o`0000Koje8000?o0000onUH0?l000000_l00002onUG0003o`000?oXF`3o
j5/000?oj5/00_l00006onMN0003o`000?oWH@3o000000;o000000?oiel0o`000?oVHP001?oVHP00
0ol0003oiV@0o`000002o`0000;oiV8000?o0000onIS0?oVH`000ooVH`04o`0000?oiV8000?o0000
onIR0?oVHP000ooVHP04o`0000?oiel000?o0000onMN0?oWGP000ooWGP04o`0000?ojEX000?o0000
onUH0?oYF0000ooYF0000ol0003ojUD0o`000002o`000003on]A0?l0003ok4h000Gok4h000Co0000
one:0?o]BP3okDX01Ol00003oo100003o`000?oa>P3olCX000?olCX000Co0000oo<d0?oc=03olc@0
1Ol00003ooHW0003o`000?oh7P3on1h000Con1h000?o0000ooTM0?l000000_l00002ooPQ0003o`00
0?o^AP3o000000Sooooo00Go0000ooooooooooooooooo`000003ooooo`00Boooool00ol0003ooooo
ooooo`0Booooo`05o`000?o]B@3okDT0one90?l000001Oo_@@02o`0000KokTL000?o0000ona=0?l0
00000_l00002ona=0003o`000?o[DP3oje8000?oje800_l00006onUG0003o`000?oXF`3o000000;o
00000_oYFP000ol0003oieh0onMN0003onMN00;o00001OoWG`001?l0003oiV80onIR0?oVHP04o`00
00GoiV8000?o0000onIS0?l000000_l00002onMQ0003o`000?oVHP3oiV8000?oiV8000?o0000onIR
0?l000000_l00002onMO0003o`000?oWG`3oiel000?oiel000?o0000onMN0?l000000_l000000ooX
F`3o0000onUJ0005onUJ0004o`000?oYF03ojEP0onUH00?o00001Oo[D@001?l0003ok4h0ona>0?o/
CP06o`0000;okTD000?o0000oo100?o`@0001?o`@0001?l0003olCX0oo4j0?oa>P05o`0000?om2h0
00?o0000ooHW0?of9`000oof9`001?l0003on1h0ooPN0?oh7P04o`0000Gon2400_l0000:ooooo`04
o`000?ooooooooooo`0000?ooooo001<ooooo`;o00004oooool01_l0003okDT0one90?o]B@3o0000
onm100?o00000_o_@@000ol0003okTL0oni70003oni700;o00001_o/C@000ol0003oje80o`000002
o`0000;oje8000?o0000onUG0?oYE`000ooYE`02o`0000KojEX000?o0000onMN0?l000000_l00000
0ooXG03o0000onMO0004onMO00Co00001?oWH0001?l0003oiV80onIR0?oVHP03o`0000Koif4000Co
0000onIR0?oVHP3oiV800ol00006onMO0004o`000?oWG`3oiel0onMO00?o00001OoXF`001?l0003o
jEX0onUJ0?oYFP06o`0000;ojU<000?o0000on]A0?o[D@000oo[D@04o`0000?okDT000?o0000oni5
0?o^A@000oo^A@001?l0003ol400oo100?o`@006o`0000;olSD000?o0000oo@^0?od;P001?od;P00
1?l0003omRL0ooHW0?of9`05o`0000Comb8000?o0000ooPQ0?l000000_l0000=ooooo`03o`000?oo
oooo000000?ooooo001>ooooo`03o`000?oooooooooo017ooooo1_l00005onm10003o`000?o^A`3o
000000;o00000_o^AP000ol0003ok4d0ona=0003ona=00?o00001Oo[DP000ol0003ojEL0o`000002
o`0000;ojUD000?o0000onUJ0?oYFP000ooYFP02o`0000Goj5`000?o0000onMO0?l000000_l00002
onQM0003o`000?oWH03oif0000?oif001?l00003onMO0003o`000?oWH@3oif4000?oif401?l00002
onMO0003o`000?oWG`3oiel000Coiel01?l00002onQK0003o`000?oXF`3oj5/000?oj5/01?l00003
onYF0003o`000?oZD`3ojU<000?ojU<000?o0000on]A0?l000000_l00002ona<0003o`000?o]B@3o
kDT000?okDT000Co0000oni50?o^A@3okTD01Ol00003oo4k0003o`000?ob=@3olSD000?olSD000Co
0000oo@^0?od;P3om2h01_l00003ooHY0004o`000?og8P3omb80ooLR00Co00004?ooool01?l0003o
ooooooooool00002ooooo`00Coooool00ol0003oooooooooo`0Booooo`05o`000?o]B@3okDT0one9
0?l000000oo_@@04o`0000GokTH000?o0000ona=0?l000000_l00003one<0004o`000?o[DP3oje80
on]B00Co00001OoZE@000ol0003ojEX0o`000002o`000003onUH0?l0003oj5`000Coj5`00_l00006
onQM0003o`000?oWH03o000000;o00000_oXG@000ol0003oiel0onMO0003onMO0003o`000?oWH@3o
000000;o000000?oieh0o`000?oWG`001?oWG`000ol0003oiel0onMO0003o`000003onQL0?l0003o
j5/000Coj5/000?o0000onQK0?l000000_l00002onUG0003o`000?oZEP3ojUH000?ojUH000Co0000
onYC0?oZD`3ojU<00ol00006ona<0004o`000?o]B@3okDT0one900Go00000oo`@0000ol0003olC/0
oo4k0003oo4k0004o`000?ob=@3olSD0oo8e00Go00001?od<0001?l0003omRT0ooHY0?of:@05o`00
01Gooooo00?o0000ooooool000000_ooool0053ooooo00?o0000ooooooooool04_ooool7o`0000Co
l40000Co0000oni60?o^AP3okTH01?l00005one<00Co00001?o[D0001?l0003ojUD0onYE0?oZE@04
o`0000CojEP000?o0000onQL0?l000000_l00002onUJ0003o`000?oXG@3oj5d000?oj5d00_l00006
onQM0004o`000?oWG`3oiel0onMO00?o00001OoWGP001?l0003oiel0onMO0?oWG`04o`0000Goj5`0
00Co0000onQK0?oXF`3oj5/00ol00006onUG0004o`000?oZEP3ojUH0onYF00Go00000oo/C`000ol0
003ok4`0ona<0003ona<00Co00000_o_A0000ol0003ol400oo100004oo100004o`000?oa>`3olC/0
oo4k00Go00000oob=P001?l0003om300oo@`0?od<006o`0001_ooooo0_l00002ooooo`00DOooool2
o`0001?ooooo00Go0000one80?o]B03okDP0o`000005oo1000Co00001?o^A@000ol0003okD`0o`00
0002o`0000;okDX000?o0000on]@0?o[D0000oo[D004o`0000Coje<000?o0000onUH0?oYF0001?l0
0005onUJ0003o`000?oXG@3o000000;o00000_oXFP000ol0003oj5d0onQM0003onQM00Co00000_oX
G0000ol0003oieh0onMN0003onMN00Co00001?oXF`001?l0003oj5`0onQL0?oXG005o`0000?ojEP0
00?o0000onUG0?oYE`000ooYE`04o`0000;oje4000?o0000ona?0?o/C`001?o/C`000ol0003ok4`0
o`000002o`000003oni70?l0003okd@000Cokd@000Co0000oo100?o`@03ol4001_l00003oo4k0004
o`000?ob=P3olSH0oo8f00Go00008?ooool3o`0000;ooooo001Cooooo`03o`000?oooooooooo017o
oooo00Ko0000one80?o]B03okDP0o`000?o`@003o`0000;ol3l000?o0000oni50?o^A@000oo^A@02
o`0000KokDX000?o0000on]@0?l000000_l00002ona>0003o`000?o[D`3oje<000?oje<00ol00004
onYF0004o`000?oYFP3ojEX0onUJ00Co00001OoXFP000ol0003oj5d0o`000002o`000003onQJ0?l0
003oj5`000Coj5`000?o0000onMN0?l000000_l00002onQJ0003o`000?oXF`3oj5/000?oj5/01?l0
0003onUH0003o`000?oYF03ojEP000?ojEP000?o0000onUG0?l000000_l000000oo[DP3o0000on]A
0004on]A0004o`000?o/C`3ok4l0ona?00Co00001Oo^A`001?l0003okd@0onm40?o_A005o`0000Co
l40000Co0000oo4k0?oa>`3olC/01Ol0000Qooooo`Co00001Oooool005Cooooo00?o0000oooooooo
ool04Oooool6o`0000Gol3l000?o0000oni50?l000000_l00002onm30003o`000?o]BP3okDX000?o
kDX00_l00006ona>0003o`000?o[D`3o000000;o000000?oje40o`000?oZEP001?oZEP04o`0000Co
jEL000Co0000onQJ0?oXFP3oj5X00ol00005onQJ0004o`000?oXG03oj5`0onQL00Co00001OoXFP00
0ol0003oj5/0o`000002o`0000;ojEL000?o0000onUH0?oYF0000ooYF0001?l0003ojEP0onUH0?oY
F003o`0000Goje8000Co0000on]A0?o[D@3oje401Ol00003one:0003o`000?o^A`3okTL000?okTL0
1?l00003onm40003o`000?o`@03ol40000?ol4001?l0000Sooooo`?o00002Oooool005Gooooo00?o
0000ooooooooool04Oooool00ol0003okTL0oni70002oni70003o`000?o`?`3ol3l000;ol3l00_l0
0006onm30003o`000?o]BP3o000000;o00000_o^B0000ol0003ok4h0ona>0003ona>00;o00001Oo[
D@000ol0003ojUH0o`000002o`0000;oje<000?o0000onUG0?oYE`000ooYE`04o`0000?ojEL000?o
0000onQJ0?oXFP000_oXFP04o`0000CojET000Co0000onQJ0?oXFP3oj5X00ol00006onUG0004o`00
0?oYF03ojEP0onUH00Go00000_o[D`000ol0003oje80on]B0003on]B00Co00000oo/C0000ol0003o
kDX0one:0003one:0003o`000?o^A`3o000000;o000000?okTL0o`000?o_A0001Oo_A0000ol0003o
l400o`000002o`0002?ooooo1?l0000<ooooo`00E_ooool2o`0001;ooooo00?o0000oni70?o^A`00
0_o^A`001?l0003ol3l0o`000?l00002oo0m0003o`000?o_@`3okd<000?okd<00_l00006oni80003
o`000?o/CP3o000000;o00000_o]C0000ol0003oje40on]A0002on]A00;o00001_o[D`000ol0003o
jEL0o`000002o`0000;ojU@000?o0000onUG0?oYE`000ooYE`001?l0003oj5X0o`000?l00002onUF
0003o`000?oYF@3ojET000?ojET01?l00003onYF0003o`000?oYE`3ojEL000?ojEL01?l00002on]C
0003o`000?o[D`3oje<000?oje<000?o0000on]B0?l000000_l00002ona=0003o`000?o/C03ok4`0
00?ok4`000Co0000one:0?o]BP3okDX00ol00005oni70004o`000?o_A03okd@0onm400Co00008_oo
ool4o`00013ooooo001Hooooo`03o`000?oooooooooo013ooooo1_l00005oo0m0003o`000?o_@`3o
000000;o00000_o_@@000ol0003okTP0oni80003oni800;o00001_o]C0001?l0003oje40o`000?l0
0002ona>0003o`000?o[D`3oje<000?oje<00_l00006onYD0004o`000?oYE`3ojEL0onUG00?o0000
1OoYEP000ol0003ojET0o`000002o`0000;ojU@000?o0000onYF0?oZEP000ooZEP000ol0003ojEL0
o`000002o`000003on]C0?l0003oje<000Coje<000Co0000on]C0?o[D`3oje<01?l00005ona=0004
o`000?o/C03ok4`0ona<00Go00000oo]BP001?l0003okTL0oni70?o^A`05o`0002;ooooo1?l0000D
ooooo`00FOooool00ol0003oooooooooo`0Aooooo`05o`000?o^AP3okTH0oni60?l000001?o`?@02
o`0000Kokd4000?o0000oni80?l000000_l00002oni50003o`000?o]C03okD`000?okD`00_l00005
ona>0003o`000?o[D`3o000000;o00000_o/D0000ol0003ojU@0onYD0003onYD00Co00000_oZD`00
0ol0003ojEH0onUF0003onUF00;o00001_oZE0001?l0003ojUH0onYF0?oZEP03o`0000Goje<000Co
0000on]C0?o[D`3oje<01Ol00004ona>0004o`000?o/C@3ok4d0ona=00Go00000oo]C0001?l0003o
kDX0one:0?o]BP05o`0002Cooooo0ol0000Hooooo`00F_ooool00ol0003oooooooooo`0Aooooo`Go
000000?ol3d0o`000?l000000_oa>`000ol0003okd40onm10003onm100?o00001Oo^A@000ol0003o
kD`0o`000002o`000003one90?l0003ok4h000Cok4h00_l00006ona@0003o`000?oZE03o000000;o
000000?oje00o`000?oZD`001?oZD`000ol0003ojEH0o`000002o`0000;oje8000?o0000onYD0?oZ
E0000ooZE004o`0000;oje4000?o0000on]C0?o[D`000oo[D`04o`0000?ok4h000?o0000ona>0?o/
CP000oo/CP04o`0000?ok4d000Co0000one<0?o]C03okD`01Ol0000Uooooo`Co00006oooool005_o
oooo0_l0000Booooo`03o`000?o_A03okd@000;o00001Ooa>`000ol0003okd40o`000002o`0000?o
l3h000Co0000oni50?o^A@3okTD01?l00004one90003o`000?o/CP3o000000;o00000_o]B`000ol0
003ok500ona@0003ona@00;o00001Oo[D0001?l0003ojU<0onYC0?oZD`04o`0000Goje8000?o0000
onYD0?l000000_l000000oo[D03o0000on]A0004on]A0003o`000?o[D`3o000000;o00000_o/CP00
0ol0003ok4h0ona>0003ona>0003o`000?o/CP3o000000;o000000?ok4h0o`000?o/C@001?o/C@04
o`0002Kooooo1?l0000Oooooo`00GOooool00ol0003oooooooooo`0@ooooo`05o`000?o_A03okd@0
onm40?l000000ooa>`04o`0000Gol3h01?l00004onm20003o`000?o]B@3okDT000Co00001Oo]B`00
0ol0003ok500o`000002o`000003one<0?l0003oje0000Coje001?l00004ona?0004o`000?o[DP3o
je80on]B00?o00001Oo[D0001?l0003oje40on]A0?o[D@03o`0000Kok4h000Co0000ona>0?o/CP3o
k4h00ol00005ona>0003o`000?o/C@3o000000;o00009oooool3o`0002?ooooo001Nooooo`03o`00
0?oooooooooo013ooooo1ol00004oo8i0003o`000?o`?P3o000000;o00000_oa>`000ol0003okd80
onm20003onm200?o00001?o^A@001?l0003okD/0one;0?o]B`04o`0000CokD`000?o0000on]@0?l0
00000_l00002one<0003o`000?o/C`3ok4l000?ok4l01?l00002ona>0003o`000?o[D03oje0000?o
je001?l00003ona=0003o`000?o/CP3ok4h000?ok4h01?l00003ona>0004o`000?o/CP3ok4h0ona>
00?o00009_ooool4o`0002Kooooo001Oooooo`03o`000?oooooooooo013ooooo00Go0000onm20?o_
@P3okd80o`000005oo8i00;o00001_oa>`000ol0003okd80o`000002o`000003oo0o0?l0003okTD0
00CokTD01?l00004oni70003o`000?o]C03okD`000?o00001_o]C0000ol0003ok4l0o`000002o`00
0003one;0?l0003ok4h000Cok4h000?o0000on]@0?l000000_l00002one;0003o`000?o/C@3ok4d0
00?ok4d000?o0000ona>0?l000000_l00002ona=0004o`000?o/CP3ok4h0ona>00Go00009Oooool4
o`0002[ooooo001Pooooo`;o00004Oooool01_l0003okd80onm20?o_@P3o0000oo8i00?o00000_ob
=@000ol0003olC/0oo4k0003oo4k00;o00001Oo`?`000ol0003okTD0o`000002o`0000;okd4000?o
0000oni70?o^A`000oo^A`03o`0000?okTL000?o0000one<0?o]C0000oo]C002o`0000GokD/000Co
0000ona>0?o/CP3ok4h01?l00005one;0004o`000?o/C@3ok4d0ona=00?o00001Oo/C@04o`0002Ko
oooo1?l0000^ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`Go00001_ob=@000ol0003olC/0
o`000002o`0000;olSP000?o0000oo0o0?o`?`000_o`?`02o`0000Kokd4000?o0000oni70?l00000
0_l000000oo_@P3o0000oni70004oni70003o`000?o]C03o000000;o00000_o^A`000ol0003okD/0
one;0002one;00Co00001?o]B0001?l0003okD/0one;0?o]B`05o`0000?ok4`000?o0000ona=0?l0
00000_l0000Wooooo`?o0000<_ooool006?ooooo00?o0000ooooooooool04?ooool01?l0003ol3l0
oo0o0?l00005oo8e00;o00001_ob>0001?l0003ol3l0o`000?l00002oo4j0003o`000?o_@@3okd40
00?okd400_l00005onm20004o`000?o^A`3okTL0oni700Co00001Oo^A`001?l0003okD/0o`000?l0
0002oni50003o`000?o]B03okDP000?okDP01?l00003one;0004o`000?o/C03ok4`0ona<00?o0000
9_ooool4o`0003Gooooo001Tooooo`03o`000?oooooooooo013ooooo1?l000001?ob=@3o0000o`00
0?l00002oo<a0003o`000?ob>03olSP000?olSP00_l00005oo4j0003o`000?o_@@3o000000;o0000
0_oa?0000ol0003okd80onm20002onm200Co00001?o_@P001?l0003okTL0oni70?o^A`03o`0000Go
kTD000?o0000one80?l000000_l000000oo]B03o0000one;0004one;00Co00009Oooool4o`0003Wo
oooo001Uooooo`;o00004Oooool00ol0003olC/0o`000002o`0000Golc4000?o0000oo8h0?l00000
0_l000000ooc<`3o0000oo4j0004oo4j00;o00001_oa?0001?l0003okd80o`000?l00002oo0m0003
o`000?o_@P3okd8000?okd801?l00003onm20004o`000?o^A@3okTD0oni500?o00001Oo]B0000ol0
003okD/0o`000002o`0002Gooooo1?l0000mooooo`00Ioooool00ol0003oooooooooo`0?ooooo`05
o`000?oa>`3olC/0oo4k0?l000000ooc<@04o`0000Colc<000?o0000oo4j0?l000000_l00002oo8f
0003o`000?oa?03olC`000?olC`00_l00005oo0m0003o`000?o_@P3o000000;o000000?ol3d0o`00
0?o_@P001?o_@P04o`0000?okTD000Co0000one80?o]B03okDP00ol0000Uooooo`?o0000@Oooool0
06Sooooo00?o0000ooooooooool03oooool7o`0000Com2d000?o0000oo<c0?oc<`001?l00005oo8f
0003o`000?oa?03o000000;o000000?olSL0o`000?o`?@001?o`?@02o`0000Gol3d000?o0000onm2
0?l000000_l00002onm20003o`000?o^A@3okTD000;okTD01?l0000Tooooo`Co0000A?ooool006Wo
oooo00?o0000ooooooooool03_ooool00ol0003olSL0oo8g0002oo8g0003o`000?od;@3om2d000?o
m2d00ol00004oo@^0004o`000?ob=P3olSH0oo8f00?o00001Oob=`000ol0003ol3d0o`000002o`00
00;olSP000?o0000oo0m0?o`?@000_o`?@03o`0000Gokd8000Co0000oni50?l0003o00009?ooool4
o`0004Sooooo001Zooooo`;o00003oooool00ol0003olSL0oo8g0002oo8g0003o`000?od;@3o0000
00;o000000?omRL0o`000?od;P001?od;P04o`0000?om30000Co0000oo8g0?ob=`3olSL01?l00005
oo8h0004o`000?o`?@3o0000o`0000?ol3d000Co0000onm20?o_@P3okd800ol0000Rooooo`Co0000
C?ooool006cooooo00?o0000ooooooooool03Oooool6o`0000GomRL000?o0000oo@^0?l000000_l0
0002ooHX0003o`000?od<03om30000;om3001?l00004oo<a0004o`000?ob>03olSP0oo8h00?o0000
1Oo`?@04o`0002;ooooo0ol0001@ooooo`00KOooool00ol0003oooooooooo`0>ooooo`05o`000?oc
<P3olc80oo<b0?l000001?of9`02o`0000KomRP000Co0000oo@`0?l0003o00000_oe:P000ol0003o
lc40oo<a0003oo<a00Co00000oob>@000ol0003ol3d0o`000002o`0002;ooooo1?l0001Cooooo`00
K_ooool00ol0003oooooooooo`0>ooooo`Go000000?omRL0o`000?l000000_og8@000ol0003omRP0
ooHX0003ooHX00;o00001Ooe:P000ol0003olc40o`000002o`0000;olc<000Co0000oo8i0?ob>@3o
lST00ol0000Qooooo`Co0000Eoooool006oooooo00?o0000ooooooooool03_ooool00ol0003om2d0
oo@]0002o`0000Gomb4000?o0000ooHX0?l000000_l000000oog8P3o0000ooDZ0004ooDZ00?o0000
1?oc<`04o`00027ooooo0ol0001Kooooo`00L?ooool2o`0000oooooo00Go0000oo@]0?od;@3om2d0
o`000003ooLQ00?o00001Oog8P000ol0003omBX0o`000002o`0000?omB`000Co0000oo<c0?l0003o
00008Oooool4o`0005kooooo001booooo`03o`000?oooooooooo00gooooo1ol00003ooTL0003o`00
0?og8P3omb8000;omb801?l00003ooD/00?o00007oooool4o`0006;ooooo001cooooo`03o`000?oo
oooooooo00kooooo00Co0000ooHX0?of:03o00001Ooi70001?l0003omb80o`000?l00003ooLU00Co
00007_ooool4o`0006Kooooo001dooooo`03o`000?oooooooooo00gooooo1Ol00003ooTL00Co0000
00CombD0o`000?l0003o00007oooool3o`0006[ooooo001eooooo`;o00003Oooool01?l0003ooooo
o`000?od;@04o`0000?on1l00_l0000Nooooo`Co0000KOooool007Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`05o`000003ooPO0?l0003o000001cooooo1?l0001aooooo`00N?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0_l0000Jooooo`Co0000MOoo
ool007Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`?o0000NOooool0
07[ooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0001looooo`00O?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l00020ooooo`00OOooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol00024ooooo`00O_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo1?l00027ooooo`00Ooooool2o`0000?ooooo00?o0000
ooooooooool02_ooool4o`0008_ooooo0021ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002?
ooooo`00P_ooool00ol0003oooooo`000005ooooo`?o0000Toooool008?ooooo0_l000000ooooooo
0000o`000002o`0009Kooooo0024ooooo`;o0000V_ooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00=Cooooo0ol00019ooooo`00eOooool00ol0003oooooooooo`18ooooo`00Hooo
ool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00002?oo
ool3o`0000?ooooo0ol00004ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
0008ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o0000
0_ooool3o`000003ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`00
0?oooooooooo04Oooooo001Sooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005
ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo04Oooooo001Sooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oo
oooo000000;ooooo1Ol00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000B?ooool0
06;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000008ooooo`?o00000oooool2o`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000018ooooo`00H_ooool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Wooooo00?o0000ooooooooool00_ooool2
o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo00Co0000
oooooooooooooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Co
ooooo`000?l0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000017ooooo`00H_oo
ool01Ol0003oooooo`000?oooooo000001[ooooo00Co0000oooooooooooo00005?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1>ooooo`00H_ooool6o`0001Sooooo1Ol0000Dooooo`03o`000?oooooooooo00Sooooo
1Ol00008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1>ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.11354, 0.0326256, \
0.00372925, 0.00372925}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
9.02522e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.02412 .26509 -6 -2.7423 ]
[.02412 .26509 0 6.2577 ]
[.01077 .34875 -12 -2.8131 ]
[.01077 .34875 0 6.1869 ]
[-0.00332 .43708 -12 -2.88827 ]
[-0.00332 .43708 0 6.11173 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26032 m
.04245 .25793 L
s
[(0)] .02412 .26509 1 -0.3906 Mshowa
.02306 .34414 m
.0292 .34184 L
s
[(20)] .01077 .34875 1 -0.37487 Mshowa
.00903 .43265 m
.01521 .43044 L
s
[(40)] -0.00332 .43708 1 -0.35816 Mshowa
.125 Mabswid
.03308 .28085 m
.03676 .27943 L
s
.02979 .30167 m
.03346 .30026 L
s
.02644 .32276 m
.03013 .32137 L
s
.01962 .36581 m
.02331 .36445 L
s
.01614 .38779 m
.01984 .38643 L
s
.01261 .41006 m
.01631 .40872 L
s
.0054 .45556 m
.00911 .45425 L
s
.00172 .47879 m
.00543 .47749 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.976 .099 0 r
.38757 .79726 .39809 .8049 .41556 .80118 .40517 .79142 Metetra
.972 .117 0 r
.40517 .79142 .41556 .80118 .4332 .7955 .42294 .78377 Metetra
.961 .161 0 r
.42294 .78377 .4332 .7955 .45097 .78828 .44082 .77474 Metetra
.946 .223 0 r
.44082 .77474 .45097 .78828 .46885 .77987 .45879 .76468 Metetra
.926 .296 0 r
.45879 .76468 .46885 .77987 .48683 .77063 .47684 .75394 Metetra
.904 .374 0 r
.47684 .75394 .48683 .77063 .50488 .76084 .49496 .74281 Metetra
.882 .452 0 r
.49496 .74281 .50488 .76084 .523 .75079 .51312 .73155 Metetra
.859 .526 0 r
.51312 .73155 .523 .75079 .54118 .7407 .53135 .72041 Metetra
.836 .593 0 r
.53135 .72041 .54118 .7407 .55944 .7308 .54963 .70957 Metetra
.815 .652 0 r
.54963 .70957 .55944 .7308 .57776 .72124 .56798 .69922 Metetra
.797 .702 0 r
.56798 .69922 .57776 .72124 .59618 .71219 .58641 .68949 Metetra
.781 .742 0 r
.58641 .68949 .59618 .71219 .61469 .70376 .60493 .68051 Metetra
.763 .768 0 r
.60493 .68051 .61469 .70376 .63332 .69606 .62356 .67238 Metetra
.722 .758 0 r
.62356 .67238 .63332 .69606 .65207 .68916 .64232 .66515 Metetra
.698 .752 0 r
.64232 .66515 .65207 .68916 .67096 .6831 .66122 .65889 Metetra
.69 .75 0 r
.66122 .65889 .67096 .6831 .69002 .67792 .68028 .65362 Metetra
.698 .752 0 r
.68028 .65362 .69002 .67792 .70925 .67362 .69952 .64934 Metetra
.722 .758 0 r
.69952 .64934 .70925 .67362 .72868 .67019 .71897 .64604 Metetra
.763 .768 0 r
.71897 .64604 .72868 .67019 .74831 .66757 .73862 .64368 Metetra
.781 .742 0 r
.73862 .64368 .74831 .66757 .76816 .66571 .75851 .6422 Metetra
.797 .702 0 r
.75851 .6422 .76816 .66571 .78824 .66451 .77864 .64151 Metetra
.815 .652 0 r
.77864 .64151 .78824 .66451 .80856 .66386 .79902 .64149 Metetra
.836 .593 0 r
.79902 .64149 .80856 .66386 .8291 .66361 .81965 .64201 Metetra
.859 .526 0 r
.81965 .64201 .8291 .66361 .84987 .66357 .84053 .64289 Metetra
.882 .452 0 r
.84053 .64289 .84987 .66357 .87085 .66354 .86165 .64393 Metetra
.904 .374 0 r
.86165 .64393 .87085 .66354 .89202 .66327 .88299 .64489 Metetra
.926 .296 0 r
.88299 .64489 .89202 .66327 .91335 .66247 .90453 .64549 Metetra
.946 .223 0 r
.90453 .64549 .91335 .66247 .93478 .66082 .92621 .64541 Metetra
.961 .161 0 r
.92621 .64541 .93478 .66082 .95627 .65795 .948 .64429 Metetra
.972 .117 0 r
.948 .64429 .95627 .65795 .97774 .65345 .96982 .64173 Metetra
.976 .099 0 r
.96982 .64173 .97774 .65345 .99909 .64687 .99158 .63727 Metetra
.972 .117 0 r
.37699 .7876 .38757 .79726 .40517 .79142 .39474 .77978 Metetra
.96 .165 0 r
.39474 .77978 .40517 .79142 .42294 .78377 .41262 .77031 Metetra
.942 .235 0 r
.41262 .77031 .42294 .78377 .44082 .77474 .43061 .75961 Metetra
.92 .318 0 r
.43061 .75961 .44082 .77474 .45879 .76468 .44868 .74804 Metetra
.895 .406 0 r
.44868 .74804 .45879 .76468 .47684 .75394 .4668 .73593 Metetra
.868 .495 0 r
.4668 .73593 .47684 .75394 .49496 .74281 .48497 .72356 Metetra
.841 .58 0 r
.48497 .72356 .49496 .74281 .51312 .73155 .50319 .7112 Metetra
.814 .657 0 r
.50319 .7112 .51312 .73155 .53135 .72041 .52146 .69909 Metetra
.788 .724 0 r
.52146 .69909 .53135 .72041 .54963 .70957 .53977 .6874 Metetra
.746 .764 0 r
.53977 .6874 .54963 .70957 .56798 .69922 .55814 .67632 Metetra
.657 .743 0 r
.55814 .67632 .56798 .69922 .58641 .68949 .57659 .66597 Metetra
.584 .725 0 r
.57659 .66597 .58641 .68949 .60493 .68051 .59512 .65649 Metetra
.528 .71 0 r
.59512 .65649 .60493 .68051 .62356 .67238 .61375 .64795 Metetra
.488 .699 0 r
.61375 .64795 .62356 .67238 .64232 .66515 .63251 .64042 Metetra
.464 .693 0 r
.63251 .64042 .64232 .66515 .66122 .65889 .65141 .63397 Metetra
.456 .691 0 r
.65141 .63397 .66122 .65889 .68028 .65362 .67048 .6286 Metetra
.464 .693 0 r
.67048 .6286 .68028 .65362 .69952 .64934 .68973 .62433 Metetra
.488 .699 0 r
.68973 .62433 .69952 .64934 .71897 .64604 .70918 .62114 Metetra
.528 .71 0 r
.70918 .62114 .71897 .64604 .73862 .64368 .72885 .619 Metetra
.584 .725 0 r
.72885 .619 .73862 .64368 .75851 .6422 .74877 .61785 Metetra
.657 .743 0 r
.74877 .61785 .75851 .6422 .77864 .64151 .76893 .6176 Metetra
.746 .764 0 r
.76893 .6176 .77864 .64151 .79902 .64149 .78936 .61814 Metetra
.788 .724 0 r
.78936 .61814 .79902 .64149 .81965 .64201 .81007 .61935 Metetra
.814 .657 0 r
.81007 .61935 .81965 .64201 .84053 .64289 .83104 .62105 Metetra
.841 .58 0 r
.83104 .62105 .84053 .64289 .86165 .64393 .85228 .62304 Metetra
.868 .495 0 r
.85228 .62304 .86165 .64393 .88299 .64489 .87376 .62511 Metetra
.895 .406 0 r
.87376 .62511 .88299 .64489 .90453 .64549 .89548 .62697 Metetra
.92 .318 0 r
.89548 .62697 .90453 .64549 .92621 .64541 .91738 .62831 Metetra
.942 .235 0 r
.91738 .62831 .92621 .64541 .948 .64429 .93943 .62878 Metetra
.96 .165 0 r
.93943 .62878 .948 .64429 .96982 .64173 .96156 .62799 Metetra
.972 .117 0 r
.96156 .62799 .96982 .64173 .99158 .63727 .98368 .62548 Metetra
.961 .161 0 r
.36636 .77629 .37699 .7876 .39474 .77978 .38424 .76666 Metetra
.942 .235 0 r
.38424 .76666 .39474 .77978 .41262 .77031 .40225 .75553 Metetra
.918 .325 0 r
.40225 .75553 .41262 .77031 .43061 .75961 .42034 .7433 Metetra
.89 .423 0 r
.42034 .7433 .43061 .75961 .44868 .74804 .4385 .73034 Metetra
.86 .522 0 r
.4385 .73034 .44868 .74804 .4668 .73593 .4567 .71697 Metetra
.828 .616 0 r
.4567 .71697 .4668 .73593 .48497 .72356 .47494 .70347 Metetra
.797 .702 0 r
.47494 .70347 .48497 .72356 .50319 .7112 .49321 .69012 Metetra
.755 .766 0 r
.49321 .69012 .50319 .7112 .52146 .69909 .51151 .67711 Metetra
.633 .737 0 r
.51151 .67711 .52146 .69909 .53977 .6874 .52986 .66466 Metetra
.528 .71 0 r
.52986 .66466 .53977 .6874 .55814 .67632 .54826 .6529 Metetra
.44 .686 0 r
.54826 .6529 .55814 .67632 .57659 .66597 .56672 .642 Metetra
.369 .666 0 r
.56672 .642 .57659 .66597 .59512 .65649 .58526 .63204 Metetra
.315 .65 0 r
.58526 .63204 .59512 .65649 .61375 .64795 .6039 .62313 Metetra
.277 .639 0 r
.6039 .62313 .61375 .64795 .63251 .64042 .62266 .61533 Metetra
.255 .632 0 r
.62266 .61533 .63251 .64042 .65141 .63397 .64156 .60869 Metetra
.247 .629 0 r
.64156 .60869 .65141 .63397 .67048 .6286 .66063 .60323 Metetra
.255 .632 0 r
.66063 .60323 .67048 .6286 .68973 .62433 .67988 .59895 Metetra
.277 .639 0 r
.67988 .59895 .68973 .62433 .70918 .62114 .69934 .59585 Metetra
.315 .65 0 r
.69934 .59585 .70918 .62114 .72885 .619 .71902 .5939 Metetra
.369 .666 0 r
.71902 .5939 .72885 .619 .74877 .61785 .73895 .59302 Metetra
.44 .686 0 r
.73895 .59302 .74877 .61785 .76893 .6176 .75915 .59315 Metetra
.528 .71 0 r
.75915 .59315 .76893 .6176 .78936 .61814 .77962 .59419 Metetra
.633 .737 0 r
.77962 .59419 .78936 .61814 .81007 .61935 .80038 .596 Metetra
.755 .766 0 r
.80038 .596 .81007 .61935 .83104 .62105 .82143 .59842 Metetra
.797 .702 0 r
.82143 .59842 .83104 .62105 .85228 .62304 .84277 .60127 Metetra
.828 .616 0 r
.84277 .60127 .85228 .62304 .87376 .62511 .86438 .60432 Metetra
.86 .522 0 r
.86438 .60432 .87376 .62511 .89548 .62697 .88625 .60731 Metetra
.89 .423 0 r
.88625 .60731 .89548 .62697 .91738 .62831 .90834 .60994 Metetra
.918 .325 0 r
.90834 .60994 .91738 .62831 .93943 .62878 .93062 .61185 Metetra
.942 .235 0 r
.93062 .61185 .93943 .62878 .96156 .62799 .95302 .61265 Metetra
.961 .161 0 r
.95302 .61265 .96156 .62799 .98368 .62548 .97547 .61191 Metetra
.946 .223 0 r
.35566 .76372 .36636 .77629 .38424 .76666 .37369 .75242 Metetra
.92 .318 0 r
.37369 .75242 .38424 .76666 .40225 .75553 .39181 .73976 Metetra
.89 .423 0 r
.39181 .73976 .40225 .75553 .42034 .7433 .41001 .72614 Metetra
.857 .531 0 r
.41001 .72614 .42034 .7433 .4385 .73034 .42826 .71192 Metetra
.822 .634 0 r
.42826 .71192 .4385 .73034 .4567 .71697 .44654 .69741 Metetra
.786 .729 0 r
.44654 .69741 .4567 .71697 .47494 .70347 .46485 .6829 Metetra
.69 .751 0 r
.46485 .6829 .47494 .70347 .49321 .69012 .48317 .66863 Metetra
.552 .716 0 r
.48317 .66863 .49321 .69012 .51151 .67711 .50152 .65482 Metetra
.432 .684 0 r
.50152 .65482 .51151 .67711 .52986 .66466 .5199 .64166 Metetra
.331 .655 0 r
.5199 .64166 .52986 .66466 .54826 .6529 .53832 .62931 Metetra
.247 .629 0 r
.53832 .62931 .54826 .6529 .56672 .642 .5568 .61788 Metetra
.182 .607 0 r
.5568 .61788 .56672 .642 .58526 .63204 .57536 .6075 Metetra
.132 .59 0 r
.57536 .6075 .58526 .63204 .6039 .62313 .59401 .59825 Metetra
.098 .577 0 r
.59401 .59825 .6039 .62313 .62266 .61533 .61277 .5902 Metetra
.077 .57 0 r
.61277 .5902 .62266 .61533 .64156 .60869 .63168 .58337 Metetra
.071 .567 0 r
.63168 .58337 .64156 .60869 .66063 .60323 .65074 .57782 Metetra
.077 .57 0 r
.65074 .57782 .66063 .60323 .67988 .59895 .67 .57353 Metetra
.098 .577 0 r
.67 .57353 .67988 .59895 .69934 .59585 .68946 .5705 Metetra
.132 .59 0 r
.68946 .5705 .69934 .59585 .71902 .5939 .70915 .56869 Metetra
.182 .607 0 r
.70915 .56869 .71902 .5939 .73895 .59302 .7291 .56806 Metetra
.247 .629 0 r
.7291 .56806 .73895 .59302 .75915 .59315 .74932 .56852 Metetra
.331 .655 0 r
.74932 .56852 .75915 .59315 .77962 .59419 .76982 .56998 Metetra
.432 .684 0 r
.76982 .56998 .77962 .59419 .80038 .596 .79063 .57232 Metetra
.552 .716 0 r
.79063 .57232 .80038 .596 .82143 .59842 .81174 .57538 Metetra
.69 .751 0 r
.81174 .57538 .82143 .59842 .84277 .60127 .83316 .57898 Metetra
.786 .729 0 r
.83316 .57898 .84277 .60127 .86438 .60432 .85488 .5829 Metetra
.822 .634 0 r
.85488 .5829 .86438 .60432 .88625 .60731 .87688 .58689 Metetra
.857 .531 0 r
.87688 .58689 .88625 .60731 .90834 .60994 .89914 .59066 Metetra
.89 .423 0 r
.89914 .59066 .90834 .60994 .93062 .61185 .92162 .59386 Metetra
.92 .318 0 r
.92162 .59386 .93062 .61185 .95302 .61265 .94427 .59611 Metetra
.946 .223 0 r
.94427 .59611 .95302 .61265 .97547 .61191 .96701 .59697 Metetra
.926 .296 0 r
.3449 .75021 .35566 .76372 .37369 .75242 .36306 .7374 Metetra
.895 .406 0 r
.36306 .7374 .37369 .75242 .39181 .73976 .38131 .72336 Metetra
.86 .522 0 r
.38131 .72336 .39181 .73976 .41001 .72614 .39962 .70847 Metetra
.822 .634 0 r
.39962 .70847 .41001 .72614 .42826 .71192 .41796 .69311 Metetra
.782 .738 0 r
.41796 .69311 .42826 .71192 .44654 .69741 .43632 .67757 Metetra
.657 .743 0 r
.43632 .67757 .44654 .69741 .46485 .6829 .4547 .66213 Metetra
.504 .704 0 r
.4547 .66213 .46485 .6829 .48317 .66863 .47308 .64704 Metetra
.369 .666 0 r
.47308 .64704 .48317 .66863 .50152 .65482 .49148 .63251 Metetra
.255 .632 0 r
.49148 .63251 .50152 .65482 .5199 .64166 .5099 .61872 Metetra
.16 .6 0 r
.5099 .61872 .5199 .64166 .53832 .62931 .52835 .60581 Metetra
.084 .572 0 r
.52835 .60581 .53832 .62931 .5568 .61788 .54685 .59392 Metetra
.025 .549 0 r
.54685 .59392 .5568 .61788 .57536 .6075 .56542 .58316 Metetra
0 .53 .018 r
.56542 .58316 .57536 .6075 .59401 .59825 .58408 .57359 Metetra
0 .517 .048 r
.58408 .57359 .59401 .59825 .61277 .5902 .60286 .5653 Metetra
0 .509 .065 r
.60286 .5653 .61277 .5902 .63168 .58337 .62177 .55831 Metetra
0 .506 .071 r
.62177 .55831 .63168 .58337 .65074 .57782 .64084 .55265 Metetra
0 .509 .065 r
.64084 .55265 .65074 .57782 .67 .57353 .66009 .54834 Metetra
0 .517 .048 r
.66009 .54834 .67 .57353 .68946 .5705 .67956 .54536 Metetra
0 .53 .018 r
.67956 .54536 .68946 .5705 .70915 .56869 .69926 .54367 Metetra
.025 .549 0 r
.69926 .54367 .70915 .56869 .7291 .56806 .71921 .54324 Metetra
.084 .572 0 r
.71921 .54324 .7291 .56806 .74932 .56852 .73945 .54398 Metetra
.16 .6 0 r
.73945 .54398 .74932 .56852 .76982 .56998 .75998 .54581 Metetra
.255 .632 0 r
.75998 .54581 .76982 .56998 .79063 .57232 .78083 .5486 Metetra
.369 .666 0 r
.78083 .5486 .79063 .57232 .81174 .57538 .80199 .55222 Metetra
.504 .704 0 r
.80199 .55222 .81174 .57538 .83316 .57898 .82348 .55647 Metetra
.657 .743 0 r
.82348 .55647 .83316 .57898 .85488 .5829 .84529 .56116 Metetra
.782 .738 0 r
.84529 .56116 .85488 .5829 .87688 .58689 .86741 .56604 Metetra
.822 .634 0 r
.86741 .56604 .87688 .58689 .89914 .59066 .88982 .57082 Metetra
.86 .522 0 r
.88982 .57082 .89914 .59066 .92162 .59386 .91248 .57516 Metetra
.895 .406 0 r
.91248 .57516 .92162 .59386 .94427 .59611 .93534 .57869 Metetra
.926 .296 0 r
.93534 .57869 .94427 .59611 .96701 .59697 .95834 .58099 Metetra
.904 .374 0 r
.33406 .73606 .3449 .75021 .36306 .7374 .35236 .72188 Metetra
.868 .495 0 r
.35236 .72188 .36306 .7374 .38131 .72336 .37073 .70659 Metetra
.828 .616 0 r
.37073 .70659 .38131 .72336 .39962 .70847 .38915 .69058 Metetra
.786 .729 0 r
.38915 .69058 .39962 .70847 .41796 .69311 .40759 .67418 Metetra
.657 .743 0 r
.40759 .67418 .41796 .69311 .43632 .67757 .42604 .65771 Metetra
.488 .699 0 r
.42604 .65771 .43632 .67757 .4547 .66213 .44448 .64145 Metetra
.338 .657 0 r
.44448 .64145 .4547 .66213 .47308 .64704 .46293 .62562 Metetra
.211 .617 0 r
.46293 .62562 .47308 .64704 .49148 .63251 .48138 .61044 Metetra
.104 .58 0 r
.48138 .61044 .49148 .63251 .5099 .61872 .49984 .59607 Metetra
.019 .546 0 r
.49984 .59607 .5099 .61872 .52835 .60581 .51833 .58267 Metetra
0 .517 .048 r
.51833 .58267 .52835 .60581 .54685 .59392 .53686 .57036 Metetra
0 .492 .099 r
.53686 .57036 .54685 .59392 .56542 .58316 .55545 .55924 Metetra
0 .473 .135 r
.55545 .55924 .56542 .58316 .58408 .57359 .57413 .54939 Metetra
0 .458 .159 r
.57413 .54939 .58408 .57359 .60286 .5653 .59291 .54087 Metetra
0 .45 .173 r
.59291 .54087 .60286 .5653 .62177 .55831 .61183 .53373 Metetra
0 .447 .177 r
.61183 .53373 .62177 .55831 .64084 .55265 .63091 .52798 Metetra
0 .45 .173 r
.63091 .52798 .64084 .55265 .66009 .54834 .65017 .52363 Metetra
0 .458 .159 r
.65017 .52363 .66009 .54834 .67956 .54536 .66964 .52068 Metetra
0 .473 .135 r
.66964 .52068 .67956 .54536 .69926 .54367 .68935 .51909 Metetra
0 .492 .099 r
.68935 .51909 .69926 .54367 .71921 .54324 .70932 .51882 Metetra
0 .517 .048 r
.70932 .51882 .71921 .54324 .73945 .54398 .72957 .5198 Metetra
.019 .546 0 r
.72957 .5198 .73945 .54398 .75998 .54581 .75013 .52194 Metetra
.104 .58 0 r
.75013 .52194 .75998 .54581 .78083 .5486 .771 .52512 Metetra
.211 .617 0 r
.771 .52512 .78083 .5486 .80199 .55222 .79221 .52921 Metetra
.338 .657 0 r
.79221 .52921 .80199 .55222 .82348 .55647 .81377 .53404 Metetra
.488 .699 0 r
.81377 .53404 .82348 .55647 .84529 .56116 .83566 .5394 Metetra
.657 .743 0 r
.83566 .5394 .84529 .56116 .86741 .56604 .85788 .54505 Metetra
.786 .729 0 r
.85788 .54505 .86741 .56604 .88982 .57082 .88041 .55071 Metetra
.828 .616 0 r
.88041 .55071 .88982 .57082 .91248 .57516 .90323 .55607 Metetra
.868 .495 0 r
.90323 .55607 .91248 .57516 .93534 .57869 .92628 .56073 Metetra
.904 .374 0 r
.92628 .56073 .93534 .57869 .95834 .58099 .9495 .56429 Metetra
.882 .452 0 r
.32313 .72153 .33406 .73606 .35236 .72188 .34156 .70614 Metetra
.841 .58 0 r
.34156 .70614 .35236 .72188 .37073 .70659 .36006 .68973 Metetra
.797 .702 0 r
.36006 .68973 .37073 .70659 .38915 .69058 .37859 .6727 Metetra
.69 .751 0 r
.37859 .6727 .38915 .69058 .40759 .67418 .39713 .65538 Metetra
.504 .704 0 r
.39713 .65538 .40759 .67418 .42604 .65771 .41567 .63809 Metetra
.338 .657 0 r
.41567 .63809 .42604 .65771 .44448 .64145 .43419 .62108 Metetra
.196 .612 0 r
.43419 .62108 .44448 .64145 .46293 .62562 .45271 .6046 Metetra
.077 .57 0 r
.45271 .6046 .46293 .62562 .48138 .61044 .47122 .58883 Metetra
0 .531 .018 r
.47122 .58883 .48138 .61044 .49984 .59607 .48973 .57395 Metetra
0 .495 .093 r
.48973 .57395 .49984 .59607 .51833 .58267 .50826 .56011 Metetra
0 .464 .15 r
.50826 .56011 .51833 .58267 .53686 .57036 .52682 .54742 Metetra
0 .438 .191 r
.52682 .54742 .53686 .57036 .55545 .55924 .54544 .53598 Metetra
0 .417 .219 r
.54544 .53598 .55545 .55924 .57413 .54939 .56414 .52587 Metetra
0 .403 .237 r
.56414 .52587 .57413 .54939 .59291 .54087 .58294 .51715 Metetra
0 .393 .247 r
.58294 .51715 .59291 .54087 .61183 .53373 .60187 .50985 Metetra
0 .39 .25 r
.60187 .50985 .61183 .53373 .63091 .52798 .62096 .504 Metetra
0 .393 .247 r
.62096 .504 .63091 .52798 .65017 .52363 .64023 .49962 Metetra
0 .403 .237 r
.64023 .49962 .65017 .52363 .66964 .52068 .65971 .49668 Metetra
0 .417 .219 r
.65971 .49668 .66964 .52068 .68935 .51909 .67943 .49516 Metetra
0 .438 .191 r
.67943 .49516 .68935 .51909 .70932 .51882 .69941 .49502 Metetra
0 .464 .15 r
.69941 .49502 .70932 .51882 .72957 .5198 .71968 .4962 Metetra
0 .495 .093 r
.71968 .4962 .72957 .5198 .75013 .52194 .74026 .49859 Metetra
0 .531 .018 r
.74026 .49859 .75013 .52194 .771 .52512 .76117 .50211 Metetra
.077 .57 0 r
.76117 .50211 .771 .52512 .79221 .52921 .78242 .50661 Metetra
.196 .612 0 r
.78242 .50661 .79221 .52921 .81377 .53404 .80402 .51192 Metetra
.338 .657 0 r
.80402 .51192 .81377 .53404 .83566 .5394 .82598 .51785 Metetra
.504 .704 0 r
.82598 .51785 .83566 .5394 .85788 .54505 .8483 .52417 Metetra
.69 .751 0 r
.8483 .52417 .85788 .54505 .88041 .55071 .87094 .53061 Metetra
.797 .702 0 r
.87094 .53061 .88041 .55071 .90323 .55607 .89389 .53684 Metetra
.841 .58 0 r
.89389 .53684 .90323 .55607 .92628 .56073 .91711 .5425 Metetra
.882 .452 0 r
.91711 .5425 .92628 .56073 .9495 .56429 .94054 .54717 Metetra
.859 .526 0 r
.31209 .70688 .32313 .72153 .34156 .70614 .33066 .6904 Metetra
.814 .657 0 r
.33066 .6904 .34156 .70614 .36006 .68973 .34929 .67301 Metetra
.755 .766 0 r
.34929 .67301 .36006 .68973 .37859 .6727 .36794 .65507 Metetra
.552 .716 0 r
.36794 .65507 .37859 .6727 .39713 .65538 .38658 .63694 Metetra
.369 .666 0 r
.38658 .63694 .39713 .65538 .41567 .63809 .40521 .61891 Metetra
.211 .617 0 r
.40521 .61891 .41567 .63809 .43419 .62108 .42382 .60125 Metetra
.077 .57 0 r
.42382 .60125 .43419 .62108 .45271 .6046 .44241 .58417 Metetra
0 .525 .03 r
.44241 .58417 .45271 .6046 .47122 .58883 .46098 .56789 Metetra
0 .484 .114 r
.46098 .56789 .47122 .58883 .48973 .57395 .47955 .55255 Metetra
0 .447 .177 r
.47955 .55255 .48973 .57395 .50826 .56011 .49813 .53831 Metetra
0 .414 .223 r
.49813 .53831 .50826 .56011 .52682 .54742 .51673 .52528 Metetra
0 .387 .254 r
.51673 .52528 .52682 .54742 .54544 .53598 .53539 .51355 Metetra
0 .366 .274 r
.53539 .51355 .54544 .53598 .56414 .52587 .55412 .5032 Metetra
0 .35 .286 r
.55412 .5032 .56414 .52587 .58294 .51715 .57294 .49429 Metetra
0 .341 .292 r
.57294 .49429 .58294 .51715 .60187 .50985 .59189 .48685 Metetra
0 .338 .294 r
.59189 .48685 .60187 .50985 .62096 .504 .61099 .48091 Metetra
0 .341 .292 r
.61099 .48091 .62096 .504 .64023 .49962 .63028 .47648 Metetra
0 .35 .286 r
.63028 .47648 .64023 .49962 .65971 .49668 .64977 .47354 Metetra
0 .366 .274 r
.64977 .47354 .65971 .49668 .67943 .49516 .6695 .47207 Metetra
0 .387 .254 r
.6695 .47207 .67943 .49516 .69941 .49502 .6895 .47204 Metetra
0 .414 .223 r
.6895 .47204 .69941 .49502 .71968 .4962 .70978 .47336 Metetra
0 .447 .177 r
.70978 .47336 .71968 .4962 .74026 .49859 .73039 .47597 Metetra
0 .484 .114 r
.73039 .47597 .74026 .49859 .76117 .50211 .75132 .47976 Metetra
0 .525 .03 r
.75132 .47976 .76117 .50211 .78242 .50661 .77262 .4846 Metetra
.077 .57 0 r
.77262 .4846 .78242 .50661 .80402 .51192 .79427 .49033 Metetra
.211 .617 0 r
.79427 .49033 .80402 .51192 .82598 .51785 .81629 .49675 Metetra
.369 .666 0 r
.81629 .49675 .82598 .51785 .8483 .52417 .83869 .50364 Metetra
.552 .716 0 r
.83869 .50364 .8483 .52417 .87094 .53061 .86143 .51074 Metetra
.755 .766 0 r
.86143 .51074 .87094 .53061 .89389 .53684 .88451 .51772 Metetra
.814 .657 0 r
.88451 .51772 .89389 .53684 .91711 .5425 .90788 .52424 Metetra
.859 .526 0 r
.90788 .52424 .91711 .5425 .94054 .54717 .93149 .52988 Metetra
.836 .593 0 r
.30094 .69231 .31209 .70688 .33066 .6904 .31965 .67487 Metetra
.788 .724 0 r
.31965 .67487 .33066 .6904 .34929 .67301 .3384 .65661 Metetra
.633 .737 0 r
.3384 .65661 .34929 .67301 .36794 .65507 .35717 .63788 Metetra
.432 .684 0 r
.35717 .63788 .36794 .65507 .38658 .63694 .37592 .61903 Metetra
.255 .632 0 r
.37592 .61903 .38658 .63694 .40521 .61891 .39465 .60036 Metetra
.105 .58 0 r
.39465 .60036 .40521 .61891 .42382 .60125 .41335 .58211 Metetra
0 .531 .018 r
.41335 .58211 .42382 .60125 .44241 .58417 .43202 .56452 Metetra
0 .484 .114 r
.43202 .56452 .44241 .58417 .46098 .56789 .45066 .54777 Metetra
0 .441 .186 r
.45066 .54777 .46098 .56789 .47955 .55255 .46929 .53203 Metetra
0 .403 .237 r
.46929 .53203 .47955 .55255 .49813 .53831 .48793 .51744 Metetra
0 .369 .271 r
.48793 .51744 .49813 .53831 .51673 .52528 .50658 .5041 Metetra
0 .341 .292 r
.50658 .5041 .51673 .52528 .53539 .51355 .52528 .49211 Metetra
0 .319 .303 r
.52528 .49211 .53539 .51355 .55412 .5032 .54404 .48155 Metetra
0 .296 .303 r
.54404 .48155 .55412 .5032 .57294 .49429 .5629 .47246 Metetra
0 .274 .293 r
.5629 .47246 .57294 .49429 .59189 .48685 .58187 .46489 Metetra
0 .267 .29 r
.58187 .46489 .59189 .48685 .61099 .48091 .601 .45885 Metetra
0 .274 .293 r
.601 .45885 .61099 .48091 .63028 .47648 .6203 .45437 Metetra
0 .296 .303 r
.6203 .45437 .63028 .47648 .64977 .47354 .63982 .45142 Metetra
0 .319 .303 r
.63982 .45142 .64977 .47354 .6695 .47207 .65957 .44998 Metetra
0 .341 .292 r
.65957 .44998 .6695 .47207 .6895 .47204 .67958 .45002 Metetra
0 .369 .271 r
.67958 .45002 .6895 .47204 .70978 .47336 .69989 .45147 Metetra
0 .403 .237 r
.69989 .45147 .70978 .47336 .73039 .47597 .72052 .45425 Metetra
0 .441 .186 r
.72052 .45425 .73039 .47597 .75132 .47976 .74148 .45826 Metetra
0 .484 .114 r
.74148 .45826 .75132 .47976 .77262 .4846 .76281 .46338 Metetra
0 .531 .018 r
.76281 .46338 .77262 .4846 .79427 .49033 .78451 .46944 Metetra
.105 .58 0 r
.78451 .46944 .79427 .49033 .81629 .49675 .8066 .47627 Metetra
.255 .632 0 r
.8066 .47627 .81629 .49675 .83869 .50364 .82906 .48364 Metetra
.432 .684 0 r
.82906 .48364 .83869 .50364 .86143 .51074 .8519 .4913 Metetra
.633 .737 0 r
.8519 .4913 .86143 .51074 .88451 .51772 .87509 .49892 Metetra
.788 .724 0 r
.87509 .49892 .88451 .51772 .90788 .52424 .89859 .50617 Metetra
.836 .593 0 r
.89859 .50617 .90788 .52424 .93149 .52988 .92237 .51263 Metetra
.815 .652 0 r
.28965 .67799 .30094 .69231 .31965 .67487 .3085 .65973 Metetra
.747 .764 0 r
.3085 .65973 .31965 .67487 .3384 .65661 .32738 .64071 Metetra
.528 .71 0 r
.32738 .64071 .3384 .65661 .35717 .63788 .34627 .62129 Metetra
.331 .655 0 r
.34627 .62129 .35717 .63788 .37592 .61903 .36514 .60182 Metetra
.16 .6 0 r
.36514 .60182 .37592 .61903 .39465 .60036 .38397 .58258 Metetra
.019 .546 0 r
.38397 .58258 .39465 .60036 .41335 .58211 .40277 .56383 Metetra
0 .495 .093 r
.40277 .56383 .41335 .58211 .43202 .56452 .42152 .54579 Metetra
0 .447 .177 r
.42152 .54579 .43202 .56452 .45066 .54777 .44024 .52864 Metetra
0 .403 .237 r
.44024 .52864 .45066 .54777 .46929 .53203 .45895 .51254 Metetra
0 .363 .276 r
.45895 .51254 .46929 .53203 .48793 .51744 .47764 .49763 Metetra
0 .328 .299 r
.47764 .49763 .48793 .51744 .50658 .5041 .49635 .48402 Metetra
0 .289 .299 r
.49635 .48402 .50658 .5041 .52528 .49211 .5151 .4718 Metetra
0 .239 .277 r
.5151 .4718 .52528 .49211 .54404 .48155 .53391 .46104 Metetra
0 .206 .26 r
.53391 .46104 .54404 .48155 .5629 .47246 .5528 .45179 Metetra
0 .187 .25 r
.5528 .45179 .5629 .47246 .58187 .46489 .57182 .44409 Metetra
0 .181 .247 r
.57182 .44409 .58187 .46489 .601 .45885 .59097 .43796 Metetra
0 .187 .25 r
.59097 .43796 .601 .45885 .6203 .45437 .6103 .43342 Metetra
0 .206 .26 r
.6103 .43342 .6203 .45437 .63982 .45142 .62984 .43044 Metetra
0 .239 .277 r
.62984 .43044 .63982 .45142 .65957 .44998 .64962 .42902 Metetra
0 .289 .299 r
.64962 .42902 .65957 .44998 .67958 .45002 .66966 .42911 Metetra
0 .328 .299 r
.66966 .42911 .67958 .45002 .69989 .45147 .68999 .43064 Metetra
0 .363 .276 r
.68999 .43064 .69989 .45147 .72052 .45425 .71065 .43355 Metetra
0 .403 .237 r
.71065 .43355 .72052 .45425 .74148 .45826 .73165 .43774 Metetra
0 .447 .177 r
.73165 .43774 .74148 .45826 .76281 .46338 .75301 .44308 Metetra
0 .495 .093 r
.75301 .44308 .76281 .46338 .78451 .46944 .77476 .44942 Metetra
.019 .546 0 r
.77476 .44942 .78451 .46944 .8066 .47627 .7969 .45659 Metetra
.16 .6 0 r
.7969 .45659 .8066 .47627 .82906 .48364 .81943 .46435 Metetra
.331 .655 0 r
.81943 .46435 .82906 .48364 .8519 .4913 .84236 .47246 Metetra
.528 .71 0 r
.84236 .47246 .8519 .4913 .87509 .49892 .86565 .48062 Metetra
.747 .764 0 r
.86565 .48062 .87509 .49892 .89859 .50617 .88927 .48847 Metetra
.815 .652 0 r
.88927 .48847 .89859 .50617 .92237 .51263 .91319 .49562 Metetra
.797 .702 0 r
.27821 .66407 .28965 .67799 .3085 .65973 .2972 .64511 Metetra
.657 .743 0 r
.2972 .64511 .3085 .65973 .32738 .64071 .31622 .62545 Metetra
.44 .686 0 r
.31622 .62545 .32738 .64071 .34627 .62129 .33523 .60545 Metetra
.247 .629 0 r
.33523 .60545 .34627 .62129 .36514 .60182 .35422 .58544 Metetra
.084 .572 0 r
.35422 .58544 .36514 .60182 .38397 .58258 .37316 .56572 Metetra
0 .517 .048 r
.37316 .56572 .38397 .58258 .40277 .56383 .39205 .54653 Metetra
0 .464 .15 r
.39205 .54653 .40277 .56383 .42152 .54579 .4109 .52809 Metetra
0 .414 .223 r
.4109 .52809 .42152 .54579 .44024 .52864 .42971 .51059 Metetra
0 .369 .271 r
.42971 .51059 .44024 .52864 .45895 .51254 .44849 .49419 Metetra
0 .328 .299 r
.44849 .49419 .45895 .51254 .47764 .49763 .46726 .479 Metetra
0 .274 .293 r
.46726 .479 .47764 .49763 .49635 .48402 .48604 .46515 Metetra
0 .213 .263 r
.48604 .46515 .49635 .48402 .5151 .4718 .50484 .45272 Metetra
0 .169 .24 r
.50484 .45272 .5151 .4718 .53391 .46104 .52371 .44178 Metetra
0 .141 .223 r
.52371 .44178 .53391 .46104 .5528 .45179 .54265 .43238 Metetra
0 .125 .213 r
.54265 .43238 .5528 .45179 .57182 .44409 .5617 .42456 Metetra
0 .12 .209 r
.5617 .42456 .57182 .44409 .59097 .43796 .5809 .41834 Metetra
0 .125 .213 r
.5809 .41834 .59097 .43796 .6103 .43342 .60027 .41374 Metetra
0 .141 .223 r
.60027 .41374 .6103 .43342 .62984 .43044 .61984 .41073 Metetra
0 .169 .24 r
.61984 .41073 .62984 .43044 .64962 .42902 .63964 .4093 Metetra
0 .213 .263 r
.63964 .4093 .64962 .42902 .66966 .42911 .65972 .40941 Metetra
0 .274 .293 r
.65972 .40941 .66966 .42911 .68999 .43064 .68008 .41101 Metetra
0 .328 .299 r
.68008 .41101 .68999 .43064 .71065 .43355 .70077 .41401 Metetra
0 .369 .271 r
.70077 .41401 .71065 .43355 .73165 .43774 .72181 .41833 Metetra
0 .414 .223 r
.72181 .41833 .73165 .43774 .75301 .44308 .74322 .42384 Metetra
0 .464 .15 r
.74322 .42384 .75301 .44308 .77476 .44942 .76501 .4304 Metetra
0 .517 .048 r
.76501 .4304 .77476 .44942 .7969 .45659 .78721 .43782 Metetra
.084 .572 0 r
.78721 .43782 .7969 .45659 .81943 .46435 .80981 .44589 Metetra
.247 .629 0 r
.80981 .44589 .81943 .46435 .84236 .47246 .83281 .45437 Metetra
.44 .686 0 r
.83281 .45437 .84236 .47246 .86565 .48062 .85619 .46295 Metetra
.657 .743 0 r
.85619 .46295 .86565 .48062 .88927 .48847 .87993 .47129 Metetra
.797 .702 0 r
.87993 .47129 .88927 .48847 .91319 .49562 .90398 .479 Metetra
.781 .742 0 r
.2666 .6507 .27821 .66407 .2972 .64511 .28573 .63115 Metetra
.584 .725 0 r
.28573 .63115 .2972 .64511 .31622 .62545 .30488 .61095 Metetra
.369 .666 0 r
.30488 .61095 .31622 .62545 .33523 .60545 .32403 .59046 Metetra
.182 .607 0 r
.32403 .59046 .33523 .60545 .35422 .58544 .34313 .57 Metetra
.025 .549 0 r
.34313 .57 .35422 .58544 .37316 .56572 .36219 .54987 Metetra
0 .492 .099 r
.36219 .54987 .37316 .56572 .39205 .54653 .3812 .53032 Metetra
0 .438 .191 r
.3812 .53032 .39205 .54653 .4109 .52809 .40015 .51155 Metetra
0 .387 .254 r
.40015 .51155 .4109 .52809 .42971 .51059 .41905 .49375 Metetra
0 .341 .292 r
.41905 .49375 .42971 .51059 .44849 .49419 .43792 .47707 Metetra
0 .289 .299 r
.43792 .47707 .44849 .49419 .46726 .479 .45677 .46165 Metetra
0 .213 .263 r
.45677 .46165 .46726 .479 .48604 .46515 .47562 .44758 Metetra
0 .158 .233 r
.47562 .44758 .48604 .46515 .50484 .45272 .49449 .43497 Metetra
0 .12 .209 r
.49449 .43497 .50484 .45272 .52371 .44178 .51342 .42386 Metetra
0 .096 .192 r
.51342 .42386 .52371 .44178 .54265 .43238 .53242 .41433 Metetra
0 .082 .182 r
.53242 .41433 .54265 .43238 .5617 .42456 .55153 .4064 Metetra
0 .078 .178 r
.55153 .4064 .5617 .42456 .5809 .41834 .57077 .40009 Metetra
0 .082 .182 r
.57077 .40009 .5809 .41834 .60027 .41374 .59018 .39541 Metetra
0 .096 .192 r
.59018 .39541 .60027 .41374 .61984 .41073 .6098 .39236 Metetra
0 .12 .209 r
.6098 .39236 .61984 .41073 .63964 .4093 .62964 .39091 Metetra
0 .158 .233 r
.62964 .39091 .63964 .4093 .65972 .40941 .64975 .39103 Metetra
0 .213 .263 r
.64975 .39103 .65972 .40941 .68008 .41101 .67016 .39266 Metetra
0 .289 .299 r
.67016 .39266 .68008 .41101 .70077 .41401 .69088 .39572 Metetra
0 .341 .292 r
.69088 .39572 .70077 .41401 .72181 .41833 .71196 .40013 Metetra
0 .387 .254 r
.71196 .40013 .72181 .41833 .74322 .42384 .73342 .40576 Metetra
0 .438 .191 r
.73342 .40576 .74322 .42384 .76501 .4304 .75526 .41247 Metetra
0 .492 .099 r
.75526 .41247 .76501 .4304 .78721 .43782 .77752 .42008 Metetra
.025 .549 0 r
.77752 .42008 .78721 .43782 .80981 .44589 .80018 .42839 Metetra
.182 .607 0 r
.80018 .42839 .80981 .44589 .83281 .45437 .82326 .43715 Metetra
.369 .666 0 r
.82326 .43715 .83281 .45437 .85619 .46295 .84673 .44605 Metetra
.584 .725 0 r
.84673 .44605 .85619 .46295 .87993 .47129 .87057 .45477 Metetra
.781 .742 0 r
.87057 .45477 .87993 .47129 .90398 .479 .89475 .4629 Metetra
.763 .768 0 r
.2548 .63796 .2666 .6507 .28573 .63115 .27407 .61795 Metetra
.528 .71 0 r
.27407 .61795 .28573 .63115 .30488 .61095 .29337 .59731 Metetra
.315 .65 0 r
.29337 .59731 .30488 .61095 .32403 .59046 .31264 .57642 Metetra
.132 .59 0 r
.31264 .57642 .32403 .59046 .34313 .57 .33188 .5556 Metetra
0 .53 .018 r
.33188 .5556 .34313 .57 .36219 .54987 .35106 .53513 Metetra
0 .473 .135 r
.35106 .53513 .36219 .54987 .3812 .53032 .37018 .51527 Metetra
0 .417 .219 r
.37018 .51527 .3812 .53032 .40015 .51155 .38924 .49622 Metetra
0 .366 .274 r
.38924 .49622 .40015 .51155 .41905 .49375 .40824 .47817 Metetra
0 .319 .303 r
.40824 .47817 .41905 .49375 .43792 .47707 .42721 .46127 Metetra
0 .239 .277 r
.42721 .46127 .43792 .47707 .45677 .46165 .44615 .44564 Metetra
0 .169 .24 r
.44615 .44564 .45677 .46165 .47562 .44758 .46508 .43139 Metetra
0 .12 .209 r
.46508 .43139 .47562 .44758 .49449 .43497 .48403 .41861 Metetra
0 .087 .185 r
.48403 .41861 .49449 .43497 .51342 .42386 .50303 .40736 Metetra
0 .066 .168 r
.50303 .40736 .51342 .42386 .53242 .41433 .5221 .3977 Metetra
0 .055 .157 r
.5221 .3977 .53242 .41433 .55153 .4064 .54127 .38966 Metetra
0 .051 .154 r
.54127 .38966 .55153 .4064 .57077 .40009 .56057 .38327 Metetra
0 .055 .157 r
.56057 .38327 .57077 .40009 .59018 .39541 .58004 .37852 Metetra
0 .066 .168 r
.58004 .37852 .59018 .39541 .6098 .39236 .5997 .37542 Metetra
0 .087 .185 r
.5997 .37542 .6098 .39236 .62964 .39091 .6196 .37393 Metetra
0 .12 .209 r
.6196 .37393 .62964 .39091 .64975 .39103 .63975 .37403 Metetra
0 .169 .24 r
.63975 .37403 .64975 .39103 .67016 .39266 .6602 .37566 Metetra
0 .239 .277 r
.6602 .37566 .67016 .39266 .69088 .39572 .68098 .37875 Metetra
0 .319 .303 r
.68098 .37875 .69088 .39572 .71196 .40013 .70211 .38321 Metetra
0 .366 .274 r
.70211 .38321 .71196 .40013 .73342 .40576 .72361 .38891 Metetra
0 .417 .219 r
.72361 .38891 .73342 .40576 .75526 .41247 .74551 .39573 Metetra
0 .473 .135 r
.74551 .39573 .75526 .41247 .77752 .42008 .76782 .40347 Metetra
0 .53 .018 r
.76782 .40347 .77752 .42008 .80018 .42839 .79055 .41194 Metetra
.132 .59 0 r
.79055 .41194 .80018 .42839 .82326 .43715 .8137 .42089 Metetra
.315 .65 0 r
.8137 .42089 .82326 .43715 .84673 .44605 .83726 .43002 Metetra
.528 .71 0 r
.83726 .43002 .84673 .44605 .87057 .45477 .86121 .439 Metetra
.763 .768 0 r
.86121 .439 .87057 .45477 .89475 .4629 .88549 .44744 Metetra
.722 .758 0 r
.2428 .62593 .2548 .63796 .27407 .61795 .26222 .60556 Metetra
.488 .699 0 r
.26222 .60556 .27407 .61795 .29337 .59731 .28165 .5846 Metetra
.277 .639 0 r
.28165 .5846 .29337 .59731 .31264 .57642 .30106 .5634 Metetra
.098 .577 0 r
.30106 .5634 .31264 .57642 .33188 .5556 .32043 .5423 Metetra
0 .517 .048 r
.32043 .5423 .33188 .5556 .35106 .53513 .33973 .52157 Metetra
0 .458 .159 r
.33973 .52157 .35106 .53513 .37018 .51527 .35898 .50146 Metetra
0 .403 .237 r
.35898 .50146 .37018 .51527 .38924 .49622 .37815 .48219 Metetra
0 .35 .286 r
.37815 .48219 .38924 .49622 .40824 .47817 .39727 .46393 Metetra
0 .296 .303 r
.39727 .46393 .40824 .47817 .42721 .46127 .41634 .44684 Metetra
0 .206 .26 r
.41634 .44684 .42721 .46127 .44615 .44564 .43538 .43103 Metetra
0 .141 .223 r
.43538 .43103 .44615 .44564 .46508 .43139 .45441 .41663 Metetra
0 .096 .192 r
.45441 .41663 .46508 .43139 .48403 .41861 .47345 .40371 Metetra
0 .066 .168 r
.47345 .40371 .48403 .41861 .50303 .40736 .49252 .39233 Metetra
0 .048 .15 r
.49252 .39233 .50303 .40736 .5221 .3977 .51167 .38256 Metetra
0 .038 .139 r
.51167 .38256 .5221 .3977 .54127 .38966 .53091 .37442 Metetra
0 .035 .136 r
.53091 .37442 .54127 .38966 .56057 .38327 .55028 .36793 Metetra
0 .038 .139 r
.55028 .36793 .56057 .38327 .58004 .37852 .56981 .36311 Metetra
0 .048 .15 r
.56981 .36311 .58004 .37852 .5997 .37542 .58954 .35994 Metetra
0 .066 .168 r
.58954 .35994 .5997 .37542 .6196 .37393 .60949 .35841 Metetra
0 .096 .192 r
.60949 .35841 .6196 .37393 .63975 .37403 .62971 .35848 Metetra
0 .141 .223 r
.62971 .35848 .63975 .37403 .6602 .37566 .65021 .36009 Metetra
0 .206 .26 r
.65021 .36009 .6602 .37566 .68098 .37875 .67104 .36317 Metetra
0 .296 .303 r
.67104 .36317 .68098 .37875 .70211 .38321 .69222 .36764 Metetra
0 .35 .286 r
.69222 .36764 .70211 .38321 .72361 .38891 .71378 .37337 Metetra
0 .403 .237 r
.71378 .37337 .72361 .38891 .74551 .39573 .73574 .38023 Metetra
0 .458 .159 r
.73574 .38023 .74551 .39573 .76782 .40347 .75812 .38804 Metetra
0 .517 .048 r
.75812 .38804 .76782 .40347 .79055 .41194 .78092 .3966 Metetra
.098 .577 0 r
.78092 .3966 .79055 .41194 .8137 .42089 .80415 .40565 Metetra
.277 .639 0 r
.80415 .40565 .8137 .42089 .83726 .43002 .82779 .41492 Metetra
.488 .699 0 r
.82779 .41492 .83726 .43002 .86121 .439 .85183 .42406 Metetra
.722 .758 0 r
.85183 .42406 .86121 .439 .88549 .44744 .87622 .43269 Metetra
.698 .752 0 r
.23058 .61466 .2428 .62593 .26222 .60556 .25013 .59406 Metetra
.464 .693 0 r
.25013 .59406 .26222 .60556 .28165 .5846 .26971 .57287 Metetra
.255 .632 0 r
.26971 .57287 .28165 .5846 .30106 .5634 .28926 .55145 Metetra
.077 .57 0 r
.28926 .55145 .30106 .5634 .32043 .5423 .30876 .53014 Metetra
0 .509 .065 r
.30876 .53014 .32043 .5423 .33973 .52157 .3282 .50922 Metetra
0 .45 .173 r
.3282 .50922 .33973 .52157 .35898 .50146 .34757 .48893 Metetra
0 .393 .247 r
.34757 .48893 .35898 .50146 .37815 .48219 .36687 .46949 Metetra
0 .341 .292 r
.36687 .46949 .37815 .48219 .39727 .46393 .38611 .45107 Metetra
0 .274 .293 r
.38611 .45107 .39727 .46393 .41634 .44684 .40529 .43382 Metetra
0 .187 .25 r
.40529 .43382 .41634 .44684 .43538 .43103 .42444 .41788 Metetra
0 .125 .213 r
.42444 .41788 .43538 .43103 .45441 .41663 .44357 .40334 Metetra
0 .082 .182 r
.44357 .40334 .45441 .41663 .47345 .40371 .46271 .3903 Metetra
0 .055 .157 r
.46271 .3903 .47345 .40371 .49252 .39233 .48188 .37881 Metetra
0 .038 .139 r
.48188 .37881 .49252 .39233 .51167 .38256 .50112 .36893 Metetra
0 .029 .129 r
.50112 .36893 .51167 .38256 .53091 .37442 .52044 .3607 Metetra
0 .026 .125 r
.52044 .3607 .53091 .37442 .55028 .36793 .53989 .35412 Metetra
0 .029 .129 r
.53989 .35412 .55028 .36793 .56981 .36311 .5595 .34922 Metetra
0 .038 .139 r
.5595 .34922 .56981 .36311 .58954 .35994 .5793 .34599 Metetra
0 .055 .157 r
.5793 .34599 .58954 .35994 .60949 .35841 .59932 .34439 Metetra
0 .082 .182 r
.59932 .34439 .60949 .35841 .62971 .35848 .6196 .3444 Metetra
0 .125 .213 r
.6196 .3444 .62971 .35848 .65021 .36009 .64017 .34597 Metetra
0 .187 .25 r
.64017 .34597 .65021 .36009 .67104 .36317 .66106 .34902 Metetra
0 .274 .293 r
.66106 .34902 .67104 .36317 .69222 .36764 .68231 .35346 Metetra
0 .341 .292 r
.68231 .35346 .69222 .36764 .71378 .37337 .70393 .35918 Metetra
0 .393 .247 r
.70393 .35918 .71378 .37337 .73574 .38023 .72595 .36603 Metetra
0 .45 .173 r
.72595 .36603 .73574 .38023 .75812 .38804 .7484 .37385 Metetra
0 .509 .065 r
.7484 .37385 .75812 .38804 .78092 .3966 .77127 .38242 Metetra
.077 .57 0 r
.77127 .38242 .78092 .3966 .80415 .40565 .79457 .39151 Metetra
.255 .632 0 r
.79457 .39151 .80415 .40565 .82779 .41492 .8183 .40082 Metetra
.464 .693 0 r
.8183 .40082 .82779 .41492 .85183 .42406 .84243 .41001 Metetra
.698 .752 0 r
.84243 .41001 .85183 .42406 .87622 .43269 .86692 .4187 Metetra
.69 .751 0 r
.21812 .6042 .23058 .61466 .25013 .59406 .23781 .58347 Metetra
.456 .691 0 r
.23781 .58347 .25013 .59406 .26971 .57287 .25753 .56215 Metetra
.247 .629 0 r
.25753 .56215 .26971 .57287 .28926 .55145 .27722 .54061 Metetra
.071 .567 0 r
.27722 .54061 .28926 .55145 .30876 .53014 .29686 .51917 Metetra
0 .506 .071 r
.29686 .51917 .30876 .53014 .3282 .50922 .31644 .49812 Metetra
0 .447 .177 r
.31644 .49812 .3282 .50922 .34757 .48893 .33595 .47771 Metetra
0 .39 .25 r
.33595 .47771 .34757 .48893 .36687 .46949 .35538 .45815 Metetra
0 .338 .294 r
.35538 .45815 .36687 .46949 .38611 .45107 .37474 .43961 Metetra
0 .267 .29 r
.37474 .43961 .38611 .45107 .40529 .43382 .39405 .42225 Metetra
0 .181 .247 r
.39405 .42225 .40529 .43382 .42444 .41788 .41332 .4062 Metetra
0 .12 .209 r
.41332 .4062 .42444 .41788 .44357 .40334 .43256 .39156 Metetra
0 .078 .178 r
.43256 .39156 .44357 .40334 .46271 .3903 .45181 .37841 Metetra
0 .051 .154 r
.45181 .37841 .46271 .3903 .48188 .37881 .47108 .36683 Metetra
0 .035 .136 r
.47108 .36683 .48188 .37881 .50112 .36893 .49042 .35685 Metetra
0 .026 .125 r
.49042 .35685 .50112 .36893 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .026 .125 r
.52938 .34187 .53989 .35412 .5595 .34922 .54907 .33688 Metetra
0 .035 .136 r
.54907 .33688 .5595 .34922 .5793 .34599 .56895 .33357 Metetra
0 .051 .154 r
.56895 .33357 .5793 .34599 .59932 .34439 .58905 .3319 Metetra
0 .078 .178 r
.58905 .3319 .59932 .34439 .6196 .3444 .60941 .33184 Metetra
0 .12 .209 r
.60941 .33184 .6196 .3444 .64017 .34597 .63005 .33333 Metetra
0 .181 .247 r
.63005 .33333 .64017 .34597 .66106 .34902 .65102 .33632 Metetra
0 .267 .29 r
.65102 .33632 .66106 .34902 .68231 .35346 .67233 .3407 Metetra
0 .338 .294 r
.67233 .3407 .68231 .35346 .70393 .35918 .69403 .34635 Metetra
0 .39 .25 r
.69403 .34635 .70393 .35918 .72595 .36603 .71613 .35315 Metetra
0 .447 .177 r
.71613 .35315 .72595 .36603 .7484 .37385 .73865 .36091 Metetra
0 .506 .071 r
.73865 .36091 .7484 .37385 .77127 .38242 .7616 .36943 Metetra
.071 .567 0 r
.7616 .36943 .77127 .38242 .79457 .39151 .78498 .37847 Metetra
.247 .629 0 r
.78498 .37847 .79457 .39151 .8183 .40082 .80879 .38773 Metetra
.456 .691 0 r
.80879 .38773 .8183 .40082 .84243 .41001 .83301 .39687 Metetra
.69 .751 0 r
.83301 .39687 .84243 .41001 .86692 .4187 .8576 .4055 Metetra
.698 .752 0 r
.20541 .59453 .21812 .6042 .23781 .58347 .22524 .57379 Metetra
.464 .693 0 r
.22524 .57379 .23781 .58347 .25753 .56215 .24509 .55245 Metetra
.255 .632 0 r
.24509 .55245 .25753 .56215 .27722 .54061 .26492 .53087 Metetra
.077 .57 0 r
.26492 .53087 .27722 .54061 .29686 .51917 .28471 .50938 Metetra
0 .509 .065 r
.28471 .50938 .29686 .51917 .31644 .49812 .30443 .48828 Metetra
0 .45 .173 r
.30443 .48828 .31644 .49812 .33595 .47771 .32408 .46781 Metetra
0 .393 .247 r
.32408 .46781 .33595 .47771 .35538 .45815 .34365 .44817 Metetra
0 .341 .292 r
.34365 .44817 .35538 .45815 .37474 .43961 .36315 .42957 Metetra
0 .274 .293 r
.36315 .42957 .37474 .43961 .39405 .42225 .38259 .41213 Metetra
0 .187 .25 r
.38259 .41213 .39405 .42225 .41332 .4062 .40198 .396 Metetra
0 .125 .213 r
.40198 .396 .41332 .4062 .43256 .39156 .42135 .38128 Metetra
0 .082 .182 r
.42135 .38128 .43256 .39156 .45181 .37841 .44072 .36805 Metetra
0 .055 .157 r
.44072 .36805 .45181 .37841 .47108 .36683 .46011 .35639 Metetra
0 .038 .139 r
.46011 .35639 .47108 .36683 .49042 .35685 .47955 .34633 Metetra
0 .029 .129 r
.47955 .34633 .49042 .35685 .50984 .34853 .49908 .33792 Metetra
0 .026 .125 r
.49908 .33792 .50984 .34853 .52938 .34187 .51872 .33117 Metetra
0 .029 .129 r
.51872 .33117 .52938 .34187 .54907 .33688 .53851 .3261 Metetra
0 .038 .139 r
.53851 .3261 .54907 .33688 .56895 .33357 .55848 .3227 Metetra
0 .055 .157 r
.55848 .3227 .56895 .33357 .58905 .3319 .57867 .32094 Metetra
0 .082 .182 r
.57867 .32094 .58905 .3319 .60941 .33184 .59912 .32079 Metetra
0 .125 .213 r
.59912 .32079 .60941 .33184 .63005 .33333 .61985 .32219 Metetra
0 .187 .25 r
.61985 .32219 .63005 .33333 .65102 .33632 .6409 .32508 Metetra
0 .274 .293 r
.6409 .32508 .65102 .33632 .67233 .3407 .6623 .32936 Metetra
0 .341 .292 r
.6623 .32936 .67233 .3407 .69403 .34635 .68407 .33491 Metetra
0 .393 .247 r
.68407 .33491 .69403 .34635 .71613 .35315 .70625 .3416 Metetra
0 .45 .173 r
.70625 .3416 .71613 .35315 .73865 .36091 .72885 .34925 Metetra
0 .509 .065 r
.72885 .34925 .73865 .36091 .7616 .36943 .75188 .35765 Metetra
.077 .57 0 r
.75188 .35765 .7616 .36943 .78498 .37847 .77535 .36655 Metetra
.255 .632 0 r
.77535 .36655 .78498 .37847 .80879 .38773 .79925 .37566 Metetra
.464 .693 0 r
.79925 .37566 .80879 .38773 .83301 .39687 .82355 .38465 Metetra
.698 .752 0 r
.82355 .38465 .83301 .39687 .8576 .4055 .84823 .39311 Metetra
.722 .758 0 r
.19243 .58565 .20541 .59453 .22524 .57379 .21239 .56502 Metetra
.488 .699 0 r
.21239 .56502 .22524 .57379 .24509 .55245 .23238 .54376 Metetra
.277 .639 0 r
.23238 .54376 .24509 .55245 .26492 .53087 .25236 .52223 Metetra
.098 .577 0 r
.25236 .52223 .26492 .53087 .28471 .50938 .27229 .50078 Metetra
0 .517 .048 r
.27229 .50078 .28471 .50938 .30443 .48828 .29216 .47969 Metetra
0 .458 .159 r
.29216 .47969 .30443 .48828 .32408 .46781 .31195 .45922 Metetra
0 .403 .237 r
.31195 .45922 .32408 .46781 .34365 .44817 .33167 .43957 Metetra
0 .35 .286 r
.33167 .43957 .34365 .44817 .36315 .42957 .35131 .42093 Metetra
0 .296 .303 r
.35131 .42093 .36315 .42957 .38259 .41213 .37089 .40347 Metetra
0 .206 .26 r
.37089 .40347 .38259 .41213 .40198 .396 .39042 .38729 Metetra
0 .141 .223 r
.39042 .38729 .40198 .396 .42135 .38128 .40993 .37251 Metetra
0 .096 .192 r
.40993 .37251 .42135 .38128 .44072 .36805 .42942 .35922 Metetra
0 .066 .168 r
.42942 .35922 .44072 .36805 .46011 .35639 .44894 .34749 Metetra
0 .048 .15 r
.44894 .34749 .46011 .35639 .47955 .34633 .4685 .33736 Metetra
0 .038 .139 r
.4685 .33736 .47955 .34633 .49908 .33792 .48815 .32887 Metetra
0 .035 .136 r
.48815 .32887 .49908 .33792 .51872 .33117 .5079 .32204 Metetra
0 .038 .139 r
.5079 .32204 .51872 .33117 .53851 .3261 .5278 .31687 Metetra
0 .048 .15 r
.5278 .31687 .53851 .3261 .55848 .3227 .54788 .31337 Metetra
0 .066 .168 r
.54788 .31337 .55848 .3227 .57867 .32094 .56817 .31151 Metetra
0 .096 .192 r
.56817 .31151 .57867 .32094 .59912 .32079 .58871 .31125 Metetra
0 .141 .223 r
.58871 .31125 .59912 .32079 .61985 .32219 .60954 .31254 Metetra
0 .206 .26 r
.60954 .31254 .61985 .32219 .6409 .32508 .63068 .3153 Metetra
0 .296 .303 r
.63068 .3153 .6409 .32508 .6623 .32936 .65217 .31944 Metetra
0 .35 .286 r
.65217 .31944 .6623 .32936 .68407 .33491 .67404 .32485 Metetra
0 .403 .237 r
.67404 .32485 .68407 .33491 .70625 .3416 .69631 .33137 Metetra
0 .458 .159 r
.69631 .33137 .70625 .3416 .72885 .34925 .71899 .33884 Metetra
0 .517 .048 r
.71899 .33884 .72885 .34925 .75188 .35765 .74211 .34705 Metetra
.098 .577 0 r
.74211 .34705 .75188 .35765 .77535 .36655 .76567 .35574 Metetra
.277 .639 0 r
.76567 .35574 .77535 .36655 .79925 .37566 .78965 .36461 Metetra
.488 .699 0 r
.78965 .36461 .79925 .37566 .82355 .38465 .81405 .37333 Metetra
.722 .758 0 r
.81405 .37333 .82355 .38465 .84823 .39311 .83882 .3815 Metetra
.763 .768 0 r
.17918 .57752 .19243 .58565 .21239 .56502 .19927 .55712 Metetra
.528 .71 0 r
.19927 .55712 .21239 .56502 .23238 .54376 .21939 .53603 Metetra
.315 .65 0 r
.21939 .53603 .23238 .54376 .25236 .52223 .23951 .51466 Metetra
.132 .59 0 r
.23951 .51466 .25236 .52223 .27229 .50078 .25958 .49332 Metetra
0 .53 .018 r
.25958 .49332 .27229 .50078 .29216 .47969 .2796 .47232 Metetra
0 .473 .135 r
.2796 .47232 .29216 .47969 .31195 .45922 .29954 .45191 Metetra
0 .417 .219 r
.29954 .45191 .31195 .45922 .33167 .43957 .31941 .43231 Metetra
0 .366 .274 r
.31941 .43231 .33167 .43957 .35131 .42093 .33921 .41369 Metetra
0 .319 .303 r
.33921 .41369 .35131 .42093 .37089 .40347 .35893 .39622 Metetra
0 .239 .277 r
.35893 .39622 .37089 .40347 .39042 .38729 .37861 .38004 Metetra
0 .169 .24 r
.37861 .38004 .39042 .38729 .40993 .37251 .39826 .36523 Metetra
0 .12 .209 r
.39826 .36523 .40993 .37251 .42942 .35922 .41789 .3519 Metetra
0 .087 .185 r
.41789 .3519 .42942 .35922 .44894 .34749 .43755 .34012 Metetra
0 .066 .168 r
.43755 .34012 .44894 .34749 .4685 .33736 .45724 .32992 Metetra
0 .055 .157 r
.45724 .32992 .4685 .33736 .48815 .32887 .47702 .32136 Metetra
0 .051 .154 r
.47702 .32136 .48815 .32887 .5079 .32204 .4969 .31444 Metetra
0 .055 .157 r
.4969 .31444 .5079 .32204 .5278 .31687 .51692 .30918 Metetra
0 .066 .168 r
.51692 .30918 .5278 .31687 .54788 .31337 .53711 .30558 Metetra
0 .087 .185 r
.53711 .30558 .54788 .31337 .56817 .31151 .55752 .3036 Metetra
0 .12 .209 r
.55752 .3036 .56817 .31151 .58871 .31125 .57817 .30321 Metetra
0 .169 .24 r
.57817 .30321 .58871 .31125 .60954 .31254 .59911 .30435 Metetra
0 .239 .277 r
.59911 .30435 .60954 .31254 .63068 .3153 .62035 .30695 Metetra
0 .319 .303 r
.62035 .30695 .63068 .3153 .65217 .31944 .64195 .31092 Metetra
0 .366 .274 r
.64195 .31092 .65217 .31944 .67404 .32485 .66391 .31613 Metetra
0 .417 .219 r
.66391 .31613 .67404 .32485 .69631 .33137 .68628 .32244 Metetra
0 .473 .135 r
.68628 .32244 .69631 .33137 .71899 .33884 .70906 .32967 Metetra
0 .53 .018 r
.70906 .32967 .71899 .33884 .74211 .34705 .73227 .33761 Metetra
.132 .59 0 r
.73227 .33761 .74211 .34705 .76567 .35574 .75592 .34599 Metetra
.315 .65 0 r
.75592 .34599 .76567 .35574 .78965 .36461 .78 .35453 Metetra
.528 .71 0 r
.78 .35453 .78965 .36461 .81405 .37333 .80448 .36288 Metetra
.763 .768 0 r
.80448 .36288 .81405 .37333 .83882 .3815 .82934 .37062 Metetra
.781 .742 0 r
.16565 .57007 .17918 .57752 .19927 .55712 .18585 .55001 Metetra
.584 .725 0 r
.18585 .55001 .19927 .55712 .21939 .53603 .2061 .52923 Metetra
.369 .666 0 r
.2061 .52923 .21939 .53603 .23951 .51466 .22635 .5081 Metetra
.182 .607 0 r
.22635 .5081 .23951 .51466 .25958 .49332 .24657 .48697 Metetra
.025 .549 0 r
.24657 .48697 .25958 .49332 .2796 .47232 .26674 .46613 Metetra
0 .492 .099 r
.26674 .46613 .2796 .47232 .29954 .45191 .28684 .44585 Metetra
0 .438 .191 r
.28684 .44585 .29954 .45191 .31941 .43231 .30686 .42634 Metetra
0 .387 .254 r
.30686 .42634 .31941 .43231 .33921 .41369 .32681 .4078 Metetra
0 .341 .292 r
.32681 .4078 .33921 .41369 .35893 .39622 .3467 .39037 Metetra
0 .289 .299 r
.3467 .39037 .35893 .39622 .37861 .38004 .36653 .37421 Metetra
0 .213 .263 r
.36653 .37421 .37861 .38004 .39826 .36523 .38633 .3594 Metetra
0 .158 .233 r
.38633 .3594 .39826 .36523 .41789 .3519 .40612 .34606 Metetra
0 .12 .209 r
.40612 .34606 .41789 .3519 .43755 .34012 .42592 .33423 Metetra
0 .096 .192 r
.42592 .33423 .43755 .34012 .45724 .32992 .44576 .32399 Metetra
0 .082 .182 r
.44576 .32399 .45724 .32992 .47702 .32136 .46567 .31535 Metetra
0 .078 .178 r
.46567 .31535 .47702 .32136 .4969 .31444 .48568 .30835 Metetra
0 .082 .182 r
.48568 .30835 .4969 .31444 .51692 .30918 .50584 .303 Metetra
0 .096 .192 r
.50584 .303 .51692 .30918 .53711 .30558 .52616 .29927 Metetra
0 .12 .209 r
.52616 .29927 .53711 .30558 .55752 .3036 .5467 .29716 Metetra
0 .158 .233 r
.5467 .29716 .55752 .3036 .57817 .30321 .56747 .29662 Metetra
0 .213 .263 r
.56747 .29662 .57817 .30321 .59911 .30435 .58852 .29759 Metetra
0 .289 .299 r
.58852 .29759 .59911 .30435 .62035 .30695 .60989 .3 Metetra
0 .341 .292 r
.60989 .3 .62035 .30695 .64195 .31092 .63159 .30375 Metetra
0 .387 .254 r
.63159 .30375 .64195 .31092 .66391 .31613 .65367 .30872 Metetra
0 .438 .191 r
.65367 .30872 .66391 .31613 .68628 .32244 .67614 .31475 Metetra
0 .492 .099 r
.67614 .31475 .68628 .32244 .70906 .32967 .69903 .32168 Metetra
.025 .549 0 r
.69903 .32168 .70906 .32967 .73227 .33761 .72234 .32927 Metetra
.182 .607 0 r
.72234 .32927 .73227 .33761 .75592 .34599 .74609 .33726 Metetra
.369 .666 0 r
.74609 .33726 .75592 .34599 .78 .35453 .77026 .34537 Metetra
.584 .725 0 r
.77026 .34537 .78 .35453 .80448 .36288 .79484 .35322 Metetra
.781 .742 0 r
.79484 .35322 .80448 .36288 .82934 .37062 .81978 .36041 Metetra
.797 .702 0 r
.15182 .56321 .16565 .57007 .18585 .55001 .17212 .54363 Metetra
.657 .743 0 r
.17212 .54363 .18585 .55001 .2061 .52923 .19249 .52325 Metetra
.44 .686 0 r
.19249 .52325 .2061 .52923 .22635 .5081 .21288 .50247 Metetra
.247 .629 0 r
.21288 .50247 .22635 .5081 .24657 .48697 .23324 .48164 Metetra
.084 .572 0 r
.23324 .48164 .24657 .48697 .26674 .46613 .25356 .46105 Metetra
0 .517 .048 r
.25356 .46105 .26674 .46613 .28684 .44585 .27382 .44096 Metetra
0 .464 .15 r
.27382 .44096 .28684 .44585 .30686 .42634 .294 .42161 Metetra
0 .414 .223 r
.294 .42161 .30686 .42634 .32681 .4078 .31411 .40319 Metetra
0 .369 .271 r
.31411 .40319 .32681 .4078 .3467 .39037 .33416 .38586 Metetra
0 .328 .299 r
.33416 .38586 .3467 .39037 .36653 .37421 .35416 .36975 Metetra
0 .274 .293 r
.35416 .36975 .36653 .37421 .38633 .3594 .37412 .35497 Metetra
0 .213 .263 r
.37412 .35497 .38633 .3594 .40612 .34606 .39406 .34163 Metetra
0 .169 .24 r
.39406 .34163 .40612 .34606 .42592 .33423 .41402 .32979 Metetra
0 .141 .223 r
.41402 .32979 .42592 .33423 .44576 .32399 .43402 .3195 Metetra
0 .125 .213 r
.43402 .3195 .44576 .32399 .46567 .31535 .45408 .31081 Metetra
0 .12 .209 r
.45408 .31081 .46567 .31535 .48568 .30835 .47424 .30372 Metetra
0 .125 .213 r
.47424 .30372 .48568 .30835 .50584 .303 .49454 .29826 Metetra
0 .141 .223 r
.49454 .29826 .50584 .303 .52616 .29927 .51501 .29441 Metetra
0 .169 .24 r
.51501 .29441 .52616 .29927 .5467 .29716 .53568 .29215 Metetra
0 .213 .263 r
.53568 .29215 .5467 .29716 .56747 .29662 .55659 .29143 Metetra
0 .274 .293 r
.55659 .29143 .56747 .29662 .58852 .29759 .57777 .2922 Metetra
0 .328 .299 r
.57777 .2922 .58852 .29759 .60989 .3 .59926 .29438 Metetra
0 .369 .271 r
.59926 .29438 .60989 .3 .63159 .30375 .62109 .29787 Metetra
0 .414 .223 r
.62109 .29787 .63159 .30375 .65367 .30872 .64329 .30255 Metetra
0 .464 .15 r
.64329 .30255 .65367 .30872 .67614 .31475 .66588 .30825 Metetra
0 .517 .048 r
.66588 .30825 .67614 .31475 .69903 .32168 .68888 .31479 Metetra
.084 .572 0 r
.68888 .31479 .69903 .32168 .72234 .32927 .7123 .32195 Metetra
.247 .629 0 r
.7123 .32195 .72234 .32927 .74609 .33726 .73615 .32946 Metetra
.44 .686 0 r
.73615 .32946 .74609 .33726 .77026 .34537 .76042 .33702 Metetra
.657 .743 0 r
.76042 .33702 .77026 .34537 .79484 .35322 .78509 .34426 Metetra
.797 .702 0 r
.78509 .34426 .79484 .35322 .81978 .36041 .81012 .35076 Metetra
.815 .652 0 r
.13771 .55681 .15182 .56321 .17212 .54363 .1581 .53784 Metetra
.747 .764 0 r
.1581 .53784 .17212 .54363 .19249 .52325 .17857 .518 Metetra
.528 .71 0 r
.17857 .518 .19249 .52325 .21288 .50247 .19908 .49768 Metetra
.331 .655 0 r
.19908 .49768 .21288 .50247 .23324 .48164 .21959 .47724 Metetra
.16 .6 0 r
.21959 .47724 .23324 .48164 .25356 .46105 .24005 .45698 Metetra
.019 .546 0 r
.24005 .45698 .25356 .46105 .27382 .44096 .26047 .43717 Metetra
0 .495 .093 r
.26047 .43717 .27382 .44096 .294 .42161 .28081 .41804 Metetra
0 .447 .177 r
.28081 .41804 .294 .42161 .31411 .40319 .30109 .39979 Metetra
0 .403 .237 r
.30109 .39979 .31411 .40319 .33416 .38586 .32131 .38259 Metetra
0 .363 .276 r
.32131 .38259 .33416 .38586 .35416 .36975 .34147 .36658 Metetra
0 .328 .299 r
.34147 .36658 .35416 .36975 .37412 .35497 .3616 .35187 Metetra
0 .289 .299 r
.3616 .35187 .37412 .35497 .39406 .34163 .38172 .33856 Metetra
0 .239 .277 r
.38172 .33856 .39406 .34163 .41402 .32979 .40184 .32672 Metetra
0 .206 .26 r
.40184 .32672 .41402 .32979 .43402 .3195 .422 .3164 Metetra
0 .187 .25 r
.422 .3164 .43402 .3195 .45408 .31081 .44223 .30765 Metetra
0 .181 .247 r
.44223 .30765 .45408 .31081 .47424 .30372 .46255 .30048 Metetra
0 .187 .25 r
.46255 .30048 .47424 .30372 .49454 .29826 .48301 .29491 Metetra
0 .206 .26 r
.48301 .29491 .49454 .29826 .51501 .29441 .50363 .29092 Metetra
0 .239 .277 r
.50363 .29092 .51501 .29441 .53568 .29215 .52445 .28849 Metetra
0 .289 .299 r
.52445 .28849 .53568 .29215 .55659 .29143 .54551 .28757 Metetra
0 .328 .299 r
.54551 .28757 .55659 .29143 .57777 .2922 .56683 .28811 Metetra
0 .363 .276 r
.56683 .28811 .57777 .2922 .59926 .29438 .58846 .29003 Metetra
0 .403 .237 r
.58846 .29003 .59926 .29438 .62109 .29787 .61043 .29321 Metetra
0 .447 .177 r
.61043 .29321 .62109 .29787 .64329 .30255 .63276 .29753 Metetra
0 .495 .093 r
.63276 .29753 .64329 .30255 .66588 .30825 .65547 .30283 Metetra
.019 .546 0 r
.65547 .30283 .66588 .30825 .68888 .31479 .67859 .30891 Metetra
.16 .6 0 r
.67859 .30891 .68888 .31479 .7123 .32195 .70213 .31555 Metetra
.331 .655 0 r
.70213 .31555 .7123 .32195 .73615 .32946 .72609 .32248 Metetra
.528 .71 0 r
.72609 .32248 .73615 .32946 .76042 .33702 .75046 .32938 Metetra
.747 .764 0 r
.75046 .32938 .76042 .33702 .78509 .34426 .77522 .33588 Metetra
.815 .652 0 r
.77522 .33588 .78509 .34426 .81012 .35076 .80033 .34154 Metetra
.836 .593 0 r
.12331 .55072 .13771 .55681 .1581 .53784 .14377 .53251 Metetra
.788 .724 0 r
.14377 .53251 .1581 .53784 .17857 .518 .16434 .51333 Metetra
.633 .737 0 r
.16434 .51333 .17857 .518 .19908 .49768 .18496 .49359 Metetra
.432 .684 0 r
.18496 .49359 .19908 .49768 .21959 .47724 .2056 .47364 Metetra
.255 .632 0 r
.2056 .47364 .21959 .47724 .24005 .45698 .22621 .4538 Metetra
.105 .58 0 r
.22621 .4538 .24005 .45698 .26047 .43717 .24677 .43434 Metetra
0 .531 .018 r
.24677 .43434 .26047 .43717 .28081 .41804 .26728 .41551 Metetra
0 .484 .114 r
.26728 .41551 .28081 .41804 .30109 .39979 .28773 .3975 Metetra
0 .441 .186 r
.28773 .3975 .30109 .39979 .32131 .38259 .30812 .38049 Metetra
0 .403 .237 r
.30812 .38049 .32131 .38259 .34147 .36658 .32846 .36461 Metetra
0 .369 .271 r
.32846 .36461 .34147 .36658 .3616 .35187 .34877 .35 Metetra
0 .341 .292 r
.34877 .35 .3616 .35187 .38172 .33856 .36906 .33675 Metetra
0 .319 .303 r
.36906 .33675 .38172 .33856 .40184 .32672 .38936 .32492 Metetra
0 .296 .303 r
.38936 .32492 .40184 .32672 .422 .3164 .4097 .31459 Metetra
0 .274 .293 r
.4097 .31459 .422 .3164 .44223 .30765 .4301 .30579 Metetra
0 .267 .29 r
.4301 .30579 .44223 .30765 .46255 .30048 .45059 .29854 Metetra
0 .274 .293 r
.45059 .29854 .46255 .30048 .48301 .29491 .47122 .29285 Metetra
0 .296 .303 r
.47122 .29285 .48301 .29491 .50363 .29092 .492 .28871 Metetra
0 .319 .303 r
.492 .28871 .50363 .29092 .52445 .28849 .51298 .28609 Metetra
0 .341 .292 r
.51298 .28609 .52445 .28849 .54551 .28757 .5342 .28495 Metetra
0 .369 .271 r
.5342 .28495 .54551 .28757 .56683 .28811 .55568 .28522 Metetra
0 .403 .237 r
.55568 .28522 .56683 .28811 .58846 .29003 .57746 .28682 Metetra
0 .441 .186 r
.57746 .28682 .58846 .29003 .61043 .29321 .59957 .28964 Metetra
0 .484 .114 r
.59957 .28964 .61043 .29321 .63276 .29753 .62204 .29355 Metetra
0 .531 .018 r
.62204 .29355 .63276 .29753 .65547 .30283 .64489 .29837 Metetra
.105 .58 0 r
.64489 .29837 .65547 .30283 .67859 .30891 .66814 .30392 Metetra
.255 .632 0 r
.66814 .30392 .67859 .30891 .70213 .31555 .6918 .30995 Metetra
.432 .684 0 r
.6918 .30995 .70213 .31555 .72609 .32248 .71587 .31619 Metetra
.633 .737 0 r
.71587 .31619 .72609 .32248 .75046 .32938 .74035 .3223 Metetra
.788 .724 0 r
.74035 .3223 .75046 .32938 .77522 .33588 .7652 .32791 Metetra
.836 .593 0 r
.7652 .32791 .77522 .33588 .80033 .34154 .7904 .3326 Metetra
.859 .526 0 r
.10863 .54476 .12331 .55072 .14377 .53251 .12914 .52745 Metetra
.814 .657 0 r
.12914 .52745 .14377 .53251 .16434 .51333 .14978 .50908 Metetra
.755 .766 0 r
.14978 .50908 .16434 .51333 .18496 .49359 .17051 .49003 Metetra
.552 .716 0 r
.17051 .49003 .18496 .49359 .2056 .47364 .19126 .47069 Metetra
.369 .666 0 r
.19126 .47069 .2056 .47364 .22621 .4538 .21201 .45137 Metetra
.211 .617 0 r
.21201 .45137 .22621 .4538 .24677 .43434 .23273 .43235 Metetra
.077 .57 0 r
.23273 .43235 .24677 .43434 .26728 .41551 .2534 .41389 Metetra
0 .525 .03 r
.2534 .41389 .26728 .41551 .28773 .3975 .27402 .39618 Metetra
0 .484 .114 r
.27402 .39618 .28773 .3975 .30812 .38049 .29458 .37941 Metetra
0 .447 .177 r
.29458 .37941 .30812 .38049 .32846 .36461 .31511 .36372 Metetra
0 .414 .223 r
.31511 .36372 .32846 .36461 .34877 .35 .3356 .34924 Metetra
0 .387 .254 r
.3356 .34924 .34877 .35 .36906 .33675 .35607 .33607 Metetra
0 .366 .274 r
.35607 .33607 .36906 .33675 .38936 .32492 .37656 .32429 Metetra
0 .35 .286 r
.37656 .32429 .38936 .32492 .4097 .31459 .39708 .31396 Metetra
0 .341 .292 r
.39708 .31396 .4097 .31459 .4301 .30579 .41766 .30511 Metetra
0 .338 .294 r
.41766 .30511 .4301 .30579 .45059 .29854 .43834 .29778 Metetra
0 .341 .292 r
.43834 .29778 .45059 .29854 .47122 .29285 .45914 .29197 Metetra
0 .35 .286 r
.45914 .29197 .47122 .29285 .492 .28871 .4801 .28766 Metetra
0 .366 .274 r
.4801 .28766 .492 .28871 .51298 .28609 .50126 .28483 Metetra
0 .387 .254 r
.50126 .28483 .51298 .28609 .5342 .28495 .52264 .28343 Metetra
0 .414 .223 r
.52264 .28343 .5342 .28495 .55568 .28522 .54429 .2834 Metetra
0 .447 .177 r
.54429 .2834 .55568 .28522 .57746 .28682 .56623 .28464 Metetra
0 .484 .114 r
.56623 .28464 .57746 .28682 .59957 .28964 .5885 .28704 Metetra
0 .525 .03 r
.5885 .28704 .59957 .28964 .62204 .29355 .61112 .29047 Metetra
.077 .57 0 r
.61112 .29047 .62204 .29355 .64489 .29837 .63412 .29474 Metetra
.211 .617 0 r
.63412 .29474 .64489 .29837 .66814 .30392 .6575 .29966 Metetra
.369 .666 0 r
.6575 .29966 .66814 .30392 .6918 .30995 .6813 .30498 Metetra
.552 .716 0 r
.6813 .30498 .6918 .30995 .71587 .31619 .70549 .3104 Metetra
.755 .766 0 r
.70549 .3104 .71587 .31619 .74035 .3223 .73007 .3156 Metetra
.814 .657 0 r
.73007 .3156 .74035 .3223 .7652 .32791 .75502 .32019 Metetra
.859 .526 0 r
.75502 .32019 .7652 .32791 .7904 .3326 .78029 .32372 Metetra
.882 .452 0 r
.0937 .5387 .10863 .54476 .12914 .52745 .11423 .52246 Metetra
.841 .58 0 r
.11423 .52246 .12914 .52745 .14978 .50908 .13493 .50503 Metetra
.797 .702 0 r
.13493 .50503 .14978 .50908 .17051 .49003 .15574 .48682 Metetra
.69 .751 0 r
.15574 .48682 .17051 .49003 .19126 .47069 .1766 .4682 Metetra
.504 .704 0 r
.1766 .4682 .19126 .47069 .21201 .45137 .19747 .4495 Metetra
.338 .657 0 r
.19747 .4495 .21201 .45137 .23273 .43235 .21833 .43102 Metetra
.196 .612 0 r
.21833 .43102 .23273 .43235 .2534 .41389 .23916 .41301 Metetra
.077 .57 0 r
.23916 .41301 .2534 .41389 .27402 .39618 .25995 .39567 Metetra
0 .531 .018 r
.25995 .39567 .27402 .39618 .29458 .37941 .28069 .3792 Metetra
0 .495 .093 r
.28069 .3792 .29458 .37941 .31511 .36372 .30139 .36375 Metetra
0 .464 .15 r
.30139 .36375 .31511 .36372 .3356 .34924 .32207 .34945 Metetra
0 .438 .191 r
.32207 .34945 .3356 .34924 .35607 .33607 .34274 .3364 Metetra
0 .417 .219 r
.34274 .3364 .35607 .33607 .37656 .32429 .36342 .32469 Metetra
0 .403 .237 r
.36342 .32469 .37656 .32429 .39708 .31396 .38413 .31437 Metetra
0 .393 .247 r
.38413 .31437 .39708 .31396 .41766 .30511 .40491 .30549 Metetra
0 .39 .25 r
.40491 .30549 .41766 .30511 .43834 .29778 .42577 .29807 Metetra
0 .393 .247 r
.42577 .29807 .43834 .29778 .45914 .29197 .44677 .29212 Metetra
0 .403 .237 r
.44677 .29212 .45914 .29197 .4801 .28766 .46792 .28763 Metetra
0 .417 .219 r
.46792 .28763 .4801 .28766 .50126 .28483 .48926 .28456 Metetra
0 .438 .191 r
.48926 .28456 .50126 .28483 .52264 .28343 .51082 .28288 Metetra
0 .464 .15 r
.51082 .28288 .52264 .28343 .54429 .2834 .53265 .2825 Metetra
0 .495 .093 r
.53265 .2825 .54429 .2834 .56623 .28464 .55476 .28333 Metetra
0 .531 .018 r
.55476 .28333 .56623 .28464 .5885 .28704 .5772 .28525 Metetra
.077 .57 0 r
.5772 .28525 .5885 .28704 .61112 .29047 .59998 .28812 Metetra
.196 .612 0 r
.59998 .28812 .61112 .29047 .63412 .29474 .62313 .29176 Metetra
.338 .657 0 r
.62313 .29176 .63412 .29474 .6575 .29966 .64666 .29595 Metetra
.504 .704 0 r
.64666 .29595 .6575 .29966 .6813 .30498 .67059 .30043 Metetra
.69 .751 0 r
.67059 .30043 .6813 .30498 .70549 .3104 .6949 .30492 Metetra
.797 .702 0 r
.6949 .30492 .70549 .3104 .73007 .3156 .7196 .30906 Metetra
.841 .58 0 r
.7196 .30906 .73007 .3156 .75502 .32019 .74464 .31246 Metetra
.882 .452 0 r
.74464 .31246 .75502 .32019 .78029 .32372 .76999 .31467 Metetra
.904 .374 0 r
.07854 .53228 .0937 .5387 .11423 .52246 .09906 .51728 Metetra
.868 .495 0 r
.09906 .51728 .11423 .52246 .13493 .50503 .11978 .50095 Metetra
.828 .616 0 r
.11978 .50095 .13493 .50503 .15574 .48682 .14065 .48371 Metetra
.786 .729 0 r
.14065 .48371 .15574 .48682 .1766 .4682 .1616 .46595 Metetra
.657 .743 0 r
.1616 .46595 .1766 .4682 .19747 .4495 .18259 .44799 Metetra
.488 .699 0 r
.18259 .44799 .19747 .4495 .21833 .43102 .20358 .43014 Metetra
.338 .657 0 r
.20358 .43014 .21833 .43102 .23916 .41301 .22456 .41267 Metetra
.211 .617 0 r
.22456 .41267 .23916 .41301 .25995 .39567 .24551 .39578 Metetra
.104 .58 0 r
.24551 .39578 .25995 .39567 .28069 .3792 .26643 .37968 Metetra
.019 .546 0 r
.26643 .37968 .28069 .3792 .30139 .36375 .28732 .36452 Metetra
0 .517 .048 r
.28732 .36452 .30139 .36375 .32207 .34945 .30819 .35044 Metetra
0 .492 .099 r
.30819 .35044 .32207 .34945 .34274 .3364 .32905 .33755 Metetra
0 .473 .135 r
.32905 .33755 .34274 .3364 .36342 .32469 .34992 .32593 Metetra
0 .458 .159 r
.34992 .32593 .36342 .32469 .38413 .31437 .37084 .31564 Metetra
0 .45 .173 r
.37084 .31564 .38413 .31437 .40491 .30549 .39181 .30673 Metetra
0 .447 .177 r
.39181 .30673 .40491 .30549 .42577 .29807 .41288 .29923 Metetra
0 .45 .173 r
.41288 .29923 .42577 .29807 .44677 .29212 .43407 .29314 Metetra
0 .458 .159 r
.43407 .29314 .44677 .29212 .46792 .28763 .45542 .28844 Metetra
0 .473 .135 r
.45542 .28844 .46792 .28763 .48926 .28456 .47696 .28512 Metetra
0 .492 .099 r
.47696 .28512 .48926 .28456 .51082 .28288 .49872 .2831 Metetra
0 .517 .048 r
.49872 .2831 .51082 .28288 .53265 .2825 .52073 .28232 Metetra
.019 .546 0 r
.52073 .28232 .53265 .2825 .55476 .28333 .54303 .28268 Metetra
.104 .58 0 r
.54303 .28268 .55476 .28333 .5772 .28525 .56564 .28406 Metetra
.211 .617 0 r
.56564 .28406 .5772 .28525 .59998 .28812 .58859 .28629 Metetra
.338 .657 0 r
.58859 .28629 .59998 .28812 .62313 .29176 .6119 .2892 Metetra
.488 .699 0 r
.6119 .2892 .62313 .29176 .64666 .29595 .63559 .29255 Metetra
.657 .743 0 r
.63559 .29255 .64666 .29595 .67059 .30043 .65966 .29609 Metetra
.786 .729 0 r
.65966 .29609 .67059 .30043 .6949 .30492 .6841 .2995 Metetra
.828 .616 0 r
.6841 .2995 .6949 .30492 .7196 .30906 .7089 .30244 Metetra
.868 .495 0 r
.7089 .30244 .7196 .30906 .74464 .31246 .73404 .30448 Metetra
.904 .374 0 r
.73404 .30448 .74464 .31246 .76999 .31467 .75946 .30518 Metetra
.926 .296 0 r
.06319 .5252 .07854 .53228 .09906 .51728 .08366 .51162 Metetra
.895 .406 0 r
.08366 .51162 .09906 .51728 .11978 .50095 .10438 .49656 Metetra
.86 .522 0 r
.10438 .49656 .11978 .50095 .14065 .48371 .12528 .48044 Metetra
.822 .634 0 r
.12528 .48044 .14065 .48371 .1616 .46595 .1463 .46366 Metetra
.782 .738 0 r
.1463 .46366 .1616 .46595 .18259 .44799 .16738 .44657 Metetra
.657 .743 0 r
.16738 .44657 .18259 .44799 .20358 .43014 .18849 .42947 Metetra
.504 .704 0 r
.18849 .42947 .20358 .43014 .22456 .41267 .20961 .41263 Metetra
.369 .666 0 r
.20961 .41263 .22456 .41267 .24551 .39578 .23072 .39628 Metetra
.255 .632 0 r
.23072 .39628 .24551 .39578 .26643 .37968 .2518 .38062 Metetra
.16 .6 0 r
.2518 .38062 .26643 .37968 .28732 .36452 .27287 .36581 Metetra
.084 .572 0 r
.27287 .36581 .28732 .36452 .30819 .35044 .29393 .352 Metetra
.025 .549 0 r
.29393 .352 .30819 .35044 .32905 .33755 .31499 .3393 Metetra
0 .53 .018 r
.31499 .3393 .32905 .33755 .34992 .32593 .33607 .3278 Metetra
0 .517 .048 r
.33607 .3278 .34992 .32593 .37084 .31564 .35719 .31757 Metetra
0 .509 .065 r
.35719 .31757 .37084 .31564 .39181 .30673 .37837 .30864 Metetra
0 .506 .071 r
.37837 .30864 .39181 .30673 .41288 .29923 .39965 .30105 Metetra
0 .509 .065 r
.39965 .30105 .41288 .29923 .43407 .29314 .42105 .29481 Metetra
0 .517 .048 r
.42105 .29481 .43407 .29314 .45542 .28844 .4426 .28989 Metetra
0 .53 .018 r
.4426 .28989 .45542 .28844 .47696 .28512 .46435 .28627 Metetra
.025 .549 0 r
.46435 .28627 .47696 .28512 .49872 .2831 .48631 .28388 Metetra
.084 .572 0 r
.48631 .28388 .49872 .2831 .52073 .28232 .50852 .28266 Metetra
.16 .6 0 r
.50852 .28266 .52073 .28232 .54303 .28268 .53101 .28248 Metetra
.255 .632 0 r
.53101 .28248 .54303 .28268 .56564 .28406 .55381 .28323 Metetra
.369 .666 0 r
.55381 .28323 .56564 .28406 .58859 .28629 .57694 .28474 Metetra
.504 .704 0 r
.57694 .28474 .58859 .28629 .6119 .2892 .60042 .28681 Metetra
.657 .743 0 r
.60042 .28681 .6119 .2892 .63559 .29255 .62427 .28921 Metetra
.782 .738 0 r
.62427 .28921 .63559 .29255 .65966 .29609 .64848 .29166 Metetra
.822 .634 0 r
.64848 .29166 .65966 .29609 .6841 .2995 .67305 .29386 Metetra
.86 .522 0 r
.67305 .29386 .6841 .2995 .7089 .30244 .69797 .29542 Metetra
.895 .406 0 r
.69797 .29542 .7089 .30244 .73404 .30448 .72319 .29593 Metetra
.926 .296 0 r
.72319 .29593 .73404 .30448 .75946 .30518 .74867 .29491 Metetra
.946 .223 0 r
.0477 .51711 .06319 .5252 .08366 .51162 .06807 .50514 Metetra
.92 .318 0 r
.06807 .50514 .08366 .51162 .10438 .49656 .08875 .49152 Metetra
.89 .423 0 r
.08875 .49152 .10438 .49656 .12528 .48044 .10965 .47669 Metetra
.857 .531 0 r
.10965 .47669 .12528 .48044 .1463 .46366 .13071 .46105 Metetra
.822 .634 0 r
.13071 .46105 .1463 .46366 .16738 .44657 .15186 .44495 Metetra
.786 .729 0 r
.15186 .44495 .16738 .44657 .18849 .42947 .17307 .42871 Metetra
.69 .751 0 r
.17307 .42871 .18849 .42947 .20961 .41263 .19432 .41261 Metetra
.552 .716 0 r
.19432 .41261 .20961 .41263 .23072 .39628 .21557 .39689 Metetra
.432 .684 0 r
.21557 .39689 .23072 .39628 .2518 .38062 .23682 .38175 Metetra
.331 .655 0 r
.23682 .38175 .2518 .38062 .27287 .36581 .25807 .36736 Metetra
.247 .629 0 r
.25807 .36736 .27287 .36581 .29393 .352 .27931 .35388 Metetra
.182 .607 0 r
.27931 .35388 .29393 .352 .31499 .3393 .30057 .34142 Metetra
.132 .59 0 r
.30057 .34142 .31499 .3393 .33607 .3278 .32185 .33007 Metetra
.098 .577 0 r
.32185 .33007 .33607 .3278 .35719 .31757 .34318 .3199 Metetra
.077 .57 0 r
.34318 .3199 .35719 .31757 .37837 .30864 .36457 .31097 Metetra
.071 .567 0 r
.36457 .31097 .37837 .30864 .39965 .30105 .38607 .30329 Metetra
.077 .57 0 r
.38607 .30329 .39965 .30105 .42105 .29481 .40768 .29688 Metetra
.098 .577 0 r
.40768 .29688 .42105 .29481 .4426 .28989 .42945 .29172 Metetra
.132 .59 0 r
.42945 .29172 .4426 .28989 .46435 .28627 .45141 .28777 Metetra
.182 .607 0 r
.45141 .28777 .46435 .28627 .48631 .28388 .47358 .28497 Metetra
.247 .629 0 r
.47358 .28497 .48631 .28388 .50852 .28266 .496 .28323 Metetra
.331 .655 0 r
.496 .28323 .50852 .28266 .53101 .28248 .51869 .28245 Metetra
.432 .684 0 r
.51869 .28245 .53101 .28248 .55381 .28323 .54168 .28249 Metetra
.552 .716 0 r
.54168 .28249 .55381 .28323 .57694 .28474 .565 .28317 Metetra
.69 .751 0 r
.565 .28317 .57694 .28474 .60042 .28681 .58866 .28429 Metetra
.786 .729 0 r
.58866 .28429 .60042 .28681 .62427 .28921 .61267 .28561 Metetra
.822 .634 0 r
.61267 .28561 .62427 .28921 .64848 .29166 .63703 .28684 Metetra
.857 .531 0 r
.63703 .28684 .64848 .29166 .67305 .29386 .66174 .28765 Metetra
.89 .423 0 r
.66174 .28765 .67305 .29386 .69797 .29542 .68677 .28766 Metetra
.92 .318 0 r
.68677 .28766 .69797 .29542 .72319 .29593 .71208 .28644 Metetra
.946 .223 0 r
.71208 .28644 .72319 .29593 .74867 .29491 .73762 .28351 Metetra
.961 .161 0 r
.03213 .50762 .0477 .51711 .06807 .50514 .05236 .49745 Metetra
.942 .235 0 r
.05236 .49745 .06807 .50514 .08875 .49152 .07295 .48546 Metetra
.918 .325 0 r
.07295 .48546 .08875 .49152 .10965 .47669 .09381 .47208 Metetra
.89 .423 0 r
.09381 .47208 .10965 .47669 .13071 .46105 .11487 .45773 Metetra
.86 .522 0 r
.11487 .45773 .13071 .46105 .15186 .44495 .13607 .44277 Metetra
.828 .616 0 r
.13607 .44277 .15186 .44495 .17307 .42871 .15736 .42753 Metetra
.797 .702 0 r
.15736 .42753 .17307 .42871 .19432 .41261 .17871 .41228 Metetra
.755 .766 0 r
.17871 .41228 .19432 .41261 .21557 .39689 .20009 .39729 Metetra
.633 .737 0 r
.20009 .39729 .21557 .39689 .23682 .38175 .22149 .38275 Metetra
.528 .71 0 r
.22149 .38275 .23682 .38175 .25807 .36736 .2429 .36886 Metetra
.44 .686 0 r
.2429 .36886 .25807 .36736 .27931 .35388 .26433 .35576 Metetra
.369 .666 0 r
.26433 .35576 .27931 .35388 .30057 .34142 .28578 .34358 Metetra
.315 .65 0 r
.28578 .34358 .30057 .34142 .32185 .33007 .30727 .33242 Metetra
.277 .639 0 r
.30727 .33242 .32185 .33007 .34318 .3199 .32881 .32235 Metetra
.255 .632 0 r
.32881 .32235 .34318 .3199 .36457 .31097 .35042 .31342 Metetra
.247 .629 0 r
.35042 .31342 .36457 .31097 .38607 .30329 .37213 .30565 Metetra
.255 .632 0 r
.37213 .30565 .38607 .30329 .40768 .29688 .39397 .29906 Metetra
.277 .639 0 r
.39397 .29906 .40768 .29688 .42945 .29172 .41596 .29363 Metetra
.315 .65 0 r
.41596 .29363 .42945 .29172 .45141 .28777 .43814 .28931 Metetra
.369 .666 0 r
.43814 .28931 .45141 .28777 .47358 .28497 .46053 .28604 Metetra
.44 .686 0 r
.46053 .28604 .47358 .28497 .496 .28323 .48316 .28373 Metetra
.528 .71 0 r
.48316 .28373 .496 .28323 .51869 .28245 .50606 .28226 Metetra
.633 .737 0 r
.50606 .28226 .51869 .28245 .54168 .28249 .52926 .28149 Metetra
.755 .766 0 r
.52926 .28149 .54168 .28249 .565 .28317 .55277 .28124 Metetra
.797 .702 0 r
.55277 .28124 .565 .28317 .58866 .28429 .57661 .28129 Metetra
.828 .616 0 r
.57661 .28129 .58866 .28429 .61267 .28561 .60079 .28138 Metetra
.86 .522 0 r
.60079 .28138 .61267 .28561 .63703 .28684 .62531 .28123 Metetra
.89 .423 0 r
.62531 .28123 .63703 .28684 .66174 .28765 .65014 .28049 Metetra
.918 .325 0 r
.65014 .28049 .66174 .28765 .68677 .28766 .67528 .27876 Metetra
.942 .235 0 r
.67528 .27876 .68677 .28766 .71208 .28644 .70067 .27561 Metetra
.961 .161 0 r
.70067 .27561 .71208 .28644 .73762 .28351 .72626 .27056 Metetra
.972 .117 0 r
.01657 .4963 .03213 .50762 .05236 .49745 .0366 .48813 Metetra
.96 .165 0 r
.0366 .48813 .05236 .49745 .07295 .48546 .05705 .47795 Metetra
.942 .235 0 r
.05705 .47795 .07295 .48546 .09381 .47208 .07782 .46621 Metetra
.92 .318 0 r
.07782 .46621 .09381 .47208 .11487 .45773 .09884 .45332 Metetra
.895 .406 0 r
.09884 .45332 .11487 .45773 .13607 .44277 .12005 .43964 Metetra
.868 .495 0 r
.12005 .43964 .13607 .44277 .15736 .42753 .14139 .42553 Metetra
.841 .58 0 r
.14139 .42553 .15736 .42753 .17871 .41228 .16282 .41126 Metetra
.814 .657 0 r
.16282 .41126 .17871 .41228 .20009 .39729 .18431 .3971 Metetra
.788 .724 0 r
.18431 .3971 .20009 .39729 .22149 .38275 .20584 .38326 Metetra
.746 .764 0 r
.20584 .38326 .22149 .38275 .2429 .36886 .22741 .36994 Metetra
.657 .743 0 r
.22741 .36994 .2429 .36886 .26433 .35576 .24901 .35729 Metetra
.584 .725 0 r
.24901 .35729 .26433 .35576 .28578 .34358 .27065 .34545 Metetra
.528 .71 0 r
.27065 .34545 .28578 .34358 .30727 .33242 .29234 .33451 Metetra
.488 .699 0 r
.29234 .33451 .30727 .33242 .32881 .32235 .31409 .32456 Metetra
.464 .693 0 r
.31409 .32456 .32881 .32235 .35042 .31342 .33591 .31564 Metetra
.456 .691 0 r
.33591 .31564 .35042 .31342 .37213 .30565 .35785 .30778 Metetra
.464 .693 0 r
.35785 .30778 .37213 .30565 .39397 .29906 .37991 .301 Metetra
.488 .699 0 r
.37991 .301 .39397 .29906 .41596 .29363 .40213 .29526 Metetra
.528 .71 0 r
.40213 .29526 .41596 .29363 .43814 .28931 .42453 .29053 Metetra
.584 .725 0 r
.42453 .29053 .43814 .28931 .46053 .28604 .44715 .28673 Metetra
.657 .743 0 r
.44715 .28673 .46053 .28604 .48316 .28373 .47 .28377 Metetra
.746 .764 0 r
.47 .28377 .48316 .28373 .50606 .28226 .49312 .28154 Metetra
.788 .724 0 r
.49312 .28154 .50606 .28226 .52926 .28149 .51653 .27986 Metetra
.814 .657 0 r
.51653 .27986 .52926 .28149 .55277 .28124 .54024 .27856 Metetra
.841 .58 0 r
.54024 .27856 .55277 .28124 .57661 .28129 .56426 .2774 Metetra
.868 .495 0 r
.56426 .2774 .57661 .28129 .60079 .28138 .58861 .27612 Metetra
.895 .406 0 r
.58861 .27612 .60079 .28138 .62531 .28123 .61328 .27442 Metetra
.92 .318 0 r
.61328 .27442 .62531 .28123 .65014 .28049 .63825 .27194 Metetra
.942 .235 0 r
.63825 .27194 .65014 .28049 .67528 .27876 .66349 .26828 Metetra
.96 .165 0 r
.66349 .26828 .67528 .27876 .70067 .27561 .68895 .26299 Metetra
.972 .117 0 r
.68895 .26299 .70067 .27561 .72626 .27056 .71457 .25558 Metetra
.976 .099 0 r
.00111 .48265 .01657 .4963 .0366 .48813 .02087 .47669 Metetra
.972 .117 0 r
.02087 .47669 .0366 .48813 .05705 .47795 .04112 .46852 Metetra
.961 .161 0 r
.04112 .46852 .05705 .47795 .07782 .46621 .06175 .4586 Metetra
.946 .223 0 r
.06175 .4586 .07782 .46621 .09884 .45332 .08269 .44733 Metetra
.926 .296 0 r
.08269 .44733 .09884 .45332 .12005 .43964 .10387 .43511 Metetra
.904 .374 0 r
.10387 .43511 .12005 .43964 .14139 .42553 .12521 .42226 Metetra
.882 .452 0 r
.12521 .42226 .14139 .42553 .16282 .41126 .14669 .4091 Metetra
.859 .526 0 r
.14669 .4091 .16282 .41126 .18431 .3971 .16827 .39589 Metetra
.836 .593 0 r
.16827 .39589 .18431 .3971 .20584 .38326 .18992 .38285 Metetra
.815 .652 0 r
.18992 .38285 .20584 .38326 .22741 .36994 .21162 .37018 Metetra
.797 .702 0 r
.21162 .37018 .22741 .36994 .24901 .35729 .23339 .35806 Metetra
.781 .742 0 r
.23339 .35806 .24901 .35729 .27065 .34545 .2552 .34661 Metetra
.763 .768 0 r
.2552 .34661 .27065 .34545 .29234 .33451 .27708 .33594 Metetra
.722 .758 0 r
.27708 .33594 .29234 .33451 .31409 .32456 .29903 .32613 Metetra
.698 .752 0 r
.29903 .32613 .31409 .32456 .33591 .31564 .32107 .31723 Metetra
.69 .75 0 r
.32107 .31723 .33591 .31564 .35785 .30778 .34323 .30928 Metetra
.698 .752 0 r
.34323 .30928 .35785 .30778 .37991 .301 .36552 .30228 Metetra
.722 .758 0 r
.36552 .30228 .37991 .301 .40213 .29526 .38797 .29621 Metetra
.763 .768 0 r
.38797 .29621 .40213 .29526 .42453 .29053 .4106 .29101 Metetra
.781 .742 0 r
.4106 .29101 .42453 .29053 .44715 .28673 .43344 .28663 Metetra
.797 .702 0 r
.43344 .28663 .44715 .28673 .47 .28377 .45652 .28295 Metetra
.815 .652 0 r
.45652 .28295 .47 .28377 .49312 .28154 .47986 .27984 Metetra
.836 .593 0 r
.47986 .27984 .49312 .28154 .51653 .27986 .50348 .27715 Metetra
.859 .526 0 r
.50348 .27715 .51653 .27986 .54024 .27856 .52739 .27466 Metetra
.882 .452 0 r
.52739 .27466 .54024 .27856 .56426 .2774 .55161 .27216 Metetra
.904 .374 0 r
.55161 .27216 .56426 .2774 .58861 .27612 .57613 .26935 Metetra
.926 .296 0 r
.57613 .26935 .58861 .27612 .61328 .27442 .60095 .26592 Metetra
.946 .223 0 r
.60095 .26592 .61328 .27442 .63825 .27194 .62604 .26151 Metetra
.961 .161 0 r
.62604 .26151 .63825 .27194 .66349 .26828 .65138 .25571 Metetra
.972 .117 0 r
.65138 .25571 .66349 .26828 .68895 .26299 .67691 .24806 Metetra
.976 .099 0 r
.67691 .24806 .68895 .26299 .71457 .25558 .70256 .23806 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00Z?ooool3o`0000Cooooo0_l0001_ooooo`00ZOooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0006kooooo002Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000K_ooool00:Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Doooo
o`;o0000F?ooool00:Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Aoooo
o`?o000000?oooooo`000?ooool0Eoooool00:Sooooo0_l00004ooooo`04o`000?ooooooooooo`00
00oooooo0_l00004ooooo`;o0000Eoooool00:Wooooo00?o0000ooooooooool00oooool2o`0000go
oooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`00001Fooooo`00_?ooool2o`00
00Wooooo00Co0000ooooool0003o0000EOooool00;Wooooo0ol0000;ooooo`04o`000?oooooooooo
o`0005Gooooo002fooooo`?o00003_ooool01Ol0003ooooooooooooooooo000005Cooooo002doooo
o`;o00004Oooool01Ol0003ooooooooooooooooo000005Cooooo002aooooo`?o00004oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo057ooooo002_ooooo`;o00000oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool3o`0000Co
oooo0_l0000looooo`00[?ooool3o`0001Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool00:[ooooo
0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool5o`0000?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000kooooo`00Yoooool3o`0001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000>oooool00:Gooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003_o
oooo002Rooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`;o00002Oooool2o`0000Cooooo
00Co0000oooooooooooo0000>oooool00:3ooooo0_l0000Vooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooool000002_ooool00ol0003oooooooooo`03ooooo`;o0000??ooool009gooooo0ol0
000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0C?ooool009[ooooo0ol0000[
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Boooool009Sooooo0_l0000^oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B_ooool009Gooooo0ol0000`ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0B_ooool009?ooooo0_l000000ooooooo0000
ooooo`0`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0BOooool0093ooooo0ol0
000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0BOooool008kooooo0_l0000h
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B?ooool008_ooooo0ol0000joooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Aoooool008Wooooo0_l0000mooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Aoooool006Gooooo0_l0000Oooooo`?o0000
@?ooool00ol0003oooooooooo`0;ooooo`;o0000Aoooool006Cooooo00Co0000oooooooooooo0000
7?ooool2o`0000;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04Gooooo001Tooooo`04o`000?ooooooooooo`0001Wooooo0ol00015ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0AOooool006Cooooo00Co0000oooooooooooo0000
5_ooool3o`0004Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`14ooooo`00I?oo
ool01?l0003oooooooooool0000Dooooo`;o0000Boooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04?ooooo001Tooooo`04o`000?ooooooooooo`00017ooooo0ol0001=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0@oooool006Gooooo0_l0000@ooooo`;o000000?o
ooooo`000?ooool0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo001d
ooooo`?o0000D_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo047ooooo001boooo
o`;o0000EOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo047ooooo001_ooooo`?o
0000Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo043ooooo001]ooooo`;o0000
F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo001Zooooo`?o0000G?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo001Xooooo`;o00000_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?_ooool0
06Gooooo0ol0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?Oooool006?o
oooo0_l0001Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?Oooool0063ooooo
0ol0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0??ooool005gooooo0ol0
001Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>oooool005_ooooo0_l00000
0ooooooo0000ooooo`1Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>oooool0
05Sooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>_ooool005Ko
oooo0_l0001booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>Oooool005?ooooo
0ol0001dooooo`03o`000?oooooooooo01Oooooo0_l0000jooooo`00D?ooool3o`0007Oooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0hooooo`00C_ooool4o`0007Sooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0gooooo`00C?ooool2o`0007cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0gooooo`00BOooool3o`0007kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0fooooo`00Aoooool2o`00087ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0eooooo`007Oooool3o`0000Cooooo0_l0000Mooooo`Co0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Gooooo000Nooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00006_ooool4o`0008Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0dooooo`005_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Hooooo`;o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03?ooooo000Nooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005Ooo
ool3o`0008_ooooo00?o0000ooooooooool07Oooool2o`0003Cooooo000Nooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00004oooool2o`0008kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0booooo`007Oooool2o`0000Cooooo00Co0000oooooooooooo00004?oo
ool3o`00093ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0aooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o00003oooool3o`0009;ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0aooooo`00<_ooool3o`0009Kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`06ooooo`;o0000:?ooool0033ooooo0_l0002Iooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Wooooo`00;Oooool3o`0009_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
02Oooooo000Zooooo`?o0000W_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00009oooool002Sooooo0ol0002Pooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Wooooo`009Oooool3o`0000?o
oooo00?o0000ooooooooool0W?ooool2o`0002Cooooo0_l00003ooooo`04o`000?ooooooooooo`00
02Oooooo000Sooooo`;o0000X_ooool3o`000003ooTI0?l0003ooooo02;ooooo00?o0000ooooool0
00001?ooool2o`0002Sooooo000Pooooo`?o0000X_ooool2o`0000?onAT00ol0000Tooooo`03o`00
0?oooooooooo02cooooo000Nooooo`;o0000Xoooool2o`0000;onAT00ol000001?oi6@3o0000ooTI
0?l0000Tooooo`03o`000?oooooooooo02_ooooo000Kooooo`?o000000?oooooo`000?ooool0Wooo
ool3o`000004ooPM0?l0003o0000o`0000GonAT00_l0000Uooooo`03o`000?oooooooooo02[ooooo
000Jooooo`;o0000X?ooool4o`000004ooPM0?l0003o0000o`0000;on1d000?o0000ooTI0?oi6@00
1?oi6@02o`0002Cooooo00?o0000ooooooooool0:_ooool001Wooooo1?l0002Looooo`?o00000_of
:@03o`0000Kon1d000?o0000ooTI0?oi6@000ol000000ooh7@3o0000ooooo`0Tooooo`03o`000?oo
oooooooo02Wooooo000Booooo`;o00001_ooool01?l0003oooooooooool0002Fooooo`Go00000_of
:@03o`0000;omRT000?o0000ooPM0?oh7@000_oh7@05o`0000Con1d00_l0000Uooooo`03o`000?oo
oooooooo02Sooooo000Aooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooooooooooooooo
o`00002>ooooo`Oo00001?ob>@03o`0000?omRT01ol00004ooDZ0003o`000?oh7@3on1d000?on1d0
0_l0000Tooooo`03o`000?oooooooooo02Sooooo000Aooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1nooooo`go00001Oo]B`000ol0003olST0
oo8i0009o`0000ColC`000?o0000ooDZ0?oe:P001Ooe:P001?l0003on1d0ooPM0?oh7@05o`0002?o
oooo0_l0000Xooooo`004Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0M_ooool7o`0000GohG<000?o0000onMO0?oWG`000_oWG`0=o`0000Co
je4000?o0000oo4l0?oa?0001Ooa?0000ol0003omBX0ooDZ0002ooDZ00Ko00000oof:@000ol0003o
mRT0o`00000Sooooo`03o`000?oooooooooo02Kooooo000Aooooo`04o`000?ooooooooooo`0000Co
oooo0_l00006ooooo`03o`000?oooooooooo06Wooooo7Ol00005omin00Co00000_oUI`02o`0000Go
je4000?o0000oo4l0?oa?0000_oa?007o`0000ColC`000?o0000ooHY0?of:@000_of:@001?l0003o
mRT0ooHY0?l0000Rooooo`03o`000?oooooooooo02Kooooo000Aooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Roooooc[o00001?o[D`000ol0
003olC`0oo4l0005oo4l0003o`000?of:@3omRT000;omRT01?l0000Rooooo`03o`000?oooooooooo
02Gooooo000Booooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[o
oooo?_l000000ooSK03o0000on]C0005on]C0003o`000?oa?03olC`000;olC`01ol000001?ob>@3o
0000oo8i0?l0000Sooooo`03o`000?oooooooooo02Cooooo000Iooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0EOooool@o`000003o`1W??l0003o0000013o00001?l0BD`00ol0003o
05=<o`00000Eo`000003om:R0?l0003ofhL000go00001?o[D@001Ol0003olST0oo8i0?ob>@3o0000
00;olST000?o0000ooooooooool08?ooool00ol0003oooooooooo`0Tooooo`006?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo057ooooo0ol000000oo3a03o0000o`00000Eo`0000?o
03A2<Ol000000ooSK03o0000on]A0005on]A0004o`000?ob>@3olST0oo8i00Co00008_ooool00ol0
003oooooooooo`0Sooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04_o
oooo2ol000000ol0PQ3o0000o`000009o`0000;o04I;0ol00003o`0_?`Co00001?l093T01?l0003o
02/mo`0[?Ol0:cdCo`0000;o05i54?l000001?oBXP3o0000omb50?oLQ@0<o`000005one;0?l0003o
kD/0one;0?l000008_ooool00ol0003oooooooooo`0Rooooo`006?ooool2o`0000gooooo00?o0000
ooooooooool0A_ooool@o`000003o`1S?ol0003o000000Co00000ol0A4X4o`0000;o02lo0ol00003
o`0O=P04o`000?l093Wo02@io`0T>@Oo00000_l07SD00ol0003o02Pko`0X>`03o`0X>`03o`000?l0
=T?o03I300?o03I300?o0000o`19C?l000001?l000000ol0GTGo0000o`1Y>@0Io`000005onEW0?l0
003okD/0one;0?l000000_o]B`000ol0003oooooooooo`0Oooooo`;o00008oooool001Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`12ooooo`?o000000?o//00o`000?l000001_l0
00000ol0PA;o0000o`000009o`0000;o04A:0ol00003o`0^?`Co00000ol07cH6o`0000;o01Pa6Ol0
00000ol0Ed[o0000o`000004o`000003o`1Y>Ol0003o000000oo000000Codid0o`000?oNOP3ogWh0
2Ol0000Pooooo`;o00008oooool001Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0nooooo`So000000?o?j40o`000?l000001_l000001?l0I3oo0000o`000?l0EdX2o`0000Co04I;
1?l000001?l0;Soo0000o`000?l00003o`0N=@Co00001Ol052h4o`0000Co010[00?o0000o`0F;ol0
5Rl00_l05Rl00ol0003o01heo`0N=@03o`0N=@03o`000?l0:cgo02/m00;o02/m00?o0000o`0mA_l0
?DH01Ol000000ol0Ed[o0000o`1S@@0@o`0000;oc;<01_l000001?oNOP3o0000onMO0?l00003onMO
0003o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool001Sooooo00?o0000oooooooo
ool03oooool2o`0003_ooooo0ol000000on`_`3o0000o`00000<o`0000;o06@o00Co0000o`1GB_l0
Ed[o00000ol0AT/3o`0000?o02lo1?l000001?l07SGo0000o`000?l00003o`0C;@03o`000?l052ko
01@^00?o00000ol03RP01?l0003o010[o`0@:ol042/Fo`000003o`0mA_l0003o055=00Ko000000?o
06=1o`000?l000003ol000000oo</`3o0000omND0007o`000003onMO0?l0003ooooo01oooooo00?o
0000ooooooooool08?ooool001Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0e
ooooo`So000000?o@J40o`000?l000005?l00002o`0_?`?o00000ol07cH4o`0000?o01<]1?l00006
o`0>:0Co00000ol032H00ol0003o010[o`0@:`03o`0@:`03o`000?l0637o01Pa00?o01Pa00Go0000
o`0T>Ol093Wo02@io`000002o`0d@PKo000000?o055=o`000?l0GDH06?l000001?oGU03o0000o`00
0?oQL`04o`0001oooooo00?o0000ooooooooool07oooool001Oooooo0_l0000Dooooo`03o`000?oo
oooooooo03;ooooo0_l000000onb`03o0000o`000007o`0000;o08@<1Ol000000ol0Icco0000o`00
0004o`000003o`1;COl0003o000000Co03A21?l000001?l07cKo0000o`000?l00003o`0D;PGo0000
0ol03BL00ol0003o00hXo`0>:003o`000003o`098ol0003o00`V00Go00`V00Co0000o`0@:ol042_o
010[3Ol00005o`0d@P03o`000?l0Bdgo000000Go000000?o05e6o`000?l000001Ol000000olETP3o
0000o`000004o`000004oj:l0?l0003o0000o`0000;od:P01ol000000ooQL`3o0000ooooo`0Noooo
o`03o`000?oooooooooo01kooooo000Gooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0<?ooool;o`0000;o08@<3Ol000000ol0Bdgo0000o`0d@P03o`0d@P;o00000ol093T3o`0000?o
01@^1Ol00005o`0=9`?o00001Ol02B<01?l0003o00`Vo`0<9_l032H6o`0000?o00hX00?o0000o`0D
;_l052h00_l052h01?l0003o01lfo`0O=_l07cH9o`000003o`1;COl0003o05U900;o05U92ol00000
0olETP3o0000o`000004o`000003oj:l0?l0003o000000Go00000_oKQP04o`0001gooooo00?o0000
ooooooooool07_ooool001Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]oooo
o`Oo000000?oAZ<0o`000?l000001ol000000ol0JSSo0000o`000003o`1MAP04o`000?l0DDgo055=
o`1AC@Co000000?o03A2o`000?l000000ol093T2o`0000?o01Pa1?l00004o`0>:003o`000?l03BOo
000000;o00000ol022801?l0003o00TSo`098ol02B<5o`0000Co00TS00?o0000o`0>:?l03RP00ol0
3RP00ol0003o01@^o`0D;P02o`0D;P03o`000?l07cKo01lf00;o01lf00?o0000o`0_?ol0;cl00_l0
;cl00ol0003o04I;o`000002o`0000Co05U900?o0000o`1W??l0Ic`02Ol000000oloX@3o0000o`00
0005o`0000;obKT01ol000000ooKQP3o0000ooooo`0Looooo`03o`000?oooooooooo01gooooo000G
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool<o`0000;o08L40_l00000
1Ol0NB;o0000o`000?l0JSSo000000?o05e60_l00002o`1AC@;o00000ol0?DH4o`000003o`0T>Ol0
003o000000?o01Pa1Ol00005o`0>:0?o00001Ol02284o`0000?o00LQ00?o0000o`098ol02B<01?l0
2B<01?l0003o00hXo`0>:?l03RP;o`000003o`0O=_l0003o02lo00?o02lo00Co0000o`16Bol0AT_o
04I;1?l000000ol0FDWo0000o`1W?003o`1W?0Wo000000?o?j40o`000?l000001ol000001?o9^@3o
0000omJG0?oFU`03o`0001gooooo00?o0000ooooooooool07?ooool001Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Uooooo`So00000_m@YP03o`0000?o08L400?o0000o`1i8_l0
NB801_l000000ol0GDKo0000o`1AC@02o`1AC@04o`000?l0?DKo03e6o`0mAP;o00000ol0:cd3o`00
00;o01Pa1?l00003o`0@:`03o`000?l03RSo000000;o00000ol02B<00ol0003o00PRo`000002o`00
00;o00HO00?o0000o`078Ol01b400ol01b401?l0003o00TSo`098ol02B<6o`0000;o00dW00?o0000
o`0C;Ol04bd00_l04bd01?l0003o01heo`0N=Ol07SD:o`000004o`16Bol0003o05M:o`1GBPGo0000
00Co06Llo`000?l0MBSo07DX3_l000000ono``3o0000o`000004o`000003omJG0?l0003ooooo01co
oooo0_l0000Mooooo`005oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02;ooooo
0_l00002ol?400Co00000_m@YP0=o`0000?o06=12?l000000ol0?DKo0000o`0[?@02o`0[?@;o0000
0_l07SD5o`0000Go010[0ol00005o`098`;o00001_l01Ql01?l0003o00LQo`078Ol01b45o`0000?o
00PR00?o0000o`0=9ol03BL00ol03BL00ol0003o01<]o`0C;@02o`0C;@03o`000?l07SGo01he00?o
01he00Go0000o`0^?ol0;Soo02hoo`000002o`14BP?o00001?l0EdX00ol0003o06@oo`000002o`00
00Co07DX3_l000001?no``3o0000om2V0?o@YP03o`0001gooooo00?o0000ooooooooool06oooool0
01Kooooo0ol0000Jooooo`03o`000?oooooooooo01oooooo0_l00002ol?400[o00000_l6S002o`00
0004o`1m6Ol0003o0000o`1`<0;o00000_l0Hd42o`0000?o05M:00Co0000o`19C?l0BDco04U<1?l0
00000ol0:cgo0000o`0N=@03o`000003o`0N=Ol0003o000000;o00000_l042/3o`0000?o00`V00?o
0000o`098ol000000_l00002o`078@03o`000?l01Qoo00HO00?o00HO1?l00003o`067`03o`000?l0
22;o00PR00?o00PR00?o0000o`0=9ol03BL00ol03BL00ol0003o01<]o`0C;@02o`0C;@03o`000?l0
7SGo01he00?o01he00Go0000o`0^?ol0;Soo02hoo`000004o`14BPCo000000?o05M:o`000?l0I3l0
0_l0I3l3o`000004o`1e:?l0003o08@<o`2430Ko000000GoGZX0o`000?l0003o0000ojRn0003o`00
00Cod:H00_l0000Looooo`03o`000?oooooooooo01[ooooo0007ooooo`Go00000oooool2o`0000Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`So00000_mNZP02o`000004
objK0?l0003o0000o`J<00;o00000_l0OAT01?l0003o070`o`1`<?l00003o`1S@@04o`000?l0Ed[o
05M:o`1GBP;o00000_l0BD`2o`0000?o03I31?l00002o`0N=@;o00001?l05Rl2o`0000Ko00`V0_l0
0006o`078@03o`000?l01Qoo000000;o00000_l01Ah00ol0003o00HOo`067`03o`067`04o`000?l0
22;o00PRo`088QSo00001?l0A4X00ol0003o05I;o`1FB`05o`000003o`1T?ol0003o07</00?o0000
1?l0Q0`2o`000005ob6G0?l0003o0000o`000?mNZP000ol000000onX_P3o0000o`000003o`000003
om2V0?l0003ooooo01[ooooo00?o0000ooooooooool06_ooool000Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06Oooool2o`0000;oakd00_l000001?nE^@3o0000o`000?mNZP02o`0000;o;Y/04Ol00000
0ol0Ed[o0000o`19C002o`19C004o`000?l0=T?o03I3o`0f@`?o00000_l0:3/00ol0003o01heo`00
0005o`0F;`03o`000?l042_o000000Co00`V0_l00002o`098`03o`000?l01b7o00LQ00?o00LQ0_l0
0006o`057P04o`000?l01Qoo00HOo`067`Go00000_l02B<00ol0003o00hXo`0>:003o`0>:003o`00
0?l052ko01@^00?o01@^00?o0000o`0O=_l07cH00_l07cH01?l0003o02loo`0_?ol0;cl5o`000003
o`14B_l0003o05I;00;o05I;00?o0000o`1S?ol0Hcl00ol00003o`1c;0?o000000?o08@<o`000?lI
T`000ol000000om@YP3o0000o`000006o`0000;oc;<00ol0000Kooooo`03o`000?oooooooooo01Wo
oooo0009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo0_l00002olNm00;o00000_nE^@0:o`0000?o
08@<00Co0000o`1f9_l0MRKo00000ol0JCT01?l0003o05i5o`1NAOl0GTD;o`0000Co02Pk0ol00003
o`0F;`;o00000ol042/01?l0003o00`Vo`000?l00005o`098`03o`000?l01b7o000000;o00000_l0
1Ql00ol0003o00DNo`057P03o`057PCo00000_l01b400ol0003o00TSo`098`03o`098`03o`000?l0
3RSo00hX00?o00hX00?o0000o`0D;_l052h00ol052h00ol0003o01lfo`0O=P02o`0O=P05o`000?l0
;coo02loo`0_?ol000000ol0AT/5o`000003o`1FBol0003o06<o00?o06<o0ol000000ol0Lbco0000
o`224003o`0000;o6I<00_l00003oe2V00?o000000?oUKT0o`000?l000000_l000000oo</`3o0000
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo000:ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
4oooool<o`0000;o?j400_l000000olETP3o0000o`000002o`2430;o00000_l0MRH00ol0003o06Ti
o`1Y>@02o`0000?o05i500Co0000o`1CC?l0Ddco05=<1Ol000000ol0=T?o0000o`0X>`02o`0X>`;o
00000ol07SD00ol0003o01H_o`000005o`0@:`;o00001ol02B<2o`0000Ko00HO00?o0000o`057_l0
00000_l000000ol01Qoo0000o`078@04o`078@03o`000?l02B?o00TS00?o00TS00Co0000o`0>:?l0
3RSo00hX3Ol00004o`0_?`03o`000?l0AT_o04I;00;o04I;00?o0000o`1GB_l0EdX00ol00003o`1S
?`03o`000?l0LRgo078]00?o00000ol0PQ02o`0000;o6I<00ol000000om@YP3o0000o`000003o`00
00;oakd00ol0000Kooooo`03o`000?oooooooooo01Sooooo0007ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool04Oooool00ol0003oc;<0olbc0002o`0000;oZ;h00_l00002og2_0004o`000?loX@3o
?j40o`0000;o5I8000Go0000o`243?l0Q0co08@<o`000003o`1f9P04o`000?l0JCWo06Tio`0000Co
05i500?o0000o`1CC?l0Dd`00ol00003o`16B`Co000000?o02Pko`000?l07SD01?l07SD3o`0000?o
010[0_l00002o`0>:003o`000?l02B?o00TS00;o00TS0_l000000ol022;o0000o`067`05o`067`;o
00001Ol01Ql00ol0003o00LQo`078@03o`078@04o`000?l02B?o00TSo`098`Go00000_l042/00ol0
003o01Pao`0H<@03o`0H<@04o`000?l093Wo02@io`0T>@Go000000?o02loo`000?l0AT/00ol0AT/0
0ol0003o05M:o`1GBP02o`1GBPGo00001?l0LRd3o`000003o`224?l0003o000000?o000000CoAZ<0
o`000?l0003o00000_n7]@02o`0000Coakd000?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Gooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0oooool2o`0002;ooooo00?o0000ooooooooool03_ooool2o`000003olbc0?l0003o000000?oZ;h0
00Co0000og2_0?m`[`3oL:l05?l00002o`1NA@Co00001Ol0AT/01?l0003o03I3o`0f@ol0=T<3o`00
00?o01he0_l00003o`0H<@03o`000?l042_o000000Go00hX00Co0000o`098ol0003o00001?l02280
0ol0003o00HOo`067`03o`000003o`078Ol0003o00HO00Go00HO00Co0000o`078Ol01b7o00LQ1Ol0
0002o`0<9P03o`000?l042_o010[00?o010[00?o0000o`0H<Ol063400ol063401Ol0003o02@io`0T
>Ol093Wo000000?o03A21ol00004o`1GBP04o`000?l0I3oo06@oo`1T?`?o00000_l0LRd00ol0003o
084Bo`214P03o`0000;o4i400_l00003odJS00?o000000CoQkD0o`000?l0003o00000_o7_@000ol0
003oooooooooo`0Hooooo`;o00006?ooool000Sooooo0ol00004ooooo`;o00001?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00cooooo3ol00002obRI0005o`000?l4R`3o18/0o`B;
0?l000000ol0OQL01?l0003o078]o`1b;Ol00004o`1W?0Ko00001?l0AT/01Ol0003o03I3o`0f@ol0
=T?o000000?o02/m00?o0000o`0N=Ol000001Ol06342o`0000Ko00hX0_l00006o`088P?o00001Ol0
1b400ol0003o00HOo`067`03o`067`Co00000_l02B<00ol0003o00`Vo`0<9P03o`0<9P03o`000?l0
42_o010[00?o010[00?o0000o`0H<Ol063400_l063400ol0003o02@io`0T>@02o`0T>@03o`000?l0
=4;o03A200;o03A200Co0000o`1;COl0Bdgo04]=1Ol000000ol0Ed[o0000o`1T?`02o`1T?`06o`00
0?l0Lbco0000o`000?l0LRgo00001?l0PA82o`0000;o4i400ol000000om6X`3o0000ogbb0008o`00
01[ooooo00?o0000ooooooooool05_ooool001Gooooo00?o0000ooooooooool08oooool2o`0000[o
oooo1?l00004okk30006o`000?n7]@3oQkD0ohNe0?l0003oE:L00_l00002obRI0005o`000?l4R`3o
18/0o`B;0?l000000_l0OQL2o`0000;o078]00Co0000o`1W??l0Icco06Ll0ol00002o`1LAP03o`00
0?l0Ddco05=<00;o000000?o04I;o`000?l0=T<00_l0=T<00ol0003o02/mo`0[?@02o`0[?@?o0000
0ol06342o`0000;o01@^00Co0000o`0>:?l03RSo00hX0_l00002o`0=9`04o`000?l022;o00PRo`08
8P;o000000?o00TSo`000?l01b401Ol01b400ol0003o00HOo`067`03o`000003o`088_l0003o00TS
00Co00TS00?o0000o`0<9_l032H00ol032H00ol0003o010[o`0@:`02o`0@:`03o`000?l0637o01Pa
00;o01Pa00?o0000o`0T>Ol093T00ol093T00ol0003o03A2o`0d@P02o`0d@P05o`000?l0Bdgo04]=
o`1;COl000000ol0FDT5o`000004o`1T?ol0003o07</o`1c;0;o00001?l0PA800ol0003o4Y40o`00
0002o`0000;o@J400ol00003ogbb00?o000000?o`l@0o`000?l000006_ooool00ol0003ooooooooo
o`05ooooo`?o00001?ooool2o`0000Oooooo000Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01Oooool2o`0000;od:H000Co0000okk30?nn``3o_/<00_l00002ohNe00;o000000?o
E:L0o`000?lXV@000_lXV@001Ol0003o18/0o`B;0?l4R`3o000000;o07hG00Ko0000o`1b;Ol0LRgo
078]o`000?l0Ic`4o`0000?o05a600?o0000o`1CC?l0Dd`00_l0Dd`4o`000003o`0f@ol0003o02/m
00?o02/m00Oo0000o`0T>Ol093Wo02@io`000?l0637o000000Go01@^00?o0000o`0>:?l000001Ol0
3BL00ol0003o00PRo`000004o`098`03o`000?l01b7o00LQ00?o00LQ0ol00005o`088P03o`000?l0
2B?o00TS00;o00TS00Co0000o`0<9_l032Ko00`V6?l00004o`1;C@03o`000?l0FDWo05U900;o05U9
00?o0000o`1W??l0Ic`00ol00003o`1c;0?o00000_l0PA800ol0003o4Y40oa:A0002o`0000?o@J40
1?l000000oml/P3o0000okS20004o`0001Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Eooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool00_ooool2o`0000?od:H000Go0000okk30?nn``3o_/<0o`000003ohNe01Go
000000?o06Llo`000?l0G4H00ol0G4H00ol0003o05=<o`1CC002o`1CC004o`000?l0BDco04U<o`19
C0?o00000ol0:cd00ol0003o02@io`0T>@02o`0T>@;o00001_l052h2o`0000Ko00dW0_l00006o`09
8`03o`000?l01b7o000000;o000000?o00TSo`000?l022801Ol022801?l0003o00TSo`098ol02B<5
o`0000?o010[00?o0000o`0F;ol05Rl00_l05Rl00ol0003o01heo`0N=@02o`0N=@03o`000?l0:cgo
02/m00?o02/m00Co0000o`0mA_l0?DKo03e61Ol000000ol0Bdgo0000o`1IB@03o`1IB@03o`000?l0
Icco06Ll00;o06Ll0ol000000ol0Lbco0000o`224003o`0000Co4Y400ol000001?m1X@3o0000o`00
0?mf/@03o`0000?o^<800_l0000Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00006ooooo`005Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooo0000013o00000om1X@001Ol0003o6Y@0oaZD0?lJU03o000000;o08L400?o0000o`1k7Ol0
Nad00ol00002o`1`;`Co00000_l0G4H01?l0003o05=<o`1CC?l0Dd`2o`0000?o04U<00Oo0000o`0m
A_l0?DKo03e6o`000?l0:cgo000000Co02@i00Co0000o`0O=_l07cKo00000ol052h2o`0000;o01<]
00Co0000o`0=9ol03BOo00dW0_l00002o`0>:003o`000?l02B?o00TS00?o00TS0_l00005o`098`03
o`000?l022;o00PR00?o00PR1?l00002o`0>:003o`000?l042_o010[00Co010[00?o0000o`0F;ol0
5Rl00_l05Rl00ol0003o01heo`0N=@02o`0N=@03o`000?l0:cgo02/m00?o02/m00Go0000o`0mA_l0
?DKo03e6o`000003o`1AC@Go00000_l0FDT01Ol0003o06Llo`1W??l0Icco000000;o07DX0ol00003
o`2240?o00000_lBT@000ol0003o?j40o`000003o`0000?oM[400_l00003okS20003o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Kooooo000Dooooo`;o0000:Oooool2o`0000CoeYL000Go0000olVi0?o9^@3obKT0o`00
0003oj:l0004o`000?m^[`3o0000o`0000;o@J400_l00002oaZD00;o00000_l0Q`@5o`0000?o070_
00?o0000o`1W??l0Ic`00_l0Ic`4o`000003o`1CC?l0003o04U<00;o04U<0_l00004o`0mAP?o0000
0ol093T00ol0003o01lfo`0O=P02o`0O=P03o`000?l052ko000000Go01<]00?o0000o`0=9ol00000
1Ol03RP00ol0003o00TSo`000002o`000003o`0<9_l0003o00TS00Go00TS00?o0000o`088_l00000
0_l000000ol03BOo0000o`0>:004o`0>:003o`000?l042_o010[00?o010[00?o0000o`0F;ol05Rl0
0ol05Rl00ol0003o01heo`0N=@02o`0N=@03o`000?l0:cgo02/m00?o02/m00Go0000o`0mA_l0?DKo
03e6o`000004o`1AC@03o`000?l0GDKo05e600?o00001?l0Ic`00ol0003o07DXo`1e:002o`1e:0;o
000000Co088@o`000?lCT@3o4i401?l00003ocnQ00?o000000?oM[40o`000?nb`0001?l0000Ioooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006
ooooo`005?ooool00ol0003oooooooooo`0Wooooo`03o`000?oFU`3oeYL000;oeYL00_l00002olVi
00;o00000_nR_002o`000003ofj_0?l0003o@J4000;o@J4000Go0000oaZD0?lJU03o6Y@0o`000002
o`2710?o00000_l0Nad01Ol0003o070_o`1`;ol0L2oo000000Co06Ll00?o0000o`1NAOl0GTD00_l0
GTD3o`000003o`19C?l0003o03e600Co03e600Oo0000o`0d@_l0=4;o03A2o`000?l093Wo000000Go
01lf0_l00006o`0C;@;o00001_l03RP2o`0000Go00`V00?o0000o`098ol02B<00ol02B<2o`0000Go
00dW00?o0000o`0>:?l03RP00ol03RP01?l0003o010[o`0@:ol042/Ao`000003o`0[?Ol0003o03e6
00?o03e600?o0000o`1ACOl0DDd00_l0DDd00ol0003o05e6o`1MAP02o`1MAPCo000000?o06Llo`00
0?l0MBP00_l0MBP00ol0003o08@<o`000002o`0000Co4i400ol000001?loX@3o0000o`000?md/003
o`0000?o//000_l0000Iooooo`;o00000oooool2o`0000Cooooo00Co0000oooooooooooo00001_oo
ool001Cooooo00?o0000ooooooooool09Oooool4o`0000;oeYL000Go0000olVi0?o9^@3obKT0o`00
0003oj:l01;o000000?o07/Mo`000?l0L2l00_l0L2l00ol0003o06Llo`1W?002o`1W?003o`000?l0
GTGo05i500;o05i500Co0000o`1GB_l0Ed[o05M:0_l00004o`0mAP03o`000?l0=4;o03A200?o03A2
00?o0000o`0O=_l07cH00ol07cH01?l0003o01heo`0N=Ol00003o`0C;@;o00000_l052h01?l0003o
00hXo`0>:?l03RP2o`000003o`0@:ol0003o00`V00Go00`V00?o0000o`098ol000000_l000000ol0
3RSo0000o`0=9`05o`0=9`03o`000?l03RSo00hX00;o00hX1?l00002o`0H<@03o`000?l07SGo01he
00?o01he00?o0000o`0X>ol0:3/00_l0:3/01?l0003o03I3o`0f@ol0=T<:o`0000;o055=00Go0000
o`1MA_l0GDKo05e6o`000003o`1Z>0Go000000Co07DXo`000?l0Q0co08@<0_l00004oa>A0003o`00
0?m1X@3o000000?o00000_md/002o`0000Co//0000?o0000ooooooooool05Oooool00ol0003ooooo
o`000004ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`005?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oKQP3ofhH000;ofhH02ol000000on=]`3o0000oejZ0002oejZ0004o`000?lf
W@3o=Yd0ocJM00;o000000?o4i40o`000?l0QPL00ol0QPL7o`0000;o06Ll00?o0000o`1NAOl0GTD0
0_l0GTD01Ol0003o05M:o`1GB_l0Ed[o000000;o055=0_l000000ol0?DKo0000o`0d@P04o`0d@P03
o`000?l0;coo000000?o01lf00?o0000o`0N=Ol07SD00_l07SD00ol0003o01<]o`000005o`0D;P03
o`000?l03RSo000000Co010[00?o0000o`0<9_l032H00ol032H2o`0000Go00hX00?o0000o`0=9ol0
3BL00ol03BL00ol0003o00hXo`000002o`000003o`0D;_l0003o01Pa00Co01Pa00?o0000o`0N=Ol0
7SD00ol07SD00ol0003o02Pko`0X>`02o`0X>`03o`000?l0=T?o03I300;o03I300?o0000o`19C?l0
BD`00_l0BD`00ol0003o05M:o`1GBP03o`0000Co05e600?o0000o`1Z>?l0JSP00_l0JSP00ol0003o
07TRo`1i8P03o`0000?o08@<0ol00002oa>A0003o`000?m1X@3o@J4000;o00001?md/003o`0000;o
//0000?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`005?ooool00ol0003ooooo
ooooo`0Rooooo`;o00000ooKQP02o`0000?od:P000Go0000ol740?o1a03o`L@0o`000003ohfg0006
o`000?mNZP3oGZX0oejZ0?l0003o=Yd00ol00002oa>A0003o`000?l0QPOo08H700;o08H700Go0000
o`1k7Ol0Nago07/Mo`000003o`1b;@?o00000ol0GTD01Ol0003o05M:o`1GB_l0Ed[o000000Co055=
0_l00005o`0d@P07o`000?l0;coo02loo`0_?ol0003o01lfo`000005o`0N=@;o00001_l052h2o`00
00Ko010[00?o0000o`0<9_l000000_l000000ol042_o0000o`0>:005o`0>:004o`000?l03BOo00dW
o`0=9`?o00001Ol052h00ol0003o01Pao`0H<@03o`0H<@03o`000?l07SGo01he00;o01he00?o0000
o`0X>ol0:3/00ol0:3/00ol0003o03I3o`0f@`02o`0f@`03o`000?l0BDco04U<00;o04U<00?o0000
o`1GB_l0EdX00_l0EdX5o`0000Go06Xh00?o0000o`1i8_l0NB800_l0NB82o`000004o`243?l0003o
6I<0oaVC00?o00000om1X@04o`000004ogB`0?l0003o/<00ok3000Co00006?ooool00ol0003ooooo
ooooo`0@ooooo`005?ooool00ol0003oooooooooo`0Qooooo`04o`000?oKQP3ofhH0om^600;o0000
0oo@Z002o`0000?o`L@000Go0000ohfg0?n=]`3oSKL0o`000003oejZ00?o000000Go=Yd0o`000?lC
T@3o4i40o`000004o`261`05o`000?l0Nago07/Mo`1k7Ol000000ol0LRd01ol0003o06Tio`1Y>Ol0
JCWo0000o`1NAOl000000ol0EdX00ol0003o055=o`1AC@02o`1AC@04o`000?l0Bdgo04]=o`0000?o
03A200?o0000o`0_?ol0;cl00_l0;cl2o`0000Go01he00?o0000o`0O=_l000001Ol052h00ol0003o
01Pao`000006o`0@:`;o00001Ol042/00ol0003o00hXo`0>:003o`0>:0Co00000_l04bd00ol0003o
01@^o`0D;P04o`0D;P03o`000?l0637o01Pa00;o01Pa00?o0000o`0N=Ol07SD00_l07SD00ol0003o
02Pko`0X>`03o`0X>`03o`000?l0=T?o03I300;o03I300?o0000o`19C?l0BD`00ol0BD`01Ol0003o
05M:o`1GB_l0Ed[o000000?o06=11?l00002o`1Z>003o`000?l0NB;o07TR00;o07TR00?o0000o`27
1?l000000_l00004oaVC00?o000000Co@J40o`000?l0003oM[400ol00004ok3000;o00006?ooool0
0ol0003oooooooooo`0?ooooo`004oooool2o`00027ooooo2?l00002om2X0003o`000?o1a03o`L@0
00;o`L@000Ko0000ohfg0?n=]`3oSKL0o`000?mNZP03o`0000?o=Yd000Co0000oa>A0?lCT@3o0000
1?l0QPL01Ol0003o07/Mo`1k7Ol0Nago000000?o078]00?o0000o`1Y>Ol0JCT00ol0JCT3o`000003
o`1GB_l0003o055=00?o055=00?o0000o`1;COl0Bdd00_l0Bdd00ol0003o03A2o`000004o`0_?`04
o`000?l0;Soo02hoo`0000?o01he00Go0000o`0O=_l07cKo01lfo`000003o`0D;P05o`000?l0637o
01Pao`0H<Ol000000ol042/2o`000003o`0F;ol0003o010[00Go010[00?o0000o`0>:?l000000_l0
00000ol052ko0000o`0C;@04o`0C;@03o`000?l052ko01@^00?o01@^00Co0000o`0H<Ol0637o01Pa
5_l000000ol0BDco0000o`1GBP03o`1GBP05o`000?l0Hd7o06=1o`1S@Ol000000_l0L303o`0000Go
07TR00?o0000o`271?l0Q`@00_l00003oaVC0003o`000?m6X`3oAZ<000Co00000omf/@03o`0000;o
/<0000?o0000ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`004oooool00ol0003ooooo
ooooo`0Nooooo`;o00000ooQL`000ol0003oei@0omND0002omND01So00000_l0QPL01Ol0003o07/M
o`1k7Ol0Nago000000?o078]00?o0000o`1Y>Ol0JCT00ol0JCT01?l0003o06=1o`1S@Ol0Hd42o`00
00?o055=00?o0000o`1;COl0Bdd00ol0Bdd3o`0000?o02lo00?o0000o`0^?ol0;Sl00_l0;Sl00ol0
003o01heo`000005o`0O=P03o`000?l052ko000000Go01Pa00?o0000o`0@:ol000001?l05Rl00ol0
003o010[o`0@:`03o`0@:`;o00001Ol052h00ol0003o01<]o`0C;@03o`0C;@04o`000?l052ko01@^
o`0D;PGo00000_l093T00ol0003o02/mo`0[?@02o`0[?@03o`000?l0=T?o03I300?o03I300?o0000
o`16Bol0AT/00_l0AT/01?l0003o05=<o`1CC?l0Dd`7o`0000Co06=100?o0000o`1`<?l0L3000_l0
L303o`0000;o07TR00?o0000o`271?l0Q`@00_l0Q`@3o`000003oaVC0?l0003oAZ<000?oAZ<00ol0
00001?mf/@3o0000ok;00?nb`004o`0001Sooooo00?o0000ooooooooool03_ooool001?ooooo00?o
0000ooooooooool07?ooool2o`0000?ohG<00_l00004omND0003o`000?o</`3oc;<000;oc;<000?o
0000ok300?n``0000ol00002oh6d0005o`000?mFZ03oEZP0oeJX0?l000000olbW0001?l0003o4i40
oa>A0?lCT@08o`000003o`1b;Ol0003o06Ti00Co06Ti00Go0000o`1S@Ol0Hd7o06=1o`000002o`1M
AP03o`000?l0DDgo000000Go04]=00Oo0000o`16Bol0AT_o04I;o`000?l0;coo000000Go02ho0_l0
0006o`0O=P;o00001_l06342o`0000Ko01H_00?o0000o`0@:ol042/00_l000000ol0637o0000o`0D
;P05o`0D;P03o`000?l04bgo01<]00;o01<]1?l00002o`0O=P03o`000?l093Wo02@i00?o02@i00?o
0000o`0[?Ol0:cd00_l0:cd00ol0003o03I3o`0f@`03o`0f@`03o`000?l0AT_o04I;00;o04I;00?o
0000o`1CC?l0Dd`00_l0Dd`01?l0003o05i5o`1NAOl0GTD4o`0000;o06=100Go0000o`1`<?l0L33o
070`o`000002o`1m6@?o00001?l0Q`@00ol0003o8IL0ob6G0003o`0000?oAZ<00_l000001?ml/P3o
0000o`000?l00004ok;000;o00006?ooool00ol0003oooooooooo`0=ooooo`004oooool00ol0003o
ooooooooo`0Jooooo`Co00000_oQL`000ol0003oei@0omND0003omND0004o`000?o</`3oc;<0olbc
00Ko00000on1]0001Ol0003oEZP0oeJX0?mFZ03o000000?o<Y`000?o0000oa>A0?lCT@000_lCT@00
1?l0003o08L4o`271?l00004o`1n5`;o00001?l0JCT01Ol0003o06=1o`1S@Ol0Hd7o000000Co05e6
0_l00004o`1;C@03o`000?l0AT_o04I;00?o04I;00?o0000o`0^?ol0;Sl00ol0;Sl00ol0003o02lo
o`000005o`0O=P03o`000?l093Wo000000Go01Pa00?o0000o`0N=Ol000001_l05Rl00ol0003o010[
o`000004o`0H<@03o`000?l052ko01@^00?o01@^00?o0000o`0C;Ol000000_l000000ol07SGo0000
o`0O=P04o`0O=P03o`000?l093Wo02@i00;o02@i00?o0000o`0[?Ol0:cd00ol0:cd00ol0003o03I3
o`0f@`02o`0f@`03o`000?l0AT_o04I;00;o04I;00?o0000o`1CC?l0Dd`00ol0Dd`01Ol0003o05i5
o`1NAOl0GTGo000000;o06Ti0ol00004o`1`<003o`000?l0OAWo07dI00;o07dI0ol00002o`271003
o`000?lQU`3o8IL000;o8IL00ol000000om6X`3o0000o`000002ogbb00;o00001?nb`0000ol0003o
ooooooooo`0Fooooo`;o00003_ooool001?ooooo00?o0000ooooooooool06Oooool00ol0003oiel0
onMO0002onMO00Go00000_oGU0001?l0003oc;<0olbc0?o</`03o`000003ok300?l0003oPK@000?o
PK@000Go0000oeJX0?mFZ03oEZP0o`000003oc:L0003o`000?lCT@3o4i4000;o4i4000Co0000o`27
1?l0Q`Co00001?l0OQL00ol0003o07HVo`1f9P02o`000003o`1Y>Ol0003o06=100;o06=100?o0000
o`1MA_l0GDH00_l0GDH00ol0003o05U9o`1IB@02o`000003o`1;COl0003o04I;00Co04I;00?o0000
o`14B_l000000ol0;Sl01Ol0003o02loo`0_?ol0;coo000000?o01lf00Go0000o`0T>Ol093Wo02@i
o`000003o`0H<@05o`000?l07SGo01heo`0N=Ol000001Ol05Rl2o`0000Ko01Pa00?o0000o`0D;_l0
52h00_l052h2o`0000Go01he00?o0000o`0O=_l07cH00ol07cH00ol0003o02@io`0T>@02o`0T>@03
o`000?l0:cgo02/m00;o02/m00?o0000o`0f@ol0=T<00_l0=T<00ol0003o04I;o`16B`03o`16B`03
o`000?l0Ddco05=<00;o05=<00?o0000o`1NAOl0GTD00_l0GTD00ol0003o06Tio`1Y>@02o`1Y>@?o
00000_l0L3001Ol0003o07dIo`1m6Ol0OAWo000000;o1X`00ol00004ob6G0003o`000?m@YP3oD:H0
00?o00001?ml/P03o`0000;o//0000?o0000ooooooooool05_ooool00ol0003oooooooooo`0<oooo
o`004oooool00ol0003oooooooooo`0Gooooo`;o00001?oWG`000ol0003ogWh0omin0003omin00co
00000_n1]0001Ol0003oEZP0oeJX0?mFZ03o000000?o<Y`000?o0000oa>A0?lCT@000_lCT@001?l0
003o08L4o`271?l00004o`1n5`03o`000?l0MRKo07HV00;o07HV1?l000000ol0Hd7o0000o`1MAP03
o`1MAP03o`000?l0FDWo05U900;o05U90_l00005o`16B`07o`000?l0A4[o04A:o`14B_l0003o02ho
o`000005o`0_?`03o`000?l07cKo000000Go02@i00?o0000o`0H<Ol000001Ol07SD00ol0003o01H_
o`0F;`02o`000003o`0N=Ol0003o01Pa00Go01Pa00?o0000o`0D;_l000000_l000000ol07cKo0000
o`0N=@04o`0N=@03o`000?l07cKo01lf00?o01lf00?o0000o`0T>Ol093T00_l093T01?l0003o02/m
o`0[?Ol0:cd;o`000003o`16Bol0003o05=<00?o05=<00?o0000o`1NAOl0GTD00_l0GTD00ol0003o
06Tio`1Y>@02o`1Y>@03o`000?l0MRKo07HV00?o00001?l0OAT00ol0003o1X`0o`J<0002o`J<00?o
00000_lQU`000ol0003oD:H0oe2V0002oe2V00;o00000_ml/P000ol0003o^<80okS20003o`0001Oo
oooo0ol0000=ooooo`004_ooool3o`0001Oooooo00?o0000onMO0?oWG`000ooWG`000ol0003ogWh0
omin0003omin0003o`000?oCW@3o000000;o00000oo9^P000ol0003oZ;h0ojRn0002ojRn00co0000
0_lCT@001?l0003o08L4o`271?l00004o`1n5`03o`000?l0MRKo07HV00;o07HV00?o0000o`1`<?l0
L3000_l0L302o`0000?o05e600?o0000o`1IBOl0FDT00_l0FDT01?l0003o05M:o`1GB_l00003o`16
B`03o`000?l0A4[o04A:00?o04A:00?o0000o`0_?ol0;cl01?l0;cl2o`0000Ko02@i0_l00006o`0N
=@03o`000?l05Roo000000Co01he00?o0000o`0H<Ol063400ol06342o`0000Go01lf00?o0000o`0N
=Ol07SD00_l07SD00ol0003o01lfo`0O=P03o`0O=PWo00000_l0?DH00ol0003o04U<o`19C002o`19
C004o`000?l0Ddco05=<o`1CC0[o00000_l0GTD00ol0003o06Tio`1Y>@02o`1Y>@03o`000?l0MRKo
07HV00;o07HV0ol00002o`1m6@05o`000?l6S03o1X`0o`J<0?l000000_l^V`03o`0000CoD:H000Ko
0000ohNe0?l0003o0000ogbb0?l00004okS20003o`000?oooooooooo017ooooo0ol00002ooooo`03
o`000?oooooooooo00_ooooo0005ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool0
5Oooool5o`0000;oiel000?o0000omin0?oNOP000_oNOP06o`0000?obKX000?o0000ojRn0?nX_P00
0_nX_P001Ol0003oO;80ogbb0?ml/P3o000000?oEZP000?o0000ocJM0?lfW@000_lfW@07o`0000;o
07hG00?o0000o`1f9_l0MRH00_l0MRH00ol0003o070`o`1`<002o`1`<006o`000?l0JSSo06Xho`00
0?l0GDKo00001?l0FDT00ol0003o05M:o`1GBP02o`1GBP03o`000?l0AT_o000000Go04A:0_l00005
o`0_?`03o`000?l0=4;o000000Go02@i00?o0000o`0[?Ol000001_l07SD2o`0000Go01he00Co0000
o`0H<Ol0637o01Pa0_l000000ol093Wo0000o`0O=P04o`0O=P03o`000?l07SGo01he00?o01he00?o
0000o`0O=_l000000_l000000ol0;coo0000o`0d@P03o`0d@P03o`000?l0?DKo03e600?o03e600?o
0000o`19C?l0BD`00_l0BD`00ol0003o05=<o`1CC002o`1CC003o`000?l0G4Ko05a600;o05a600?o
0000o`1W??l0Ic`00ol00005o`1Y>@05o`000?l0MRKo07HVo`1f9_l000000_l0Q0`3o`0000Co1X`0
00?o0000objK0?l^V`000_l^V`02o`0000?oD:H000?o0000ohNe0?n7]@000_l00004okS20003o`00
0?oooooooooo00kooooo0ol00005ooooo`03o`000?oooooooooo00_ooooo0006ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
0_l00005one;00Co000000CogWh0o`000?l0003o00000_oCW@000ol0003obKX0olVj0002olVj0004
o`000?nX_P3oZ;h0ojRn00;o00000oml/P001Ol0003oEZP0oeJX0?mFZ03o000000Co=Yd000?o0000
oaZD0?lJU0000_lJU0000ol0003o18/0o`B;0003o`0000?o07HV00?o0000o`1`<?l0L3000_l0L300
0ol0003o06Xho`1Z>002o`1Z>0;o00000ol0FDT00ol0003o05M:o`1GBP04o`1GBP03o`000?l0A4[o
04A:00?o04A:00Co0000o`16Bol0AT_o00000ol0;cl01Ol0003o03A2o`0d@_l0=4;o000000?o02@i
00Go0000o`0[?Ol0:cgo02/mo`000003o`0N=@;o000000?o02Pko`000?l07SD01?l07SD01?l0003o
01Pao`000?l00004o`0T>@03o`000?l07cKo01lf00;o01lf00Co0000o`0N=Ol07SGo01he1?l00005
o`0_?`03o`000?l0=4;o03A200;o03A200?o0000o`0mA_l0?DH00_l0?DH00ol0003o04U<o`19C002
o`19C003o`000?l0Ddco05=<00?o05=<00?o0000o`1LA_l0G4H00_l0G4H00ol0003o06Llo`1W?002
o`1W?0Co000000?o06Tio`000?l0MRH00ol0MRH00ol0003o08@<o`243002o`2430?o00000_l6S000
1_l0003o;Y/0objK0?l^V`3o0000oejZ00?o000000?oD:H0o`000?n7]@000_n7]@03o`0000;o^<80
00?o0000ooooooooool02_ooool3o`0000Sooooo00?o0000ooooooooool02oooool000?ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04_ooool00ol0003okD/0
one;0004one;0003o`000?oUI`3oiFL000[o00000_o9^P001Ol0003oZ;h0ojRn0?nX_P3o000000Co
O;8000Go0000oeJX0?mFZ03oEZP0o`000004ocJM0003o`000?lJU03o6Y@000;o6Y@000Go0000o`B;
0?l4R`3o18/0o`000002o`243003o`000?l0MRKo000000Co070`00?o0000o`1Z>?l0JSP00_l0JSP0
1_l0003o06Llo`1W??l0003o05U9o`0000Ko05M:00?o0000o`1FBol000000ol0A4X00ol0003o04I;
o`16B`02o`16B`03o`000?l0;coo000000Go03A200?o0000o`0T>Ol000001Ol0:cd00ol0003o01he
o`000004o`0X>`03o`000?l07SGo01he00;o01he0_l00006o`0T>@03o`000?l07cKo01lf00;o01lf
1?l00002o`0^?`03o`000?l0;coo02lo00Co02lo00?o0000o`0d@_l0=4800_l0=4800ol0003o03e6
o`0mAP03o`0mAP03o`000?l0BDco04U<00;o04U<00?o0000o`1CC?l0Dd`00_l0Dd`00ol0003o05a6
o`1LAP02o`1LAP03o`000?l0Icco06Ll00;o06Ll00Co0000o`1b;Ol0LRgo078]1?l00002o`1f9P03
o`000?l0Q0co08@<00;o08@<00?o0000oaFB0?lETP000ol00004objK0004o`000?mNZP3oGZX0oejZ
00?o00000_n7]@000ol0003o`l@0ol?40004o`0000Oooooo1?l0000<ooooo`03o`000?oooooooooo
00[ooooo0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0@ooooo`?o00001?o]B`05o`000003onEW0?l0003og8D000?og8D000Co0000
om:R0?oBXP3odZ802?l00002ogbb0005o`000?mFZ03oEZP0oeJX0?l000001?lfW@000ol0003o6Y@0
oaZD0002oaZD0005o`000?l4R`3o18/0o`B;0?l000001?l0Q0`3o`0000;o070`00?o0000o`1Z>?l0
JSP00_l0JSP00ol0003o06Llo`1W?002o`1W?0;o00001Ol0EdX01ol0003o05I;o`1FBol0ET_o0000
o`14B_l000001_l0AT/00ol0003o03A2o`0d@P04o`0d@P;o00001_l0:cd2o`0000Go02Pk00?o0000
o`0N=Ol07SD00_l000000ol0:cgo0000o`0T>@05o`0T>@03o`000?l07cKo000000;o000000?o02lo
o`000?l0;Sl01?l0;Sl00ol0003o02loo`0_?`03o`0_?`03o`000?l0=4;o03A200;o03A200?o0000
o`0mA_l0?DH00ol0?DH00ol0003o04U<o`19C002o`19C003o`000?l0Ddco05=<00;o05=<00?o0000
o`1LA_l0G4H00ol0G4H00ol0003o06Llo`1W?002o`1W?003o`000?l0LRgo078]00;o078]00?o0000
o`1n5ol000000_l00005o`243003o`000?lETP3o5I8000;o5I800ol00002objK0003o`000?mNZP3o
GZX000;oGZX00ol000000on7]@3o0000ol?40003ol?400;o00000oooool3o`00013ooooo00?o0000
ooooooooool02_ooool000Cooooo00?o0000ooooool000000oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00kooooo0_l00003oo8i00;o000000CokD/0o`000?l0003o00000_oU
I`02o`0000Cog8D000Go0000om:R0?oBXP3odZ80o`000004olRl0004o`000?nX_P3oZ;h0ojRn00So
00000_lfW@000ol0003o6Y@0oaZD0002oaZD0005o`000?l4R`3o18/0o`B;0?l000001?l0Q0`01?l0
003o07dIo`1m6Ol0OAT3o`0000?o06Xh00?o0000o`1W??l0Ic`00ol0Ic`00ol0003o06@oo`000003
o`1GBP03o`000?l0ET_o05I;00?o05I;00?o0000o`16Bol0AT/01?l0AT/2o`0000Go03A200?o0000
o`0mA_l000001Ol0:cd00ol0003o03I3o`000005o`0X>`03o`000?l07SGo000000Co02/m00?o0000
o`0T>Ol093T00ol093T2o`0000Go02lo00?o0000o`0^?ol0;Sl00ol0;Sl00ol0003o02loo`0_?`03
o`0_?`03o`000?l0=4;o03A201Ko000000?o05a6o`000?l0Ic`01?l0Ic`00ol0003o078]o`1b;@02
o`1b;@04o`000?l0OQOo07hGo`1n5`?o00000_l0Q0`00ol0003o5I80oaFB0002oaFB0003o`000?lo
X@3o?j4000?o00001?mNZP02o`000004oiFi0?l0003o0000o`0000Co`l@01?l0000Cooooo`03o`00
0?oooooooooo00[ooooo0005ooooo`;o00000oooool01?l0003oooooooooool00003ooooo`;o0000
3_ooool2o`0000GolST01Ol00002onEW0003o`000?oLQ@3og8D000?og8D000Go0000om:R0?oBXP3o
dZ80o`000004olRl0003o`000?nX_P3oZ;h000;oZ;h000Go0000oh6d0?n1]03oPK@0o`000003oejZ
00Co00000_lJU0001Ol0003o18/0o`B;0?l4R`3o000000Co08@<00?o0000o`1m6Ol0OAT00_l0OAT0
1_l0003o07TRo`1i8_l0003o06Xho`0000Go06Ll00Oo0000o`1T?ol0I3oo06@oo`000?l0Ed[o0000
00Go05I;0_l00005o`16B`04o`000?l0Bdgo04]=o`0000?o03A200Go0000o`0mA_l0?DKo03e6o`00
0003o`0[?@05o`000?l0=T?o03I3o`0f@ol000001?l0:3/2o`0000Ko02/m00?o0000o`0T>Ol093T0
0_l000000ol0=4;o0000o`0_?`04o`0_?`03o`000?l0;Soo02ho00?o02ho00Co0000o`0_?ol0;coo
02lo1Ol00002o`1;C@03o`000?l0DDgo055=00?o055=00?o0000o`1GB_l0EdX00_l0EdX00ol0003o
05i5o`1NA@02o`1NA@04o`000?l0Icco06Llo`1W?0Ko000000?o06Llo`000?l0LRd00ol0LRd01Ol0
003o07hGo`1n5ol0OQOo000000;o18/00ol00005oaFB0003o`000?loX@3o?j4000;o?j400ol00002
oejZ00;o00000onE^@03o`0000;o`l@000?o0000ooooooooool04oooool00ol0003oooooooooo`0:
ooooo`001_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`0;oooo
o`?o00001?ob>@03o`0000Coje401Ol00002omb50005o`000?oBXP3odZ80om:R0?l000001?o8_000
0ol0003oZ;h0ojRn0002ojRn0005o`000?n1]03oPK@0oh6d0?l000001?mNZP001?l0003o@J40od6Q
0?m1X@04o`000003o`B;0?l0003o08@<00?o08@<00?o0000o`1m6Ol0OAT00_l0OAT00ol0003o07TR
o`1i8P02o`1i8P03o`000?l0Icco06Ll00?o06Ll00?o0000o`1T?ol0I3l00_l0I3l2o`0000Go05I;
00Co0000o`1GB_l0Ed[o00000ol0AT/00ol0003o04]=o`1;C@02o`1;C@03o`000?l0=4;o000000Go
03e600?o0000o`0[?Ol000001?l0=T<00ol0003o02Pko`0X>`02o`000003o`0f@ol0003o02/m00Go
02/m00?o0000o`0T>Ol000001?l0=4800ol0003o02loo`0_?`03o`0_?`03o`000?l0;Soo02ho00;o
02ho1?l00002o`16B`03o`000?l0Bdgo04]=00?o04]=00?o0000o`1ACOl0DDd00ol0DDd00ol0003o
05M:o`1GBP02o`1GBP03o`000?l0GTGo05i500;o05i500?o0000o`1W??l0Ic`00_l0Ic`01?l0003o
070_o`1`;ol0L2l7o`0000Co07hG00?o0000o`B;0?l4R`000_l4R`03o`0000;o5I8000?o0000ocnQ
0?loX@000_loX@000ol0003oL:l0og2_0004o`0000?oUKT000?o0000olNm0?o7_@000ol0000Eoooo
o`03o`000?oooooooooo00[ooooo000Aooooo`03o`000?oooooooooo00Wooooo0_l00003ooHY00Go
00001Oo[D@000ol0003ohf`0on=/0003on=/00So00000_o8_0000ol0003oZ;h0ojRn0002ojRn0005
o`000?n1]03oPK@0oh6d0?l000001?mNZP001Ol0003o@J40od6Q0?m1X@3o000000Co:9T00ol00002
o`243003o`000?l0OAWo07dI00;o07dI00?o0000o`1i8_l0NB800ol0NB82o`0000?o06Ll00?o0000
o`1T?ol0I3l00_l0I3l01?l0003o06<oo`1S?ol00003o`1FB`03o`000?l0Ed[o05M:00;o05M:00?o
0000o`16Bol000001Ol0Bdd2o`0000Ko03e60_l00005o`0f@`03o`000?l0:3_o000000Co03I300?o
0000o`0[?Ol0:cd00ol0:cd2o`0000Go03A200?o0000o`0_?ol0;cl00ol0;cl00ol0003o02hoo`00
0002o`000003o`14B_l0003o04I;00Co04I;00?o0000o`1;COl0Bdd00_l0Bdd00ol0003o055=o`1A
C@03o`1AC@03o`000?l0Ed[o05M:00;o05M:00?o0000o`1NAOl0GTD00_l0GTD00ol0003o06Llo`1W
?003o`1W?003o`000?l0L2oo070_00;o070_00Co0000o`1k7Ol0Nago07/M1?l00002o`1n5`05o`00
0?l4R`3o18/0o`B;0?l000000_lXV@03o`0000Go?j4000?o0000og2_0?m`[`000_m`[`03o`0000;o
UKT000?o0000olNm0?o7_@000_o7_@000ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[o
oooo000Aooooo`03o`000?oooooooooo00Sooooo00Co0000ooHY0?of:@3omRT01_l00005on]A0003
o`000?oSK03ohf`000?ohf`000Go0000om^70?oKQ`3ofhL0o`000004om:R00Co00000_nX_P001Ol0
003oPK@0oh6d0?n1]03o000000CoGZX000Go0000od6Q0?m1X@3o@J40o`000004obRI0004o`000?lE
TP3o5I80oaFB00?o00000ol0OAT00ol0003o07TRo`1i8P03o`1i8P06o`000?l0MBSo07DXo`000?l0
Icco00001?l0I3l00ol0003o06<oo`1S?`02o`1S?`03o`000?l0ET_o000000Go05M:0_l00005o`1;
C@03o`000?l0DDgo000000Go03e600?o0000o`19C?l000001Ol0=T<2o`0000Ko03I300?o0000o`0[
?Ol0:cd00_l000000ol0?DKo0000o`0d@P05o`0d@P03o`000?l0;coo02lo00;o02lo0_l00005o`14
BP03o`000?l0AT_o04I;00;o04I;00?o0000o`1;COl0Bdd00ol0Bdd00ol0003o055=o`1AC@02o`1A
C@03o`000?l0Ed[o05M:00?o05M:00?o0000o`1NAOl0GTD00_l0GTD00ol0003o06Llo`1W?002o`1W
?003o`000?l0L2oo070_00?o070_00Go0000o`1k7Ol0Nago07/Mo`000002o`2710?o00001?l4R`00
0ol0003o:9T0obRI0002obRI00?o00000_loX@000ol0003oL:l0og2_0002og2_0003o`000?nX_P3o
000000?o00001?o7_@000ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo000Aoooo
o`03o`000?oooooooooo00Kooooo1_l000000oof:@3o0000o`000003oo4l00?o000000?oje40o`00
0?oSK0000ooSK002o`0000?ofhL000?o0000om:R0?oBXP000_oBXP000ol0003obKX0olVj0002olVj
00So00000_mNZP001Ol0003o@J40od6Q0?m1X@3o000000Co:9T000?o0000oaFB0?lETP000olETP00
1Ol0003o1X`0o`000?l0OAWo000000Go07TR00?o0000o`1e:?l0MBP00_l0MBP2o`0000?o06@o00?o
0000o`1S?ol0Hcl00ol0Hcl2o`0000Go05M:00Co0000o`1IBOl0FDWo00000ol0Bdd01Ol0003o055=
o`1ACOl0DDgo000000?o03e600Go0000o`19C?l0BDco04U<o`000003o`0f@`03o`000?l0AT_o0000
00Ko03I300?o0000o`0[?Ol000001?l0?DH00ol0003o03A2o`0d@P03o`0d@P03o`000?l0;coo0000
00;o000000?o04I;o`000?l0A4X01?l0A4X00ol0003o04I;o`16B`03o`16B`03o`000?l0Bdgo04]=
00;o04]=00?o0000o`1ACOl0DDd00ol0DDd00ol0003o05M:o`1GBP02o`1GBP03o`000?l0GTGo05i5
00;o05i500?o0000o`1W??l0Ic`00ol0Ic`00ol0003o070_o`1`;`02o`1`;`03o`000?l0Nago07/M
00;o07/M00?o0000o`271?l0Q`@00_l0Q`@3o`0000;o18/000Go0000obRI0?lXV@3o:9T0o`000002
oeBW00?o00001Om`[`000ol0003oZ;h0o`000002ojRn00;o00000oo7_@000ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooooooo00?ooooo2?l000000oof
:@3o0000oo4l0006oo4l00Co00000_oSK0000ol0003ofhL0om^70002om^70003o`000?oBXP3odZ80
00;odZ8000?o0000olVj0?o9^P000_o9^P001Ol0003o/<00ok300?n``03o000000CoSKL01?l00000
0om1X@3o0000obRI0003obRI0003o`000?lETP3o5I8000?o5I8000Co0000o`J<0?l6S03o1X`00_l0
0004o`1i8P03o`000?l0MBSo07DX00;o07DX00Ko0000o`1c;?l0Lbco0000o`1T?ol00005o`1S?`04
o`000?l0I3oo06@oo`0000?o05M:00?o0000o`1IBOl0FDT00_l0FDT00ol0003o04]=o`000005o`1A
C@03o`000?l0?DKo000000Co04U<00Co0000o`0f@ol0=T?o00000ol0AT/00ol0003o03I3o`0f@`03
o`0f@`;o00001_l0?DH00ol0003o03A2o`0d@P02o`0d@P;o00001Ol0AT/00ol0003o04A:o`14BP03
o`14BP03o`000?l0AT_o04I;00;o04I;00Co0000o`1;COl0Bdgo04]=5_l000000ol0Icco0000o`1`
;`03o`1`;`03o`000?l0Nago07/M00;o07/M00?o0000o`271?l0Q`@00_l0Q`@00ol0003o6Y@0oaZD
0003o`0000Co:9T000?o0000oeBW0?mDY`000_mDY`03o`0000?oL:l00_l00002ojRn0003o`000?o<
/`3o000000;o000000?oakd0o`000?ooool04_ooool00ol0003oooooooooo`09ooooo`004?ooool2
o`0000;ooooo1_l00004ooPM00?o00001Ooa?002o`0000Coje<01?l00002om^70003o`000?oBXP3o
dZ8000;odZ8000?o0000olVj0?o9^P000_o9^P001Ol0003o/<00ok300?n``03o000000CoSKL000?o
0000ofj_0?m^[`000_m^[`03o`0000;o:9T000?o0000oaFB0?lETP000olETP001Ol0003o1X`0o`J<
0?l6S03o000000;o08L40_l000000ol0NB;o0000o`1e:003o`1e:003o`000?l0Lbco07</00;o07</
00?o0000o`1S?ol0Hcl00ol0Hcl00ol0003o06@oo`1T?`02o`1T?`03o`000?l0Ed[o000000Ko05U9
00?o0000o`1ACOl0DDd01?l0DDd2o`0000Go04U<00?o0000o`0f@ol000001Ol0AT/00ol0003o03I3
o`0f@`02o`000003o`19C?l0003o03e600Go03e600?o0000o`0d@_l000000_l000000ol0Bdgo0000
o`16B`04o`16B`03o`000?l0A4[o04A:00?o04A:00Co0000o`16Bol0AT_o04I;1Ol00002o`1IB@03
o`000?l0GDKo05e600;o05e600?o0000o`1S@Ol0Hd400ol0Hd400ol0003o06Tio`1Y>@02o`1Y>@04
o`000?l0LRgo078]o`1b;@Ko000000?o070_o`000?l0Nad00ol0Nad00ol0003o08L4o`271002o`27
1003o`000?lJU03o6Y@000;o6Y@00ol00002obRI0005o`000?mDY`3oE:L0oeBW0?l000000_n7]@04
o`000005ojRn0?l0003oZ;h0ojRn0?l000000oo</`02o`0001?ooooo00?o0000ooooooooool02Ooo
ool0013ooooo2Ol00003ooPM00;o00000ooe:P02o`000003oo4l0?l0003o000000Goje<000?o0000
on=/0?oSK0000_oSK004o`0000;odZ8000?o0000olVj0?o9^P000_o9^P001Ol0003o/<00ok300?n`
`03o000000CoSKL000?o0000ofj_0?m^[`000om^[`000ol0003oE:L0oeBW0003o`0000Co5I8000Go
0000o`J<0?l6S03o1X`0o`000004o`2710?o00000ol0MBP00ol0003o07</o`1c;003o`1c;0;o0000
0ol0Hcl00ol0003o06@oo`1T?`04o`1T?`03o`000?l0FDWo05U900Co05U90_l00005o`1AC@03o`00
0?l0Ed[o000000Go04U<0_l00006o`16B`03o`000?l0=T?o000000Co04U<00?o0000o`0mA_l0?DH0
0ol0?DH2o`0000Go04]=00?o0000o`16Bol0AT/00ol0AT/00ol0003o04A:o`14BP02o`14BPCo0000
0_l0EdX00ol0003o05U9o`1IB@03o`1IB@03o`000?l0GDKo05e600;o05e600?o0000o`1S@Ol0Hd40
0ol0Hd400ol0003o06Tio`1Y>@02o`1Y>@03o`000?l0LRgo078]00;o078]00Co0000o`1k7Ol0Nago
07/M1Ol000000ol0Nago0000o`271003o`271003o`000?lJU03o6Y@000;o6Y@000?o0000od6Q0?m1
X@000ol00004oeBW0003o`000?n7]@3oQkD000;oQkD01?l00002ojRn0003o`000?o</`3oc;<000;o
c;<000?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`004?ooool4o`0000GonAT0
00?o0000ooPM0?l000001_oe:P03o`0000Coje<00_l00004on=/0003o`000?oLQ@3og8D000;og8D0
1?l00002olVj0005o`000?n``03o/<00ok300?l000001?n=]`000ol0003oKZl0ofj_0003ofj_0003
o`000?mDY`3oE:L000;oE:L000Ko0000ocnQ0?l0003o0000oaFB0?l00003o`J<0003o`000?l0Q`Co
08L400;o08L400Oo0000o`243?l0Q0co08@<o`000?l0MBSo000000Go07</00Ko0000o`1b;Ol0LRgo
0000o`1S?ol00007o`1T?`03o`000?l0FDWo05U900?o05U900Co0000o`1MA_l0GDKo00000ol0DDd0
1Ol0003o05M:o`1GB_l0Ed[o000000?o04U<00?o0000o`1CC?l000001_l0AT/2o`0000Ko04U<00?o
0000o`0mA_l0?DH00_l000000ol0DDgo0000o`1;C@04o`1;C@03o`000?l0AT_o04I;00?o04I;00?o
0000o`14B_l000000_l000000ol0ET_o0000o`1GBP04o`1GBP03o`000?l0FDWo05U900;o05U900?o
0000o`1MA_l0GDH00_l0GDH00ol0003o06=1o`1S@@03o`1S@@03o`000?l0JCWo06Ti00;o06Ti00?o
0000o`1b;Ol0LRd00ol0LRd01Ol0003o07/Mo`1k7Ol0Nago000000?o08H71Ol00002o`271003o`00
0?lJU03o6Y@000;o6Y@000?o0000od6Q0?m1X@000_m1X@03o`0000;oE:L000?o0000ohNe0?n7]@00
0_n7]@000ol0003o_l<0oko30003o`0000Coc;<000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`004?ooool3o`0000KonAT00ol00004ooDZ00;o00000ooa?002o`000003on]C0?l0
003ohf`000Cohf`000?o0000omb50?oLQ@000_oLQ@000ol0003odid0om>M0002om>M00So00000_n=
]`000ol0003oKZl0ofj_0003ofj_0003o`000?mDY`3oE:L000;oE:L000Co0000ocnQ0?loX@3o?j40
1?l000000ol6S03o0000o`271003o`271003o`000?l0Q0co08@<00?o08@<00?o0000o`1c;?l0Lb`0
0ol0Lb`00ol0003o078]o`1b;@02o`1b;@03o`000?l0I3oo06@o00Go06@o00?o0000o`1W??l00000
0ol0FDT00ol0003o05e6o`1MAP02o`1MAP03o`000?l0DDgo000000Co05M:00Co0000o`19C?l0BDco
00000ol0Dd`00ol0003o04I;o`16B`02o`16B`03o`000?l0Ddco000000Ko04U<00?o0000o`0mA_l0
00001?l0DDd00ol0003o04]=o`1;C@03o`1;C@03o`000?l0AT_o04I;00;o04I;0_l00005o`1FB`03
o`000?l0Ed[o05M:00;o05M:00?o0000o`1IBOl0FDT00ol0FDT00ol0003o05e6o`1MAP02o`1MAP03
o`000?l0Hd7o06=100;o06=100?o0000o`1Y>Ol0JCT00ol0JCT00ol0003o078]o`1b;@02o`1b;@03
o`000?l0Nago07/M00;o07/M00?o0000o`261ol0QPL00_l0QPL00ol0003o4i40oa>A0003o`0000Go
6Y@000Go0000od6Q0?m1X@3o@J40o`000002ofj_00?o00001On7]@000ol0003o_l<0o`000002oko3
00?o00000_o</`000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo000Booooo`;o
00000_oi6@03o`0000?on1d00_l000000ooe:P3o0000oo4l0005oo4l00Go00000_oSK0000ol0003o
g8D0omb50002omb50003o`000?oCW@3odid000;odid000?o0000olbc0?o</`000oo</`000ol0003o
`L@0ol740003o`0000CoKZl000?o0000oeBW0?mDY`000_mDY`001Ol0003o?j40ocnQ0?loX@3o0000
00Co;Y/00_l00003o`271003o`000?l0Q0co08@<00Co08@<0_l00003o`1c;003o`000?l0LRgo078]
00?o078]0_l00005o`1T?`07o`000?l0Icco06Llo`1W??l0003o05U9o`000005o`1MAP;o00001Ol0
EdX00ol0003o04U<o`000005o`1CC004o`000?l0AT_o04I;o`0000?o05=<00?o0000o`19C?l0BD`0
0ol0BD`2o`0000Go055=00?o0000o`1;COl0Bdd00ol0Bdd00ol0003o04I;o`000002o`000003o`1G
B_l0003o05I;00Co05I;00?o0000o`1GB_l0EdX00ol0EdX00ol0003o05U9o`1IB@02o`1IB@03o`00
0?l0GDKo05e600;o05e600?o0000o`1S@Ol0Hd400ol0Hd400ol0003o06Tio`1Y>@02o`1Y>@03o`00
0?l0LRgo078]00;o078]00?o0000o`1k7Ol0Nad00_l0Nad00ol0003o08H7o`261`03o`261`03o`00
0?lCT@3o4i4000;o4i401?l000000olJU03o0000od6Q0003od6Q0003o`000?m^[`3oKZl000;oKZl0
0ol00002ohNe0006o`000?no``3o_l<0o`000?no``3o00000_o@YP03o`00017ooooo00?o0000oooo
ooooool02Oooool001?ooooo0ol00007ooPM00?o00001Ooa?0000ol0003oje40on]A0003on]A00Co
00000_oLQ@000ol0003odid0om>M0002om>M0003o`000?o</`3oc;<000?oc;<000?o0000ol740?o1
a0000_o1a0001_l0003oX[`0o`000?l0003oKZl0o`0000CoE:L000Go0000ocnQ0?loX@3o?j40o`00
0005objK0005o`000?lQU`3o0000o`271?l000001_l0Q0`01_l0003o088@o`224?l0003o07</o`00
00Go078]00Co0000o`1c;?l0Lbco00000ol0I3l00ol0003o06Llo`1W?002o`1W?0;o00001Ol0GDH0
0ol0003o06=1o`000005o`1GBP;o00001_l0Dd`00ol0003o04I;o`000005o`1CC003o`000?l0BDco
04U<00;o000000?o05M:o`000?l0DDd01Ol0DDd00ol0003o04]=o`1;C@02o`1;C@;o00001Ol0EdX0
0ol0003o05I;o`1FB`02o`1FB`03o`000?l0Ed[o05M:00?o05M:00Co0000o`1IBOl0FDWo05U95_l0
00000ol0LRgo0000o`1k7@03o`1k7@03o`000?l0QPOo08H700;o08H700?o0000oa>A0?lCT@000_lC
T@001?l0003o=Yd0ocJM0?lfW@04o`0000;o@J4000?o0000ofj_0?m^[`000_m^[`000ol0003oX[`0
oj:l0003o`0000?o_l<000?o0000oko30?l000001?o@YP000ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Sooooo000Dooooo`03o`000?oooooo000000Con1d00_l00003ooHY0005o`000?oa
?03olC`0oo4l0?l000001Oo[D@000ol0003oiFL0onEW0002onEW00Co00000_oCW@000ol0003oc;<0
olbc0003olbc0003o`000?o1a03o`L@000;o`L@000Co0000oj:l0?nR_03oX[`01?l00002oeBW0005
o`000?loX@3o?j40ocnQ0?l000001Ol^V`001?l0003o8IL0ob6G0?lQU`02o`0000Go08@<00?o0000
o`224?l0PQ000_l0PQ000ol0003o078]o`1b;@03o`1b;@03o`000?l0Lbco07</00;o07</00?o0000
o`1T?ol000001?l0Ic`00ol0003o06Xho`000004o`1MAP05o`000?l0Hd7o06=1o`1S@Ol000000ol0
EdX00ol0003o05i5o`000006o`1CC0;o00001_l0Dd`00ol0003o04U<o`000004o`1GBP03o`000?l0
DDgo055=00?o055=00?o0000o`1;COl000000_l000000ol0FDWo0000o`1GBP04o`1GBP03o`000?l0
ET_o05I;00?o05I;00?o0000o`1GB_l0EdX01_l00002o`1W?003o`000?l0JSSo06Xh00;o06Xh00?o
0000o`1`<?l0L3000_l0L3000ol0003o07HVo`1f9P03o`1f9P04o`000?l0OQOo07hGo`1n5`Go0000
00?o07/Mo`000?l0QPL00ol0QPL00ol0003o4i40oa>A0003oa>A0003o`000?lfW@3o=Yd000;o=Yd0
00?o0000oejZ0?l000000_l00005ofj_0003o`000?nR_03oX[`000;oX[`00ol000000ono``3o0000
o`000004om2V0003o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool001Gooooo0ol0
00000ooh7@3o0000o`000006ooHY0003o`000?oa?03o000000Coje400_l00004onEW0003o`000?oN
OP3ogWh000;ogWh00ol00004olbc0003o`000?o1a03o`L@000;o`L@000Go0000oj:l0?nR_03oX[`0
o`000004ohNe00Co000000?o?j40o`000?l^V`001?l^V`000ol0003o8IL0ob6G0002ob6G0003o`00
0?lIT`3o000000?o08@<00?o0000o`224?l0PQ000_l0PQ000ol0003o084Bo`000003o`1b;@03o`00
0?l0Lbco07</00?o07</0_l00004o`1W?005o`000?l0JSSo06Xho`1Z>?l000000_l0GDH00ol0003o
06=1o`1S@@02o`1S@@04o`000?l0Ed[o05M:o`0000?o05i500?o0000o`1CC?l0Dd`00_l0Dd`00ol0
003o05a6o`000006o`1CC0;o00001Ol0EdX00ol0003o055=o`1AC@03o`1AC@;o00001Ol0FDT00ol0
003o05M:o`1GBP02o`1GBP03o`000?l0ET_o05I;00;o05I;1?l00003o`1T?`03o`000?l0Icco06Ll
00;o06Ll00?o0000o`1Z>?l0JSP00ol0JSP00ol0003o070`o`1`<002o`1`<003o`000?l0MRKo07HV
00?o07HV00Go0000o`1n5ol0OQOo07hGo`000003o`2710Ko000000?o08H7o`000?lCT@000olCT@00
0ol0003o=Yd0ocJM0003ocJM0004o`000?mNZP3oGZX0oejZ00?o00000om^[`001Ol0003oX[`0oj:l
0?nR_03o000000;obKT00ol00005om2V0003o`000?oooooooooo00kooooo00?o0000ooooooooool0
2?ooool001Oooooo0ol00007ooHY00Co00000_o[D@000ol0003oiFL0onEW0003onEW0003o`000?oN
OP3ogWh000;ogWh000Co0000omND0?oGU03oei@00_l000000oo</`3o0000ol740003ol740005o`00
0?nR_03oX[`0oj:l0?l000001?n7]@000ol0003oL:l0og2_0002og2_00;o00001?l^V`000ol0003o
8IL0ob6G0002ob6G0007o`000?lIT`3o6I<0oaVC0?l0003o08@<o`000004o`224007o`000?l0PA;o
084Bo`214_l0003o078]o`000005o`1c;003o`000?l0MBSo000000?o06Ll00?o0000o`1Z>?l0JSP0
0_l0JSP00ol0003o05e6o`000005o`1S@@03o`000?l0Ed[o000000Go05i500Co0000o`1CC?l0Ddco
00000ol0G4H00ol0003o05=<o`1CC002o`1CC003o`000?l0GTGo000000Ko05M:00?o0000o`1ACOl0
DDd00_l000000ol0GDKo0000o`1IB@04o`1IB@03o`000?l0Ed[o05M:00?o05M:1?l000000ol0Hcoo
0000o`1T?`05o`1T?`03o`000?l0Icco06Ll00;o06Ll00?o0000o`1Z>?l0JSP00_l0JSP00ol0003o
070`o`1`<002o`1`<003o`000?l0MRKo07HV00?o07HV00?o0000o`1n5ol0OQL00_l0OQL00ol0003o
08L4o`271002o`271004o`000?lCT@3o4i40oa>A00Go000000?o4i40o`000?lfW@001?lfW@001Ol0
003oGZX0oejZ0?mNZP3o000000;oSKL01?l00004oj:l0004o`000?o9^@3obKT0olVi00Co00000oo@
YP000ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooo
000000ComRT00_l00004oo8i00?o00001?oUI`000ol0003ogWh0omin0002omin0003o`000?oGU03o
ei@000?oei@01?l00002ol740005o`000?nR_03oX[`0oj:l0?l000001?n7]@000ol0003oL:l0og2_
0003og2_0006o`000?mNZP3o0000o`000?l^V`3o00001?lQU`000ol0003o6I<0oaVC0002oaVC00?o
00000ol0PQ000ol0003o084Bo`214P03o`214P03o`000?l0Lbco07</00?o07</00Oo0000o`1e:?l0
MBSo07DXo`000?l0Icco000000Ko06Xh00?o0000o`1S@Ol0Hd401Ol0Hd400ol0003o05i5o`1NA@04
o`1NA@03o`000?l0Ddco000000Go05a600Co0000o`1CC?l0Ddco00000ol0GTD00ol0003o05M:o`1G
BP03o`1GBP03o`000?l0DDgo000000Co05e600?o0000o`1IBOl0FDT00_l0FDT00ol0003o05M:o`1G
BP02o`1GBP;o00001Ol0Hcl00ol0003o06@oo`1T?`03o`1T?`03o`000?l0Icco06Ll00;o06Ll00?o
0000o`1Z>?l0JSP00ol0JSP00ol0003o070`o`1`<002o`1`<003o`000?l0MRKo07HV00;o07HV00?o
0000o`1n5ol0OQL00_l0OQL00ol0003o08L4o`271003o`271005o`000?lCT@3o4i40oa>A0?l00000
0olbW005o`0000;o=Yd000?o0000oejZ0?mNZP000_mNZP000ol0003oSKL0ohfg0002ohfg00Co0000
0_nR_0001Ol0003obKT0olVi0?o9^@3o000000;oeYL01?l0000?ooooo`03o`000?oooooooooo00So
oooo000Iooooo`04o`000?oooooo0000ooHY00;o00001Oob>@001?l0003okD/0one;0?o]B`02o`00
0003onEW0?l0003ogWh000?ogWh000?o0000omND0?oGU0000ooGU0000ol0003od:P0om2X0002om2X
00Co000000?oX[`0o`000?n7]@000on7]@000ol0003oL:l0og2_0003og2_0003o`000?mNZP3oGZX0
00;oGZX00_l00003ob6G0003o`000?lIT`3o6I<000;o6I<000Oo0000oa>A0?lCT@3o4i40o`000?l0
PQ3o000000Go084B00?o0000o`224?l000000ol0Lb`00ol0003o07DXo`1e:003o`1e:003o`000?l0
JSSo06Xh00Co06Xh0_l00006o`1S@@;o00001_l0GTD2o`0000Ko05a600?o0000o`1CC?l000001?l0
GTD00ol0003o05M:o`1GBP03o`1GBP;o00001Ol0GDH00ol0003o05U9o`1IB@03o`1IB@Co000000?o
06@oo`000?l0Hcl01?l0Hcl00ol0003o06@oo`1T?`03o`1T?`03o`000?l0Icco06Ll00;o06Ll00?o
0000o`1Z>?l0JSP00ol0JSP00ol0003o070`o`1`<002o`1`<003o`000?l0MRKo07HV00?o07HV00?o
0000o`1n5ol0OQL00_l0OQL00ol0003o08L4o`271002o`271003o`000?lCT@3o4i4000;o4i4000?o
0000oc:L0?lbW0000_lbW0000ol0003oEZP0oeJX0004o`0000?oGZX000?o0000ohfg0?n=]`000on=
]`000ol0003o`L@0ol740003o`0000?obKT00_l00004omJG00;o00003_ooool00ol0003ooooooooo
o`08ooooo`006_ooool01?l0003oooooo`000?l00005oo8i0003o`000?o]B`3okD/000?okD/01?l0
0002omin0003o`000?oGU03oei@000;oei@00_l00004om2X0003o`000?o9^@3obKT000;obKT00ol0
0002ohNe0003o`000?m`[`3oL:l000?oL:l000?o0000oejZ0?mNZP000_mNZP001_l0003oD:H0oe2V
0?l0003o8IL0o`0000Co6I<000?o0000oa>A0?lCT@000olCT@000ol0003o084Bo`214P03o`214P07
o`000?l0PQ3o088@o`224?l0003o07</o`000006o`1e:003o`000?l0JSSo06Xh00?o06Xh00Co0000
o`1`<?l0L33o00001?l0Hd401?l0003o06Tio`1Y>Ol00004o`1NA@03o`000?l0Icco000000Ko05a6
0_l00006o`1NA@03o`000?l0Ed[o05M:00;o000000?o06=1o`000?l0GDH01?l0GDH00ol0003o05U9
o`1IB@02o`1IB@;o00001Ol0I3l00ol0003o06<oo`1S?`03o`1S?`03o`000?l0I3oo06@o00?o06@o
00?o0000o`1W??l0Ic`00_l0Ic`00ol0003o06Xho`1Z>00Ao`000003o`1n5ol0003o08L400?o08L4
00?o0000oa>A0?lCT@000_lCT@000ol0003o<Y`0oc:L0003oc:L0003o`000?mFZ03oEZP000;oEZP0
0ol00002oejZ0003o`000?n=]`3oSKL000?oSKL000?o0000ol740?o1a0000_o1a003o`000003olVi
0?l0003o000000CoeYL000?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`000006ooooool0003o0000o`000?ob>@3o00001Oo]B`000ol0003oiel0onMO0002onMO00Co
00000_oGU0000ol0003od:P0om2X0003om2X0003o`000?o9^@3obKT000;obKT000Co0000oko30?no
``3o_l<00ol00004og2_0003o`000?mNZP3oGZX000;oGZX000?o0000oe2V0?m@YP000_m@YP02o`00
00?o6I<000?o0000oa>A0?lCT@001?lCT@02o`0000?o084B00?o0000o`224?l0PQ000ol0PQ000ol0
003o07DXo`1e:004o`1e:003o`000?l0NB;o000000?o06Xh00?o0000o`1`<?l0L3000_l0L3001?l0
003o06=1o`1S@Ol00004o`1Y>@04o`000?l0GTGo05i5o`0000?o06Ll00?o0000o`1LA_l0G4H00_l0
G4H00ol0003o06Llo`000006o`1NA@03o`000?l0Ed[o000000Co06=100?o0000o`1MA_l0GDH00ol0
GDH4o`000003o`1W??l0003o06@o00Co06@o00?o0000o`1S?ol0Hcl00ol0Hcl00ol0003o06@oo`1T
?`02o`1T?`Wo00000ol0NB800ol0003o07dIo`1m6@02o`1m6@03o`000?l0Q0co08@<00;o08@<00Co
0000o`B;0?l4R`3o18/01_l000000ol0Q`Co0000oa>A0003oa>A0003o`000?lbW03o<Y`000;o<Y`0
00?o0000oeJX0?mFZ0000_mFZ0000ol0003oPK@0oh6d0003o`0000GoSKL000?o0000ol740?o1a000
0_o1a0000ol0003od:P0om2X0003o`0000GoeYL000?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`07ooooo`007Oooool01?l0003oooooooooooooool2o`0000CokD/000?o0000onMO0?oWG`00
0_oWG`000ol0003ohG<0on5c0002on5c00?o00001?o@Z0000ol0003obKT0olVi0002olVi0003o`00
0?no``3o_l<000?o_l<000Ko0000ojRn0?l0003o0000og2_0?l00004oejZ0003o`000?m@YP3oD:H0
00?oD:H000Go0000odJS0?l0003o6I<0o`000006oa>A0006o`000?lBT@3o4Y40o`000?l0PA;o0000
1Ol0PQ02o`0000Go07DX00Oo0000o`1i8_l0NB;o07TRo`000?l0JSSo000000Go070`00?o0000o`1S
@Ol000001Ol0JCT00ol0003o05i5o`000005o`1W?004o`000?l0G4Ko05a6o`0000?o06Ll00?o0000
o`1NAOl0GTD00ol0GTD2o`0000Go06=100?o0000o`1MA_l0GDH00_l0GDH2o`0000Go06Ll00?o0000
o`1T?ol0I3l00ol0I3l00ol0003o06<oo`1S?`02o`1S?`03o`000?l0I3oo000000;o000000?o07</
o`000?l0MBP00ol0MBP00ol0003o07TRo`1i8P03o`1i8P03o`000?l0OAWo07dI00?o07dI00?o0000
o`243?l0Q0`00_l0Q0`00ol0003o18/0o`B;0002o`B;0004o`000?lJU03o6Y@0oaZD00Go000000?o
4i40o`000?lbW0001?lbW0000ol0003oEZP0oeJX0002oeJX0003o`000?n1]03oPK@000;oPK@01?l0
00000on=]`3o0000ol740004ol740003o`000?o@Z03od:P000;od:P01?l000000ooFU`3o0000oooo
o`0=ooooo`03o`000?oooooooooo00Oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00000
0oo]B`3o0000onMO0003onMO0003o`000?oQL`3ohG<000?ohG<000?o0000om^60?oKQP000_l00000
0oo@Z03o0000olVi0003olVi0003o`000?no``3o_l<000?o_l<000Co0000ojRn0?nX_P3oZ;h00ol0
0003oejZ0003o`000?m@YP3oD:H000?oD:H000Co0000odJS0?m6X`3oAZ<00_l00005oa>A0003o`00
0?lBT@3o4Y4000;o4Y4000?o0000o`224?l0PQ000ol0PQ001?l0003o08@<o`243?l00003o`1e:003
o`000?l0NB;o07TR00?o07TR00?o0000o`1`<?l0L3001Ol0L3000ol0003o06Tio`1Y>@04o`1Y>@;o
00001_l0Ic`00ol0003o05a6o`000005o`1W?003o`000?l0GTGo05i500;o000000?o06Tio`000?l0
Hd401?l0Hd400ol0003o05e6o`1MAP02o`000003o`1Z>?l0003o06Ll00Co06Ll00?o0000o`1T?ol0
I3l00ol0I3l01?l0003o06<oo`1S?ol0Hcl3o`0000Go07</00?o0000o`1e:?l0MBP00_l0MBP00ol0
003o07TRo`1i8P03o`1i8P03o`000?l0OAWo07dI00;o07dI00?o0000o`243?l0Q0`00_l0Q0`00ol0
003o18/0o`B;0003o`B;0005o`000?lJU03o6Y@0oaZD0?l000000olfW@06o`000003oc:L0?l0003o
EZP000?oEZP000?o0000oh6d0?n1]0000_n1]0001?l0003o/<00ok300?n``005o`0000;o`L@000?o
0000om2X0?o@Z0000_o@Z0001?l0003ofhH0om^60?oKQP03o`0000gooooo00?o0000ooooooooool0
1oooool001oooooo00?o0000ooooooooool00oooool3o`0000;oiel000?o0000on5c0?oQL`000ooQ
L`000ol0003ofhH0om^60003om^600?o00000_o9^@000ol0003o_l<0oko30003oko30005o`000?nX
_P3oZ;h0ojRn0?l000000onE^@000ol0003oGZX0o`000005oe2V0003o`000?m6X`3oAZ<000;oAZ<0
00?o0000od6Q0?l000000olCT@000ol0003o4Y40oa:A0003oa:A00;o00000ol0PQ000ol0003o08@<
o`243002o`243003o`000?l0MBSo000000Go07TR0_l00006o`1`<0;o00001Ol0JCT00ol0003o078]
o`000006o`1W?0;o00001_l0Ic`00ol0003o05i5o`000004o`1Y>@03o`000?l0Hd7o06=100?o06=1
0_l00004o`1Z>003o`000?l0Icco06Ll00?o06Ll00?o0000o`1T?ol0I3l00_l0I3l4o`0000;o078]
00?o0000o`1c;?l0Lb`00ol0Lb`00ol0003o07DXo`1e:002o`1e:003o`000?l0NB;o07TR00?o07TR
00?o0000o`1m6Ol0OAT00ol0OAT00ol0003o08@<o`243002o`243003o`000?l4R`3o18/000;o18/0
00?o0000oaZD0?lJU0000_lJU0000ol0003o=Yd0ocJM0002ocJM0004o`000?mFZ03oEZP0oeJX00Go
00000_mFZ0000ol0003oPK@0oh6d0002oh6d0003o`000?n``03o/<0000;o/<0000?o0000olbc0?o<
/`000ol00005om2X0003o`000?oKQP3ofhH000;ofhH000?o0000ooooooooool02oooool00ol0003o
ooooooooo`07ooooo`008?ooool2o`0000Kooooo0ol00004on5c0003o`000?oKQP3ofhH000?ofhH0
00Co0000omJG0?oFU`3oeYL00ol00004oko30005o`000?nX_P3oZ;h0ojRn0?l000001OnE^@02o`00
00CoD:H000?o0000odJS0?m6X`000_m6X`001ol0003o@J40od6Q0?m1X@3o0000oa>A0?l000001OlB
T@001_l0003o4i40oa>A0?l0003o088@o`0000Ko08@<00?o0000o`1i8_l0NB800ol0NB801?l0003o
07dIo`1m6Ol00004o`1`<004o`000?l0MRKo07HVo`0000?o06Ti00Go0000o`1b;Ol0LRgo078]o`00
0004o`1W?003o`000?l0L2oo000000Ko06Ll0_l00005o`1Y>@03o`000?l0Hd7o06=100;o06=10_l0
0005o`1Z>003o`000?l0Icco06Ll00?o06Ll00?o0000o`1T?ol000000_l000000ol0Lbco0000o`1b
;@04o`1b;@03o`000?l0Lbco07</00?o07</00?o0000o`1e:?l0MBP00_l0MBP00ol0003o07TRo`1i
8P02o`1i8P03o`000?l0OAWo07dI00?o07dI00?o0000o`243?l0Q0`00_l0Q0`00ol0003o18/0o`B;
0002o`B;0003o`000?lJU03o6Y@000;o6Y@000?o0000ocJM0?lfW@000olfW@000ol0003oEZP0oeJX
0002oeJX0003o`000?ml/P3oO;8000?o00001On1]0000ol0003o/<00ok300002ok300003o`000?o<
/`3oc;<000;oc;<01?l000000oo@Z03o0000o`000004om^60003o`000?oooooooooo00[ooooo00?o
0000ooooooooool01oooool002;ooooo00?o0000ooooooooool01_ooool2o`000003on5c0?l0003o
fhH000CofhH000Go0000omJG0?oFU`3oeYL0o`000003om2V00;o000000?o_l<0o`000?nX_P000_nX
_P000ol0003oUKT0oiFi0003oiFi0003o`000?n7]@3oQkD000;o000000?oD:H0o`000?m6X`000om6
X`000ol0003o@J40od6Q0003od6Q0003o`000?lBT@3o4Y4000?o4Y4000?o0000oa>A0?lCT@000_lC
T@000ol0003o08@<o`243004o`243003o`000?l0Q`Co000000?o07TR00?o0000o`1m6Ol0OAT00_l0
OAT01?l0003o070`o`1`<?l00004o`1f9P03o`000?l0JCWo000000Go078]00Co0000o`1W??l0Icco
00000ol0L2l00ol0003o06Llo`1W?002o`1W?003o`000?l0LRgo000000Go06Ti00?o0000o`1S@Ol0
Hd400_l000000ol0L33o0000o`1Z>005o`1Z>003o`000?l0Icco06Ll00;o06Ll0_l00005o`1c;003
o`000?l0LRgo078]00;o078]00?o0000o`1c;?l0Lb`00ol0Lb`00ol0003o07DXo`1e:002o`1e:003
o`000?l0NB;o07TR00?o07TR00?o0000o`1m6Ol0OAT00_l0OAT00ol0003o08@<o`243002o`243003
o`000?l4R`3o18/000?o18/000?o0000oaZD0?lJU0000_lJU0000ol0003o=Yd0ocJM0002ocJM0003
o`000?mFZ03oEZP000?oEZP000?o0000ogbb0?ml/P000_ml/P04o`000003oh6d0?l0003o/<0000?o
/<0000?o0000olbc0?o</`000_o</`001?l0003oei@0omND0?oGU005o`0000?ofhH000?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`008oooool00ol0003oooooooooo`07ooooo`;o
00001?oKQP001Ol0003oeYL0omJG0?oFU`3o000000God:H01?l000000onX_P3o0000oiFi0004oiFi
0003o`000?n7]@3oQkD000?oQkD00_l00003odJS0003o`000?m1X@3o@J4000?o@J4000?o0000ocnQ
0?l000000olBT@000ol0003o4i40oa>A0003oa>A0003o`000?l0Q0co08@<00?o08@<00Oo0000o`27
1?l0Q`Co08L4o`000?l0NB;o000000Go07dI00?o0000o`1`<?l000001_l0MRH00ol0003o078]o`1b
;@04o`1b;@03o`000?l0Icco000000Go070_00Co0000o`1W??l0Icco00000ol0LRd00ol0003o06Ti
o`1Y>@03o`1Y>@;o00001?l0L3000ol0003o06Xho`1Z>003o`1Z>003o`000?l0Icco000000;o0000
00?o07DXo`000?l0Lb`01?l0Lb`00ol0003o078]o`1b;@03o`1b;@03o`000?l0Lbco07</00;o07</
00Co0000o`1e:?l0MBSo07DX6ol000000olJU03o0000ocJM0004ocJM0003o`000?mFZ03oEZP000;o
EZP000?o0000ogbb0?ml/P000_ml/P001?l0003oZ;h0ojRn0?nX_P05o`0000;o/<0000?o0000olbc
0?o</`000_o</`000ol0003oei@0omND0002omND00;o000000?ohG<0o`000?l000000_l0000<oooo
o`03o`000?oooooooooo00Kooooo000Tooooo`03o`000?oooooooooo00Sooooo0_l000000ooKQP3o
0000omJG0002omJG0003o`000?o@YP3od:H000?od:H000?o0000olbc0?o</`000_o</`02o`0000Co
UKT000?o0000ohNe0?n7]@000on7]@001_l0003oO;80ogbb0?l0003oAZ<0o`0000Go@J4000Oo0000
ocnQ0?loX@3o?j40o`000?lBT@3o000000Go4i4000?o0000oaVC0?l000000ol0Q0`00ol0003o08L4
o`271003o`271003o`000?l0OAWo07dI00Go07dI00?o0000o`1f9_l0MRH01?l0MRH2o`0000Ko078]
0_l00006o`1`;`03o`000?l0Icco000000Co078]00?o0000o`1Y>Ol0JCT00_l0JCT2o`0000Go070`
00?o0000o`1Z>?l0JSP00ol0JSP2o`0000Go07DX00?o0000o`1c;?l0Lb`00ol0Lb`00ol0003o078]
o`1b;@02o`1b;@04o`000?l0Lbco07</o`1c;0Go00000_l0Q0`00ol0003o08L4o`271002o`271003
o`000?l6S03o1X`000?o1X`000?o0000oaFB0?lETP000_lETP000ol0003o:9T0obRI0002obRI0004
o`000?m1X@3o@J40od6Q00Ko000000?o=Yd0o`000?mFZ0000omFZ0000ol0003oO;80ogbb0003ogbb
0003o`000?nX_P3oZ;h000;oZ;h000?o0000olVj0?o9^P000ol00005olbc0003o`000?oGU03oei@0
00;oei@00_l00003on5c00;o00002oooool00ol0003oooooooooo`06ooooo`009Oooool2o`0000[o
oooo0ol000000ooFU`3o0000om2V0004om2V0003o`000?o</`3oc;<000?oc;<000Ko0000olNm0?l0
003o0000oiFi0?l00005ohNe0003o`000?ml/P3oO;8000;oO;8000?o0000od6Q0?m1X@000om1X@00
0ol0003o?j40ocnQ0003ocnQ0003o`000?lCT@3o4i4000?o4i4000Oo0000oaVC0?lIT`3o6I<0o`00
0?l0Q0co000000Ko08L400?o0000o`1m6Ol0OAT01?l0OAT2o`0000Go07HV00Co0000o`1n5ol0OQOo
00001?l0LRd00ol0003o07/Mo`000006o`1`;`;o00001Ol0LRd00ol0003o06Tio`1Y>@02o`000003
o`1f9_l0003o070`00Go070`00?o0000o`1Z>?l0JSP00_l000000ol0NB;o0000o`1e:004o`1e:003
o`000?l0Lbco07</00?o07</00?o0000o`1b;Ol0LRd00_l0LRd4o`0000;o088@00?o0000o`243?l0
Q0`00ol0Q0`00ol0003o08L4o`271002o`271003o`000?l6S03o1X`000?o1X`000?o0000oaFB0?lE
TP000_lETP000ol0003o:9T0obRI0002obRI0003o`000?m1X@3o@J4000;o@J4000Co0000oejZ0?mN
ZP3oGZX01_l000000omFZ03o0000ogbb0003ogbb0003o`000?nX_P3oZ;h000?oZ;h000?o0000olVj
0?o9^P000_o9^P04o`000003olbc0?l0003oei@000Coei@00_l00003on5c0003o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool02_ooool2o`0000Co
d:H000?o0000olbc0?o</`000oo</`000ol0003oakd0olNm0002olNm0003o`000?n7]@3oQkD000?o
QkD000?o0000ogbb0?ml/P000oml/P02o`0000?o@J4000?o0000ocnQ0?loX@001?loX@02o`0000?o
4i4000?o0000oaVC0?lIT`000olIT`000ol0003o08L4o`271004o`271003o`000?l6S03o000000Co
07dI00Co0000o`243?l0Q0co00000ol0MRH00ol0003o07hGo`1n5`02o`1n5`04o`000?l0LRgo078]
o`0000?o07/M00?o0000o`1`;ol0L2l00_l0L2l00ol0003o07/Mo`000006o`1b;@;o00001?l0MRH0
0ol0003o070`o`1`<003o`1`<003o`000?l0JSSo000000Co07TR00?o0000o`1e:?l0MBP00ol0MBP0
0ol0003o07</o`1c;002o`1c;003o`000?l0LRgo000000;o000000?o084Bo`000?l0PQ000ol0PQ00
0ol0003o08@<o`243003o`243003o`000?l0Q`Co08L400;o08L400?o0000o`J<0?l6S0000ol6S000
0ol0003o5I80oaFB0002oaFB0003o`000?lXV@3o:9T000;o:9T000?o0000od6Q0?m1X@000om1X@00
0ol0003oGZX0oejZ0002oejZ0004o`000?n1]03oPK@0oh6d00Go000000?oO;80o`000?nX_P001?nX
_P000ol0003obKX0olVj0002olVj0004o`000?oCW@3odid0om>M00Ko000000Coei@0o`000?oQL`3o
00000ooQL`000ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`00
0?oooooooooo00_ooooo0_l000000oo@YP3o0000olbc0004olbc0003o`000?o7_@3oakd000?oakd0
0_l00003ohNe0003o`000?ml/P3oO;8000?oO;8000Ko0000ogJa0?mf/@3o0000od6Q0?l00006ocnQ
0006o`000?m1X@3o@J40o`000?lCT@3o00001_lIT`000ol0003o08L4o`271003o`271005o`000?l6
S03o1X`0o`J<0?l000000_l0OAT00ol0003o08@<o`243002o`243003o`000?l0MRKo000000Go07hG
00?o0000o`1b;Ol000001Ol0Nad01?l0003o070_o`1`;ol00003o`1k7@03o`000?l0LRgo078]00;o
078]0_l00005o`1f9P03o`000?l0L33o070`00?o070`0_l00005o`1i8P03o`000?l0MBSo07DX00?o
07DX00?o0000o`1c;?l0Lb`00_l0Lb`2o`0000Co084B00?o0000o`224?l0PQ000ol0PQ000ol0003o
08@<o`243003o`243003o`000?l0Q`Co08L400;o08L400?o0000o`J<0?l6S0000_l6S0000ol0003o
5I80oaFB0003oaFB0003o`000?lXV@3o:9T000;o:9T000?o0000od6Q0?m1X@000_m1X@000ol0003o
GZX0oejZ0003oejZ0005o`000?n1]03oPK@0oh6d0?l000000onX_P05o`0000;oZ;h000?o0000olVj
0?o9^P000oo9^P000ol0003odid0om>M0002om>M0004o`000?oNOP3ogWh0omin00Ko000000?ohG<0
o`000?ooool02Oooool00ol0003oooooooooo`06ooooo`00:Oooool00ol0003oooooooooo`0<oooo
o`;o00001?o</`000ol0003oakd0olNm0003olNm0006o`000?o3a03o`l@0o`000?n7]@3o00001Oml
/P000ol0003oM[40ogJa0002ogJa00;o00001OloX@000ol0003o@J40od6Q0002od6Q0003o`000?lI
T`3o6I<000Co6I<000?o0000ob6G0?l000000ol0Q`@00ol0003o1X`0o`J<0002o`J<0003o`000?l0
OAWo000000Ko08@<00?o0000o`1n5ol0OQL01Ol0OQL00ol0003o07/Mo`1k7@04o`1k7@03o`000?l0
L2oo000000Co07/M00Oo0000o`1b;Ol0LRgo078]o`000?l0OQOo000000Ko07HV00?o0000o`1`<?l0
L3000_l000000ol0OAWo0000o`1i8P05o`1i8P03o`000?l0MBSo07DX00;o07DX00?o0000o`1c;?l0
00000_l000000ol0PQ3o0000o`214P04o`214P03o`000?l0PQ3o088@00;o088@00?o0000o`243?l0
Q0`00ol0Q0`00ol0003o08L4o`271002o`271003o`000?l6S03o1X`000?o1X`000?o0000oaFB0?lE
TP000_lETP000ol0003o:9T0obRI0002obRI0003o`000?m1X@3o@J4000?o@J4000?o0000oejZ0?mN
ZP000_mNZP000ol0003oPK@0oh6d0002oh6d0003o`000?nX_P3oZ;h000;oZ;h000?o0000olRl0?o8
_0001?l00004olVj0003o`000?oCW@3odid000?odid000?o0000omin0?oNOP000_oNOP001?l0003o
iel0o`000?oWG`03o`0000Wooooo00?o0000ooooooooool01_ooool002[ooooo0_l0000>ooooo`;o
000000?oc;<0o`000?o7_@001?o7_@000ol0003o`l@0ol?40002ol?400;o00001?ml/P000ol0003o
M[40ogJa0002ogJa0004o`000?md/03oM;00o`0000?o?j4000?o0000od6Q0?m1X@000om1X@000ol0
003o6I<0oaVC0003oaVC0007o`000?lQU`3o8IL0ob6G0?l0003o08L4o`000006o`J<0003o`000?l0
Q0co08@<00Co08@<0_l00006o`1n5`;o00001ol0Nad00ol0003o07/Mo`1k7@03o`1k7@04o`000?l0
LRgo078]o`0000?o07hG00?o0000o`1f9_l0MRH00ol0MRH00ol0003o070`o`000004o`1m6@03o`00
0?l0NB;o07TR00?o07TR00?o0000o`1e:?l0MBP00_l0MBP2o`0000Go088@00?o0000o`214_l0PA80
0_l0PA800ol0003o088@o`224002o`224003o`000?l0Q0co08@<00?o08@<00Co0000o`271?l0Q`Co
08L44_l00005od6Q0003o`000?mNZP3oGZX000;oGZX000?o0000oh6d0?n1]0000_n1]0000ol0003o
Z;h0ojRn0003ojRn0003o`000?o8_03ob;`000;ob;`01?l000000oo9^P3o0000om>M0004om>M0003
o`000?oNOP3ogWh000?ogWh000?o0000onMO0?l000000_oWG`000ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo000/ooooo`03o`000?oooooooooo00gooooo0_l00004olNm0003o`00
0?o3a03o`l@000;o`l@000?o0000okS20?nh`P000_l000000oml/P3o0000ogJa0003ogJa0003o`00
0?md/03oM;0000;oM;0000?o0000ocnQ0?l000001Om1X@000ol0003oAZ<0o`000003oaVC0003o`00
0?lQU`3o8IL000?o8IL000?o0000o`J<0?l6S0001?l6S002o`0000Go08@<00Co0000o`B;0?l4R`3o
00001?l0OQL01?l0003o08L4o`271?l00005o`1k7@;o00001_l0Nad2o`0000Co07hG00?o0000o`1f
9_l0MRH00ol0MRH2o`0000Go07dI00?o0000o`1i8_l0NB800ol0NB800ol0003o07DXo`000002o`00
0003o`243?l0003o088@00Co088@00?o0000o`214_l0PA800_l0PA800ol0003o088@o`224003o`22
4003o`000?l0Q0co08@<00Ko00000_lQU`000ol0003o;Y/0objK0002objK0003o`000?loX@3o?j40
00?o?j4000Co0000oeBW0?mDY`3oE:L02ol000000omNZP3o0000oh6d0003oh6d0003o`000?nX_P3o
Z;h000;oZ;h000?o0000olRl0?o8_0000_o8_0001?l0003odZ80om:R0?oBXP06o`000003om>M0?l0
003ogWh000CogWh000?o0000onMO0?l000000ooWG`000ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo000]ooooo`03o`000?oooooooooo00kooooo0_l000000oo7_@3o0000ol?40003
ol?40003o`000?nh`P3o^<8000?o^<800_l00003ogJa0003o`000?md/03oM;0000?oM;000_l00005
od6Q0007o`000?m6X`3oAZ<0odJS0?l0003o6I<0o`000005ob6G00;o00001Ol6S0001?l0003o5I80
oaFB0?l00003o`243003o`000?l4R`3o18/000;o18/000Co0000o`1n5ol0OQOo00000ol0Q`@00ol0
003o07/Mo`1k7@02o`1k7@04o`000?l0QPOo08H7o`0000Co07/M0_l00006o`1n5`03o`000?l0MRKo
07HV00;o000000?o08@<o`000?l0OAT01Ol0OAT00ol0003o07TRo`1i8P02o`1i8P;o00001Ol0Q0`0
0ol0003o088@o`224002o`224003o`000?l0PA;o084B00?o084B00?o0000o`224?l0PQ001Ol00003
oaVC0003o`000?lQU`3o8IL000?o8IL000?o0000objK0?l^V`000_l^V`000ol0003o?j40ocnQ0002
ocnQ0003o`000?mDY`3oE:L000;oE:L000?o0000ofj_0?m^[`000om^[`001?l0003oSKL0ohfg0?n=
]`05o`000003oh6d0?l0003oZ;h000CoZ;h000?o0000olRl0?o8_0000_o8_0000ol0003odZ80om:R
0002om:R0004o`000?oLQ@3og8D0omb500Ko000000GogWh0o`000?oWG`3oiel0o`000002onMO0003
o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool002kooooo00?o0000ooooooooool0
3oooool2o`0000?o`l@000?o0000okS20?nh`P000onh`P001_l0003o//00ok;00?l0003oM[40o`00
00GoM;0000Co0000ogJa0?mf/@3o00000om1X@000ol0003oAZ<0odJS0003odJS0003o`000?lQU`3o
8IL000?o8IL000Co0000objK0?l^V`3o00000ol6S0000ol0003o5I80oaFB0002oaFB0003o`000?l0
Q0co000000Go18/000?o0000o`1n5ol000001Ol0Q`@01?l0003o07/Mo`1k7Ol00003o`261`07o`00
0?l0Nago07/Mo`1k7Ol0003o08L4o`000006o`1n5`03o`000?l0MRKo000000Co08@<00?o0000o`1m
6Ol0OAT00ol0OAT00ol0003o07TRo`000002o`000003o`271?l0003o08@<00Co08@<00?o0000o`22
4?l0PQ000ol0PQ000ol0003o084Bo`214P05o`0000;o4i4000?o0000oaVC0?lIT`000olIT`000ol0
003o8IL0ob6G0003ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o0000ocnQ0?loX@000oloX@000ol0
003oE:L0oeBW0002oeBW0003o`000?m^[`3oKZl000;oKZl000?o0000ohfg0?n=]`000_n=]`001?l0
003o/<00ok300?n``006o`000003ojRn0?l0003ob;`000Cob;`000?o0000om:R0?oBXP000_oBXP00
0ol0003og8D0omb50002omb50004o`000?oUI`3oiFL0onEW00Ko000000?oiel0o`000?ooool02?oo
ool00ol0003oooooooooo`05ooooo`00;oooool00ol0003oooooooooo`0@ooooo`03o`000?o3a03o
000000Go^<8000?o0000ok;00?nb`0000_nb`0000ol0003oM;00ogB`0003ogB`0003o`000?mf/@3o
M[4000;oM[4000?o0000od6Q0?l000001Om6X`000ol0003oD:H0o`000003ob6G0003o`000?l^V`3o
;Y/000;o;Y/000?o0000o`J<0?l000001_lETP000ol0003o18/0o`B;0005o`B;0003o`000?l0Q`Co
08L400Co08L400?o0000o`1k7Ol000001?l0QPL01?l0003o07/Mo`1k7Ol00003o`271003o`000?l0
OQOo07hG00?o07hG0_l00005o`243003o`000?l0OAWo07dI00?o07dI0_l00005o`271003o`000?l0
Q0co08@<00;o08@<00?o0000o`224?l0PQ000_l0PQ04o`0000;o4Y4000?o0000oa>A0?lCT@000olC
T@000ol0003o6I<0oaVC0003oaVC0003o`000?lQU`3o8IL000?o8IL000?o0000objK0?l^V`000_l^
V`000ol0003o?j40ocnQ0002ocnQ0003o`000?mDY`3oE:L000;oE:L000?o0000ofj_0?m^[`000om^
[`000ol0003oSKL0ohfg0002ohfg0003o`000?n``03o/<0000;o/<0000Co0000olVj0?o9^P3obKX0
1_l000000oo8_03o0000om:R0004om:R0003o`000?oLQ@3og8D000;og8D000?o0000onEW0?oUI`00
0_oUI`001?l0003okD/0one;0?o]B`03o`0000Sooooo00?o0000ooooooooool01Oooool0033ooooo
0_l0000Aooooo`;o00001?nh`P000ol0003o//00ok;00003ok;000;o00000omd/0000ol0003oM[40
ogJa0004ogJa0003o`000?m6X`3oAZ<000?oAZ<000Oo0000oe2V0?m@YP3oD:H0o`000?lQU`3o0000
00Ko;Y/000?o0000oaFB0?lETP001?lETP02o`0000Ko18/00_l00006o`2710;o00001_l0QPL2o`00
00Co08L400?o0000o`1n5ol0OQL00_l0OQL00ol0003o18/0o`000006o`243003o`000?l0OAWo07dI
00;o000000?o1X`0o`000?l0Q`@01?l0Q`@00ol0003o08@<o`243003o`2430Co000000?o4i40o`00
0?lBT@001?lBT@000ol0003o4i40oa>A0002oa>A0003o`000?lIT`3o6I<000?o6I<000?o0000ob6G
0?lQU`000olQU`000ol0003o;Y/0objK0002objK0003o`000?loX@3o?j4000;o?j4000?o0000oeBW
0?mDY`000omDY`000ol0003oKZl0ofj_0002ofj_0003o`000?n=]`3oSKL000;oSKL000?o0000ok30
0?n``0000on``0000ol0003obKX0olVj0002olVj0004o`000?oBXP3odZ80om:R00Ko000000?odZ80
o`000?oLQ@001?oLQ@000ol0003oiFL0onEW0002onEW0006o`000?o]B`3okD/0o`000?o]B`3o0000
2?ooool00ol0003oooooooooo`05ooooo`00<_ooool00ol0003oooooooooo`0@ooooo`;o000000?o
^<80o`000?nb`0001?nb`0001_l0003o/<00ok300?l0003oM;00o`0000KoM[4000?o0000ogbb0?l0
00000om6X`000ol0003oD:H0oe2V0003oe2V0003o`000?l^V`3o;Y/000Co;Y/00_l00005oaFB0004
o`000?lXV@3o:9T0o`0000Co18/000Co0000oaZD0?lJU03o00001?l0Q`@00ol0003o4i40o`000006
o`261`03o`000?l0Q`Co08L400Co08L400Co0000o`1n5ol0OQOo00000ol4R`000ol0003o08@<o`24
3003o`243003o`000?l0OAWo000000?o1X`000?o0000o`271?l0Q`@00ol0Q`@00ol0003o08@<o`24
3002o`2430;o00001OlCT@000ol0003o4Y40oa:A0002oa:A0003o`000?lCT@3o4i4000?o4i4000?o
0000oaVC0?lIT`000_lIT`000ol0003o8IL0ob6G0003ob6G0003o`000?l^V`3o;Y/000;o;Y/000?o
0000ocnQ0?loX@000oloX@000ol0003oE:L0oeBW0002oeBW0003o`000?m^[`3oKZl000;oKZl000?o
0000ohfg0?n=]`000on=]`000ol0003o/<00ok300002ok300003o`000?o9^P3obKX000?obKX000?o
0000om:R0?oBXP000_oBXP001?l0003ofhL0om^70?oKQ`06o`000003omb50?l0003oiFL000CoiFL0
00Ko0000one;0?o]B`3o0000one;0?l00007ooooo`03o`000?oooooooooo00Gooooo000cooooo`03
o`000?oooooooooo017ooooo00?o0000ok;00?nb`0000onb`0000ol0003o/<00ok300002ok3000;o
00001Omf/@001ol0003oO;80ogbb0?ml/P3o0000odJS0?l000001_m@YP000ol0003o;Y/0objK0003
objK0004o`000?loX@3o?j40o`0000?o5I8000?o0000obRI0?lXV@000_lXV@001?l0003o18/0o`B;
0?l00004oaZD0004o`000?l0Q`Co08L4o`0000?o4i4000?o0000o`261ol0QPL00_l0QPL2o`0000Ko
08L400?o0000o`1n5ol000001?l4R`000ol0003o08@<o`243003o`2430;o00001Ol6S0000ol0003o
08L4o`271003o`2710Co000000?o6I<0o`000?lCT@001?lCT@000ol0003o4Y40oa:A0003oa:A0003
o`000?lCT@3o4i4000;o4i4000?o0000oaVC0?lIT`000olIT`000ol0003o8IL0ob6G000Go`000003
ofj_0?l0003oSKL000?oSKL000?o0000ok300?n``0000on``0000ol0003obKX0olVj0002olVj0003
o`000?oBXP3odZ8000?odZ8000?o0000om^70?oKQ`000_oKQ`001?l0003ohf`0on=/0?oSK006o`00
0003onEW0?l0003okD/000;okD/000?o0000one;0?l000001oooool00ol0003oooooooooo`04oooo
o`00=?ooool00ol0003oooooooooo`0Aooooo`05o`000?nb`03o//00ok;00?l000001On``0000ol0
003o//00o`000003ogJa0003o`000?ml/P3oO;8000?oO;8000?o0000oe2V0?m@YP001?m@YP000ol0
003oGZX0o`000003objK0003o`000?loX@3o?j4000;o?j4000?o0000oaFB0?l000001OlXV@000ol0
003o18/0o`000005oaZD0003o`000?l0Q`Co000000Go4i4000Co0000o`261ol0QPOo00000_lCT@00
0ol0003o08L4o`271003o`2710;o00001_l4R`000ol0003o08@<o`243002o`000003oaFB0?l0003o
1X`000Co1X`000?o0000o`271?l0Q`@00_l0Q`@2o`0000Go6I<000?o0000oa>A0?lCT@000olCT@00
0ol0003o4Y40oa:A0002oa:A0003o`000?lCT@3o4i4000;o4i4000Co0000oaVC0?lIT`3o6I<01Ol0
0003oe2V0003o`000?mNZP3oGZX000;oGZX000?o0000og2_0?m`[`000_m`[`000ol0003oQkD0ohNe
0003ohNe0004o`000?nR_03oX[`0oj:l00_o000000?o/<00o`000?o9^P000oo9^P000ol0003odZ80
om:R0003om:R0003o`000?oKQ`3ofhL000?ofhL000?o0000on=/0?oSK0000_oSK0001?l0003oje40
on]A0?o[D@09o`0000Kooooo00?o0000ooooooooool01?ooool003Gooooo0_l0000Booooo`03o`00
0?nb`03o000000Go/<0000Oo0000ok;00?nb`03o//00o`000?mf/@3o000000KoO;8000?o0000oe2V
0?m@YP000om@YP001ol0003oGZX0oejZ0?mNZP3o0000objK0?l000001_loX@000ol0003o:9T0obRI
0005obRI0003o`000?lJU03o6Y@000Go6Y@000?o0000oa>A0?lCT@001?lCT@000ol0003o08H7o`00
0003oa>A0003o`000?l0Q`Co08L400;o08L400?o0000oaZD0?l000001_l4R`000ol0003o08@<o`00
0003oaFB0003o`000?l6S03o1X`000?o1X`000?o0000o`271?l0Q`@00_l000000olQU`3o0000oaVC
0004oaVC0003o`000?lCT@3o4i4000?o4i4000?o0000oa:A0?lBT@000_lBT@001?l0003o4i40oa>A
0?lCT@05o`0000;oAZ<000?o0000oe2V0?m@YP000om@YP000ol0003oGZX0oejZ0002oejZ0003o`00
0?m`[`3oL:l000?oL:l000?o0000ohNe0?n7]@000_n7]@000ol0003oX[`0oj:l0002oj:l0003o`00
0?o1a03o`L@000?o`L@000Co0000olbc0?o</`3oc;<01_l000000oo9^P3o0000om:R0003om:R0003
o`000?oKQ`3ofhL000?ofhL000?o0000on=/0?oSK0000ooSK0000ol0003oje40on]A0002on]A0007
o`000?ob>@3olST0oo8i0?l0003olST0o`000006ooooo`03o`000?oooooooooo00Cooooo000goooo
o`03o`000?oooooooooo013ooooo00?o0000ok300?n``0000on``0000ol0003o//00ok;00003ok;0
0003o`000?ml/P3oO;8000CoO;8000?o0000ohNe0?l000000om@YP000ol0003oGZX0oejZ0003oejZ
0003o`000?loX@3o?j4000Go?j4000?o0000obRI0?lXV@001?lXV@02o`0000Ko6Y@00_l00006oa>A
00;o00001OlCT@001?l0003o08L4o`271?l00003oaZD0003o`000?l4R`3o18/000?o18/00_l00005
oaFB0003o`000?l6S03o1X`000?o1X`00_l00004ob6G0003o`000?lIT`3o6I<000?o6I<000?o0000
oa>A0?lCT@000_lCT@001?l0003o4Y40oa:A0?lBT@05o`0000;o@J4000?o0000odJS0?m6X`000om6
X`000ol0003oD:H0oe2V0003oe2V0003o`000?mNZP3oGZX000;oGZX000?o0000og2_0?m`[`000_m`
[`000ol0003oQkD0ohNe0003ohNe0003o`000?nR_03oX[`000;oX[`000?o0000ol740?o1a0000oo1
a0000ol0003oc;<0olbc0002olbc0004o`000?oCW@3odid0om>M00Go00000_oBXP000ol0003ofhL0
om^70002om^70003o`000?oSK03ohf`000?ohf`000?o0000on]A0?o[D@000oo[D@001ol0003olST0
oo8i0?ob>@3o0000oo8i0?l000001Oooool00ol0003oooooooooo`04ooooo`00>?ooool00ol0003o
ooooooooo`0@ooooo`05o`000?n``03o/<00ok300?l000001_nb`0000ol0003oO;80ogbb0003ogbb
0007o`000?n7]@3oQkD0ohNe0?l0003oD:H0o`000006oejZ0003o`000?loX@3o?j4000Co?j4000?o
0000oeBW0?l000001?lXV@001?l0003o@J40od6Q0?l00004oaZD0004o`000?lfW@3o=Yd0o`0000Co
4i4000?o0000oc:L0?l000001OlCT@000ol0003o08L4o`000004oaZD0003o`000?l4R`3o18/000;o
18/000?o0000obRI0?l000001OlETP000ol0003o1X`0o`J<0002o`J<00;o00001OlQU`000ol0003o
6I<0oaVC0003oaVC0003o`000?lCT@3o4i4000;o4i401?l00002ocnQ0003o`000?m1X@3o@J4000?o
@J4000?o0000odJS0?m6X`000_m6X`000ol0003oD:H0oe2V0003oe2V0003o`000?mNZP3oGZX000;o
GZX000?o0000og2_0?m`[`000om`[`000ol0003oQkD0ohNe0002ohNe0003o`000?nR_03oX[`000;o
X[`000?o0000ol740?o1a0000oo1a0000ol0003oc;<0olbc0003olbc0005o`000?oCW@3odid0om>M
0?l000000ooLQ@0<o`000003on=/0?l0003oje4000Coje4000?o0000oo8i0?ob>@000_ob>@02o`00
00Gooooo00?o0000ooooooooool01?ooool003Wooooo00?o0000ooooooooool04?ooool00ol0003o
/<00o`000006ok;00003o`000?nh`P3o000000?oO;8000?o0000ohNe0?n7]@000on7]@000ol0003o
GZX0oejZ0004oejZ0003o`000?m`[`3o000000Co?j4000Go0000oeBW0?mDY`3oE:L0o`000002obRI
0003o`000?m1X@3o@J4000;o@J4000Co0000oaZD0?lJU03o00001?lfW@001?l0003o4i40oa>A0?l0
0003oc:L0003o`000?lCT@3o4i4000;o4i400_l00006oaZD0004o`000?l4R`3o18/0o`0000;o:9T0
00?o0000oaFB0?lETP000olETP000ol0003o1X`0o`J<0002o`000003objK0?l0003o8IL000Go8IL0
00?o0000oaVC0?lIT`000_lIT`000ol0003o4i40o`000002o`000003od6Q0?l0003o?j4000Co?j40
00?o0000od6Q0?m1X@000_m1X@000ol0003oAZ<0odJS0003odJS0003o`000?m@YP3oD:H000;oD:H0
00?o0000oejZ0?mNZP000_mNZP000ol0003oL:l0og2_0003og2_0003o`000?n7]@3oQkD000;oQkD0
00?o0000oj:l0?nR_0000onR_0000ol0003o`L@0ol740002ol740003o`000?o</`3oc;<000?oc;<0
00?o0000om>M0?oCW@000_oCW@000ol0003og8D0omb50002omb50003o`000?oSK03ohf`000?ohf`0
00Co0000on]C0?o[D`3oje<03ol00004ooooo`03o`000?oooooooooo00Cooooo000jooooo`;o0000
4Oooool2o`0000Go//0000Oo0000okS20?nh`P3o^<80o`000?ml/P3o000000GoQkD00_l00005oejZ
0005o`000?m`[`3oL:l0og2_0?l000000_loX@000ol0003oE:L0oeBW0002oeBW0003o`000?lXV@3o
000000Go@J4000?o0000oaZD0?l000001OlfW@000ol0003o4i40o`000004oc:L0007o`000?lCT@3o
4i40oa>A0?l0003o=Yd0o`000006oaZD0003o`000?l4R`3o000000Co:9T000?o0000oaFB0?lETP00
0olETP02o`0000Co;Y/000?o0000ob6G0?lQU`000olQU`000ol0003o6I<0oaVC0002oaVC00;o0000
1Om1X@000ol0003o?j40ocnQ0002ocnQ0003o`000?m1X@3o@J4000?o@J4000?o0000odJS0?m6X`00
0_m6X`000ol0003oD:H0oe2V0003oe2V0003o`000?mNZP3oGZX000;oGZX000?o0000og2_0?m`[`00
0_m`[`000ol0003oQkD0ohNe0003ohNe0003o`000?nR_03oX[`000;oX[`000?o0000ol740?o1a000
0oo1a0000ol0003oc;<0olbc0002olbc0003o`000?oCW@3odid000;odid000?o0000omb50?oLQ@00
0ooLQ@000ol0003ohf`0on=/0003on=/0003o`000?o[D`3oje<000;oje<000?o0000oo4l0?oa?000
0ooa?0000ol0003omRT0ooHY0002ooHY00;o00001?ooool00ol0003oooooooooo`04ooooo`00??oo
ool00ol0003oooooooooo`0@ooooo`05o`000?nb`03o//00ok;00?l000001Onh`P000ol0003oQkD0
ohNe0003ohNe0004o`000?nE^@3oUKT0o`0000?oGZX000?o0000og2_0?m`[`000_m`[`000ol0003o
?j40o`000006oeBW0003o`000?m1X@3o@J4000Go@J4000?o0000ocJM0?lfW@001OlfW@000ol0003o
<Y`0oc:L0003oc:L0004o`000?lCT@3o4i40o`0000?o=Yd000?o0000oaZD0?lJU0000olJU002o`00
00Go:9T000?o0000oaFB0?lETP000_lETP02o`0000Go;Y/000?o0000ob6G0?lQU`000olQU`000ol0
003o6I<0o`000002o`000003odJS0?l0003o@J4000Co@J4000?o0000ocnQ0?loX@000oloX@000ol0
003o@J40od6Q0002od6Q0004o`000?m6X`3oAZ<0odJS02Ko00000_o</`000ol0003odid0om>M0002
om>M0003o`000?oLQ@3og8D000?og8D000?o0000on=/0?oSK0000_oSK0000ol0003oje<0on]C0003
on]C0003o`000?oa?03olC`000?olC`000?o0000ooHY0?of:@000_of:@02o`0000Cooooo00?o0000
ooooooooool00oooool003gooooo00?o0000ooooooooool04?ooool00ol0003o//00o`000005okS2
0003o`000?o3a03o000000?oQkD000?o0000oiFi0?nE^@000_nE^@000ol0003oGZX0o`000006og2_
0003o`000?mDY`3oE:L000CoE:L00_l00006od6Q00;o00001_lfW@02o`0000Ko<Y`00_l00004ocJM
0003o`000?lJU03o6Y@000;o6Y@000?o0000od6Q0?l000001OlXV@000ol0003o5I80oaFB0002o`00
0003ocnQ0?l0003o;Y/000Go;Y/000?o0000ob6G0?lQU`000_lQU`02o`0000CoAZ<000?o0000od6Q
0?m1X@001?m1X@000ol0003o?j40ocnQ0002ocnQ0004o`000?m1X@3o@J40od6Q00Go00000_ml/P00
0ol0003oQkD0ohNe0002ohNe0003o`000?nE^@3oUKT000;oUKT000?o0000ojRn0?nX_P000onX_P00
0ol0003o_/<0okk30002okk30003o`000?o9^@3obKT000?obKT000?o0000om2X0?o@Z0000_o@Z000
1?l0003oei@0omND0?oGU006o`000003om>M0?l0003og8D000Cog8D000?o0000on=/0?oSK0000_oS
K0000ol0003oje<0on]C0003on]C0003o`000?oa?03olC`000?olC`000?o0000ooHY0?of:@000oof
:@000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo000nooooo`03o`000?oooooo
oooo013ooooo00?o0000okS20?nh`P000onh`P001ol0003o`l@0ol?40?o3a03o0000ohNe0?l00000
1_nE^@000ol0003oL:l0og2_0004og2_00;o00001OmDY`001?l0003oKZl0ofj_0?l00004od6Q0004
o`000?mNZP3oGZX0o`0000Co=Yd000Co0000oeJX0?mFZ03o00001?lbW002o`0000Ko=Yd000Co0000
oaZD0?lJU03o00000om1X@000ol0003o:9T0obRI0003obRI00;o00001?loX@000ol0003o;Y/0objK
0003objK0003o`000?lQU`3o000000;o000000?oD:H0o`000?m6X`001?m6X`000ol0003o@J40od6Q
0003od6Q0003o`000?loX@3o?j4000;o?j401?l00002ogJa0003o`000?ml/P3oO;8000?oO;8000?o
0000ohNe0?n7]@000_n7]@000ol0003oUKT0oiFi0002oiFi0003o`000?nX_P3oZ;h000?oZ;h000?o
0000okk30?nn``000_nn``000ol0003obKT0olVi0003olVi0003o`000?o@Z03od:P000;od:P000?o
0000omND0?oGU0000_oGU0001?l0003ogWh0omin0?oNOP0Ao`000003on]C0?l0003olC`000;olC`0
2_l00003ooooo`03o`000?oooooooooo00?ooooo000oooooo`03o`000?oooooooooo013ooooo00Go
0000okS20?nh`P3o^<80o`000005ol?40003o`000?nE^@3oUKT000CoUKT00_l00005og2_0004o`00
0?n7]@3oQkD0o`0000?oE:L000?o0000ofj_0?m^[`000_m^[`001?l0003o@J40od6Q0?l00004oejZ
0004o`000?lfW@3o=Yd0o`0000?oEZP000Oo0000oc:L0?lbW03o<Y`0o`000?mFZ03o000000Ko=Yd0
00?o0000oaZD0?l000001?m1X@000ol0003o:9T0obRI0002obRI00;o00001OloX@000ol0003o;Y/0
objK0003objK00;o00001?m@YP000ol0003oAZ<0odJS0003odJS0003o`000?m1X@3o@J4000?o@J40
00?o0000ocnQ0?l000000_l000000omd/03o0000ogJa0003ogJa0003o`000?ml/P3oO;8000?oO;80
00?o0000ohNe0?n7]@000_n7]@000ol0003oUKT0oiFi0002oiFi0003o`000?nX_P3oZ;h000?oZ;h0
00?o0000okk30?nn``000_nn``000ol0003obKT0olVi0003olVi0003o`000?o@Z03od:P000;od:P0
00?o0000omND0?oGU0000ooGU0000ol0003ogWh0omin0002omin0003o`000?oUI`3oiFL000?oiFL0
00?o0000on]A0?o[D@000_o[D@001?l0003olC`0oo4l0?oa?005o`0000?omBX000?o0000ooPM0?oh
7@000ooh7@001Ol0003ooooooooooooooooo000000Gooooo0010ooooo`;o00004Oooool00ol0003o
^<80o`000005ol?400;o00001OnE^@001?l0003oZ;h0ojRn0?l00003og2_0003o`000?n7]@3oQkD0
00;oQkD000?o0000oeBW0?l000001Om^[`000ol0003o@J40o`000005oejZ0003o`000?lfW@3o0000
00CoEZP000Co0000oc:L0?lbW03o00000omFZ0000ol0003o=Yd0ocJM0003ocJM00;o00001Om1X@00
0ol0003o:9T0obRI0002o`000003oeBW0?l0003o?j4000Go?j4000?o0000objK0?l^V`000_l00000
0omNZP3o0000oe2V0004oe2V0003o`000?m6X`3oAZ<000;oAZ<000?o0000od6Q0?m1X@000om1X@02
o`0000CoM;0000?o0000ogJa0?mf/@000omf/@000ol0003oO;80ogbb0003ogbb0003o`000?n7]@3o
QkD000;oQkD000?o0000oiFi0?nE^@000_nE^@000ol0003oZ;h0ojRn0002ojRn0003o`000?nn``3o
_/<000?o_/<000?o0000olVi0?o9^@000_o9^@000ol0003od:P0om2X0003om2X0003o`000?oGU03o
ei@000;oei@000?o0000omin0?oNOP000ooNOP000ol0003oiFL0onEW0003onEW0003o`000?o[D@3o
je4000;oje4000?o0000oo4l0?oa?0000_oa?0000ol0003omBX0ooDZ0004ooDZ0003o`000?oh7@3o
n1d000?on1d000Co0000oooooooooooo00001Oooool004;ooooo00?o0000ooooooooool03oooool0
0ol0003o`l@0ol?40003ol?40004o`000?o7_@3oakd0o`0000?oUKT000?o0000ojRn0?nX_P000_nX
_P000ol0003oL:l0o`000006ohNe0003o`000?m^[`3oKZl000GoKZl000?o0000oejZ0?mNZP001OmN
ZP000ol0003oEZP0oeJX0004oeJX00;o00001OmFZ0000ol0003o=Yd0ocJM0002o`000003oejZ0?l0
003o@J4000Go@J400_l00004oeBW0003o`000?loX@3o?j4000?o?j4000?o0000objK0?l000001?mN
ZP000ol0003oD:H0oe2V0002oe2V0003o`000?m6X`3oAZ<000?oAZ<000?o0000od6Q0?l000000_l0
00000omf/@3o0000ogB`0004ogB`0003o`000?mf/@3oM[4000;oM[4000?o0000ogbb0?ml/P000oml
/P000ol0003oQkD0ohNe0002ohNe0003o`000?nE^@3oUKT000;oUKT000?o0000ojRn0?nX_P000onX
_P000ol0003o_/<0okk30002okk30003o`000?o9^@3obKT000?obKT000?o0000om2X0?o@Z0000_o@
Z0000ol0003oei@0omND0003omND0003o`000?oNOP3ogWh000;ogWh000?o0000onEW0?oUI`000ooU
I`000ol0003oje40on]A0003on]A0003o`000?oa?03olC`000;olC`000?o0000ooDZ0?oe:P000ooe
:P001?l0003on1d0ooPM0?oh7@04o`000003ooooool0003ooooo00Cooooo0013ooooo`03o`000?oo
oooooooo00oooooo00Go0000ol?40?o3a03o`l@0o`000004olNm0003o`000?nE^@3o000000KoZ;h0
00?o0000ohNe0?n7]@001?n7]@02o`0000KoKZl00_l00006oejZ00;o00001OmFZ002o`0000KoEZP0
00?o0000ocJM0?l000001?mNZP000ol0003o@J40od6Q0002od6Q00;o00001OmDY`000ol0003o?j40
ocnQ0003ocnQ00;o00001OmNZP000ol0003oD:H0oe2V0002oe2V0003o`000?m6X`3oAZ<000;oAZ<0
0ol00004ogJa0003o`000?md/03oM;0000?oM;0000?o0000ogJa0?mf/@000_mf/@000ol0003oO;80
ogbb0003ogbb0004o`000?n7]@3oQkD0ohNe027o000000?oei@0o`000?oNOP000ooNOP000ol0003o
iFL0onEW0003onEW0003o`000?o[D@3oje4000?oje4000?o0000oo4l0?oa?0000ooa?0001?l0003o
mBX0ooDZ0?oe:P05o`0000?onAT00ol00005ooooo`00A?ooool00ol0003oooooooooo`0?ooooo`03
o`000?o3a03o000000Koakd000?o0000ojRn0?nX_P001?nX_P02o`0000GoQkD000Co0000oj:l0?nR
_03o00001?m^[`001?l0003oSKL0ohfg0?l00004oejZ0004o`000?n1]03oPK@0o`0000?oEZP000?o
0000ogbb0?l000001_mFZ002o`0000KoGZX000Ko0000od6Q0?m1X@3o0000ofj_0?l00006oeBW0003
o`000?loX@3o?j4000;o000000?oL:l0o`000?mNZP001OmNZP000ol0003oD:H0oe2V0002oe2V00Co
000000?oO;80o`000?mf/@001Omf/@000ol0003oM;00ogB`0002ogB`0003o`000?mf/@3oM[4000?o
M[4000?o0000ogbb0?ml/P001_l00002ol?40003o`000?o7_@3oakd000;oakd000?o0000olbc0?o<
/`000_o</`000ol0003od:H0om2V0003om2V0003o`000?oFU`3oeYL000;oeYL000?o0000om^60?oK
QP000ooKQP001?l0003ohG<0on5c0?oQL`0Lo`0000?on1d000?o0000ooTI0?oi6@000ooi6@03o`00
00Cooooo0015ooooo`;o00004?ooool00ol0003oakd0olNm0004olNm00;o00001OnX_P001?l0003o
_l<0oko30?l00003ohNe0003o`000?nR_03oX[`000;oX[`000Co0000ofj_0?m^[`3o00001?n=]`00
1?l0003oGZX0oejZ0?l00003oh6d0004o`000?mFZ03oEZP0o`0000?oO;8000?o0000oeJX0?mFZ000
0_mFZ0000ol0003oPK@0o`000006oejZ0003o`000?m1X@3o000000?oKZl000?o0000oeBW0?mDY`00
0omDY`000ol0003o?j40o`000004og2_0003o`000?mNZP3oGZX000?oGZX000Co0000oe2V0?m@YP3o
D:H00_l00005ogbb0003o`000?mf/@3oM[4000?oM[4000?o0000ogB`0?md/0000omd/0000ol0003o
M[40ogJa0005o`0000?o^<8000?o0000ol?40?o3a0000_o3a0000ol0003oakd0olNm0003olNm0003
o`000?o</`3oc;<000;oc;<000?o0000om2V0?o@YP000oo@YP000ol0003oeYL0omJG0002omJG0003
o`000?oKQP3ofhH000?ofhH000?o0000on5c0?oQL`000_oQL`000ol0003oiel0onMO0002onMO0003
o`000?o]B`3okD/000?okD/000?o0000oo8i0?ob>@000oob>@000ol0003omRT0ooHY0003ooHY0003
o`000?oh7@3on1d000Con1d000?o0000ooTI0?l000000_l000000ooooooo0000o`000004ooooo`00
Aoooool00ol0003oooooooooo`0=ooooo`03o`000?o7_@3oakd000?oakd000Co0000olbc0?o</`3o
00000onX_P000ol0003o_l<0oko30002oko30003o`000?n7]@3o000000GoX[`000?o0000ofj_0?l0
00001On=]`000ol0003oGZX0o`000004oh6d0003o`000?mFZ03o000000GoO;8000Co0000oeJX0?mF
Z03o00000on1]0000ol0003oGZX0oejZ0003oejZ00;o00001?m^[`000ol0003oE:L0oeBW0003oeBW
00;o00001Om`[`000ol0003oGZX0oejZ0003oejZ0006o`000?m@YP3o0000o`000?n7]@3o00001Oml
/P000ol0003oM[40ogJa0003ogJa0003o`000?md/03oM;0000;oM;001?l00002ok;00003o`000?nh
`P3o^<8000?o^<8000?o0000ol?40?o3a0000oo3a0000ol0003oakd0olNm0002olNm0003o`000?o<
/`3oc;<000;oc;<000?o0000om2V0?o@YP000oo@YP000ol0003oeYL0omJG0002omJG0003o`000?oK
QP3ofhH000?ofhH000?o0000on5c0?oQL`000ooQL`000ol0003oiel0onMO0002onMO0003o`000?o]
B`3okD/000?okD/000?o0000oo8i0?ob>@000oob>@000ol0003omRT0ooHY0003ooHY0004o`000?oh
7@3on1d0ooPM00Co00000oooool3o`0000Cooooo0018ooooo`03o`000?oooooooooo00gooooo00Go
0000olNm0?o7_@3oakd0o`000004olbc0003o`000?nX_P3o000000Ko_l<000?o0000oj:l0?nR_000
1?nR_002o`0000KoSKL00_l00006oh6d0003o`000?ml/P3oO;8000CoO;8000?o0000oeJX0?l00000
1?n1]0000ol0003oGZX0oejZ0002oejZ0003o`000?n=]`3o000000GoKZl000?o0000oeBW0?mDY`00
0_l000000on7]@3o0000og2_0005og2_0003o`000?mNZP3oGZX000;oGZX00_l00004ohNe0003o`00
0?ml/P3oO;8000?oO;8000?o0000ogJa0?mf/@000omf/@04o`000003ok2o0?l0003o//0000Co//00
00?o0000okS20?nh`P000onh`P000ol0003o`l@0ol?40002ol?40003o`000?o7_@3oakd000?oakd0
00?o0000olbc0?o</`000_o</`000ol0003od:H0om2V0002om2V0003o`000?oFU`3oeYL000?oeYL0
00?o0000om^60?oKQP000_oKQP000ol0003ohG<0on5c0003on5c0003o`000?oWG`3oiel000?oiel0
00?o0000one;0?o]B`000_o]B`000ol0003olST0oo8i0003oo8i0004o`000?of:@3omRT0ooHY00Ko
00000oooool4o`0000Oooooo0019ooooo`03o`000?oooooooooo00gooooo00?o0000olNm0?l00000
1_o</`000ol0003o_l<0oko30004oko300;o00001OnR_0000ol0003o`L@0o`000005ohfg0003o`00
0?n``03o000000GoPK@00_l00007ogbb0003o`000?n1]03oPK@000CoPK@000Co0000oejZ0?mNZP3o
00000on=]`000ol0003oKZl0ofj_0002ofj_0003o`000?mDY`3o000000CoQkD000?o0000og2_0?m`
[`000om`[`000ol0003oGZX0o`000002o`000003oiFi0?l0003oQkD000?oQkD000?o0000ogbb0?ml
/P000oml/P001?l0003oM[40ogJa0?mf/@03o`0000Go/;l000?o0000ok;00?nb`0000_nb`0000ol0
003o^<80okS20003okS20003o`000?o3a03o`l@000;o`l@000?o0000olNm0?o7_@000oo7_@000ol0
003oc;<0olbc0002olbc0003o`000?o@YP3od:H000?od:H000?o0000omJG0?oFU`000_oFU`000ol0
003ofhH0om^60003om^60003o`000?oQL`3ohG<000;ohG<000?o0000onMO0?oWG`000ooWG`001?l0
003okD/0one;0?o]B`0;o`0000Gooooo1?l0000;ooooo`00B_ooool2o`0000kooooo00?o0000olbc
0?o</`001?o</`02o`0000Go_l<000Co0000olVi0?o9^@3o00000onR_0001Ol0003o`L@0ol740?o1
a03o000000?oSKL000Go0000ok300?n``03o/<00o`000003oh6d0004o`000?nX_P3oZ;h0o`0000Go
O;800_l00006oh6d0003o`000?mNZP3o000000CoSKL000?o0000ofj_0?m^[`000_m^[`02o`0000Go
QkD000?o0000og2_0?m`[`000om`[`02o`0000GoUKT000?o0000ohNe0?n7]@000_n7]@000ol0003o
O;80ogbb0002ogbb00Co00000_nb`0000ol0003o/;l0ok2o0003ok2o0003o`000?nb`03o//0000?o
//0000?o0000okS20?nh`P000_nh`P000ol0003o`l@0ol?40003ol?40003o`000?o7_@3oakd002Oo
00003Oooool3o`0000oooooo001<ooooo`03o`000?oooooooooo00_ooooo00?o0000olbc0?o</`00
0oo</`001?l0003od:H0om2V0?l00003oko30003o`000?o9^@3obKT000;obKT000?o0000oj:l0?l0
00001Oo1a0000ol0003oSKL0o`000004ok300004o`000?n1]03oPK@0o`0000?oZ;h000?o0000ogbb
0?ml/P000_ml/P001?l0003oZ;h0ojRn0?l00005oh6d00;o00001On=]`000ol0003oKZl0ofj_0002
o`000003oj:l0?l0003oQkD000GoQkD000?o0000og2_0?m`[`000_l000000onX_P3o0000oiFi0004
oiFi0003o`000?n7]@3oQkD000;oQkD000?o0000ogbb0?l000000_l000000onh`P3o0000ok;00004
ok;00003o`000?n`_`3o/;l000?o/;l000?o0000ok;00?nb`0000_nb`0000ol0003o^<80okS20003
okS20003o`000?o3a03o`l@000Go0000<?ooool4o`0001;ooooo001=ooooo`03o`000?oooooooooo
00_ooooo00Go0000olbc0?o</`3oc;<0o`000004om2V0003o`000?no``3o000000KobKT000?o0000
ol740?o1a0001Oo1a0000ol0003o/<00ok300003ok300003o`000?n1]03o000000GoZ;h000Co0000
ogbb0?ml/P3o00000onX_P000ol0003oPK@0oh6d0002oh6d0003o`000?n``03o000000KoSKL00_l0
0004oj:l0003o`000?n7]@3oQkD000?oQkD000?o0000og2_0?l000000onX_P000ol0003oUKT0oiFi
0003oiFi0003o`000?n7]@3oQkD000;oQkD00_l00005okS20003o`000?nb`03o//0000;o//0000?o
0000ok2o0?n`_`000on`_`000ol0003o//00ok;00002ok;000Wo0000<Oooool4o`0001Kooooo001>
ooooo`03o`000?oooooooooo00_ooooo00?o0000olbc0?l000001Oo@YP02o`0000KobKT00_l00006
ol7400;o00001_n``0000ol0003oZ;h0ojRn0004ojRn0003o`000?ml/P3o000000GoZ;h000Co0000
oh6d0?n1]03o00000on``0000ol0003oSKL0ohfg0002ohfg00;o00001OnR_0000ol0003oQkD0ohNe
0003ohNe00;o00001OnX_P000ol0003oUKT0oiFi0003oiFi00Co000000?o`l@0o`000?nh`P001?nh
`P000ol0003o//00ok;00003ok;00003o`000?n`_`3o/;l000;o/;l000?o0000ok;00?l000000_l0
000fooooo`Co00006_ooool004oooooo00?o0000ooooooooool02oooool00ol0003od:H0om2V0003
om2V0003o`000?oFU`3o000000GobKT000Co0000om2X0?o@Z03o00001?o1a0001?l0003oc;<0olbc
0?l00004ok3000;o00001_nX_P02o`0000KoZ;h000?o0000oh6d0?l000001?n``0001ol0003oSKL0
ohfg0?n=]`3o0000ol740?l000001_nR_0000ol0003oQkD0ohNe0002o`000003okk30?l0003oZ;h0
00CoZ;h000?o0000oiFi0?nE^@000_nE^@02o`0000Go`l@000?o0000okS20?nh`P000onh`P000ol0
003o//00ok;00002ok;00004o`000?n`_`3o/;l0ok2o00?o0000=Oooool4o`0001kooooo001@oooo
o`;o00003?ooool01Ol0003od:H0om2V0?o@YP3o000000?oeYL000Go0000olVi0?o9^@3obKT0o`00
0004om2X0004o`000?o1a03o`L@0o`0000Coc;<000Co0000ok300?n``03o00000_o9^P000ol0003o
Z;h0ojRn0002ojRn0003o`000?o8_03o000000KoZ;h00_l00005ok300004o`000?n=]`3oSKL0o`00
00?o`L@000?o0000oj:l0?nR_0000onR_0000ol0003oQkD0o`000004okk30003o`000?nX_P3oZ;h0
00;oZ;h000?o0000oiFi0?nE^@000_l000000oo7_@3o0000ol?40004ol?40003o`000?nh`P3o^<80
00?o^<8000?o0000ok;00?nb`0000_nb`004o`0003Cooooo1?l0000Rooooo`00D_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?o@YP3o000000GoeYL000?o0000olVi0?l000001Oo@Z0000ol0003o
`L@0o`000005olbc0003o`000?n``03o000000CobKX000Co0000ojRn0?nX_P3o00000oo8_0000ol0
003oZ;h0ojRn0002ojRn0003o`000?o9^P3o000000Ko/<000_l00004ol740003o`000?nR_03oX[`0
00?oX[`00_l00005okk30003o`000?nX_P3oZ;h000?oZ;h00_l00004olNm0003o`000?o3a03o`l@0
00?o`l@000?o0000okS20?nh`P000_nh`P000ol0003o//00o`000002o`0003Gooooo0ol0000Voooo
o`00Doooool00ol0003oooooooooo`0:ooooo`03o`000?oFU`3oeYL000CoeYL00_l00006om2X00;o
00001_o</`02o`0000GobKX000?o0000ojRn0?l000001Oo8_0001?l0003oZ;h0ojRn0?l00003olVj
0003o`000?n``03o/<0000;o/<000_l00006ol740003o`000?nR_03oX[`000;o000000?obKT0o`00
0?nn``001?nn``000ol0003oZ;h0ojRn0002ojRn00;o00001Oo7_@000ol0003o`l@0ol?40003ol?4
0004o`000?nh`P3o^<80okS200?o0000=?ooool4o`0002Wooooo001Dooooo`03o`000?oooooooooo
00Wooooo00?o0000omJG0?oFU`000ooFU`000ol0003ofhH0o`000005om2X0003o`000?oGU03o0000
00Goc;<000?o0000om>M0?l000001Oo9^P02o`0000Kob;`000?o0000ojRn0?l000001?o9^P000ol0
003o/<00ok300002o`000003olbc0?l0003o`L@000Go`L@000?o0000oj:l0?l000001?o9^@000ol0
003o_/<0okk30003okk300Co000000?oc;<0o`000?o7_@001Oo7_@000ol0003o`l@0ol?40002ol?4
00Co0000<oooool4o`0002gooooo001Eooooo`;o00002_ooool01Ol0003oeYL0omJG0?oFU`3o0000
00?ofhH000Go0000om2X0?o@Z03od:P0o`000003omND0005o`000?o</`3oc;<0olbc0?l000000ooC
W@001ol0003obKX0olVj0?o9^P3o0000om:R0?l000001_o8_002o`0000GobKX000?o0000ok300?l0
00001?o</`000ol0003o`L@0ol740003ol7400;o00001Oo9^@000ol0003o_/<0okk30002okk300;o
00001Oo</`000ol0003oakd0olNm0003olNm0003o`000?o3a03o`l@000;o0000<oooool4o`00037o
oooo001Gooooo`03o`000?oooooooooo00Sooooo00?o0000omJG0?l000001OoKQP000ol0003od:P0
o`000005omND0003o`000?o</`3o000000Codid000Co0000olVj0?o9^P3o00000ooBXP000ol0003o
b;`0olRl0002olRl0003o`000?oBXP3o000000KobKX000?o0000olbc0?o</`001?o</`000ol0003o
`L@0ol740002o`000003om2X0?l0003obKT000CobKT000?o0000okk30?nn``000_l000000oo@YP3o
0000olbc0004olbc0003o`000?o7_@3oakd000?oakd000?o0000ol?40?l00000<Oooool4o`0003Go
oooo001Hooooo`03o`000?oooooooooo00Sooooo00?o0000om^60?oKQP001?oKQP02o`0000Koei@0
0_l00005om>M0003o`000?o9^P3o000000GodZ8000Co0000olRl0?o8_03o00000ooBXP000ol0003o
bKX0olVj0002olVj00;o00001_o</`000ol0003o`L@0o`000004om2X0003o`000?o9^@3obKT000?o
bKT00_l00004om2V0003o`000?o</`3oc;<000?oc;<000?o0000olNm0?o7_@000_o7_@02o`0002ko
oooo1?l0000iooooo`00FOooool00ol0003oooooooooo`07ooooo`03o`000?oKQP3ofhH000?ofhH0
00?o0000on5c0?l000001OoGU0000ol0003ogWh0o`000005om>M00;o00001_oBXP000ol0003ob;`0
o`000005om:R0004o`000?o9^P3obKX0o`0000;odid000?o0000olbc0?o</`000oo</`02o`0000Go
d:P000?o0000olVi0?o9^@000_o9^@02o`0000God:H000?o0000olbc0?o</`000oo</`000ol0003o
akd0o`000002o`0002gooooo0ol0000mooooo`00F_ooool2o`0000Sooooo00Go0000om^60?oKQP3o
fhH0o`000003on5c0005o`000?oGU03oei@0omND0?l000000ooNOP001ol0003odid0om>M0?oCW@3o
0000omb50?l000001_oBXP02o`0000KodZ8000?o0000olVj0?l000000ooCW@000ol0003oc;<0olbc
0002olbc0003o`000?oGU03o000000God:P000?o0000olVi0?o9^@000_l000000ooFU`3o0000om2V
0005om2V0003o`000?o</`3oc;<000;oc;<00_l0000/ooooo`Co0000@?ooool005cooooo00?o0000
ooooooooool01_ooool00ol0003ofhH0o`000005on5c0003o`000?oGU03o000000CogWh000Co0000
om>M0?oCW@3o00000ooLQ@001?l0003odZ80om:R0?oBXP02o`000003om^70?l0003odZ8000GodZ80
0_l00005om>M0004o`000?o</`3oc;<0o`0000?oei@000?o0000om2X0?o@Z0000oo@Z002o`0000Co
eYL000?o0000om2V0?o@YP000oo@YP000ol0003oc;<0o`000002o`0002[ooooo1?l00014ooooo`00
GOooool00ol0003oooooooooo`06ooooo`03o`000?oQL`3ohG<000CohG<00_l00005omin0003o`00
0?oCW@3o000000Gog8D000?o0000om:R0?l000001?oKQ`000ol0003odZ80om:R0002om:R0003o`00
0?oLQ@3o000000Godid000?o0000olbc0?l000001?oGU0000ol0003od:P0om2X0002om2X00;o0000
1OoFU`000ol0003od:H0om2V0003om2V00;o0000:Oooool4o`0004Sooooo001Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000on5c0?oQL`000ooQL`000ol0003oiel0o`000005omin00;o00001_oL
Q@02o`0000KofhL000Co0000om:R0?oBXP3o00000ooLQ@000ol0003odid0om>M0002om>M00;o0000
1_oGU0001_l0003od:P0om2X0?l0003ofhH0o`0000KoeYL000?o0000om2V0?o@YP000_l0000Woooo
o`Co0000C?ooool005oooooo0_l00006ooooo`05o`000?oQL`3ohG<0on5c0?l000000ooWG`001ol0
003ogWh0omin0?oNOP3o0000onEW0?l000001OoLQ@000ol0003ohf`0o`000006om^70003o`000?oB
XP3o000000Cog8D000?o0000om>M0?oCW@000_l000000ooNOP3o0000omND0005omND0003o`000?o@
Z03o000000?ofhH000?o0000omJG0?oFU`000ooFU`000ol0003od:H0o`00000Uooooo`Co0000D?oo
ool0067ooooo00?o0000ooooooooool01?ooool00ol0003ohG<0o`000005onMO0003o`000?oNOP3o
000000?oiFL000Go0000omb50?oLQ@3og8D0o`000003on=/0003o`000?oKQ`3ofhL000?ofhL00_l0
0005omb50003o`000?oCW@3o000000CogWh000?o0000omND0?oGU0000ooGU002o`0000GofhH000?o
0000omJG0?oFU`000_oFU`02o`0002?ooooo0ol0001Dooooo`00H_ooool00ol0003oooooooooo`04
ooooo`03o`000?oWG`3oiel000Coiel00_l00005onEW0003o`000?oLQ@3o000000Gohf`000?o0000
om^70?oKQ`000_l000000ooSK03o0000omb50004omb500;o00001_oNOP000ol0003oei@0omND0002
o`000003on5c0?l0003ofhH000CofhH000?o0000omJG0?l000000_l0000Qooooo`Co0000Eoooool0
06?ooooo00?o0000ooooooooool00oooool00ol0003oiel0onMO0003onMO0003o`000?o]B`3o0000
00GoiFL00_l00006on=/0003o`000?oKQ`3o000000Cohf`000?o0000omb50?oLQ@000_l000000ooU
I`3o0000omin0005omin0003o`000?oGU03o000000CohG<000?o0000om^60?oKQP000_oKQP02o`00
023ooooo1?l0001Kooooo`00I?ooool00ol0003oooooooooo`03ooooo`05o`000?oWG`3oiel0onMO
0?l000000oo]B`000ol0003oiFL0onEW0002o`000003on]A0?l0003ohf`000Gohf`00_l00005on=/
0003o`000?oLQ@3o000000CoiFL000?o0000omin0?oNOP000ooNOP02o`0000GohG<000?o0000om^6
0?oKQP000_l0000Nooooo`Co0000Goooool006Gooooo0_l00004ooooo`03o`000?oWG`3o000000Co
kD/000?o0000onEW0?l000001?o[D@001?l0003ohf`0on=/0?oSK002o`000003on]C0?l0003ohf`0
00Cohf`00_l00006onEW0003o`000?oNOP3ogWh000;o000000?oiel0o`000?oQL`001?oQL`000ol0
003ofhH0o`00000Looooo`Co0000Hoooool006Oooooo00?o0000ooooooooool00_ooool00ol0003o
kD/0one;0004one;0003o`000?o[D@3oje4000Coje4000?o0000on=/0?l000001?o[D`001ol0003o
hf`0on=/0?oSK03o0000on]A0?l000001_oUI`000ol0003ogWh0o`000004onMO0003o`000?oQL`3o
hG<000;ohG<00_l0000Iooooo`Co0000Ioooool006Sooooo00Go0000ooooooooooooooooo`000005
one;00;o00001_o[D@02o`0000Koje<000?o0000on=/0?l000000oo[D@000ol0003oiFL0onEW0003
onEW00;o00001OoWG`000ol0003ohG<0on5c0002o`0001Sooooo0ol0001[ooooo`00JOooool01Ol0
003ooooooooooooooooo000000?okD/000Co0000oo8i0?ob>@3o00000oo[D@02o`000003oo4l0?l0
003oje<000Goje<00_l00005on]A0003o`000?oUI`3oiFL000;o000000?okD/0o`000?oWG`001?oW
G`000ol0003ohG<0o`00000Fooooo`Co0000K_ooool006[ooooo0_l00002ooooo`03o`000?o]B`3o
000000ColST000?o0000on]A0?l000001?oa?0001?l0003oje<0on]C0?o[D`02o`000003oo4l0?l0
003oje4000Coje4000?o0000onEW0?l000001?o]B`000ol0003oiel0onMO0002onMO00;o00004ooo
ool4o`0007;ooooo001/ooooo`04o`000?ooooooooooo`0000GolST00_l00006oo4l0003o`000?o[
D`3o000000ColC`000?o0000on]A0?o[D@000_o[D@02o`0000KokD/000Co0000onMO0?l0003o0000
4Oooool4o`0007Kooooo001]ooooo`03o`000?oooooo000000?olST00_l000000oof:@3o0000oo4l
0005oo4l00;o00001Ooa?0000ol0003oje40o`000002o`000003oo8i0?l0003okD/000GokD/00_l0
000?ooooo`Co0000N_ooool006kooooo00Go0000ooooool0003olST0o`000004ooHY0004o`000?oa
?03olC`0oo4l00;o000000?omBX0o`000?oa?0001?oa?002o`0000GolST000Co0000one;0?o]B`3o
kD/00_l0000=ooooo`Co0000O_ooool006oooooo0ol00006ooHY0003o`000?oa?03o000000ComBX0
00Oo0000oo4l0?oa?03olC`0o`000?of:@3o000000KolST000?o0000one;0?l000003?ooool3o`00
08;ooooo001aooooo`;o00001Oof:@02o`0000KomBX000?o0000oo4l0?l000000oof:@000ol0003o
lST0oo8i0003oo8i00;o00002Oooool4o`0008Gooooo001booooo`;o000000ComRT0o`000?l0003o
00000_oh7@000ol0003omBX0ooDZ0003ooDZ00;o00001Oof:@000ol0003olST0o`000002o`0000Oo
oooo1?l00029ooooo`00Loooool3o`0000Gon1d000?o0000ooDZ0?l000000_l000000ooh7@3o0000
ooHY0004ooHY00;o00001_ooool4o`0008gooooo001dooooo`03o`000?oooooo000000?on1d00ol0
0005ooPM0003o`000?of:@3o000000;o00001?ooool4o`00097ooooo001eooooo`Go00000ooi6@00
0ol0003on1d0ooPM0002ooPM00;o00000oooool4o`0009Gooooo001gooooo`03o`000?oooooo0000
00ConAT000Co0000ooPM0?l0003o00000_ooool3o`0009Wooooo001hooooo`03o`000?oooooo0000
00Wo0000W?ooool007Wooooo0_l000000ooooooo0000o`000002o`000:3ooooo001jooooo`;o0000
Y?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool002cooooo0ol0002:ooooo`03
o`000?oooooooooo02_ooooo0ol0000Eooooo`03o`000?oooooooooo01kooooo000]ooooo`03o`00
0?oooooooooo08Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01gooooo000Wooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_oo
ool3o`0000?ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000ooo
ool2o`0000;ooooo1_l00006ooooo`Co00000_ooool5o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000ol00002ooooo`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Co
ooooo`000?l0003ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go0000
0_ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o
00001Oooool00ol0003oooooooooo`0Looooo`009_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000cooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0L
ooooo`009_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002
ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo0000
1Oooool5o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;o
oooo0ol00003ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`04o`000?oooooooooooooo
o`Go00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00002ooooo`?o00001Oooool00ol0003oooooooooo`0Looooo`00
9_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?oooooooooo
o`0000Gooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo01cooooo
000Vooooo`06o`000?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Co
oooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00
00;ooooo0_l00003ooooo`Co00000oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03
o`0000Cooooo1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`?o00000_ooool4o`0000?ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02
ooooo`Ko000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003
ooooo`Co00001?ooool00ol0003oooooooooo`0Looooo`009_ooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool07Oooool002Oooooo0ol00009ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?oo
ool2o`0002kooooo00?o0000ooooooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_oo
ool2o`0000_ooooo00?o0000ooooooooool07_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0579699, 0.0510678, \
0.00357065, 0.00357065}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(87.6`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            
            RowBox[{\(ComponentNumber \[Rule] 2\), 
              ",", \(Energy \[Rule] 100.`100. \), 
              ",", \(Offset \[Rule] 
                155.2325062488477613793059383543639805266091629285480529454962\
38317578723695021302672111530991186568523004075`97.94170503318654\), ",", 
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                
                TagBox[\(CompiledFunction[
                    If[#1 \[Equal] 0 && #2 \[Equal] 0, 
                      155.2324515677627310951283801273301414454985648440678835\
07925190818610684184786449747318424891019189`84.96526438775636, 
                      155.2508988570726453956837320936001403579104665190019246\
99384692886448529577538846650008183279346303`85.75702700524849 - 
                        2.8838972714250281546014743420935636216881828340112495\
97001246205739719460006388036521436`76.89606811354653*^-9\ Cos[
                            2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                        0.0137121120474191816390729906704116445800718462859301\
16451309013211930180833544591907864374608883`81.39468969297788\ \((\(-1\) + 
                              0.0062090675328425074765009214172555060561193833\
210326060947683495580559778790344959080642016356320766677413554640145`94.\
58401161724137\ \((#1\^2 + #2\^2)\))\) - 
                        8.6581598239142570446999413616403312333659899417273236\
3144792317410040722401946192180825578`76.94557620799411*^-7\ Cos[
                            2\ ArcTan[#1, #2]]\ \
\((\(-0.0093136012992637612147513821258832590841790749815489091421525243370839\
668185517438620963024534481150016120331960218`94.58401161724137\)\ \((#1\^2 + \
#2\^2)\) + 
                              0.0000385525196273989426603280671278891250566639\
465641247512261343953269041599115546332140888247796271563865605031005`94.\
28298162157739\ \((#1\^2 + #2\^2)\)\^2)\) - 
                        0.0048934823244420621490835401111649009498293198696879\
60305132973818479831569435680611519934680599`80.96212738430674\ \((1 - 
                              0.0186272025985275224295027642517665181683581499\
63097818284305048674167933637103487724192604906896230003224`94.58401161724137\
\ \((#1\^2 + #2\^2)\) + 
                              0.0000578287794410984139904921006918336875849959\
198461871268392015929903562398673319498211332371694407345798407546508`94.\
28298162157739\ \((#1\^2 + #2\^2)\)\^2)\) + 
                        6.3785182032070723250094078228212819877728284726432331\
57858578548236769096785953714543024779`78.06995560681887*^-6\ Cos[
                            4\ ArcTan[#1, #2]]\ \
\((\(-0.0000481906495342486783254100839098614063208299332051559390326679941586\
301998894432915176110309745339454832006288757`94.28298162157739\)\ \((#1\^2 + \
#2\^2)\)\^2 + 
                              1.7953139844581722388055362435133148190870348481\
09043318133554151043016247540663836121000056902780230009273374`94.\
10689036252174*^-7\ \((#1\^2 + #2\^2)\)\^3)\) - 
                        4.3494356320219980626380098531981432193937225599055324\
0727007520366503399937029723996860389`76.86521783018696*^-7\ Cos[
                            2\ ArcTan[#1, #2]]\ \
\((0.0186272025985275224295027642517665181683581499630978182843050486741679336\
37103487724192604906896230003224`94.58401161724137\ \((#1\^2 + #2\^2)\) - 
                              0.0001927625981369947133016403356394456252833197\
328206237561306719766345207995577731660704441238981357819328025155026`94.\
28298162157739\ \((#1\^2 + #2\^2)\)\^2 + 
                              4.4882849611454305970138406087832870477175871202\
72608295333885377607540618851659590302500142256950575023183435`94.\
10689036252174*^-7\ \((#1\^2 + #2\^2)\)\^3)\) - 
                        0.0001583050619469432328045645115776331179994912215768\
85296939919192564619650583369829625920962368`79.68976640240584\ \((\(-1\) + 
                              0.0372544051970550448590055285035330363367162999\
26195636568610097348335867274206975448385209813792460006448`94.58401161724137\
\ \((#1\^2 + #2\^2)\) - 
                              0.0002891438972054920699524605034591684379249795\
992309356341960079649517811993366597491056661858472036728992037732539`94.\
28298162157739\ \((#1\^2 + #2\^2)\)\^2 + 
                              5.9843799481939074626851208117110493969567828270\
30144393778513836810054158468879453736666856342600766697577913`94.\
10689036252174*^-7\ \((#1\^2 + #2\^2)\)\^3)\)], "-CompiledCode-"]\),
                  False,
                  Editable->False]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                
                TagBox[\(CompiledFunction[
                    If[#1 \[Equal] 0 && #2 \[Equal] 
                          0, \(-0.\
102783994417827401425238785411806598868579849942551825277253699322387659497978\
934409962681827502`81.73323293788266\), 
                      34.57257185128574507104086322586434455132253844712735693\
3185279830462185183353341911000541649772223`85.05252442378168 - 
                        5.4208595327538123206794630490480519204665090864873112\
72558733469435562894748849692709464692`80.11207068225917*^-6\ Cos[
                            2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                        1.5341525679962298112977651333959889825338053494284833\
5856006523206780861188408521708571714924402422`81.10619931279086*^-7\ Cos[
                            4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 + 
                        25.774646705675153456904117801525647706901966702876158\
743062054909643197055534947195233786859223835`84.61274359855912\ \((\(-1\) + 
                              0.0062090675328425074765009214172555060561193833\
210326060947683495580559778790344959080642016356320766677413554640145`94.\
58401161724137\ \((#1\^2 + #2\^2)\))\) - 
                        0.0016274736511117024520112671732406637656702988612269\
40532227053228214362260154034195828619539248`80.16158040944755\ Cos[
                            2\ ArcTan[#1, #2]]\ \
\((\(-0.0093136012992637612147513821258832590841790749815489091421525243370839\
668185517438620963024534481150016120331960218`94.58401161724137\)\ \((#1\^2 + \
#2\^2)\) + 
                              0.0000385525196273989426603280671278891250566639\
465641247512261343953269041599115546332140888247796271563865605031005`94.\
28298162157739\ \((#1\^2 + #2\^2)\)\^2)\) - 
                        9.1982750459437258441419926901595882515588719355036847\
84084537252781638288412933480300629080006006`84.18383851442343\ \((1 - 
                              0.0186272025985275224295027642517665181683581499\
63097818284305048674167933637103487724192604906896230003224`94.58401161724137\
\ \((#1\^2 + #2\^2)\) + 
                              0.0000578287794410984139904921006918336875849959\
198461871268392015929903562398673319498211332371694407345798407546508`94.\
28298162157739\ \((#1\^2 + #2\^2)\)\^2)\) + 
                        0.0119896958706899855733259545541753420822797527681263\
78116275523586911220106740514501020725622911`81.27672197512814\ Cos[
                            4\ ArcTan[#1, #2]]\ \
\((\(-0.0000481906495342486783254100839098614063208299332051559390326679941586\
301998894432915176110309745339454832006288757`94.28298162157739\)\ \((#1\^2 + \
#2\^2)\)\^2 + 
                              1.7953139844581722388055362435133148190870348481\
09043318133554151043016247540663836121000056902780230009273374`94.\
10689036252174*^-7\ \((#1\^2 + #2\^2)\)\^3)\) - 
                        0.0008175630887259394854582725287966434622920531127641\
97820915427669861848496122236323302369568805`80.08146262302121\ Cos[
                            2\ ArcTan[#1, #2]]\ \
\((0.0186272025985275224295027642517665181683581499630978182843050486741679336\
37103487724192604906896230003224`94.58401161724137\ \((#1\^2 + #2\^2)\) - 
                              0.0001927625981369947133016403356394456252833197\
328206237561306719766345207995577731660704441238981357819328025155026`94.\
28298162157739\ \((#1\^2 + #2\^2)\)\^2 + 
                              4.4882849611454305970138406087832870477175871202\
72608295333885377607540618851659590302500142256950575023183435`94.\
10689036252174*^-7\ \((#1\^2 + #2\^2)\)\^3)\) - 
                        0.2975659059153068285800084804090848082697203413099347\
68684058632640262501096559830123911607630117`82.91450772112995\ \((\(-1\) + 
                              0.0372544051970550448590055285035330363367162999\
26195636568610097348335867274206975448385209813792460006448`94.58401161724137\
\ \((#1\^2 + #2\^2)\) - 
                              0.0002891438972054920699524605034591684379249795\
992309356341960079649517811993366597491056661858472036728992037732539`94.\
28298162157739\ \((#1\^2 + #2\^2)\)\^2 + 
                              5.9843799481939074626851208117110493969567828270\
30144393778513836810054158468879453736666856342600766697577913`94.\
10689036252174*^-7\ \((#1\^2 + #2\^2)\)\^3)\)], "-CompiledCode-"]\),
                  False,
                  Editable->False]}], 
              ",", \(OpticalPathRange \[Rule] \
{155.2325062488477613793059383543639805266091629285480529454962383175787236950\
21302672111530991186568523004075`97.94170503318654, 
                  155.25963192990728936274608869039831315816575375862838442488\
4130033757431855094160716248026641915708744386461`97.86824855726309}\), ",", 
              RowBox[{"OutputGraphics", "\[Rule]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"OpticalLengthFunction", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}], ",", 
                    RowBox[{"WaveFrontIntensity", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}], ",", 
                    RowBox[{"OpticalPathDifference", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}]}], "}"}]}], 
              ",", \(RayBoundary \[Rule] \
{{\(-12.6908481309615407745297839200998319692200664165478406192003709568637718\
02038538526986732335291052173835775`94.88504161290534\), 
                    12.6908481309615407745297839200998319692200664165478406192\
00370956863771802038538526986732335291052173835775`94.88504161290534}, \
{\(-12.69062378068874646983473204011666651202111704945419736591255649596598235\
3840910685047474840323996662370812`94.88504161290535\), 
                    12.6906237806887464698347320401166665120211170494541973659\
12556495965982353840910685047474840323996662370812`94.88504161290535}}\), 
              ",", \(RayTracePrecision \[Rule] 100\), 
              ",", \(RefractiveIndex \[Rule] 
                1.000269451236569600446789541206304199143652398593908366862819\
2318713547103645960880847666416701543099632836105995966`100.30102025365451\), 
              ",", \(ResidualFitError \[Rule] 
                0.003354510990480784694604702850625475331922036441868822405602\
838717024584255281712718408709460256`80.39363950245694\), 
              ",", \(Source \[Rule] 1\), ",", \(SpatialScale \[Rule] 1\), 
              ",", \(SurfaceNumber \[Rule] 1\), 
              ",", \(WaveFrontID \[Rule] 1\), ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                
                TagBox[\(InterpolatingFunction[{{\(-17.007735850509498`\), 
                        17.007735850509498`}, {\(-17.007511500236703`\), 
                        17.007511500236703`}}, "<>"]\),
                  False,
                  Editable->False]}], 
              ",", \(WaveLength \[Rule] 
                0.531999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999999999999999999999999999999943`100. \), 
              ",", \(WaveTilt \[Rule] WaveTilt\)}], "}"}], "}"}]}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianPlot", "SubsubsectionIcon"],

Cell[TextData[{
  StyleBox["GaussianPlot", "Input"],
  " is used to calculate the diffractive behavior of Gaussian beams through \
space. We now examine how arbitrary precision calculations are made with ",
  StyleBox["GaussianPlot", "Input"],
  ". Here is ",
  StyleBox["RayTracePrecision->50", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
GaussianPlot[{GaussianBeam[.2,4.9], \
Move[Screen[200],300]},RayTracePrecision->50]\
\>", "Input",
  CellLabel->"In[12]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0 0.000727723 [
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .14554 -18 -4.5 ]
[.01131 .14554 0 4.5 ]
[.01131 .29109 -18 -4.5 ]
[.01131 .29109 0 4.5 ]
[.01131 .43663 -18 -4.5 ]
[.01131 .43663 0 4.5 ]
[.01131 .58218 -18 -4.5 ]
[.01131 .58218 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .00625 L
s
[(50)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(100)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(150)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(200)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(250)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(300)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .14554 m
.03006 .14554 L
s
[(200)] .01131 .14554 1 0 Mshowa
.02381 .29109 m
.03006 .29109 L
s
[(400)] .01131 .29109 1 0 Mshowa
.02381 .43663 m
.03006 .43663 L
s
[(600)] .01131 .43663 1 0 Mshowa
.02381 .58218 m
.03006 .58218 L
s
[(800)] .01131 .58218 1 0 Mshowa
.125 Mabswid
.02381 .03639 m
.02756 .03639 L
s
.02381 .07277 m
.02756 .07277 L
s
.02381 .10916 m
.02756 .10916 L
s
.02381 .18193 m
.02756 .18193 L
s
.02381 .21832 m
.02756 .21832 L
s
.02381 .2547 m
.02756 .2547 L
s
.02381 .32748 m
.02756 .32748 L
s
.02381 .36386 m
.02756 .36386 L
s
.02381 .40025 m
.02756 .40025 L
s
.02381 .47302 m
.02756 .47302 L
s
.02381 .50941 m
.02756 .50941 L
s
.02381 .54579 m
.02756 .54579 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .00015 m
.09004 .03734 L
.16227 .07791 L
.23011 .11601 L
.29535 .15265 L
.36479 .19165 L
.43164 .22919 L
.50269 .26909 L
.57114 .30754 L
.63699 .34452 L
.70705 .38387 L
.77451 .42175 L
.83937 .45818 L
.90843 .49697 L
.9749 .5343 L
.97619 .53502 L
s
0 0 0 r
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@oooool3o`0000Cooooo0_l0000Kooooo`?o00001?ooool2o`0000Cooooo0_l0000Goooo
o`?o00000oooool3o`0000Cooooo0_l0000Gooooo`Go00000oooool2o`0000Cooooo0_l0000Foooo
o`Go00000_ooool3o`0000Cooooo0_l0000Gooooo`?o00001?ooool2o`0000Cooooo0_l0000Aoooo
o`00@_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00006oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
5oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000Fooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004?ooool004Kooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Gooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Gooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Goooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`0>ooooo`00A_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Oo
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
01Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool05Oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0000@ooooo`00@_ooool4o`0000?ooooo00Co0000oooooooooooo00006oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005ooo
ool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00005_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Eooooo`06o`000?ooooooooooooooool0003ooooo1?l00003ooooo`04o`000?ooooooooooo`00
01Wooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00kooooo0012ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00006_oo
ool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Fooooo`;o
00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
5Oooool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool0000E
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`00013ooooo0012ooooo`Go00000oooool2o`0001cooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo0_l0000Hooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0001So
oooo0ol00004ooooo`;o00001?ooool2o`0001Oooooo0ol00002ooooo`Go00000oooool2o`0001Oo
oooo0ol00004ooooo`;o00001?ooool2o`00017ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo000Loooooo?o00004Oooool002;ooooo00Co0000ooooool9jP[o
2NX:0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05Oooool002;ooooo00Go0000ooooooooooooooooo`WZ2P3Qooooo`03o`000?oooooooooo01Go
oooo000Rooooo`03o`000?oooooooooo00;ooooo0_l9jP[Oooooo`03o`000?oooooooooo01Gooooo
000Rooooo`03o`000?oooooooooo00Cooooo0_l9jP[Mooooo`03o`000?oooooooooo01Gooooo000R
ooooo`03o`000?oooooooooo00Kooooo0_l9jP[Kooooo`03o`000?oooooooooo01Gooooo000Roooo
o`03o`000?oooooooooo00Sooooo0_l9jP[Iooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0e_ooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`0;ooooo`;o2NX:e_ooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`0=ooooo`;o2NX:e?ooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`0?ooooo`;o2NX:d_ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0
003oooooooooo`0Aooooo`;o2NX:d?ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003o
ooooooooo`0Cooooo`;o2NX:c_ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooo
ooooo`0Eooooo`;o2NX:c?ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooooooo
o`0Gooooo`03o`WZ2_oooooooooo0<Wooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000
ooooooooool06?ooool2o`WZ2/Wooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooo
ooooool06_ooool2o`WZ2/Oooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooooooo
ool07?ooool2o`WZ2/Gooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0
7_ooool2o`WZ2/?ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool08?oo
ool2o`WZ2/7ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool08_ooool0
0ol9jP[oooooooooo`2nooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo
02?ooooo0_l9jPZnooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo02Go
oooo0_l9jPZlooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo02Oooooo
00?o2NX:ooooooooool0^Oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooooooo
o`0Xooooo`;o2NX:^Oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`0Z
ooooo`;o2NX:]oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`0/oooo
o`03o`WZ2_oooooooooo0;Cooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooooooo
ool0;Oooool2o`WZ2[Cooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0
;oooool2o`WZ2[;ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0<Ooo
ool2o`WZ2[3ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0<oooool0
0ol9jP[oooooooooo`2]ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo
03Cooooo0_l9jPZ]ooooo`03o`000?oooooooooo01Gooooo000=ooooo`Go00000oooool2o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo03Kooooo0_l9jPZ[ooooo`03o`000?oooooooooo01Go
oooo000>ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03Sooooo00?o2NX:ooooooooool0Z?ooool0
0ol0003oooooooooo`0Eooooo`003oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0iooooo`;o2NX:Z?oo
ool00ol0003oooooooooo`0Eooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool2o`WZ2ZKooooo
00?o0000ooooooooool05Oooool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0moooo
o`03o`WZ2_oooooooooo0:?ooooo00?o0000ooooooooool05Oooool000gooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0nooooo`;o2NX:Xoooool00ol0003oooooooooo`0Eooooo`003_ooool3
o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`10ooooo`;o2NX:XOooool0
0ol0003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`12ooooo`;o2NX:Woooool00ol0
003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`14ooooo`;o2NX:WOooool00ol0003o
ooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`16ooooo`;o2NX:Voooool00ol0003ooooo
ooooo`0Eooooo`008_ooool00ol0003oooooooooo`18ooooo`03o`WZ2_oooooooooo09Sooooo00?o
0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0BOooool2o`WZ2YSooooo00?o0000
ooooooooool05Oooool002;ooooo00?o0000ooooooooool0Boooool2o`WZ2YKooooo00?o0000oooo
ooooool05Oooool002;ooooo00?o0000ooooooooool0COooool2o`WZ2YCooooo00?o0000oooooooo
ool05Oooool002;ooooo00?o0000ooooooooool0Coooool2o`WZ2Y;ooooo00?o0000ooooooooool0
5Oooool002;ooooo00?o0000ooooooooool0DOooool2o`WZ2Y3ooooo00?o0000ooooooooool05Ooo
ool002;ooooo00?o0000ooooooooool0Doooool00ol9jP[oooooooooo`2=ooooo`03o`000?oooooo
oooo01Gooooo000Rooooo`03o`000?oooooooooo05Cooooo0_l9jPZ=ooooo`03o`000?oooooooooo
01Gooooo000Rooooo`03o`000?oooooooooo05Kooooo0_l9jPZ;ooooo`03o`000?oooooooooo01Go
oooo000Rooooo`03o`000?oooooooooo05Sooooo0_l9jPZ9ooooo`03o`000?oooooooooo01Gooooo
000Rooooo`03o`000?oooooooooo05[ooooo0_l9jPZ7ooooo`03o`000?oooooooooo01Gooooo000R
ooooo`03o`000?oooooooooo05cooooo00?o2NX:ooooooooool0Q?ooool00ol0003oooooooooo`0E
ooooo`008_ooool00ol0003oooooooooo`1Mooooo`;o2NX:Q?ooool00ol0003oooooooooo`0Eoooo
o`008_ooool00ol0003oooooooooo`1Oooooo`;o2NX:P_ooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`1Qooooo`;o2NX:P?ooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`1Sooooo`;o2NX:O_ooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`1Uooooo`03o`WZ2_oooooooooo07_ooooo00?o0000ooooooooool05Oooool0
02;ooooo00?o0000ooooooooool0I_ooool2o`WZ2W_ooooo00?o0000ooooooooool05Oooool002;o
oooo00?o0000ooooooooool0J?ooool2o`WZ2WWooooo00?o0000ooooooooool05Oooool002;ooooo
00?o0000ooooooooool0J_ooool2o`WZ2WOooooo00?o0000ooooooooool05Oooool002;ooooo00?o
0000ooooooooool0K?ooool2o`WZ2WGooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000
ooooooooool0K_ooool00ol9jP[oooooooooo`1booooo`03o`000?oooooooooo01Gooooo000Roooo
o`03o`000?oooooooooo06oooooo0_l9jPYbooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo077ooooo0_l9jPY`ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`00
0?oooooooooo07?ooooo0_l9jPY^ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oo
oooooooo07Gooooo00?o2NX:ooooooooool0Joooool00ol0003oooooooooo`0Eooooo`003oooool3
o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`1fooooo`;o2NX:Joooool0
0ol0003oooooooooo`0Eooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Sooooo0_l9
jPYYooooo`03o`000?oooooooooo01Gooooo000=ooooo`Go00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001kooooo`;o2NX:Ioooool00ol0003ooooo
ooooo`0Eooooo`003Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1looooo`;o2NX:IOooool00ol0
003oooooooooo`0Eooooo`003_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1nooooo`03o`WZ2_oooooo
oooo06;ooooo00?o0000ooooooooool05Oooool000oooooo0_l00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1oooooo`;o2NX:H_oo
ool00ol0003oooooooooo`0Eooooo`004?ooool00ol0003oooooooooo`02ooooo`;o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0POooool2o`WZ2V3ooooo00?o0000ooooooooool05Oooool0
02;ooooo00?o0000ooooooooool0Poooool2o`WZ2Ukooooo00?o0000ooooooooool05Oooool002;o
oooo00?o0000ooooooooool0QOooool00ol9jP[oooooooooo`1Kooooo`03o`000?oooooooooo01Go
oooo000Rooooo`03o`000?oooooooooo08Kooooo0_l9jPYKooooo`03o`000?oooooooooo01Gooooo
000Rooooo`03o`000?oooooooooo08Sooooo0_l9jPYIooooo`03o`000?oooooooooo01Gooooo000R
ooooo`03o`000?oooooooooo08[ooooo0_l9jPYGooooo`03o`000?oooooooooo01Gooooo000Roooo
o`03o`000?oooooooooo08cooooo0_l9jPYEooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo08kooooo00?o2NX:ooooooooool0D_ooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`2?ooooo`;o2NX:D_ooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`2Aooooo`;o2NX:D?ooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`2Cooooo`;o2NX:C_ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0
003oooooooooo`2Eooooo`03o`WZ2_oooooooooo04_ooooo00?o0000ooooooooool05Oooool002;o
oooo00?o0000ooooooooool0U_ooool2o`WZ2T_ooooo00?o0000ooooooooool05Oooool002;ooooo
00?o0000ooooooooool0V?ooool2o`WZ2TWooooo00?o0000ooooooooool05Oooool002;ooooo00?o
0000ooooooooool0V_ooool00ol9jP[oooooooooo`16ooooo`03o`000?oooooooooo01Gooooo000R
ooooo`03o`000?oooooooooo09_ooooo0_l9jPY6ooooo`03o`000?oooooooooo01Gooooo000Roooo
o`03o`000?oooooooooo09gooooo0_l9jPY4ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo09oooooo00?o2NX:ooooooooool0@Oooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`2Pooooo`;o2NX:@Oooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`2Rooooo`;o2NX:?oooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`2Tooooo`;o2NX:?Oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0
003oooooooooo`2Vooooo`;o2NX:>oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003o
ooooooooo`2Xooooo`;o2NX:>Oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooo
ooooo`2Zooooo`;o2NX:=oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooooooo
o`2/ooooo`03o`WZ2_oooooooooo03Cooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000
ooooooooool0[Oooool2o`WZ2SCooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooo
ooooool0[oooool2o`WZ2S;ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooooooo
ool0/Oooool2o`WZ2S3ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0
/oooool2o`WZ2Rkooooo00?o0000ooooooooool05Oooool000kooooo0ol00004ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0]Oooool2o`WZ2Rcooooo00?o0000ooooooooool05Ooo
ool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2gooooo`03o`WZ2_oooooooooo02Wo
oooo00?o0000ooooooooool05Oooool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`000;Wooooo0_l9jPXY
ooooo`03o`000?oooooooooo01Gooooo000=ooooo`Co00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0^_ooool2o`WZ2ROooooo00?o
0000ooooooooool05Oooool000gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0_?ooool00ol9jP[ooooo
ooooo`0Tooooo`03o`000?oooooooooo01Gooooo000>ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0;go
oooo0_l9jPXTooooo`03o`000?oooooooooo01Gooooo000?ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo0;oooooo0_l9jPXRooooo`03o`000?oooooooooo01Gooooo
000Rooooo`03o`000?oooooooooo0<7ooooo00?o2NX:ooooooooool07oooool00ol0003ooooooooo
o`0Eooooo`008_ooool00ol0003oooooooooo`32ooooo`;o2NX:7oooool00ol0003oooooooooo`0E
ooooo`008_ooool00ol0003oooooooooo`34ooooo`;o2NX:7Oooool00ol0003oooooooooo`0Eoooo
o`008_ooool00ol0003oooooooooo`36ooooo`;o2NX:6oooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`38ooooo`;o2NX:6Oooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`3:ooooo`;o2NX:5oooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`3<ooooo`03o`WZ2_oooooooooo01Cooooo00?o0000ooooooooool05Oooool0
02;ooooo00?o0000ooooooooool0cOooool2o`WZ2QCooooo00?o0000ooooooooool05Oooool002;o
oooo00?o0000ooooooooool0coooool2o`WZ2Q;ooooo00?o0000ooooooooool05Oooool002;ooooo
00?o0000ooooooooool0dOooool2o`WZ2Q3ooooo00?o0000ooooooooool05Oooool002;ooooo00?o
0000ooooooooool0doooool2o`WZ2Pkooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000
ooooooooool0eOooool2o`WZ2Pcooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooo
ooooool0eoooool00ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo0=Sooooo0_l9jPX9ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`00
0?oooooooooo0=[ooooo0_l9jPX7ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oo
oooooooo0=cooooo0_l9jPX5ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooo
oooo0=kooooo0_l9jPX3ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo
0>3ooooo00Co2NX:oooooooooooo00005oooool002;ooooo00?o0000ooooooooool0hOooool2o`WZ
2P03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo0>?ooooo00?o0000oooooooo
ool05Oooool002;ooooo00?o0000ooooooooool0hoooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooo
oooo0>?ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0hoooool00ol0
003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo01Go
oooo000Rooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool05Oooool002;ooooo00?o
0000ooooooooool0hoooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`3k
ooooo`003_ooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`3Qoooo
o`?o00005oooool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3Qooooo`04o`000?oo
ooooooooo`0001Kooooo000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0i?ooool00ol0
003oooooooooo`0Dooooo`003_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`;o0000hoooool2o`0001Oooooo000=ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0hOooool00ol0003oooooooooo`0Gooooo`003Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo0>7ooooo00Co0000oooooooooooo00005_ooool000kooooo0ol00004oooo
o`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0h_ooool3o`0001Kooooo000Rooooo`03
o`000?oooooooooo0?_ooooo000Rooooo`03o`000?oooooooooo0?_ooooo000Rooooo`03o`000?oo
oooooooo0?_ooooo000Rooooo`03o`000?oooooooooo0?_ooooo000Rooooo`03o`000?oooooooooo
0?_ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo002?oooo
o`?o0000S_ooool0093ooooo00?o0000ooooooooool0SOooool006_ooooo1?l00003ooooo`?o0000
0oooool4o`000006ooooool0003oooooo`000?oooooo00002?ooool3o`0000?ooooo0ol00003oooo
o`?o00001?ooool2o`0000Wooooo0ol00002ooooo`Go000000?oooooo`000?l000000ol00002oooo
o`?o0000Hoooool006cooooo00Ko0000oooooooooooo0000ooooool00005ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooool0003oooooo`000008ooooo`04o`000?ooooooooooo`0000;o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00Ko0000oooooooooooo0000ooooool0001Vooooo`00K?ooool01Ol0003oooooooooool0003ooooo
00Go00000_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`00000;ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000>ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooooooool5o`0006;ooooo001/ooooo`?o
00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool02?l0003oooooooooool0
003oooooo`000?oooooo00002Oooool2o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`04o`000?ooooooooooo`0000cooooo0_l00004ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo063ooooo001/ooooo`04o`00
0?ooooooooooo`0000;ooooo0ol00003ooooo`;o00000oooool2o`000003ooooool0003ooooo00So
oooo00?o0000ooooooooool00_ooool4o`0000?ooooo0ol00002ooooo`Co00002Oooool00ol0003o
ooooooooo`02ooooo`?o00000oooool5o`0000;ooooo0ol0001Sooooo`00K?ooool01?l0003ooooo
ooooool0000Jooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool0001dooooo`00Joooool4o`0001cooooo0ol0000>ooooo`03o`000?oooooooooo
00[ooooo0ol00003ooooo`03o`000?oooooooooo06kooooo003oooooob7ooooo003oooooob7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-44.2148, -68.1803, 1.29896, \
5.66655}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"BeamSpotSizeGraphics", "\[Rule]", 
          RowBox[{"(", 
            TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
              False,
              Editable->False], ")"}]}], 
        ",", \(BeamSpotSizeFunction \[Rule] \((Which[#1 < 300, 
                0.000069100099020353344138550155654540652073813959598462010670\
9030744`50. \ \@\(1 + \
1.25711448139002462936612122782157240322530858846019860784508394605`49.\
69897000433602*^9\ \
\((0.0816326481889552079279706796429239772740420188175809750447502004967`50.  \
+ #1)\)\^2\), #1 \[GreaterEqual] 300, 
                0.000069109407954458666528773269600876205189774459647297371985\
6626684`45.98973899457993\ \@\(1 + \
1.257114481390024629366121227821572403225308588460198607845`45.08662780041855*\
^9\ \((0.0816326481889552079279706796429239772740420188175809750447502010063`\
49.67339358106304 + #1)\)\^2\)] &)\)\), 
        ",", \(BeamCurvatureFunction \[Rule] \((Which[#1 < 
                  300, \(-\((0.\
0816326481889552079279706796429239772740420188175809750447502004967`50.  + \
#1)\)\)\ \((1 + 
                      7.954725005587984574323052208570566396616847876880940151\
7007830519137`49.69897000433602*^-10\/\((0.\
0816326481889552079279706796429239772740420188175809750447502004967`50.  + \
#1)\)\^2)\), #1 \[GreaterEqual] 
                  300, \(-\((0.\
0816326481889552079279706796429239772740420188175809750447502010063`49.\
67339358106304 + #1)\)\)\ \((1 + 
                      7.954725005587984574323052208570566396616847876880940151\
702`45.08662780041855*^-10\/\((0.\
0816326481889552079279706796429239772740420188175809750447502010063`49.\
67339358106304 + #1)\)\^2)\)] &)\)\), 
        ",", \(ComplexBeamParameterFunction \[Rule] \((Which[#1 < 
                  300, \((0.\
0816326481889552079279706796429239772740420188175809750447502004967`50.  + 
                      0.000028204122049069324955843450280687621047431997763791\
8609089648731`50. \ \[ImaginaryI])\) - #1, #1 \[GreaterEqual] 
                  300, \((600.\
0816326481889552079279706796429239772740420188175809750447502010063`53.\
53974002973011 + 
                      0.000028204122049069324955843450280687621047431997763791\
8609089673564`45.38765779608253\ \[ImaginaryI])\) - #1] &)\)\), 
        ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(PlotDomain \[Rule] {0, 300}\)}], "}"}]], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "When you use ",
  StyleBox["RayTracePrecision->Infinity", "Input"],
  ", the result is calculated with fractional integers rather than floating \
point numbers."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
GaussianPlot[{GaussianBeam[.2,4.9], \
Move[Screen[200],300]},RayTracePrecision->Infinity]\
\>", "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0 0.000727723 [
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .14554 -18 -4.5 ]
[.01131 .14554 0 4.5 ]
[.01131 .29109 -18 -4.5 ]
[.01131 .29109 0 4.5 ]
[.01131 .43663 -18 -4.5 ]
[.01131 .43663 0 4.5 ]
[.01131 .58218 -18 -4.5 ]
[.01131 .58218 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .00625 L
s
[(50)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(100)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(150)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(200)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(250)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(300)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .14554 m
.03006 .14554 L
s
[(200)] .01131 .14554 1 0 Mshowa
.02381 .29109 m
.03006 .29109 L
s
[(400)] .01131 .29109 1 0 Mshowa
.02381 .43663 m
.03006 .43663 L
s
[(600)] .01131 .43663 1 0 Mshowa
.02381 .58218 m
.03006 .58218 L
s
[(800)] .01131 .58218 1 0 Mshowa
.125 Mabswid
.02381 .03639 m
.02756 .03639 L
s
.02381 .07277 m
.02756 .07277 L
s
.02381 .10916 m
.02756 .10916 L
s
.02381 .18193 m
.02756 .18193 L
s
.02381 .21832 m
.02756 .21832 L
s
.02381 .2547 m
.02756 .2547 L
s
.02381 .32748 m
.02756 .32748 L
s
.02381 .36386 m
.02756 .36386 L
s
.02381 .40025 m
.02756 .40025 L
s
.02381 .47302 m
.02756 .47302 L
s
.02381 .50941 m
.02756 .50941 L
s
.02381 .54579 m
.02756 .54579 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .00015 m
.09004 .03734 L
.16227 .07791 L
.23011 .11601 L
.29535 .15265 L
.36479 .19165 L
.43164 .22919 L
.50269 .26909 L
.57114 .30754 L
.63699 .34452 L
.70705 .38387 L
.77451 .42175 L
.83937 .45818 L
.90843 .49697 L
.9749 .5343 L
.97619 .53502 L
s
0 0 0 r
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@oooool3o`0000Cooooo0_l0000Kooooo`?o00001?ooool2o`0000Cooooo0_l0000Goooo
o`?o00000oooool3o`0000Cooooo0_l0000Gooooo`Go00000oooool2o`0000Cooooo0_l0000Foooo
o`Go00000_ooool3o`0000Cooooo0_l0000Gooooo`?o00001?ooool2o`0000Cooooo0_l0000Aoooo
o`00@_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00006oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
5oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000Fooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004?ooool004Kooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Gooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Gooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Goooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`0>ooooo`00A_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Oo
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
01Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool05Oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0000@ooooo`00@_ooool4o`0000?ooooo00Co0000oooooooooooo00006oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005ooo
ool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00005_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Eooooo`06o`000?ooooooooooooooool0003ooooo1?l00003ooooo`04o`000?ooooooooooo`00
01Wooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00kooooo0012ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00006_oo
ool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Fooooo`;o
00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
5Oooool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool0000E
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`00013ooooo0012ooooo`Go00000oooool2o`0001cooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo0_l0000Hooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0001So
oooo0ol00004ooooo`;o00001?ooool2o`0001Oooooo0ol00002ooooo`Go00000oooool2o`0001Oo
oooo0ol00004ooooo`;o00001?ooool2o`00017ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo000Loooooo?o00004Oooool002;ooooo00Co0000ooooool9jP[o
2NX:0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05Oooool002;ooooo00Go0000ooooooooooooooooo`WZ2P3Qooooo`03o`000?oooooooooo01Go
oooo000Rooooo`03o`000?oooooooooo00;ooooo0_l9jP[Oooooo`03o`000?oooooooooo01Gooooo
000Rooooo`03o`000?oooooooooo00Cooooo0_l9jP[Mooooo`03o`000?oooooooooo01Gooooo000R
ooooo`03o`000?oooooooooo00Kooooo0_l9jP[Kooooo`03o`000?oooooooooo01Gooooo000Roooo
o`03o`000?oooooooooo00Sooooo0_l9jP[Iooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo00[ooooo00?o2NX:ooooooooool0e_ooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`0;ooooo`;o2NX:e_ooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`0=ooooo`;o2NX:e?ooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`0?ooooo`;o2NX:d_ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0
003oooooooooo`0Aooooo`;o2NX:d?ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003o
ooooooooo`0Cooooo`;o2NX:c_ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooo
ooooo`0Eooooo`;o2NX:c?ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooooooo
o`0Gooooo`03o`WZ2_oooooooooo0<Wooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000
ooooooooool06?ooool2o`WZ2/Wooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooo
ooooool06_ooool2o`WZ2/Oooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooooooo
ool07?ooool2o`WZ2/Gooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0
7_ooool2o`WZ2/?ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool08?oo
ool2o`WZ2/7ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool08_ooool0
0ol9jP[oooooooooo`2nooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo
02?ooooo0_l9jPZnooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo02Go
oooo0_l9jPZlooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo02Oooooo
00?o2NX:ooooooooool0^Oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooooooo
o`0Xooooo`;o2NX:^Oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`0Z
ooooo`;o2NX:]oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`0/oooo
o`03o`WZ2_oooooooooo0;Cooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooooooo
ool0;Oooool2o`WZ2[Cooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0
;oooool2o`WZ2[;ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0<Ooo
ool2o`WZ2[3ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0<oooool0
0ol9jP[oooooooooo`2]ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo
03Cooooo0_l9jPZ]ooooo`03o`000?oooooooooo01Gooooo000=ooooo`Go00000oooool2o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo03Kooooo0_l9jPZ[ooooo`03o`000?oooooooooo01Go
oooo000>ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03Sooooo00?o2NX:ooooooooool0Z?ooool0
0ol0003oooooooooo`0Eooooo`003oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0iooooo`;o2NX:Z?oo
ool00ol0003oooooooooo`0Eooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool2o`WZ2ZKooooo
00?o0000ooooooooool05Oooool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0moooo
o`03o`WZ2_oooooooooo0:?ooooo00?o0000ooooooooool05Oooool000gooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0nooooo`;o2NX:Xoooool00ol0003oooooooooo`0Eooooo`003_ooool3
o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`10ooooo`;o2NX:XOooool0
0ol0003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`12ooooo`;o2NX:Woooool00ol0
003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`14ooooo`;o2NX:WOooool00ol0003o
ooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`16ooooo`;o2NX:Voooool00ol0003ooooo
ooooo`0Eooooo`008_ooool00ol0003oooooooooo`18ooooo`03o`WZ2_oooooooooo09Sooooo00?o
0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0BOooool2o`WZ2YSooooo00?o0000
ooooooooool05Oooool002;ooooo00?o0000ooooooooool0Boooool2o`WZ2YKooooo00?o0000oooo
ooooool05Oooool002;ooooo00?o0000ooooooooool0COooool2o`WZ2YCooooo00?o0000oooooooo
ool05Oooool002;ooooo00?o0000ooooooooool0Coooool2o`WZ2Y;ooooo00?o0000ooooooooool0
5Oooool002;ooooo00?o0000ooooooooool0DOooool2o`WZ2Y3ooooo00?o0000ooooooooool05Ooo
ool002;ooooo00?o0000ooooooooool0Doooool00ol9jP[oooooooooo`2=ooooo`03o`000?oooooo
oooo01Gooooo000Rooooo`03o`000?oooooooooo05Cooooo0_l9jPZ=ooooo`03o`000?oooooooooo
01Gooooo000Rooooo`03o`000?oooooooooo05Kooooo0_l9jPZ;ooooo`03o`000?oooooooooo01Go
oooo000Rooooo`03o`000?oooooooooo05Sooooo0_l9jPZ9ooooo`03o`000?oooooooooo01Gooooo
000Rooooo`03o`000?oooooooooo05[ooooo0_l9jPZ7ooooo`03o`000?oooooooooo01Gooooo000R
ooooo`03o`000?oooooooooo05cooooo00?o2NX:ooooooooool0Q?ooool00ol0003oooooooooo`0E
ooooo`008_ooool00ol0003oooooooooo`1Mooooo`;o2NX:Q?ooool00ol0003oooooooooo`0Eoooo
o`008_ooool00ol0003oooooooooo`1Oooooo`;o2NX:P_ooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`1Qooooo`;o2NX:P?ooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`1Sooooo`;o2NX:O_ooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`1Uooooo`03o`WZ2_oooooooooo07_ooooo00?o0000ooooooooool05Oooool0
02;ooooo00?o0000ooooooooool0I_ooool2o`WZ2W_ooooo00?o0000ooooooooool05Oooool002;o
oooo00?o0000ooooooooool0J?ooool2o`WZ2WWooooo00?o0000ooooooooool05Oooool002;ooooo
00?o0000ooooooooool0J_ooool2o`WZ2WOooooo00?o0000ooooooooool05Oooool002;ooooo00?o
0000ooooooooool0K?ooool2o`WZ2WGooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000
ooooooooool0K_ooool00ol9jP[oooooooooo`1booooo`03o`000?oooooooooo01Gooooo000Roooo
o`03o`000?oooooooooo06oooooo0_l9jPYbooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo077ooooo0_l9jPY`ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`00
0?oooooooooo07?ooooo0_l9jPY^ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oo
oooooooo07Gooooo00?o2NX:ooooooooool0Joooool00ol0003oooooooooo`0Eooooo`003oooool3
o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`1fooooo`;o2NX:Joooool0
0ol0003oooooooooo`0Eooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Sooooo0_l9
jPYYooooo`03o`000?oooooooooo01Gooooo000=ooooo`Go00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001kooooo`;o2NX:Ioooool00ol0003ooooo
ooooo`0Eooooo`003Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1looooo`;o2NX:IOooool00ol0
003oooooooooo`0Eooooo`003_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1nooooo`03o`WZ2_oooooo
oooo06;ooooo00?o0000ooooooooool05Oooool000oooooo0_l00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1oooooo`;o2NX:H_oo
ool00ol0003oooooooooo`0Eooooo`004?ooool00ol0003oooooooooo`02ooooo`;o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0POooool2o`WZ2V3ooooo00?o0000ooooooooool05Oooool0
02;ooooo00?o0000ooooooooool0Poooool2o`WZ2Ukooooo00?o0000ooooooooool05Oooool002;o
oooo00?o0000ooooooooool0QOooool00ol9jP[oooooooooo`1Kooooo`03o`000?oooooooooo01Go
oooo000Rooooo`03o`000?oooooooooo08Kooooo0_l9jPYKooooo`03o`000?oooooooooo01Gooooo
000Rooooo`03o`000?oooooooooo08Sooooo0_l9jPYIooooo`03o`000?oooooooooo01Gooooo000R
ooooo`03o`000?oooooooooo08[ooooo0_l9jPYGooooo`03o`000?oooooooooo01Gooooo000Roooo
o`03o`000?oooooooooo08cooooo0_l9jPYEooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo08kooooo00?o2NX:ooooooooool0D_ooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`2?ooooo`;o2NX:D_ooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`2Aooooo`;o2NX:D?ooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`2Cooooo`;o2NX:C_ooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0
003oooooooooo`2Eooooo`03o`WZ2_oooooooooo04_ooooo00?o0000ooooooooool05Oooool002;o
oooo00?o0000ooooooooool0U_ooool2o`WZ2T_ooooo00?o0000ooooooooool05Oooool002;ooooo
00?o0000ooooooooool0V?ooool2o`WZ2TWooooo00?o0000ooooooooool05Oooool002;ooooo00?o
0000ooooooooool0V_ooool00ol9jP[oooooooooo`16ooooo`03o`000?oooooooooo01Gooooo000R
ooooo`03o`000?oooooooooo09_ooooo0_l9jPY6ooooo`03o`000?oooooooooo01Gooooo000Roooo
o`03o`000?oooooooooo09gooooo0_l9jPY4ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo09oooooo00?o2NX:ooooooooool0@Oooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`2Pooooo`;o2NX:@Oooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`2Rooooo`;o2NX:?oooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`2Tooooo`;o2NX:?Oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0
003oooooooooo`2Vooooo`;o2NX:>oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003o
ooooooooo`2Xooooo`;o2NX:>Oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooo
ooooo`2Zooooo`;o2NX:=oooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003ooooooooo
o`2/ooooo`03o`WZ2_oooooooooo03Cooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000
ooooooooool0[Oooool2o`WZ2SCooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooo
ooooool0[oooool2o`WZ2S;ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooooooo
ool0/Oooool2o`WZ2S3ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0
/oooool2o`WZ2Rkooooo00?o0000ooooooooool05Oooool000kooooo0ol00004ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0]Oooool2o`WZ2Rcooooo00?o0000ooooooooool05Ooo
ool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2gooooo`03o`WZ2_oooooooooo02Wo
oooo00?o0000ooooooooool05Oooool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`000;Wooooo0_l9jPXY
ooooo`03o`000?oooooooooo01Gooooo000=ooooo`Co00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0^_ooool2o`WZ2ROooooo00?o
0000ooooooooool05Oooool000gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0_?ooool00ol9jP[ooooo
ooooo`0Tooooo`03o`000?oooooooooo01Gooooo000>ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0;go
oooo0_l9jPXTooooo`03o`000?oooooooooo01Gooooo000?ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo0;oooooo0_l9jPXRooooo`03o`000?oooooooooo01Gooooo
000Rooooo`03o`000?oooooooooo0<7ooooo00?o2NX:ooooooooool07oooool00ol0003ooooooooo
o`0Eooooo`008_ooool00ol0003oooooooooo`32ooooo`;o2NX:7oooool00ol0003oooooooooo`0E
ooooo`008_ooool00ol0003oooooooooo`34ooooo`;o2NX:7Oooool00ol0003oooooooooo`0Eoooo
o`008_ooool00ol0003oooooooooo`36ooooo`;o2NX:6oooool00ol0003oooooooooo`0Eooooo`00
8_ooool00ol0003oooooooooo`38ooooo`;o2NX:6Oooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`3:ooooo`;o2NX:5oooool00ol0003oooooooooo`0Eooooo`008_ooool0
0ol0003oooooooooo`3<ooooo`03o`WZ2_oooooooooo01Cooooo00?o0000ooooooooool05Oooool0
02;ooooo00?o0000ooooooooool0cOooool2o`WZ2QCooooo00?o0000ooooooooool05Oooool002;o
oooo00?o0000ooooooooool0coooool2o`WZ2Q;ooooo00?o0000ooooooooool05Oooool002;ooooo
00?o0000ooooooooool0dOooool2o`WZ2Q3ooooo00?o0000ooooooooool05Oooool002;ooooo00?o
0000ooooooooool0doooool2o`WZ2Pkooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000
ooooooooool0eOooool2o`WZ2Pcooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000oooo
ooooool0eoooool00ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03
o`000?oooooooooo0=Sooooo0_l9jPX9ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`00
0?oooooooooo0=[ooooo0_l9jPX7ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oo
oooooooo0=cooooo0_l9jPX5ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooo
oooo0=kooooo0_l9jPX3ooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo
0>3ooooo00Co2NX:oooooooooooo00005oooool002;ooooo00?o0000ooooooooool0hOooool2o`WZ
2P03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo0>?ooooo00?o0000oooooooo
ool05Oooool002;ooooo00?o0000ooooooooool0hoooool00ol0003oooooooooo`0Eooooo`008_oo
ool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo01Gooooo000Rooooo`03o`000?oooooo
oooo0>?ooooo00?o0000ooooooooool05Oooool002;ooooo00?o0000ooooooooool0hoooool00ol0
003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo01Go
oooo000Rooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool05Oooool002;ooooo00?o
0000ooooooooool0hoooool00ol0003oooooooooo`0Eooooo`008_ooool00ol0003oooooooooo`3k
ooooo`003_ooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`3Qoooo
o`?o00005oooool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3Qooooo`04o`000?oo
ooooooooo`0001Kooooo000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0i?ooool00ol0
003oooooooooo`0Dooooo`003_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`;o0000hoooool2o`0001Oooooo000=ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0hOooool00ol0003oooooooooo`0Gooooo`003Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo0>7ooooo00Co0000oooooooooooo00005_ooool000kooooo0ol00004oooo
o`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0h_ooool3o`0001Kooooo000Rooooo`03
o`000?oooooooooo0?_ooooo000Rooooo`03o`000?oooooooooo0?_ooooo000Rooooo`03o`000?oo
oooooooo0?_ooooo000Rooooo`03o`000?oooooooooo0?_ooooo000Rooooo`03o`000?oooooooooo
0?_ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo002?oooo
o`?o0000S_ooool0093ooooo00?o0000ooooooooool0SOooool006_ooooo1?l00003ooooo`?o0000
0oooool4o`000006ooooool0003oooooo`000?oooooo00002?ooool3o`0000?ooooo0ol00003oooo
o`?o00001?ooool2o`0000Wooooo0ol00002ooooo`Go000000?oooooo`000?l000000ol00002oooo
o`?o0000Hoooool006cooooo00Ko0000oooooooooooo0000ooooool00005ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooool0003oooooo`000008ooooo`04o`000?ooooooooooo`0000;o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00Ko0000oooooooooooo0000ooooool0001Vooooo`00K?ooool01Ol0003oooooooooool0003ooooo
00Go00000_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`00000;ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000>ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooooooool5o`0006;ooooo001/ooooo`?o
00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool02?l0003oooooooooool0
003oooooo`000?oooooo00002Oooool2o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`04o`000?ooooooooooo`0000cooooo0_l00004ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo063ooooo001/ooooo`04o`00
0?ooooooooooo`0000;ooooo0ol00003ooooo`;o00000oooool2o`000003ooooool0003ooooo00So
oooo00?o0000ooooooooool00_ooool4o`0000?ooooo0ol00002ooooo`Co00002Oooool00ol0003o
ooooooooo`02ooooo`?o00000oooool5o`0000;ooooo0ol0001Sooooo`00K?ooool01?l0003ooooo
ooooool0000Jooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool0001dooooo`00Joooool4o`0001cooooo0ol0000>ooooo`03o`000?oooooooooo
00[ooooo0ol00003ooooo`03o`000?oooooooooo06kooooo003oooooob7ooooo003oooooob7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-44.2148, -68.1803, 1.29896, \
5.66655}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"BeamSpotSizeGraphics", "\[Rule]", 
          RowBox[{"(", 
            TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
              False,
              Editable->False], ")"}]}], 
        ",", \(BeamSpotSizeFunction \[Rule] \((Which[#1 < 
                  300, \(4682\ \@\(1 + \(29363540516600761\ \
\((4445083\/54452270 + #1)\)\^2\)\/23357889\)\)\/67756777, #1 \[GreaterEqual] 
                  300, 3\/500\ \@\(1 + \(29363540516600761\ \
\((4445083\/54452270 + #1)\)\^2\)\/23357889\)\ \@\(71421\/\(171357931\ \
\[Pi]\)\)] &)\)\), 
        ",", \(BeamCurvatureFunction \[Rule] \((Which[#1 < 
                  300, \(-\((4445083\/54452270 + #1)\)\)\ \((1 + 
                      23357889\/\(29363540516600761\ \((4445083\/54452270 + \
#1)\)\^2\))\), #1 \[GreaterEqual] 
                  300, \(-\((4445083\/54452270 + #1)\)\)\ \((1 + 
                      23357889\/\(29363540516600761\ \((4445083\/54452270 + \
#1)\)\^2\))\)] &)\)\), 
        ",", \(ComplexBeamParameterFunction \[Rule] \((Which[#1 < 
                  300, \((4445083\/54452270 + \(4833\ \
\[ImaginaryI]\)\/171357931)\) - #1, #1 \[GreaterEqual] 
                  300, \((32675807083\/54452270 + \(4833\ \
\[ImaginaryI]\)\/171357931)\) - #1] &)\)\), 
        ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(PlotDomain \[Rule] {0, 300}\)}], "}"}]], "Output",
  CellLabel->"Out[13]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
ScreenStyleEnvironment->"Brackets",
PrintingStyleEnvironment->"Working",
WindowSize->{1481, 1093},
WindowMargins->{{53, Automatic}, {Automatic, 6}},
CellLabelAutoDelete->False,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3334565137-3359157"->{
    Cell[2792, 98, 175, 3, 21, "Print",
      CellTags->"Info3334565137-3359157"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3334565137-3359157", 1567842, 32238}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 51, 0, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1852, 57, 84, 2, 26, "Input"],
Cell[1939, 61, 85, 1, 21, "Print"],
Cell[2027, 64, 168, 3, 21, "Print"],
Cell[2198, 69, 86, 2, 21, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2333, 77, 58, 0, 36, "SubsectionIcon"],
Cell[2394, 79, 286, 11, 25, "Text"],

Cell[CellGroupData[{
Cell[2705, 94, 84, 2, 26, "Input"],
Cell[2792, 98, 175, 3, 21, "Print",
  CellTags->"Info3334565137-3359157"]
}, Open  ]],
Cell[2982, 104, 93, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[3100, 111, 164, 5, 28, "Input"],
Cell[3267, 118, 751, 24, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4055, 147, 57, 1, 28, "Input"],
Cell[4115, 150, 55983, 1125, 386, 6848, 513, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[60147, 1281, 125, 4, 36, "SubsectionIcon"],
Cell[60275, 1287, 449, 12, 41, "Text"],

Cell[CellGroupData[{
Cell[60749, 1303, 81, 1, 28, "Input"],
Cell[60833, 1306, 111, 1, 39, "Output"]
}, Open  ]],
Cell[60959, 1310, 166, 4, 25, "Text"],

Cell[CellGroupData[{
Cell[61150, 1318, 92, 1, 28, "Input"],
Cell[61245, 1321, 324, 7, 25, "Output"]
}, Open  ]],
Cell[61584, 1331, 348, 10, 25, "Text"],

Cell[CellGroupData[{
Cell[61957, 1345, 157, 5, 28, "Input"],
Cell[62117, 1352, 149, 3, 25, "Output"]
}, Open  ]],
Cell[62281, 1358, 288, 9, 25, "Text"],

Cell[CellGroupData[{
Cell[62594, 1371, 60, 1, 28, "Input"],
Cell[62657, 1374, 322, 7, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63016, 1386, 62, 1, 28, "Input"],
Cell[63081, 1389, 325, 7, 25, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63455, 1402, 125, 4, 36, "SubsectionIcon"],
Cell[63583, 1408, 632, 23, 42, "Text"],

Cell[CellGroupData[{
Cell[64240, 1435, 60, 0, 24, "SubsubsectionIcon"],
Cell[64303, 1437, 208, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[64536, 1446, 36, 0, 28, "Input"],
Cell[64575, 1448, 354, 7, 21, "Print"],

Cell[CellGroupData[{
Cell[64954, 1459, 41098, 1026, 184, 7861, 611, "GraphicsData", "PostScript", \
"Graphics"],
Cell[106055, 2487, 36955, 921, 184, 6927, 546, "GraphicsData", "PostScript", \
"Graphics"],
Cell[143013, 3410, 39090, 1012, 184, 8178, 626, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[182118, 4425, 2498, 54, 73, "Output"]
}, Open  ]],
Cell[184631, 4482, 119, 4, 25, "Text"],

Cell[CellGroupData[{
Cell[184775, 4490, 64, 0, 28, "Input"],
Cell[184842, 4492, 354, 7, 21, "Print"],

Cell[CellGroupData[{
Cell[185221, 4503, 41098, 1026, 184, 7861, 611, "GraphicsData", "PostScript", \
"Graphics"],
Cell[226322, 5531, 36955, 921, 184, 6927, 546, "GraphicsData", "PostScript", \
"Graphics"],
Cell[263280, 6454, 39090, 1012, 184, 8178, 626, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[302385, 7469, 3252, 71, 137, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[305674, 7545, 54, 0, 28, "Input"],
Cell[305731, 7547, 114, 2, 25, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[305894, 7555, 61, 0, 24, "SubsubsectionIcon"],
Cell[305958, 7557, 481, 12, 42, "Text"],

Cell[CellGroupData[{
Cell[306464, 7573, 171, 5, 28, "Input"],
Cell[306638, 7580, 757, 24, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[307432, 7609, 59, 1, 28, "Input"],
Cell[307494, 7612, 85665, 1609, 487, 8460, 651, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[393174, 9224, 162, 4, 25, "Text"],

Cell[CellGroupData[{
Cell[393361, 9232, 53, 0, 28, "Input"],
Cell[393417, 9234, 354, 7, 21, "Print"],

Cell[CellGroupData[{
Cell[393796, 9245, 173362, 3428, 240, 78274, 2250, "GraphicsData", \
"PostScript", "Graphics"],
Cell[567161, 12675, 192513, 3689, 240, 78787, 2280, "GraphicsData", \
"PostScript", "Graphics"],
Cell[759677, 16366, 183161, 3539, 240, 78133, 2238, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[942853, 19908, 6192, 112, 287, "Output"]
}, Open  ]],
Cell[949060, 20023, 211, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[949296, 20033, 75, 0, 28, "Input"],
Cell[949374, 20035, 354, 7, 21, "Print"],

Cell[CellGroupData[{
Cell[949753, 20046, 173361, 3428, 240, 78273, 2250, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1123117, 23476, 192513, 3689, 240, 78787, 2280, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1315633, 27167, 183160, 3539, 240, 78132, 2238, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1498808, 30709, 12573, 206, 1173, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1511430, 30921, 41, 0, 24, "SubsubsectionIcon"],
Cell[1511474, 30923, 323, 8, 25, "Text"],

Cell[CellGroupData[{
Cell[1511822, 30935, 133, 4, 28, "Input"],
Cell[1511958, 30941, 25405, 588, 184, 5936, 342, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1537366, 31531, 2469, 47, 220, "Output"]
}, Open  ]],
Cell[1539850, 31581, 192, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[1540067, 31590, 139, 4, 28, "Input"],
Cell[1540209, 31596, 25405, 588, 184, 5936, 342, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1565617, 32186, 1444, 28, 185, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

